@@ -1,13 +1,13 @@
 #ifndef GRID3_H
 #define GRID3_H
 
-#include "vec.h"
+#include <vec.h>
 
 template<class T>
 struct Grid3
 {
-   Vec<3,T> origin;
-   T dx, over_dx;
+    Vec<3,T> origin;
+    T dx, over_dx;
 };
 
 typedef Grid3<float> Grid3f;
