@@ -30,11 +30,14 @@
 
 #include "libmv-capi.h"
 
+#include "third_party/gflags/gflags/gflags.h"
 #include "glog/logging.h"
 #include "libmv/logging/logging.h"
 
 #include "Math/v3d_optimization.h"
 
+#include "libmv/numeric/numeric.h"
+
 #include "libmv/tracking/esm_region_tracker.h"
 #include "libmv/tracking/brute_region_tracker.h"
 #include "libmv/tracking/hybrid_region_tracker.h"
@@ -43,8 +46,6 @@
 #include "libmv/tracking/lmicklt_region_tracker.h"
 #include "libmv/tracking/pyramid_region_tracker.h"
 
-#include "libmv/tracking/sad.h"
-
 #include "libmv/simple_pipeline/callbacks.h"
 #include "libmv/simple_pipeline/tracks.h"
 #include "libmv/simple_pipeline/initialize_reconstruction.h"
@@ -52,6 +53,7 @@
 #include "libmv/simple_pipeline/detect.h"
 #include "libmv/simple_pipeline/pipeline.h"
 #include "libmv/simple_pipeline/camera_intrinsics.h"
+#include "libmv/simple_pipeline/rigid_registration.h"
 
 #include <stdlib.h>
 #include <assert.h>
@@ -136,12 +138,25 @@ libmv_RegionTracker *libmv_hybridRegionTrackerNew(int max_iterations, int half_w
 	libmv::BruteRegionTracker *brute_region_tracker = new libmv::BruteRegionTracker;
 	brute_region_tracker->half_window_size = half_window_size;
 
+	/* do not use correlation check for brute checker itself,
+	 * this check will happen in esm tracker */
+	brute_region_tracker->minimum_correlation = 0.0;
+
 	libmv::HybridRegionTracker *hybrid_region_tracker =
 		new libmv::HybridRegionTracker(brute_region_tracker, esm_region_tracker);
 
 	return (libmv_RegionTracker *)hybrid_region_tracker;
 }
 
+libmv_RegionTracker *libmv_bruteRegionTrackerNew(int half_window_size, double minimum_correlation)
+{
+	libmv::BruteRegionTracker *brute_region_tracker = new libmv::BruteRegionTracker;
+	brute_region_tracker->half_window_size = half_window_size;
+	brute_region_tracker->minimum_correlation = minimum_correlation;
+
+	return (libmv_RegionTracker *)brute_region_tracker;
+}
+
 static void floatBufToImage(const float *buf, int width, int height, libmv::FloatImage *image)
 {
 	int x, y, a = 0;
@@ -315,33 +330,6 @@ void libmv_regionTrackerDestroy(libmv_RegionTracker *libmv_tracker)
 
 /* ************ Tracks ************ */
 
-void libmv_SADSamplePattern(unsigned char *image, int stride,
-			float warp[3][2], unsigned char *pattern, int pattern_size)
-{
-	libmv::mat32 mat32;
-
-	memcpy(mat32.data, warp, sizeof(float)*3*2);
-
-	libmv::SamplePattern(image, stride, mat32, pattern, pattern_size);
-}
-
-float libmv_SADTrackerTrack(unsigned char *pattern, unsigned char *warped, int pattern_size, unsigned char *image, int stride,
-			int width, int height, float warp[3][2])
-{
-	float result;
-	libmv::mat32 mat32;
-
-	memcpy(mat32.data, warp, sizeof(float)*3*2);
-
-	result = libmv::Track(pattern, warped, pattern_size, image, stride, width, height, &mat32, 16, 16);
-
-	memcpy(warp, mat32.data, sizeof(float)*3*2);
-
-	return result;
-}
-
-/* ************ Tracks ************ */
-
 libmv_Tracks *libmv_tracksNew(void)
 {
 	libmv::Tracks *libmv_tracks = new libmv::Tracks();
@@ -853,3 +841,56 @@ void libmv_InvertIntrinsics(double focal_length, double principal_x, double prin
 		intrinsics.InvertIntrinsics(x, y, x1, y1);
 	}
 }
+
+/* ************ point clouds ************ */
+
+void libmvTransformToMat4(libmv::Mat3 &R, libmv::Vec3 &S, libmv::Vec3 &t, double M[4][4])
+{
+	for (int j = 0; j < 3; ++j)
+		for (int k = 0; k < 3; ++k)
+			M[j][k] = R(k, j) * S(j);
+
+	for (int i = 0; i < 3; ++i) {
+		M[3][0] = t(0);
+		M[3][1] = t(1);
+		M[3][2] = t(2);
+
+		M[0][3] = M[1][3] = M[2][3] = 0;
+	}
+
+	M[3][3] = 1.0;
+}
+
+void libmv_rigidRegistration(float (*reference_points)[3], float (*points)[3], int total_points,
+                             int use_scale, int use_translation, double M[4][4])
+{
+	libmv::Mat3 R;
+	libmv::Vec3 S;
+	libmv::Vec3 t;
+	libmv::vector<libmv::Vec3> reference_points_vector, points_vector;
+
+	for (int i = 0; i < total_points; i++) {
+		reference_points_vector.push_back(libmv::Vec3(reference_points[i][0],
+		                                              reference_points[i][1],
+		                                              reference_points[i][2]));
+
+		points_vector.push_back(libmv::Vec3(points[i][0],
+		                                    points[i][1],
+		                                    points[i][2]));
+	}
+
+	if (use_scale && use_translation) {
+		libmv::RigidRegistration(reference_points_vector, points_vector, R, S, t);
+	}
+	else if (use_translation) {
+		S = libmv::Vec3(1.0, 1.0, 1.0);
+		libmv::RigidRegistration(reference_points_vector, points_vector, R, t);
+	}
+	else {
+		S = libmv::Vec3(1.0, 1.0, 1.0);
+		t = libmv::Vec3::Zero();
+		libmv::RigidRegistration(reference_points_vector, points_vector, R);
+	}
+
+	libmvTransformToMat4(R, S, t, M);
+}
