@@ -27,8 +27,8 @@
  */
 
 
-#ifndef AUD_PYINIT
-#define AUD_PYINIT
+#ifndef __AUD_PYINIT_H__
+#define __AUD_PYINIT_H__
 
 #ifdef WITH_PYTHON
 #include "Python.h"
@@ -48,4 +48,4 @@ extern PyObject* AUD_initPython(void);
 
 #endif
 
-#endif //AUD_PYINIT
+#endif //__AUD_PYINIT_H__
