@@ -27,8 +27,8 @@
  */
 
 
-#ifndef AUD_SILENCEFACTORY
-#define AUD_SILENCEFACTORY
+#ifndef __AUD_SILENCEFACTORY_H__
+#define __AUD_SILENCEFACTORY_H__
 
 #include "AUD_IFactory.h"
 
@@ -51,4 +51,4 @@ public:
 	virtual AUD_Reference<AUD_IReader> createReader();
 };
 
-#endif //AUD_SILENCEFACTORY
+#endif //__AUD_SILENCEFACTORY_H__
