@@ -32,8 +32,8 @@
  */
 
  
-#ifndef BOP_MESH_H
-#define BOP_MESH_H
+#ifndef __BOP_MESH_H__
+#define __BOP_MESH_H__
 
 #include "BOP_Vertex.h"
 #include "BOP_Edge.h"
@@ -100,7 +100,7 @@ public:
 	BOP_Index replaceVertexIndex(BOP_Index oldIndex, BOP_Index newIndex);
 #ifdef HASH
 	void rehashVertex(BOP_Index oldIndex, BOP_Index newIndex,
-		   	BOP_Index otherIndex);
+			BOP_Index otherIndex);
 #endif
 	bool isClosedMesh();
 
