@@ -30,8 +30,8 @@
  */
 
 
-#ifndef CSG_BOOLEANOPS_H
-#define CSG_BOOLEANOPS_H
+#ifndef __CSG_BOOLEANOPS_H__
+#define __CSG_BOOLEANOPS_H__
 
 
 /**
