@@ -36,8 +36,8 @@
  * Simple tagged index class.
  */
 
-#ifndef NAN_INCLUDED_CTR_TaggedIndex_h
-#define NAN_INCLUDED_CTR_TaggedIndex_h
+#ifndef __CTR_TAGGEDINDEX_H__
+#define __CTR_TAGGEDINDEX_H__
 
 /**
  * This class is supposed to be a simple tagged index class. If these
