@@ -35,8 +35,8 @@
  * Copyright (C) 2001 NaN Technologies B.V.
  */
 
-#ifndef NAN_INCLUDED_LOD_ExternBufferEditor_h
-#define NAN_INCLUDED_LOD_ExternBufferEditor_h
+#ifndef __LOD_EXTERNBUFFEREDITOR_H__
+#define __LOD_EXTERNBUFFEREDITOR_H__
 
 #include "LOD_MeshPrimitives.h"
 #include <vector>
