@@ -30,8 +30,8 @@
  */
 
 
-#ifndef NAN_INCLUDED_FaceNormalEditor_h
-#define NAN_INCLUDED_FaceNormalEditor_h
+#ifndef __LOD_FACENORMALEDITOR_H__
+#define __LOD_FACENORMALEDITOR_H__
 
 #include "MEM_NonCopyable.h"
 #include "LOD_ManMesh2.h"
@@ -128,7 +128,7 @@ private :
 		MT_Vector3 
 	ComputeNormal(
 		const LOD_TriFace &face
-	) const ;
+	) const;
 
 	const 
 		MT_Vector3
