@@ -30,8 +30,8 @@
  */
 
 
-#ifndef NAN_INCLUDED_MeshBounds_h
-#define NAN_INCLUDED_MeshBounds_h
+#ifndef __LOD_MESHBOUNDS_H__
+#define __LOD_MESHBOUNDS_H__
 
 #include "MEM_SmartPtr.h"
 #include "LOD_MeshPrimitives.h"
