@@ -25,8 +25,8 @@
  * ***** END GPL LICENSE BLOCK *****
  */
 
-#ifndef NAN_INCLUDED_GlutMouseManager_h
-#define NAN_INCLUDED_GlutMouseManager_h
+#ifndef __GLUTMOUSEMANAGER_H__
+#define __GLUTMOUSEMANAGER_H__
 
 #include "MEM_NonCopyable.h"
 #include "MEM_SmartPtr.h"
