@@ -30,6 +30,7 @@
 #define GRID_DIMENSION 20
 
 #if defined(_WIN32) && !defined(__MINGW32__)
+#define isnan(n) _isnan(n)
 #define LONG __int64
 #else
 #include <stdint.h>
@@ -787,17 +788,17 @@ public:
 		LONG proj0 = cubeProj[i][0] ;
 		LONG proj1 = cubeProj[i][0] + cubeProj[i][edgeInd + 1] ;
 		LONG proj2 = inherit->trigProj[i][1] ;
+		LONG d = proj1 - proj0;
+		double alpha;
 
-		// double alpha = (double)( ( proj2 - proj0 ) * cubeProj[edgeInd][edgeInd + 1] ) / (double)( proj1 - proj0 ) ;
-		double alpha = (double)( ( proj2 - proj0 ) ) / (double)( proj1 - proj0 ) ;
-		
-		if ( alpha < 0 )
-		{
-			alpha = 0.5 ;
+		if (d == 0) {
+			alpha = 0.5;
 		}
-		else if ( alpha > 1 )
-		{
-			alpha = 0.5 ;
+		else {
+			alpha = (double)((proj2 - proj0)) / (double)d;
+
+			if (alpha < 0 || alpha > 1)
+				alpha = 0.5;
 		}
 		
 
