@@ -865,3 +865,9 @@ int GHOST_toggleConsole(int action)
 	GHOST_ISystem* system = GHOST_ISystem::getSystem();
 	return system->toggleConsole(action);
 }
+
+
+int GHOST_confirmQuit(GHOST_WindowHandle windowhandle){
+	GHOST_ISystem* system = GHOST_ISystem::getSystem();
+	return system->confirmQuit((GHOST_IWindow*) windowhandle);
+}
