@@ -21,8 +21,8 @@
  * ***** END GPL LICENSE BLOCK *****
  */
 
-#ifndef _GHOST_NDOFMANAGERCOCOA_H_
-#define _GHOST_NDOFMANAGERCOCOA_H_
+#ifndef __GHOST_NDOFMANAGERCOCOA_H__
+#define __GHOST_NDOFMANAGERCOCOA_H__
 
 #ifdef WITH_INPUT_NDOF
 
