@@ -76,6 +76,17 @@ GHOST_SystemSDL::createWindow(const STR_String& title,
 	window= new GHOST_WindowSDL (this, title, left, top, width, height, state, parentWindow, type, stereoVisual, 1);
 
 	if (window) {
+		if (GHOST_kWindowStateFullScreen == state) {
+			SDL_Window *sdl_win = window->getSDLWindow();
+			SDL_DisplayMode mode;
+
+			static_cast<GHOST_DisplayManagerSDL *> (m_displayManager)->getCurrentDisplayModeSDL(mode);
+
+			SDL_SetWindowDisplayMode(sdl_win, &mode);
+			SDL_ShowWindow(sdl_win);
+			SDL_SetWindowFullscreen(sdl_win, SDL_TRUE);
+		}
+
 		if (window->getValid()) {
 			m_windowManager->addWindow(window);
 			pushEvent(new GHOST_Event(getMilliSeconds(), GHOST_kEventWindowSize, window));
@@ -481,8 +492,8 @@ GHOST_SystemSDL::setCursorPosition(GHOST_TInt32 x,
 bool
 GHOST_SystemSDL::generateWindowExposeEvents()
 {
-	vector<GHOST_WindowSDL *>::iterator w_start= m_dirty_windows.begin();
-	vector<GHOST_WindowSDL *>::const_iterator w_end= m_dirty_windows.end();
+	std::vector<GHOST_WindowSDL *>::iterator w_start= m_dirty_windows.begin();
+	std::vector<GHOST_WindowSDL *>::const_iterator w_end= m_dirty_windows.end();
 	bool anyProcessed= false;
 
 	for (;w_start != w_end; ++w_start) {
@@ -563,10 +574,10 @@ GHOST_SystemSDL::findGhostWindow(SDL_Window *sdl_win)
 	// We should always check the window manager's list of windows
 	// and only process events on these windows.
 
-	vector<GHOST_IWindow *> & win_vec= m_windowManager->getWindows();
+	std::vector<GHOST_IWindow *> & win_vec= m_windowManager->getWindows();
 
-	vector<GHOST_IWindow *>::iterator win_it= win_vec.begin();
-	vector<GHOST_IWindow *>::const_iterator win_end= win_vec.end();
+	std::vector<GHOST_IWindow *>::iterator win_it= win_vec.begin();
+	std::vector<GHOST_IWindow *>::const_iterator win_end= win_vec.end();
 
 	for (; win_it != win_end; ++win_it) {
 		GHOST_WindowSDL * window= static_cast<GHOST_WindowSDL *>(*win_it);
