@@ -30,8 +30,8 @@
  * Declaration of GHOST_WindowWin32 class.
  */
 
-#ifndef _GHOST_WINDOW_WIN32_H_
-#define _GHOST_WINDOW_WIN32_H_
+#ifndef __GHOST_WINDOWWIN32_H__
+#define __GHOST_WINDOWWIN32_H__
 
 #ifndef WIN32
 #error WIN32 only!
@@ -236,7 +236,7 @@ public:
 	 * Returns the name of the window class.
 	 * @return The name of the window class.
 	 */
-	static LPCSTR getWindowClassName() { return s_windowClassName; }
+	static wchar_t* getWindowClassName() { return s_windowClassName; }
 
 	/**
 	 * Register a mouse click event (should be called 
@@ -351,7 +351,7 @@ protected:
 	/** ITaskbarList3 structure for progress bar*/
 	ITaskbarList3 * m_Bar;
 
-	static LPCSTR s_windowClassName;
+	static wchar_t* s_windowClassName;
 	static const int s_maxTitleLength;
 
 	/** WinTab dll handle */
@@ -390,4 +390,4 @@ protected:
 	GHOST_TEmbedderWindowID m_parentWindowHwnd;
 };
 
-#endif // _GHOST_WINDOW_WIN32_H_
+#endif // __GHOST_WINDOWWIN32_H__
