@@ -1,14 +1,10 @@
 /**
- * $Id: GHOST_Test.cpp,v 1.6 2003/01/27 21:35:26 maarten Exp $
- * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
+ * ***** BEGIN GPL LICENSE BLOCK *****
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version. The Blender
- * Foundation also sells licenses for use in proprietary software under
- * the Blender License.  See http://www.blender.org/BL/ for information
- * about this.
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
@@ -26,12 +22,11 @@
  *
  * Contributor(s): none yet.
  *
- * ***** END GPL/BL DUAL LICENSE BLOCK *****
+ * ***** END GPL LICENSE BLOCK *****
  */
 
 /**
 
- * $Id: GHOST_Test.cpp,v 1.6 2003/01/27 21:35:26 maarten Exp $
  * Copyright (C) 2001 NaN Technologies B.V.
  * Simple test file for the GHOST library.
  * The OpenGL gear code is taken from the Qt sample code which,
@@ -44,10 +39,6 @@
 #include <iostream>
 #include <math.h>
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #if defined(WIN32) || defined(__APPLE__)
 	#ifdef WIN32
 		#include <windows.h>
@@ -435,7 +426,7 @@ Application::Application(GHOST_ISystem* system)
 	// Create the main window
 	STR_String title1 ("gears - main window");
 	m_mainWindow = system->createWindow(title1, 10, 64, 320, 200, GHOST_kWindowStateNormal,
-		GHOST_kDrawingContextTypeOpenGL, true /* stereo flag */);
+		GHOST_kDrawingContextTypeOpenGL, false, false);
 
     if (!m_mainWindow) {
 		std::cout << "could not create main window\n";
@@ -445,7 +436,7 @@ Application::Application(GHOST_ISystem* system)
 	// Create a secondary window
 	STR_String title2 ("gears - secondary window");
 	m_secondaryWindow = system->createWindow(title2, 340, 64, 320, 200, GHOST_kWindowStateNormal,
-		GHOST_kDrawingContextTypeOpenGL, false /* stereo flag */);
+		GHOST_kDrawingContextTypeOpenGL, false, false);
 	if (!m_secondaryWindow) {
 		cout << "could not create secondary window\n";
 		exit(-1);
@@ -698,7 +689,7 @@ int main(int /*argc*/, char** /*argv*/)
 		//DWORD keyValue;
 //		lresult = regkey.Open(HKEY_LOCAL_MACHINE, "SOFTWARE\\NVIDIA Corporation\\Global\\Stereo3D\\StereoEnable");
 		lresult = regkey.Open(HKEY_LOCAL_MACHINE, "SOFTWARE\\NVIDIA Corporation\\Global\\Stereo3D\\StereoEnable",
-			 KEY_ALL_ACCESS );
+		                      KEY_ALL_ACCESS);
 
 		if(lresult == ERROR_SUCCESS)
 			printf("Succesfully opened key\n");
