@@ -1,14 +1,10 @@
 /**
- * $Id: MultiTest.c,v 1.4 2003/01/24 06:00:38 sirdude Exp $
- * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
+ * ***** BEGIN GPL LICENSE BLOCK *****
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version. The Blender
- * Foundation also sells licenses for use in proprietary software under
- * the Blender License.  See http://www.blender.org/BL/ for information
- * about this.
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
@@ -26,7 +22,7 @@
  *
  * Contributor(s): none yet.
  *
- * ***** END GPL/BL DUAL LICENSE BLOCK *****
+ * ***** END GPL LICENSE BLOCK *****
  */
 #define FALSE 0
 
@@ -42,14 +38,20 @@
 
 #include "GL.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "MEM_guardedalloc.h"
 
 #include "GHOST_C-api.h"
-#include "BMF_Api.h"
+
+#ifdef USE_BMF
+#  include "BMF_Api.h"
+#else
+#  include "BLF_api.h"
+   extern int datatoc_bfont_ttf_size;
+   extern char datatoc_bfont_ttf[];
+
+   /* cheat */
+   char U[1024]= {0};
+#endif
 
 #include "Util.h"
 #include "Basic.h"
@@ -298,7 +300,7 @@ MainWindow *mainwindow_new(MultiTestApp *app) {
 	
 	win= GHOST_CreateWindow(sys, "MultiTest:Main", 40, 40, 400, 400, 
 		GHOST_kWindowStateNormal, GHOST_kDrawingContextTypeOpenGL, 
-		FALSE);
+		FALSE, FALSE);
 	
 	if (win) {
 		MainWindow *mw= MEM_callocN(sizeof(*mw), "mainwindow_new");
@@ -331,8 +333,12 @@ struct _LoggerWindow {
 	MultiTestApp		*app;
 
 	GHOST_WindowHandle	win;
-	
+
+#ifdef USE_BMF	
 	BMF_Font	*font;
+#else
+	int			font;
+#endif
 	int			fonttexid;
 	int			fontheight;
 	
@@ -436,18 +442,26 @@ static void loggerwindow_do_draw(LoggerWindow *lw) {
 		char *line= lw->loglines[(lw->nloglines-1)-(i+startline)];
 		int x_pos= lw->textarea[0][0] + 4;
 		int y_pos= lw->textarea[0][1] + 4 + i*lw->fontheight;
-		
+
+#ifdef USE_BMF		
 		if (lw->fonttexid==-1) {
 			glRasterPos2i(x_pos, y_pos);
 			BMF_DrawString(lw->font, line);
 		} else {
 			BMF_DrawStringTexture(lw->font, line, x_pos, y_pos, 0.0);
 		}
+#else
+		BLF_position(lw->font, x_pos, y_pos, 0.0);
+		BLF_draw(lw->font, line, 256); // XXX
+#endif
 	}
+
+#ifdef USE_BMF
 	if (lw->fonttexid!=-1) {
 		glDisable(GL_TEXTURE_2D);		
 		glDisable(GL_BLEND);
 	}
+#endif
 
 	GHOST_SwapWindowBuffers(lw->win);
 }
@@ -538,19 +552,25 @@ LoggerWindow *loggerwindow_new(MultiTestApp *app) {
 	GHOST_GetMainDisplayDimensions(sys, &screensize[0], &screensize[1]);
 	win= GHOST_CreateWindow(sys, "MultiTest:Logger", 40, screensize[1]-432,
 		800, 300, GHOST_kWindowStateNormal, 
-		GHOST_kDrawingContextTypeOpenGL, FALSE);
+		GHOST_kDrawingContextTypeOpenGL, FALSE, FALSE);
 	
 	if (win) {
 		LoggerWindow *lw= MEM_callocN(sizeof(*lw), "loggerwindow_new");
 		int bbox[2][2];
 		lw->app= app;
 		lw->win= win;
-		
+
+#ifdef USE_BMF
 		lw->font= BMF_GetFont(BMF_kScreen12);
 		lw->fonttexid= BMF_GetFontTexture(lw->font);
 
 		BMF_GetBoundingBox(lw->font, &bbox[0][0], &bbox[0][1], &bbox[1][0], &bbox[1][1]);
 		lw->fontheight= rect_height(bbox);
+#else
+		lw->font= BLF_load_mem("default", (unsigned char*)datatoc_bfont_ttf, datatoc_bfont_ttf_size);
+		BLF_size(lw->font, 11, 72);
+		lw->fontheight= BLF_height(lw->font, "A_");
+#endif
 		
 		lw->nloglines= lw->logsize= 0;
 		lw->loglines= MEM_mallocN(sizeof(*lw->loglines)*lw->nloglines, "loglines");
@@ -718,7 +738,7 @@ ExtraWindow *extrawindow_new(MultiTestApp *app) {
 	
 	win= GHOST_CreateWindow(sys, "MultiTest:Extra", 500, 40, 400, 400, 
 		GHOST_kWindowStateNormal, GHOST_kDrawingContextTypeOpenGL,
-		FALSE);
+		FALSE, FALSE);
 	
 	if (win) {
 		ExtraWindow *ew= MEM_callocN(sizeof(*ew), "mainwindow_new");
@@ -793,7 +813,7 @@ static int multitest_event_handler(GHOST_EventHandle evt, GHOST_TUserDataPtr dat
 MultiTestApp *multitestapp_new(void) {
 	MultiTestApp *app= MEM_mallocN(sizeof(*app), "multitestapp_new");
 	GHOST_EventConsumerHandle consumer= GHOST_CreateEventConsumer(multitest_event_handler, app);
-	
+
 	app->sys= GHOST_CreateSystem();
 	if (!app->sys)
 		fatal("Unable to create ghost system");
@@ -857,6 +877,10 @@ void multitestapp_free(MultiTestApp *app) {
 	/***/
 	
 int main(int argc, char **argv) {
+#ifndef USE_BMF
+	BLF_init(11, 72);
+#endif
+
 	MultiTestApp *app= multitestapp_new();
 	
 	multitestapp_run(app);
