@@ -1,5 +1,4 @@
 /**
- * $Id: cmat.h,v 1.5 2003/05/01 19:52:30 sirdude Exp $
  */
 
 /*
@@ -39,7 +38,6 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <iostream>
-#include <strstream>
 #ifdef TNT_USE_REGIONS
 #include "region2d.h"
 #endif
@@ -204,19 +202,7 @@ class Matrix
         copy(v);
     }
 
-    Matrix(Subscript M, Subscript N, const char *s)
-    {
-        initialize(M,N);
-        std::istrstream ins(s);
 
-        Subscript i, j;
-
-        for (i=0; i<M; i++)
-            for (j=0; j<N; j++)
-                ins >> row_[i][j];
-    }
-
-		
     // destructor
     //
     ~Matrix()
@@ -590,7 +576,7 @@ inline void matmultdiag(
     for (Subscript i=0; i<M; i++) {
 		for (Subscript k=0; k<K; k++)
 		{
-			C[i][k] = A[i,k] * diag[k];		
+			C[i][k] = A[i][k] * diag[k];		
 		}
 	}
 }
