@@ -24,8 +24,8 @@
  *
  * ***** END GPL LICENSE BLOCK *****
  */
-#ifndef BKE_GLOBAL_H
-#define BKE_GLOBAL_H
+#ifndef __BKE_GLOBAL_H__
+#define __BKE_GLOBAL_H__
 
 /** \file BKE_global.h
  *  \ingroup bke
@@ -69,6 +69,7 @@ typedef struct Global {
 
 	short rt;
 	int f;
+	int debug;
 
 	/* Used for BMesh transformations */
 	struct BME_Glob *editBMesh;
@@ -104,7 +105,6 @@ typedef struct Global {
 
 /* #define G_FACESELECT	(1 <<  8) use (mesh->editflag & ME_EDIT_PAINT_MASK) */
 
-#define G_DEBUG			(1 << 12)
 #define G_SCRIPT_AUTOEXEC (1 << 13)
 #define G_SCRIPT_OVERRIDE_PREF (1 << 14) /* when this flag is set ignore the userprefs */
 
@@ -113,6 +113,18 @@ typedef struct Global {
 
 /* #define G_AUTOMATKEYS	(1 << 30)   also removed */
 
+/* G.debug */
+enum {
+	G_DEBUG =           (1 << 0), /* general debug flag, print more info in unexpected cases */
+	G_DEBUG_FFMPEG =    (1 << 1),
+	G_DEBUG_PYTHON =    (1 << 2), /* extra python info */
+	G_DEBUG_EVENTS =    (1 << 3), /* input/window/screen events */
+	G_DEBUG_WM =        (1 << 4)  /* operator, undo */
+};
+
+#define G_DEBUG_ALL  (G_DEBUG | G_DEBUG_FFMPEG | G_DEBUG_PYTHON | G_DEBUG_EVENTS | G_DEBUG_WM)
+
+
 /* G.fileflags */
 
 #define G_AUTOPACK               (1 << 0)
@@ -154,6 +166,11 @@ typedef struct Global {
 #  error Either __BIG_ENDIAN__ or __LITTLE_ENDIAN__ must be defined.
 #endif
 
+/* there is really no good place for this */
+#if defined(FREE_WINDOWS) && ((__GNUC__ < 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ < 6)))
+#  error "Mingw requires GCC 4.6 minimum"
+#endif
+
 #define L_ENDIAN	1
 #define B_ENDIAN	0
 
