@@ -23,8 +23,8 @@
  * ***** END GPL LICENSE BLOCK *****
  */
 
-#ifndef BKE_SEQUENCER_H
-#define BKE_SEQUENCER_H
+#ifndef __BKE_SEQUENCER_H__
+#define __BKE_SEQUENCER_H__
 
 /** \file BKE_sequencer.h
  *  \ingroup bke
@@ -40,6 +40,8 @@ struct Strip;
 struct StripElem;
 struct bSound;
 
+struct SeqIndexBuildContext;
+
 #define BUILD_SEQAR_COUNT_NOTHING  0
 #define BUILD_SEQAR_COUNT_CURRENT  1
 #define BUILD_SEQAR_COUNT_CHILDREN 2
@@ -67,14 +69,14 @@ void seq_array(struct Editing *ed, struct Sequence ***seqarray, int *tot, int us
 #define SEQP_BEGIN(ed, _seq)                                                  \
 {                                                                             \
 	SeqIterator iter;                                                         \
-		for(seq_begin(ed, &iter, 1); iter.valid; seq_next(&iter)) {           \
-			_seq= iter.seq;
+		for (seq_begin(ed, &iter, 1); iter.valid; seq_next(&iter)) {          \
+			_seq = iter.seq;
 			
 #define SEQ_BEGIN(ed, _seq)                                                   \
 	{                                                                         \
 		SeqIterator iter;                                                     \
-		for(seq_begin(ed, &iter, 0); iter.valid; seq_next(&iter)) {           \
-			_seq= iter.seq;
+		for (seq_begin(ed, &iter, 0); iter.valid; seq_next(&iter)) {          \
+			_seq = iter.seq;
 
 #define SEQ_END                                                               \
 		}                                                                     \
@@ -99,8 +101,14 @@ int seq_cmp_render_data(const SeqRenderData * a, const SeqRenderData * b);
 unsigned int seq_hash_render_data(const SeqRenderData * a);
 
 /* Wipe effect */
-enum {DO_SINGLE_WIPE, DO_DOUBLE_WIPE, DO_BOX_WIPE, DO_CROSS_WIPE,
-	DO_IRIS_WIPE,DO_CLOCK_WIPE};
+enum {
+	DO_SINGLE_WIPE,
+	DO_DOUBLE_WIPE,
+	DO_BOX_WIPE,
+	DO_CROSS_WIPE,
+	DO_IRIS_WIPE,
+	DO_CLOCK_WIPE
+};
 
 
 struct SeqEffectHandle {
@@ -110,11 +118,11 @@ struct SeqEffectHandle {
 	void (*init_plugin)(struct Sequence *seq, const char *fname);
 	
 	/* number of input strips needed 
-		(called directly after construction) */
+	 * (called directly after construction) */
 	int (*num_inputs)(void);
 	
 	/* load is called first time after readblenfile in
-		get_sequence_effect automatically */
+	 * get_sequence_effect automatically */
 	void (*load)(struct Sequence *seq);
 	
 	/* duplicate */
@@ -124,23 +132,21 @@ struct SeqEffectHandle {
 	void (*free)(struct Sequence *seq);
 	
 	/* returns: -1: no input needed,
-	0: no early out, 
-	1: out = ibuf1, 
-	2: out = ibuf2 */
+	 * 0: no early out,
+	 * 1: out = ibuf1,
+	 * 2: out = ibuf2 */
 	int (*early_out)(struct Sequence *seq, float facf0, float facf1); 
 	
 	/* stores the y-range of the effect IPO */
-	void (*store_icu_yrange)(struct Sequence * seq,
-                                 short adrcode, float *ymin, float *ymax);
+	void (*store_icu_yrange)(struct Sequence * seq, short adrcode, float *ymin, float *ymax);
 	
 	/* stores the default facf0 and facf1 if no IPO is present */
-	void (*get_default_fac)(struct Sequence *seq, float cfra,
-                                float * facf0, float * facf1);
+	void (*get_default_fac)(struct Sequence *seq, float cfra, float * facf0, float * facf1);
 	
 	/* execute the effect
-           sequence effects are only required to either support
-           float-rects or byte-rects 
-           (mixed cases are handled one layer up...) */
+	 * sequence effects are only required to either support
+	 * float-rects or byte-rects
+	 * (mixed cases are handled one layer up...) */
 	
 	struct ImBuf* (*execute)(
 		SeqRenderData context,
@@ -153,10 +159,10 @@ struct SeqEffectHandle {
 /* ********************* prototypes *************** */
 
 /* **********************************************************************
-   * sequence.c
-
-   * sequencer render functions
-   ********************************************************************** */
+ * sequence.c
+ *
+ * sequencer render functions
+ * ********************************************************************** */
 
 struct ImBuf *give_ibuf_seq(SeqRenderData context, float cfra, int chanshown);
 struct ImBuf *give_ibuf_seq_threaded(SeqRenderData context, float cfra, int chanshown);
@@ -168,7 +174,7 @@ void give_ibuf_prefetch_request(SeqRenderData context, float cfra, int chan_show
 int seqbase_recursive_apply(struct ListBase *seqbase, int (*apply_func)(struct Sequence *seq, void *), void *arg);
 int seq_recursive_apply(struct Sequence *seq, int (*apply_func)(struct Sequence *, void *), void *arg);
 
-/* maintainance functions, mostly for RNA */
+/* maintenance functions, mostly for RNA */
 // extern 
 void seq_free_sequence(struct Scene *scene, struct Sequence *seq);
 void seq_free_sequence_recurse(struct Scene *scene, struct Sequence *seq);
@@ -179,7 +185,6 @@ struct Editing *seq_give_editing(struct Scene *scene, int alloc);
 const char *give_seqname(struct Sequence *seq);
 void calc_sequence(struct Scene *scene, struct Sequence *seq);
 void calc_sequence_disp(struct Scene *scene, struct Sequence *seq);
-void new_tstripdata(struct Sequence *seq);
 void reload_sequence_new_file(struct Scene *scene, struct Sequence * seq, int lock_range);
 void sort_seq(struct Scene *scene);
 void build_seqar_cb(struct ListBase *seqbase, struct Sequence  ***seqar, int *totseq,
@@ -194,16 +199,17 @@ void update_changed_seq_and_deps(struct Scene *scene, struct Sequence *changed_s
 int input_have_to_preprocess(
 	SeqRenderData context, struct Sequence * seq, float cfra);
 
-void seq_proxy_rebuild(struct Main * bmain, 
-                       struct Scene *scene, struct Sequence * seq,
+struct SeqIndexBuildContext *seq_proxy_rebuild_context(struct Main *bmain, struct Scene *scene, struct Sequence *seq);
+void seq_proxy_rebuild(struct SeqIndexBuildContext *context,
                        short *stop, short *do_update, float *progress);
+void seq_proxy_rebuild_finish(struct SeqIndexBuildContext *context, short stop);
 
 
 /* **********************************************************************
-   seqcache.c
-
-   Sequencer memory cache management functions
-   ********************************************************************** */
+ * seqcache.c
+ *
+ * Sequencer memory cache management functions
+ * ********************************************************************** */
 
 typedef enum {
 	SEQ_STRIPELEM_IBUF,
@@ -221,20 +227,20 @@ struct ImBuf * seq_stripelem_cache_get(
 	float cfra, seq_stripelem_ibuf_t type);
 
 /* passed ImBuf is properly refed, so ownership is *not* 
-   transfered to the cache.
-   you can pass the same ImBuf multiple times to the cache without problems.
-*/
+ * transfered to the cache.
+ * you can pass the same ImBuf multiple times to the cache without problems.
+ */
    
 void seq_stripelem_cache_put(
 	SeqRenderData context, struct Sequence * seq, 
 	float cfra, seq_stripelem_ibuf_t type, struct ImBuf * nval);
 
 /* **********************************************************************
-   seqeffects.c 
-
-   Sequencer effect strip managment functions
-   **********************************************************************
-*/
+ * seqeffects.c
+ *
+ * Sequencer effect strip managment functions
+ *  **********************************************************************
+ */
 
 /* intern */
 struct SeqEffectHandle get_sequence_blend(struct Sequence *seq);
@@ -246,9 +252,9 @@ int get_sequence_effect_num_inputs(int seq_type);
 
 
 /* **********************************************************************
-   Sequencer editing functions
-   **********************************************************************
-*/
+ * Sequencer editing functions
+ * **********************************************************************
+ */
    
 /* for transform but also could use elsewhere */
 int seq_tx_get_start(struct Sequence *seq);
@@ -283,7 +289,6 @@ void seq_update_sound_bounds_all(struct Scene *scene);
 void seq_update_sound_bounds(struct Scene* scene, struct Sequence *seq);
 void seq_update_muting(struct Editing *ed);
 void seq_update_sound(struct Scene *scene, struct bSound *sound);
-void seqbase_sound_reload(struct Scene *scene, ListBase *seqbase);
 void seqbase_unique_name_recursive(ListBase *seqbasep, struct Sequence *seq);
 void seqbase_dupli_recursive(struct Scene *scene, struct Scene *scene_to, ListBase *nseqbase, ListBase *seqbase, int dupe_flag);
 
@@ -334,11 +339,11 @@ struct Sequence *sequencer_add_sound_strip(struct bContext *C, ListBase *seqbase
 struct Sequence *sequencer_add_movie_strip(struct bContext *C, ListBase *seqbasep, struct SeqLoadInfo *seq_load);
 
 /* view3d draw callback, run when not in background view */
-typedef struct ImBuf *(*SequencerDrawView)(struct Scene *, struct Object *, int, int, unsigned int, int, char[256]);
+typedef struct ImBuf *(*SequencerDrawView)(struct Scene *, struct Object *, int, int, unsigned int, int, int, char[256]);
 extern SequencerDrawView sequencer_view3d_cb;
 
 /* copy/paste */
 extern ListBase seqbase_clipboard;
 extern int seqbase_clipboard_frame;
 
-#endif // BKE_SEQUENCER_H
+#endif // __BKE_SEQUENCER_H__
