@@ -36,12 +36,11 @@
 
 #include "DNA_meshdata_types.h"
 
-#include "BLI_editVert.h"
 #include "BLI_utildefines.h"
 #include "BLI_linklist.h"
 
 #include "BKE_DerivedMesh.h"
-
+#include "BKE_tessmesh.h"
 
 #include "BLI_math.h"
 #include "MEM_guardedalloc.h"
@@ -52,7 +51,7 @@ float bvhtree_ray_tri_intersection(const BVHTreeRay *ray, const float UNUSED(m_d
 {
 	float dist;
 
-	if(isect_ray_tri_epsilon_v3(ray->origin, ray->direction, v0, v1, v2, &dist, NULL, FLT_EPSILON))
+	if (isect_ray_tri_epsilon_v3(ray->origin, ray->direction, v0, v1, v2, &dist, NULL, FLT_EPSILON))
 		return dist;
 
 	return FLT_MAX;
@@ -68,8 +67,7 @@ static float sphereray_tri_intersection(const BVHTreeRay *ray, float radius, con
 	normal_tri_v3(plane_normal, v0, v1, v2);
 
 	madd_v3_v3v3fl(p1, ray->origin, ray->direction, m_dist);
-	if(isect_sweeping_sphere_tri_v3(ray->origin, p1, radius, v0, v1, v2, &idist, hit_point))
-	{
+	if (isect_sweeping_sphere_tri_v3(ray->origin, p1, radius, v0, v1, v2, &idist, hit_point)) {
 		return idist * m_dist;
 	}
 
@@ -112,24 +110,18 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 	S = A01 * B1 - A11 * B0;
 	T = A01 * B0 - A00 * B1;
 
-	if ( S + T <= Det )
-	{
-		if ( S < 0.0f )
-		{
-			if ( T < 0.0f )  // Region 4
-			{
-				if ( B0 < 0.0f )
-				{
+	if (S + T <= Det) {
+		if (S < 0.0f) {
+			if (T < 0.0f) { /* Region 4 */
+				if (B0 < 0.0f) {
 					T = 0.0f;
-					if ( -B0 >= A00 )
-					{
+					if (-B0 >= A00) {
 						S = 1.0f;
 						sqrDist = A00 + 2.0f * B0 + C;
 						lv = 1;
 					}
-					else
-					{
-						if(fabsf(A00) > FLT_EPSILON)
+					else {
+						if (fabsf(A00) > FLT_EPSILON)
 							S = -B0/A00;
 						else
 							S = 0.0f;
@@ -137,24 +129,20 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 						le = 0;
 					}
 				}
-				else
-				{
+				else {
 					S = 0.0f;
-					if ( B1 >= 0.0f )
-					{
+					if (B1 >= 0.0f) {
 						T = 0.0f;
 						sqrDist = C;
 						lv = 0;
 					}
-					else if ( -B1 >= A11 )
-					{
+					else if (-B1 >= A11) {
 						T = 1.0f;
 						sqrDist = A11 + 2.0f * B1 + C;
 						lv = 2;
 					}
-					else
-					{
-						if(fabsf(A11) > FLT_EPSILON)
+					else {
+						if (fabsf(A11) > FLT_EPSILON)
 							T = -B1 / A11;
 						else
 							T = 0.0f;
@@ -163,24 +151,20 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 					}
 				}
 			}
-			else  // Region 3
-			{
+			else { /* Region 3 */
 				S = 0.0f;
-				if ( B1 >= 0.0f )
-				{
+				if (B1 >= 0.0f) {
 					T = 0.0f;
 					sqrDist = C;
 					lv = 0;
 				}
-				else if ( -B1 >= A11 )
-				{
+				else if (-B1 >= A11) {
 					T = 1.0f;
 					sqrDist = A11 + 2.0f * B1 + C;
 					lv = 2;
 				}
-				else
-				{
-					if(fabsf(A11) > FLT_EPSILON)
+				else {
+					if (fabsf(A11) > FLT_EPSILON)
 						T = -B1 / A11;
 					else
 						T = 0.0;
@@ -189,24 +173,20 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 				}
 			}
 		}
-		else if ( T < 0.0f )  // Region 5
-		{
+		else if (T < 0.0f) { /* Region 5 */
 			T = 0.0f;
-			if ( B0 >= 0.0f )
-			{
+			if (B0 >= 0.0f) {
 				S = 0.0f;
 				sqrDist = C;
 				lv = 0;
 			}
-			else if ( -B0 >= A00 )
-			{
+			else if (-B0 >= A00) {
 				S = 1.0f;
 				sqrDist = A00 + 2.0f * B0 + C;
 				lv = 1;
 			}
-			else
-			{
-				if(fabsf(A00) > FLT_EPSILON)
+			else {
+				if (fabsf(A00) > FLT_EPSILON)
 					S = -B0 / A00;
 				else
 					S = 0.0f;
@@ -214,69 +194,59 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 				le = 0;
 			}
 		}
-		else  // Region 0
-		{
+		else { /* Region 0 */
 			// Minimum at interior lv
 			float invDet;
-			if(fabsf(Det) > FLT_EPSILON)
+			if (fabsf(Det) > FLT_EPSILON)
 				invDet = 1.0f / Det;
 			else
 				invDet = 0.0f;
 			S *= invDet;
 			T *= invDet;
 			sqrDist = S * ( A00 * S + A01 * T + 2.0f * B0) +
-					T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
+			          T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
 		}
 	}
-	else
-	{
+	else {
 		float tmp0, tmp1, numer, denom;
 
-		if ( S < 0.0f )  // Region 2
-		{
+		if (S < 0.0f) { /* Region 2 */
 			tmp0 = A01 + B0;
 			tmp1 = A11 + B1;
-			if ( tmp1 > tmp0 )
-			{
+			if ( tmp1 > tmp0 ) {
 				numer = tmp1 - tmp0;
 				denom = A00 - 2.0f * A01 + A11;
-				if ( numer >= denom )
-				{
+				if ( numer >= denom ) {
 					S = 1.0f;
 					T = 0.0f;
 					sqrDist = A00 + 2.0f * B0 + C;
 					lv = 1;
 				}
-				else
-				{
-					if(fabsf(denom) > FLT_EPSILON)
+				else {
+					if (fabsf(denom) > FLT_EPSILON)
 						S = numer / denom;
 					else
 						S = 0.0f;
 					T = 1.0f - S;
 					sqrDist = S * ( A00 * S + A01 * T + 2.0f * B0 ) +
-							T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
+					          T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
 					le = 2;
 				}
 			}
-			else
-			{
+			else {
 				S = 0.0f;
-				if ( tmp1 <= 0.0f )
-				{
+				if ( tmp1 <= 0.0f ) {
 					T = 1.0f;
 					sqrDist = A11 + 2.0f * B1 + C;
 					lv = 2;
 				}
-				else if ( B1 >= 0.0f )
-				{
+				else if (B1 >= 0.0f) {
 					T = 0.0f;
 					sqrDist = C;
 					lv = 0;
 				}
-				else
-				{
-					if(fabsf(A11) > FLT_EPSILON)
+				else {
+					if (fabsf(A11) > FLT_EPSILON)
 						T = -B1 / A11;
 					else
 						T = 0.0f;
@@ -285,51 +255,43 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 				}
 			}
 		}
-		else if ( T < 0.0f )  // Region 6
-		{
+		else if (T < 0.0f) { /* Region 6 */
 			tmp0 = A01 + B1;
 			tmp1 = A00 + B0;
-			if ( tmp1 > tmp0 )
-			{
+			if ( tmp1 > tmp0 ) {
 				numer = tmp1 - tmp0;
 				denom = A00 - 2.0f * A01 + A11;
-				if ( numer >= denom )
-				{
+				if ( numer >= denom ) {
 					T = 1.0f;
 					S = 0.0f;
 					sqrDist = A11 + 2.0f * B1 + C;
 					lv = 2;
 				}
-				else
-				{
-					if(fabsf(denom) > FLT_EPSILON)
+				else {
+					if (fabsf(denom) > FLT_EPSILON)
 						T = numer / denom;
 					else
 						T = 0.0f;
 					S = 1.0f - T;
 					sqrDist = S * ( A00 * S + A01 * T + 2.0f * B0 ) +
-							T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
+					          T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
 					le = 2;
 				}
 			}
-			else
-			{
+			else {
 				T = 0.0f;
-				if ( tmp1 <= 0.0f )
-				{
+				if (tmp1 <= 0.0f) {
 					S = 1.0f;
 					sqrDist = A00 + 2.0f * B0 + C;
 					lv = 1;
 				}
-				else if ( B0 >= 0.0f )
-				{
+				else if (B0 >= 0.0f) {
 					S = 0.0f;
 					sqrDist = C;
 					lv = 0;
 				}
-				else
-				{
-					if(fabsf(A00) > FLT_EPSILON)
+				else {
+					if (fabsf(A00) > FLT_EPSILON)
 						S = -B0 / A00;
 					else
 						S = 0.0f;
@@ -338,35 +300,30 @@ float nearest_point_in_tri_surface(const float v0[3], const float v1[3], const f
 				}
 			}
 		}
-		else  // Region 1
-		{
+		else { /* Region 1 */
 			numer = A11 + B1 - A01 - B0;
-			if ( numer <= 0.0f )
-			{
+			if ( numer <= 0.0f ) {
 				S = 0.0f;
 				T = 1.0f;
 				sqrDist = A11 + 2.0f * B1 + C;
 				lv = 2;
 			}
-			else
-			{
+			else {
 				denom = A00 - 2.0f * A01 + A11;
-				if ( numer >= denom )
-				{
+				if ( numer >= denom ) {
 					S = 1.0f;
 					T = 0.0f;
 					sqrDist = A00 + 2.0f * B0 + C;
 					lv = 1;
 				}
-				else
-				{
-					if(fabsf(denom) > FLT_EPSILON)
+				else {
+					if (fabsf(denom) > FLT_EPSILON)
 						S = numer / denom;
 					else
 						S = 0.0f;
 					T = 1.0f - S;
 					sqrDist = S * ( A00 * S + A01 * T + 2.0f * B0 ) +
-							T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
+					          T * ( A01 * S + A11 * T + 2.0f * B1 ) + C;
 					le = 2;
 				}
 			}
@@ -422,8 +379,7 @@ static void mesh_faces_nearest_point(void *userdata, int index, const float co[3
 		int vertex, edge;
 		
 		dist = nearest_point_in_tri_surface(t0, t1, t2, co, &vertex, &edge, nearest_tmp);
-		if(dist < nearest->dist)
-		{
+		if (dist < nearest->dist) {
 			nearest->index = index;
 			nearest->dist = dist;
 			copy_v3_v3(nearest->co, nearest_tmp);
@@ -434,7 +390,7 @@ static void mesh_faces_nearest_point(void *userdata, int index, const float co[3
 		t2 = t3;
 		t3 = NULL;
 
-	} while(t2);
+	} while (t2);
 }
 
 // Callback to bvh tree raycast. The tree must bust have been built using bvhtree_from_mesh_faces.
@@ -455,13 +411,12 @@ static void mesh_faces_spherecast(void *userdata, int index, const BVHTreeRay *r
 	do
 	{	
 		float dist;
-		if(data->sphere_radius == 0.0f)
+		if (data->sphere_radius == 0.0f)
 			dist = bvhtree_ray_tri_intersection(ray, hit->dist, t0, t1, t2);
 		else
 			dist = sphereray_tri_intersection(ray, data->sphere_radius, hit->dist, t0, t1, t2);
 
-		if(dist >= 0 && dist < hit->dist)
-		{
+		if (dist >= 0 && dist < hit->dist) {
 			hit->index = index;
 			hit->dist = dist;
 			madd_v3_v3v3fl(hit->co, ray->origin, ray->direction, dist);
@@ -473,7 +428,7 @@ static void mesh_faces_spherecast(void *userdata, int index, const BVHTreeRay *r
 		t2 = t3;
 		t3 = NULL;
 
-	} while(t2);
+	} while (t2);
 }
 
 // Callback to bvh tree nearest point. The tree must bust have been built using bvhtree_from_mesh_edges.
@@ -492,8 +447,7 @@ static void mesh_edges_nearest_point(void *userdata, int index, const float co[3
 	closest_to_line_segment_v3(nearest_tmp, co, t0, t1);
 	dist = len_squared_v3v3(nearest_tmp, co);
 	
-	if(dist < nearest->dist)
-	{
+	if (dist < nearest->dist) {
 		nearest->index = index;
 		nearest->dist = dist;
 		copy_v3_v3(nearest->co, nearest_tmp);
@@ -511,20 +465,18 @@ BVHTree* bvhtree_from_mesh_verts(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 	BVHTree *tree = bvhcache_find(&mesh->bvhCache, BVHTREE_FROM_VERTICES);
 
 	//Not in cache
-	if(tree == NULL)
-	{
+	if (tree == NULL) {
 		int i;
 		int numVerts= mesh->getNumVerts(mesh);
 		MVert *vert	= mesh->getVertDataArray(mesh, CD_MVERT);
 
-		if(vert != NULL)
-		{
+		if (vert != NULL) {
 			tree = BLI_bvhtree_new(numVerts, epsilon, tree_type, axis);
 
-			if(tree != NULL)
-			{
-				for(i = 0; i < numVerts; i++)
+			if (tree != NULL) {
+				for (i = 0; i < numVerts; i++) {
 					BLI_bvhtree_insert(tree, i, vert[i].co, 1);
+				}
 
 				BLI_bvhtree_balance(tree);
 
@@ -534,8 +486,7 @@ BVHTree* bvhtree_from_mesh_verts(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 			}
 		}
 	}
-	else
-	{
+	else {
 //		printf("BVHTree is already build, using cached tree\n");
 	}
 
@@ -544,8 +495,7 @@ BVHTree* bvhtree_from_mesh_verts(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 	memset(data, 0, sizeof(*data));
 	data->tree = tree;
 
-	if(data->tree)
-	{
+	if (data->tree) {
 		data->cached = TRUE;
 
 		//a NULL nearest callback works fine
@@ -555,7 +505,7 @@ BVHTree* bvhtree_from_mesh_verts(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 
 		data->mesh = mesh;
 		data->vert = mesh->getVertDataArray(mesh, CD_MVERT);
-		data->face = mesh->getFaceDataArray(mesh, CD_MFACE);
+		data->face = mesh->getTessFaceDataArray(mesh, CD_MFACE);
 
 		data->sphere_radius = epsilon;
 	}
@@ -569,46 +519,95 @@ BVHTree* bvhtree_from_mesh_faces(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 	BVHTree *tree = bvhcache_find(&mesh->bvhCache, BVHTREE_FROM_FACES);
 
 	//Not in cache
-	if(tree == NULL)
-	{
+	if (tree == NULL) {
 		int i;
-		int numFaces= mesh->getNumFaces(mesh);
-		MVert *vert	= mesh->getVertDataArray(mesh, CD_MVERT);
-		MFace *face = mesh->getFaceDataArray(mesh, CD_MFACE);
+		int numFaces= mesh->getNumTessFaces(mesh);
 
-		if(vert != NULL && face != NULL)
-		{
+		/* BMESH specific check that we have tessfaces,
+		 * we _could_ tessellate here but rather not - campbell
+		 *
+		 * this assert checks we have tessfaces,
+		 * if not caller should use DM_ensure_tessface() */
+		BLI_assert(!(numFaces == 0 && mesh->getNumPolys(mesh) != 0));
+
+		if (numFaces != 0) {
 			/* Create a bvh-tree of the given target */
 			tree = BLI_bvhtree_new(numFaces, epsilon, tree_type, axis);
-			if(tree != NULL)
-			{
-				/* XXX, for snap only, em & dm are assumed to be aligned, since dm is the em's cage */
-				EditMesh *em= data->em_evil;
-				if(em) {
-					EditFace *efa= em->faces.first;
-					for(i = 0; i < numFaces; i++, efa= efa->next) {
-						if(!(efa->f & 1) && efa->h==0 && !((efa->v1->f&1)+(efa->v2->f&1)+(efa->v3->f&1)+(efa->v4?efa->v4->f&1:0))) {
+			if (tree != NULL) {
+				BMEditMesh *em= data->em_evil;
+				if (em) {
+					/* data->em_evil is only set for snapping, and only for the mesh of the object
+					 * which is currently open in edit mode. When set, the bvhtree should not contain
+					 * faces that will interfere with snapping (e.g. faces that are hidden/selected
+					 * or faces that have selected verts).*/
+
+					/* XXX, for snap only, em & dm are assumed to be aligned, since dm is the em's cage */
+
+					/* Insert BMesh-tessellation triangles into the bvh tree, unless they are hidden
+					 * and/or selected. Even if the faces themselves are not selected for the snapped
+					 * transform, having a vertex selected means the face (and thus it's tessellated
+					 * triangles) will be moving and will not be a good snap targets.*/
+					for (i = 0; i < em->tottri; i++) {
+						BMLoop **tri = em->looptris[i];
+						BMFace *f;
+						BMVert *v;
+						BMIter iter;
+						int insert;
+
+						/* Each loop of the triangle points back to the BMFace it was tessellated from.
+						 * All three should point to the same face, so just use the face from the first
+						 * loop.*/
+						f = tri[0]->f;
+
+						/* If the looptris is ordered such that all triangles tessellated from a single
+						 * faces are consecutive elements in the array, then we could speed up the tests
+						 * below by using the insert value from the previous iteration.*/
+
+						/*Start with the assumption the triangle should be included for snapping.*/
+						insert = 1;
+
+						if (BM_elem_flag_test(f, BM_ELEM_SELECT) || BM_elem_flag_test(f, BM_ELEM_HIDDEN)) {
+							/* Don't insert triangles tessellated from faces that are hidden
+							 * or selected*/
+							insert = 0;
+						}
+						else {
+							BM_ITER_ELEM (v, &iter, f, BM_VERTS_OF_FACE) {
+								if (BM_elem_flag_test(v, BM_ELEM_SELECT)) {
+									/* Don't insert triangles tessellated from faces that have
+									 * any selected verts.*/
+									insert = 0;
+								}
+							}
+						}
+
+						if (insert) {
+							/* No reason found to block hit-testing the triangle for snap,
+							 * so insert it now.*/
 							float co[4][3];
-							copy_v3_v3(co[0], vert[ face[i].v1 ].co);
-							copy_v3_v3(co[1], vert[ face[i].v2 ].co);
-							copy_v3_v3(co[2], vert[ face[i].v3 ].co);
-							if(face[i].v4)
-								copy_v3_v3(co[3], vert[ face[i].v4 ].co);
+							copy_v3_v3(co[0], tri[0]->v->co);
+							copy_v3_v3(co[1], tri[1]->v->co);
+							copy_v3_v3(co[2], tri[2]->v->co);
 					
-							BLI_bvhtree_insert(tree, i, co[0], face[i].v4 ? 4 : 3);
+							BLI_bvhtree_insert(tree, i, co[0], 3);
 						}
 					}
 				}
 				else {
-					for(i = 0; i < numFaces; i++) {
-						float co[4][3];
-						copy_v3_v3(co[0], vert[ face[i].v1 ].co);
-						copy_v3_v3(co[1], vert[ face[i].v2 ].co);
-						copy_v3_v3(co[2], vert[ face[i].v3 ].co);
-						if(face[i].v4)
-							copy_v3_v3(co[3], vert[ face[i].v4 ].co);
-				
-						BLI_bvhtree_insert(tree, i, co[0], face[i].v4 ? 4 : 3);
+					MVert *vert	= mesh->getVertDataArray(mesh, CD_MVERT);
+					MFace *face = mesh->getTessFaceDataArray(mesh, CD_MFACE);
+
+					if (vert != NULL && face != NULL) {
+						for (i = 0; i < numFaces; i++) {
+							float co[4][3];
+							copy_v3_v3(co[0], vert[ face[i].v1 ].co);
+							copy_v3_v3(co[1], vert[ face[i].v2 ].co);
+							copy_v3_v3(co[2], vert[ face[i].v3 ].co);
+							if (face[i].v4)
+								copy_v3_v3(co[3], vert[ face[i].v4 ].co);
+					
+							BLI_bvhtree_insert(tree, i, co[0], face[i].v4 ? 4 : 3);
+						}
 					}
 				}
 				BLI_bvhtree_balance(tree);
@@ -619,8 +618,7 @@ BVHTree* bvhtree_from_mesh_faces(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 			}
 		}
 	}
-	else
-	{
+	else {
 //		printf("BVHTree is already build, using cached tree\n");
 	}
 
@@ -629,8 +627,7 @@ BVHTree* bvhtree_from_mesh_faces(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 	memset(data, 0, sizeof(*data));
 	data->tree = tree;
 
-	if(data->tree)
-	{
+	if (data->tree) {
 		data->cached = TRUE;
 
 		data->nearest_callback = mesh_faces_nearest_point;
@@ -638,7 +635,7 @@ BVHTree* bvhtree_from_mesh_faces(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 
 		data->mesh = mesh;
 		data->vert = mesh->getVertDataArray(mesh, CD_MVERT);
-		data->face = mesh->getFaceDataArray(mesh, CD_MFACE);
+		data->face = mesh->getTessFaceDataArray(mesh, CD_MFACE);
 
 		data->sphere_radius = epsilon;
 	}
@@ -652,21 +649,18 @@ BVHTree* bvhtree_from_mesh_edges(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 	BVHTree *tree = bvhcache_find(&mesh->bvhCache, BVHTREE_FROM_EDGES);
 
 	//Not in cache
-	if(tree == NULL)
+	if (tree == NULL)
 	{
 		int i;
 		int numEdges= mesh->getNumEdges(mesh);
 		MVert *vert	= mesh->getVertDataArray(mesh, CD_MVERT);
 		MEdge *edge = mesh->getEdgeDataArray(mesh, CD_MEDGE);
 
-		if(vert != NULL && edge != NULL)
-		{
+		if (vert != NULL && edge != NULL) {
 			/* Create a bvh-tree of the given target */
 			tree = BLI_bvhtree_new(numEdges, epsilon, tree_type, axis);
-			if(tree != NULL)
-			{
-				for(i = 0; i < numEdges; i++)
-				{
+			if (tree != NULL) {
+				for (i = 0; i < numEdges; i++) {
 					float co[4][3];
 					copy_v3_v3(co[0], vert[ edge[i].v1 ].co);
 					copy_v3_v3(co[1], vert[ edge[i].v2 ].co);
@@ -691,8 +685,7 @@ BVHTree* bvhtree_from_mesh_edges(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 	memset(data, 0, sizeof(*data));
 	data->tree = tree;
 
-	if(data->tree)
-	{
+	if (data->tree) {
 		data->cached = TRUE;
 
 		data->nearest_callback = mesh_edges_nearest_point;
@@ -711,9 +704,8 @@ BVHTree* bvhtree_from_mesh_edges(BVHTreeFromMesh *data, DerivedMesh *mesh, float
 // Frees data allocated by a call to bvhtree_from_mesh_*.
 void free_bvhtree_from_mesh(struct BVHTreeFromMesh *data)
 {
-	if(data->tree)
-	{
-		if(!data->cached)
+	if (data->tree) {
+		if (!data->cached)
 			BLI_bvhtree_free(data->tree);
 
 		memset( data, 0, sizeof(*data) );
@@ -734,8 +726,7 @@ static void bvhcacheitem_set_if_match(void *_cached, void *_search)
 	BVHCacheItem * cached = (BVHCacheItem *)_cached;
 	BVHCacheItem * search = (BVHCacheItem *)_search;
 
-	if(search->type == cached->type)
-	{
+	if (search->type == cached->type) {
 		search->tree = cached->tree;		
 	}
 } 
@@ -763,7 +754,7 @@ void bvhcache_insert(BVHCache *cache, BVHTree *tree, int type)
 	item->type = type;
 	item->tree = tree;
 
-	BLI_linklist_prepend( cache, item );
+	BLI_linklist_prepend(cache, item);
 }
 
 
