@@ -60,8 +60,8 @@ static char idp_size_table[] = {
 
 /* --------- property array type -------------*/
 
-/*note: as a start to move away from the stupid IDP_New function, this type
-  has it's own allocation function.*/
+/* note: as a start to move away from the stupid IDP_New function, this type
+ * has it's own allocation function.*/
 IDProperty *IDP_NewIDPArray(const char *name)
 {
 	IDProperty *prop = MEM_callocN(sizeof(IDProperty), "IDProperty prop array");
@@ -74,7 +74,7 @@ IDProperty *IDP_NewIDPArray(const char *name)
 
 IDProperty *IDP_CopyIDPArray(IDProperty *array)
 {
-	/* dont use MEM_dupallocN because this may be part of an array */
+	/* don't use MEM_dupallocN because this may be part of an array */
 	IDProperty *narray = MEM_mallocN(sizeof(IDProperty), "IDP_CopyIDPArray"), *tmp;
 	int i;
 
@@ -82,12 +82,12 @@ IDProperty *IDP_CopyIDPArray(IDProperty *array)
 
 	narray->data.pointer = MEM_dupallocN(array->data.pointer);
 	for (i=0; i<narray->len; i++) {
-		/*ok, the copy functions always allocate a new structure,
-		  which doesn't work here.  instead, simply copy the
-		  contents of the new structure into the array cell,
-		  then free it.  this makes for more maintainable
-		  code than simply reimplementing the copy functions
-		  in this loop.*/
+		/* ok, the copy functions always allocate a new structure,
+		 * which doesn't work here.  instead, simply copy the
+		 * contents of the new structure into the array cell,
+		 * then free it.  this makes for more maintainable
+		 * code than simply reimplementing the copy functions
+		 * in this loop.*/
 		tmp = IDP_CopyProperty(GETPROP(narray, i));
 		memcpy(GETPROP(narray, i), tmp, sizeof(IDProperty));
 		MEM_freeN(tmp);
@@ -103,7 +103,7 @@ void IDP_FreeIDPArray(IDProperty *prop)
 	for (i=0; i<prop->len; i++)
 		IDP_FreeProperty(GETPROP(prop, i));
 
-	if(prop->data.pointer)
+	if (prop->data.pointer)
 		MEM_freeN(prop->data.pointer);
 }
 
@@ -139,14 +139,14 @@ void IDP_ResizeIDPArray(IDProperty *prop, int newlen)
 	if (newlen <= prop->totallen && prop->totallen - newlen < 200) {
 		int i;
 
-		for(i=newlen; i<prop->len; i++)
+		for (i=newlen; i<prop->len; i++)
 			IDP_FreeProperty(GETPROP(prop, i));
 
 		prop->len = newlen;
 		return;
 	}
 
-	/* - Note: This code comes from python, here's the corrusponding comment. - */
+	/* - Note: This code comes from python, here's the corresponding comment. - */
 	/* This over-allocates proportional to the list size, making room
 	 * for additional growth.  The over-allocation is mild, but is
 	 * enough to give linear-time amortized behavior over a long
@@ -170,7 +170,7 @@ void IDP_ResizeIDPArray(IDProperty *prop, int newlen)
 		memcpy(newarr, prop->data.pointer, newlen*sizeof(IDProperty));
 	}
 
-	if(prop->data.pointer)
+	if (prop->data.pointer)
 		MEM_freeN(prop->data.pointer);
 	prop->data.pointer = newarr;
 	prop->len = newlen;
@@ -180,16 +180,16 @@ void IDP_ResizeIDPArray(IDProperty *prop, int newlen)
 /* ----------- Numerical Array Type ----------- */
 static void idp_resize_group_array(IDProperty *prop, int newlen, void *newarr)
 {
-	if(prop->subtype != IDP_GROUP)
+	if (prop->subtype != IDP_GROUP)
 		return;
 
-	if(newlen >= prop->len) {
+	if (newlen >= prop->len) {
 		/* bigger */
 		IDProperty **array= newarr;
 		IDPropertyTemplate val;
 		int a;
 
-		for(a=prop->len; a<newlen; a++) {
+		for (a=prop->len; a<newlen; a++) {
 			val.i = 0; /* silence MSVC warning about uninitialized var when debugging */
 			array[a]= IDP_New(IDP_GROUP, &val, "IDP_ResizeArray group");
 		}
@@ -199,7 +199,7 @@ static void idp_resize_group_array(IDProperty *prop, int newlen, void *newarr)
 		IDProperty **array= prop->data.pointer;
 		int a;
 
-		for(a=newlen; a<prop->len; a++) {
+		for (a=newlen; a<prop->len; a++) {
 			IDP_FreeProperty(array[a]);
 			MEM_freeN(array[a]);
 		}
@@ -220,7 +220,7 @@ void IDP_ResizeArray(IDProperty *prop, int newlen)
 		return;
 	}
 
-	/* - Note: This code comes from python, here's the corrusponding comment. - */
+	/* - Note: This code comes from python, here's the corresponding comment. - */
 	/* This over-allocates proportional to the list size, making room
 	 * for additional growth.  The over-allocation is mild, but is
 	 * enough to give linear-time amortized behavior over a long
@@ -277,11 +277,11 @@ static IDProperty *IDP_CopyArray(IDProperty *prop)
 	if (prop->data.pointer) {
 		newp->data.pointer = MEM_dupallocN(prop->data.pointer);
 
-		if(prop->type == IDP_GROUP) {
+		if (prop->type == IDP_GROUP) {
 			IDProperty **array= newp->data.pointer;
 			int a;
 
-			for(a=0; a<prop->len; a++)
+			for (a=0; a<prop->len; a++)
 				array[a]= IDP_CopyProperty(array[a]);
 		}
 	}
@@ -316,7 +316,7 @@ IDProperty *IDP_NewString(const char *st, const char *name, int maxlen)
 	else {
 		int stlen = strlen(st);
 
-		if(maxlen > 0 && maxlen < stlen)
+		if (maxlen > 0 && maxlen < stlen)
 			stlen = maxlen;
 
 		stlen++; /* null terminator '\0' */
@@ -349,7 +349,7 @@ void IDP_AssignString(IDProperty *prop, const char *st, int maxlen)
 {
 	int stlen = strlen(st);
 
-	if(maxlen > 0 && maxlen < stlen)
+	if (maxlen > 0 && maxlen < stlen)
 		stlen= maxlen;
 
 	if (prop->subtype == IDP_STRING_SUB_BYTE) {
@@ -368,8 +368,8 @@ void IDP_ConcatStringC(IDProperty *prop, const char *st)
 	int newlen;
 
 	newlen = prop->len + strlen(st);
-	/*we have to remember that prop->len includes the null byte for strings.
-	 so there's no need to add +1 to the resize function.*/
+	/* we have to remember that prop->len includes the null byte for strings.
+	 * so there's no need to add +1 to the resize function.*/
 	IDP_ResizeArray(prop, newlen);
 	strcat(prop->data.pointer, st);
 }
@@ -378,8 +378,8 @@ void IDP_ConcatString(IDProperty *str1, IDProperty *append)
 {
 	int newlen;
 
-	/*since ->len for strings includes the NULL byte, we have to subtract one or
-	 we'll get an extra null byte after each concatination operation.*/
+	/* since ->len for strings includes the NULL byte, we have to subtract one or
+	 * we'll get an extra null byte after each concatenation operation.*/
 	newlen = str1->len + append->len - 1;
 	IDP_ResizeArray(str1, newlen);
 	strcat(str1->data.pointer, append->data.pointer);
@@ -387,7 +387,7 @@ void IDP_ConcatString(IDProperty *str1, IDProperty *append)
 
 void IDP_FreeString(IDProperty *prop)
 {
-	if(prop->data.pointer)
+	if (prop->data.pointer)
 		MEM_freeN(prop->data.pointer);
 }
 
@@ -455,8 +455,8 @@ void IDP_SyncGroupValues(IDProperty *dest, IDProperty *src)
 }
 
 /*
- replaces all properties with the same name in a destination group from a source group.
-*/
+ * replaces all properties with the same name in a destination group from a source group.
+ */
 void IDP_ReplaceGroupInGroup(IDProperty *dest, IDProperty *src)
 {
 	IDProperty *loop, *prop;
@@ -483,13 +483,13 @@ void IDP_ReplaceGroupInGroup(IDProperty *dest, IDProperty *src)
 	}
 }
 /*
- replaces a property with the same name in a group, or adds 
- it if the propery doesn't exist.
-*/
+ * replaces a property with the same name in a group, or adds 
+ * it if the properly doesn't exist.
+ */
 void IDP_ReplaceInGroup(IDProperty *group, IDProperty *prop)
 {
 	IDProperty *loop;
-	if((loop= IDP_GetPropertyFromGroup(group, prop->name)))  {
+	if ((loop= IDP_GetPropertyFromGroup(group, prop->name))) {
 		BLI_insertlink(&group->data.group, loop, prop);
 		
 		BLI_remlink(&group->data.group, loop);
@@ -502,11 +502,11 @@ void IDP_ReplaceInGroup(IDProperty *group, IDProperty *prop)
 	}
 }
 
-/*returns 0 if an id property with the same name exists and it failed,
-  or 1 if it succeeded in adding to the group.*/
+/* returns 0 if an id property with the same name exists and it failed,
+ * or 1 if it succeeded in adding to the group.*/
 int IDP_AddToGroup(IDProperty *group, IDProperty *prop)
 {
-	if(IDP_GetPropertyFromGroup(group, prop->name) == NULL)  {
+	if (IDP_GetPropertyFromGroup(group, prop->name) == NULL) {
 		group->len++;
 		BLI_addtail(&group->data.group, prop);
 		return 1;
@@ -517,7 +517,7 @@ int IDP_AddToGroup(IDProperty *group, IDProperty *prop)
 
 int IDP_InsertToGroup(IDProperty *group, IDProperty *previous, IDProperty *pnew)
 {
-	if(IDP_GetPropertyFromGroup(group, pnew->name) == NULL)  {
+	if (IDP_GetPropertyFromGroup(group, pnew->name) == NULL) {
 		group->len++;
 		BLI_insertlink(&group->data.group, previous, pnew);
 		return 1;
@@ -574,10 +574,10 @@ void IDP_FreeIterBeforeEnd(void *vself)
 	MEM_freeN(vself);
 }
 
-/*Ok, the way things work, Groups free the ID Property structs of their children.
-  This is because all ID Property freeing functions free only direct data (not the ID Property
-  struct itself), but for Groups the child properties *are* considered
-  direct data.*/
+/* Ok, the way things work, Groups free the ID Property structs of their children.
+ * This is because all ID Property freeing functions free only direct data (not the ID Property
+ * struct itself), but for Groups the child properties *are* considered
+ * direct data. */
 static void IDP_FreeGroup(IDProperty *prop)
 {
 	IDProperty *loop;
@@ -608,9 +608,9 @@ IDProperty *IDP_GetProperties(ID *id, int create_if_needed)
 		if (create_if_needed) {
 			id->properties = MEM_callocN(sizeof(IDProperty), "IDProperty");
 			id->properties->type = IDP_GROUP;
-			/* dont overwite the data's name and type
+			/* don't overwrite the data's name and type
 			 * some functions might need this if they
-			 * dont have a real ID, should be named elsewhere - Campbell */
+			 * don't have a real ID, should be named elsewhere - Campbell */
 			/* strcpy(id->name, "top_level_group");*/
 		}
 		return id->properties;
@@ -619,59 +619,59 @@ IDProperty *IDP_GetProperties(ID *id, int create_if_needed)
 
 int IDP_EqualsProperties(IDProperty *prop1, IDProperty *prop2)
 {
-	if(prop1 == NULL && prop2 == NULL)
+	if (prop1 == NULL && prop2 == NULL)
 		return 1;
-	else if(prop1 == NULL || prop2 == NULL)
+	else if (prop1 == NULL || prop2 == NULL)
 		return 0;
-	else if(prop1->type != prop2->type)
+	else if (prop1->type != prop2->type)
 		return 0;
 
-	if(prop1->type == IDP_INT)
+	if (prop1->type == IDP_INT)
 		return (IDP_Int(prop1) == IDP_Int(prop2));
-	else if(prop1->type == IDP_FLOAT)
+	else if (prop1->type == IDP_FLOAT)
 		return (IDP_Float(prop1) == IDP_Float(prop2));
-	else if(prop1->type == IDP_DOUBLE)
+	else if (prop1->type == IDP_DOUBLE)
 		return (IDP_Double(prop1) == IDP_Double(prop2));
-	else if(prop1->type == IDP_STRING)
+	else if (prop1->type == IDP_STRING)
 		return ((prop1->len == prop2->len) && strncmp(IDP_String(prop1), IDP_String(prop2), prop1->len) == 0);
-	else if(prop1->type == IDP_ARRAY) {
-		if(prop1->len == prop2->len && prop1->subtype == prop2->subtype)
+	else if (prop1->type == IDP_ARRAY) {
+		if (prop1->len == prop2->len && prop1->subtype == prop2->subtype)
 			return memcmp(IDP_Array(prop1), IDP_Array(prop2), idp_size_table[(int)prop1->subtype]*prop1->len);
 		else
 			return 0;
 	}
-	else if(prop1->type == IDP_GROUP) {
+	else if (prop1->type == IDP_GROUP) {
 		IDProperty *link1, *link2;
 
-		if(BLI_countlist(&prop1->data.group) != BLI_countlist(&prop2->data.group))
+		if (BLI_countlist(&prop1->data.group) != BLI_countlist(&prop2->data.group))
 			return 0;
 
-		for(link1=prop1->data.group.first; link1; link1=link1->next) {
+		for (link1=prop1->data.group.first; link1; link1=link1->next) {
 			link2= IDP_GetPropertyFromGroup(prop2, link1->name);
 
-			if(!IDP_EqualsProperties(link1, link2))
+			if (!IDP_EqualsProperties(link1, link2))
 				return 0;
 		}
 
 		return 1;
 	}
-	else if(prop1->type == IDP_IDPARRAY) {
+	else if (prop1->type == IDP_IDPARRAY) {
 		IDProperty *array1= IDP_IDPArray(prop1);
 		IDProperty *array2= IDP_IDPArray(prop2);
 		int i;
 
-		if(prop1->len != prop2->len)
+		if (prop1->len != prop2->len)
 			return 0;
 		
-		for(i=0; i<prop1->len; i++)
-			if(!IDP_EqualsProperties(&array1[i], &array2[i]))
+		for (i=0; i<prop1->len; i++)
+			if (!IDP_EqualsProperties(&array1[i], &array2[i]))
 				return 0;
 	}
 	
 	return 1;
 }
 
-/* 'val' is never NULL, dont check */
+/* 'val' is never NULL, don't check */
 IDProperty *IDP_New(const int type, const IDPropertyTemplate *val, const char *name)
 {
 	IDProperty *prop=NULL;
@@ -703,7 +703,8 @@ IDProperty *IDP_New(const int type, const IDPropertyTemplate *val, const char *n
 					prop->data.pointer = MEM_callocN(idp_size_table[val->array.type]*val->array.len, "id property array");
 				prop->len = prop->totallen = val->array.len;
 				break;
-			} else {
+			}
+			else {
 				return NULL;
 			}
 		}
@@ -761,9 +762,9 @@ IDProperty *IDP_New(const int type, const IDPropertyTemplate *val, const char *n
 	return prop;
 }
 
-/*NOTE: this will free all child properties including list arrays and groups!
-  Also, note that this does NOT unlink anything!  Plus it doesn't free
-  the actual IDProperty struct either.*/
+/* NOTE: this will free all child properties including list arrays and groups!
+ * Also, note that this does NOT unlink anything!  Plus it doesn't free
+ * the actual IDProperty struct either.*/
 void IDP_FreeProperty(IDProperty *prop)
 {
 	switch (prop->type) {
@@ -782,8 +783,8 @@ void IDP_FreeProperty(IDProperty *prop)
 	}
 }
 
-/*Unlinks any IDProperty<->ID linkage that might be going on.
-  note: currently unused.*/
+/* Unlinks any IDProperty<->ID linkage that might be going on.
+ * note: currently unused.*/
 void IDP_UnlinkProperty(IDProperty *prop)
 {
 	switch (prop->type) {
