@@ -97,8 +97,8 @@ void free_ipo (Ipo *ipo)
 		BLI_freelinkN(&ipo->curve, icu);
 	}
 	
-	if (G.f & G_DEBUG)
-		printf("Freed %d (Unconverted) Ipo-Curves from IPO '%s' \n", n, ipo->id.name+2);
+	if (G.debug & G_DEBUG)
+		printf("Freed %d (Unconverted) Ipo-Curves from IPO '%s'\n", n, ipo->id.name+2);
 }
 
 /* *************************************************** */
@@ -296,7 +296,7 @@ static const char *pchan_adrcodes_to_paths (int adrcode, int *array_index)
 	}
 	
 	/* for debugging only */
-	printf("ERROR: unmatched PoseChannel setting (code %d) \n", adrcode);
+	printf("ERROR: unmatched PoseChannel setting (code %d)\n", adrcode);
 	return NULL;
 }
 
@@ -325,12 +325,15 @@ static char *shapekey_adrcodes_to_paths (int adrcode, int *UNUSED(array_index))
 {
 	static char buf[128];
 	
-	/* block will be attached to ID_KE block, and setting that we alter is the 'value' (which sets keyblock.curval) */
-	// XXX adrcode 0 was dummy 'speed' curve 
-	if (adrcode == 0) 
-		strcpy(buf, "speed");
-	else
+	/* block will be attached to ID_KE block... */
+	if (adrcode == 0) {
+		/* adrcode=0 was the misnamed "speed" curve (now "evaluation time") */
+		BLI_strncpy(buf, "eval_time", sizeof(buf));
+	}
+	else {
+		/* setting that we alter is the "value" (i.e. keyblock.curval) */
 		BLI_snprintf(buf, sizeof(buf), "key_blocks[%d].value", adrcode);
+	}
 	return buf;
 }
 
@@ -663,8 +666,10 @@ static const char *sound_adrcodes_to_paths (int adrcode, int *array_index)
 		case SND_PITCH:
 			return "pitch";
 	/* XXX Joshua -- I had wrapped panning in rna, but someone commented out, calling it "unused" */
-	/*	case SND_PANNING:
-			return "panning"; */
+#if 0
+		case SND_PANNING:
+			return "panning";
+#endif
 		case SND_ATTEN:
 			return "attenuation";
 	}
@@ -762,11 +767,12 @@ static const char *particle_adrcodes_to_paths (int adrcode, int *array_index)
 			return "settings.billboard_tilt";
 		
 		/* PartDeflect needs to be sorted out properly in rna_object_force;
-		   If anyone else works on this, but is unfamiliar, these particular
-			settings reference the particles of the system themselves
-			being used as forces -- it will use the same rna structure
-			as the similar object forces				*/
-		/*case PART_PD_FSTR:
+		 * If anyone else works on this, but is unfamiliar, these particular
+		 * settings reference the particles of the system themselves
+		 * being used as forces -- it will use the same rna structure
+		 * as the similar object forces */
+#if 0
+		case PART_PD_FSTR:
 			if (part->pd) poin= &(part->pd->f_strength);
 			break;
 		case PART_PD_FFALL:
@@ -783,11 +789,12 @@ static const char *particle_adrcodes_to_paths (int adrcode, int *array_index)
 			break;
 		case PART_PD2_FMAXD:
 			if (part->pd2) poin= &(part->pd2->maxdist);
-			break;*/
+			break;
+#endif
 
-		}
-		
-	return NULL;	
+	}
+
+	return NULL;
 }
 
 /* ------- */
@@ -889,7 +896,7 @@ static char *get_rna_access (int blocktype, int adrcode, char actname[], char co
 			
 		// TODO... add other blocktypes...
 		default:
-			printf("IPO2ANIMATO WARNING: No path for blocktype %d, adrcode %d yet \n", blocktype, adrcode);
+			printf("IPO2ANIMATO WARNING: No path for blocktype %d, adrcode %d yet\n", blocktype, adrcode);
 			break;
 	}
 	
@@ -1098,24 +1105,22 @@ static void fcurve_add_to_list (ListBase *groups, ListBase *list, FCurve *fcu, c
 		
 		/* get the group to use */
 		agrp= action_groups_find_named(&tmp_act, grpname);
+		/* no matching group, so add one */
 		if (agrp == NULL) {
-			/* no matching group, so add one */
-			if (agrp == NULL) {
-				/* Add a new group, and make it active */
-				agrp= MEM_callocN(sizeof(bActionGroup), "bActionGroup");
-				
-				agrp->flag = AGRP_SELECTED;
-				if (muteipo) agrp->flag |= AGRP_MUTED;
-				
-				BLI_strncpy(agrp->name, grpname, sizeof(agrp->name));
-				
-				BLI_addtail(&tmp_act.groups, agrp);
-				BLI_uniquename(&tmp_act.groups, agrp, "Group", '.', offsetof(bActionGroup, name), sizeof(agrp->name));
-			}
+			/* Add a new group, and make it active */
+			agrp= MEM_callocN(sizeof(bActionGroup), "bActionGroup");
+
+			agrp->flag = AGRP_SELECTED;
+			if (muteipo) agrp->flag |= AGRP_MUTED;
+
+			BLI_strncpy(agrp->name, grpname, sizeof(agrp->name));
+
+			BLI_addtail(&tmp_act.groups, agrp);
+			BLI_uniquename(&tmp_act.groups, agrp, "Group", '.', offsetof(bActionGroup, name), sizeof(agrp->name));
 		}
 		
 		/* add F-Curve to group */
-		/* WARNING: this func should only need to look at the stuff we initialised, if not, things may crash */
+		/* WARNING: this func should only need to look at the stuff we initialized, if not, things may crash */
 		action_groups_add_channel(&tmp_act, agrp, fcu);
 		
 		if (agrp->flag & AGRP_MUTED) /* flush down */
@@ -1173,7 +1178,7 @@ static void icu_to_fcurves (ID *id, ListBase *groups, ListBase *list, IpoCurve *
 		case IPO_CYCLX: /* cyclic extrapolation + offset */
 		{
 			/* Add a new FModifier (Cyclic) instead of setting extend value 
-			 * as that's the new equivilant of that option. 
+			 * as that's the new equivalent of that option.
 			 */
 			FModifier *fcm= add_fmodifier(&fcu->modifiers, FMODIFIER_TYPE_CYCLES);
 			FMod_Cycles *data= (FMod_Cycles *)fcm->data;
@@ -1195,7 +1200,7 @@ static void icu_to_fcurves (ID *id, ListBase *groups, ListBase *list, IpoCurve *
 		FCurve *fcurve;
 		int b;
 		
-		if (G.f & G_DEBUG) printf("\tconvert bitflag ipocurve, totbits = %d \n", totbits);
+		if (G.debug & G_DEBUG) printf("\tconvert bitflag ipocurve, totbits = %d\n", totbits);
 		
 		/* add the 'only int values' flag */
 		fcu->flag |= (FCURVE_INT_VALUES|FCURVE_DISCRETE_VALUES);		
@@ -1392,7 +1397,7 @@ static void ipo_to_animato (ID *id, Ipo *ipo, char actname[], char constname[],
 	if (ELEM3(NULL, ipo, anim, drivers))
 		return;
 		
-	if (G.f & G_DEBUG) printf("ipo_to_animato \n");
+	if (G.debug & G_DEBUG) printf("ipo_to_animato\n");
 		
 	/* validate actname and constname 
 	 *	- clear actname if it was one of the generic <builtin> ones (i.e. 'Object', or 'Shapes')
@@ -1514,15 +1519,15 @@ static void ipo_to_animdata (ID *id, Ipo *ipo, char actname[], char constname[],
 	ListBase drivers = {NULL, NULL};
 	
 	/* sanity check */
-	if ELEM(NULL, id, ipo)
+	if (ELEM(NULL, id, ipo))
 		return;
 	if (adt == NULL) {
-		printf("ERROR ipo_to_animdata(): adt invalid \n");
+		printf("ERROR ipo_to_animdata(): adt invalid\n");
 		return;
 	}
 	
-	if (G.f & G_DEBUG) {
-		printf("ipo to animdata - ID:%s, IPO:%s, actname:%s constname:%s seqname:%s  curves:%d \n", 
+	if (G.debug & G_DEBUG) {
+		printf("ipo to animdata - ID:%s, IPO:%s, actname:%s constname:%s seqname:%s  curves:%d\n",
 		       id->name+2, ipo->id.name+2, (actname)?actname:"<None>", (constname)?constname:"<None>", (seq)?(seq->name+2):"<None>",
 			BLI_countlist(&ipo->curve));
 	}
@@ -1535,7 +1540,7 @@ static void ipo_to_animdata (ID *id, Ipo *ipo, char actname[], char constname[],
 	
 	/* deal with animation first */
 	if (anim.first) {
-		if (G.f & G_DEBUG) printf("\thas anim \n");
+		if (G.debug & G_DEBUG) printf("\thas anim\n");
 		/* try to get action */
 		if (adt->action == NULL) {
 			char nameBuf[MAX_ID_NAME];
@@ -1543,7 +1548,7 @@ static void ipo_to_animdata (ID *id, Ipo *ipo, char actname[], char constname[],
 			BLI_snprintf(nameBuf, sizeof(nameBuf), "CDA:%s", ipo->id.name+2);
 			
 			adt->action= add_empty_action(nameBuf);
-			if (G.f & G_DEBUG) printf("\t\tadded new action - '%s' \n", nameBuf);
+			if (G.debug & G_DEBUG) printf("\t\tadded new action - '%s'\n", nameBuf);
 		}
 		
 		/* add F-Curves to action */
@@ -1552,7 +1557,7 @@ static void ipo_to_animdata (ID *id, Ipo *ipo, char actname[], char constname[],
 	
 	/* deal with drivers */
 	if (drivers.first) {
-		if (G.f & G_DEBUG) printf("\thas drivers \n");
+		if (G.debug & G_DEBUG) printf("\thas drivers\n");
 		/* add drivers to end of driver stack */
 		BLI_movelisttolist(&adt->drivers, &drivers);
 	}
@@ -1572,7 +1577,7 @@ static void action_to_animdata (ID *id, bAction *act)
 	/* check if we need to set this Action as the AnimData's action */
 	if (adt->action == NULL) {
 		/* set this Action as AnimData's Action */
-		if (G.f & G_DEBUG) printf("act_to_adt - set adt action to act \n");
+		if (G.debug & G_DEBUG) printf("act_to_adt - set adt action to act\n");
 		adt->action= act;
 	}
 	
@@ -1681,17 +1686,17 @@ void do_versions_ipos_to_animato(Main *main)
 	ID *id;
 	
 	if (main == NULL) {
-		printf("Argh! Main is NULL in do_versions_ipos_to_animato() \n");
+		printf("Argh! Main is NULL in do_versions_ipos_to_animato()\n");
 		return;
 	}
 		
 	/* only convert if version is right */
 	if (main->versionfile >= 250) {
-		printf("WARNING: Animation data too new to convert (Version %d) \n", main->versionfile);
+		printf("WARNING: Animation data too new to convert (Version %d)\n", main->versionfile);
 		return;
 	}
-	else if (G.f & G_DEBUG)
-		printf("INFO: Converting to Animato... \n");
+	else if (G.debug & G_DEBUG)
+		printf("INFO: Converting to Animato...\n");
 		
 	/* ----------- Animation Attached to Data -------------- */
 	
@@ -1702,7 +1707,7 @@ void do_versions_ipos_to_animato(Main *main)
 		bConstraint *con;
 		bConstraintChannel *conchan, *conchann;
 		
-		if (G.f & G_DEBUG) printf("\tconverting ob %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting ob %s\n", id->name+2);
 		
 		/* check if object has any animation data */
 		if (ob->nlastrips.first) {
@@ -1827,7 +1832,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->key.first; id; id= id->next) {
 		Key *key= (Key *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting key %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting key %s\n", id->name+2);
 		
 		/* we're only interested in the IPO 
 		 * NOTE: for later, it might be good to port these over to Object instead, as many of these
@@ -1852,7 +1857,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->mat.first; id; id= id->next) {
 		Material *ma= (Material *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting material %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting material %s\n", id->name+2);
 		
 		/* we're only interested in the IPO */
 		if (ma->ipo) {
@@ -1874,7 +1879,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->world.first; id; id= id->next) {
 		World *wo= (World *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting world %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting world %s\n", id->name+2);
 		
 		/* we're only interested in the IPO */
 		if (wo->ipo) {
@@ -1905,8 +1910,8 @@ void do_versions_ipos_to_animato(Main *main)
 				IpoCurve *icu = (seq->ipo) ? seq->ipo->curve.first : NULL;
 				short adrcode = SEQ_FAC1;
 				
-				if (G.f & G_DEBUG) 
-					printf("\tconverting sequence strip %s \n", seq->name+2);
+				if (G.debug & G_DEBUG)
+					printf("\tconverting sequence strip %s\n", seq->name+2);
 				
 				if (ELEM(NULL, seq->ipo, icu)) {
 					seq->flag |= SEQ_USE_EFFECT_DEFAULT_FADE;
@@ -1914,9 +1919,9 @@ void do_versions_ipos_to_animato(Main *main)
 				}
 				
 				/* patch adrcode, so that we can map
-				   to different DNA variables later 
-				   (semi-hack (tm) )
-				*/
+				 * to different DNA variables later 
+				 * (semi-hack (tm) )
+				 */
 				switch (seq->type) {
 					case SEQ_IMAGE:
 					case SEQ_META:
@@ -1949,7 +1954,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->tex.first; id; id= id->next) {
 		Tex *te= (Tex *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting texture %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting texture %s\n", id->name+2);
 		
 		/* we're only interested in the IPO */
 		if (te->ipo) {
@@ -1971,7 +1976,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->camera.first; id; id= id->next) {
 		Camera *ca= (Camera *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting camera %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting camera %s\n", id->name+2);
 		
 		/* we're only interested in the IPO */
 		if (ca->ipo) {
@@ -1993,7 +1998,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->lamp.first; id; id= id->next) {
 		Lamp *la= (Lamp *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting lamp %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting lamp %s\n", id->name+2);
 		
 		/* we're only interested in the IPO */
 		if (la->ipo) {
@@ -2015,7 +2020,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->curve.first; id; id= id->next) {
 		Curve *cu= (Curve *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting curve %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting curve %s\n", id->name+2);
 		
 		/* we're only interested in the IPO */
 		if (cu->ipo) {
@@ -2048,7 +2053,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->action.first; id; id= id->next) {
 		bAction *act= (bAction *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting action %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting action %s\n", id->name+2);
 		
 		/* if old action, it will be object-only... */
 		if (act->chanbase.first)
@@ -2062,7 +2067,7 @@ void do_versions_ipos_to_animato(Main *main)
 	for (id= main->ipo.first; id; id= id->next) {
 		Ipo *ipo= (Ipo *)id;
 		
-		if (G.f & G_DEBUG) printf("\tconverting ipo %s \n", id->name+2);
+		if (G.debug & G_DEBUG) printf("\tconverting ipo %s\n", id->name+2);
 		
 		/* most likely this IPO has already been processed, so check if any curves left to convert */
 		if (ipo->curve.first) {
@@ -2082,7 +2087,7 @@ void do_versions_ipos_to_animato(Main *main)
 	/* free unused drivers from actions + ipos */
 	free_fcurves(&drivers);
 	
-	if (G.f & G_DEBUG)
-		printf("INFO: Animato convert done \n");
+	if (G.debug & G_DEBUG)
+		printf("INFO: Animato convert done\n");
 }
 
