@@ -140,7 +140,7 @@ void free_nladata (ListBase *tracks)
 	NlaTrack *nlt, *nltn;
 	
 	/* sanity checks */
-	if ELEM(NULL, tracks, tracks->first)
+	if (ELEM(NULL, tracks, tracks->first))
 		return;
 		
 	/* free tracks one by one */
@@ -221,7 +221,7 @@ void copy_nladata (ListBase *dst, ListBase *src)
 	NlaTrack *nlt, *nlt_d;
 	
 	/* sanity checks */
-	if ELEM(NULL, dst, src)
+	if (ELEM(NULL, dst, src))
 		return;
 		
 	/* clear out the destination list first for precautions... */
@@ -286,7 +286,7 @@ NlaStrip *add_nlastrip (bAction *act)
 	 *	- selected flag to highlight this to the user
 	 *	- auto-blends to ensure that blend in/out values are automatically 
 	 *	  determined by overlaps of strips
-	 *	- (XXX) synchronisation of strip-length in accordance with changes to action-length
+	 *	- (XXX) synchronization of strip-length in accordance with changes to action-length
 	 *	  is not done though, since this should only really happens in editmode for strips now
 	 *	  though this decision is still subject to further review...
 	 */
@@ -319,7 +319,7 @@ NlaStrip *add_nlastrip_to_stack (AnimData *adt, bAction *act)
 	NlaTrack *nlt;
 	
 	/* sanity checks */
-	if ELEM(NULL, adt, act)
+	if (ELEM(NULL, adt, act))
 		return NULL;
 	
 	/* create a new NLA strip */
@@ -352,8 +352,7 @@ NlaStrip *add_nla_soundstrip (Scene *scene, Speaker *speaker)
 	 * otherwise default to length of 10 frames
 	 */
 #ifdef WITH_AUDASPACE
-	if (speaker->sound) 
-	{
+	if (speaker->sound) {
 		AUD_SoundInfo info = AUD_getInfo(speaker->sound->playback_handle);
 		
 		strip->end = (float)ceil((double)info.length * FPS);
@@ -587,7 +586,7 @@ void BKE_nlastrips_sort_strips (ListBase *strips)
 	NlaStrip *strip, *sstrip, *stripn;
 	
 	/* sanity checks */
-	if ELEM(NULL, strips, strips->first)
+	if (ELEM(NULL, strips, strips->first))
 		return;
 	
 	/* we simply perform insertion sort on this list, since it is assumed that per track,
@@ -631,7 +630,7 @@ short BKE_nlastrips_add_strip (ListBase *strips, NlaStrip *strip)
 	short not_added = 1;
 	
 	/* sanity checks */
-	if ELEM(NULL, strips, strip)
+	if (ELEM(NULL, strips, strip))
 		return 0;
 		
 	/* check if any space to add */
@@ -669,7 +668,7 @@ void BKE_nlastrips_make_metas (ListBase *strips, short temp)
 	NlaStrip *strip, *stripn;
 	
 	/* sanity checks */
-	if ELEM(NULL, strips, strips->first)
+	if (ELEM(NULL, strips, strips->first))
 		return;
 	
 	/* group all continuous chains of selected strips into meta-strips */
@@ -720,7 +719,7 @@ void BKE_nlastrips_clear_metastrip (ListBase *strips, NlaStrip *strip)
 	NlaStrip *cs, *csn;
 	
 	/* sanity check */
-	if ELEM(NULL, strips, strip)
+	if (ELEM(NULL, strips, strip))
 		return;
 	
 	/* move each one of the meta-strip's children before the meta-strip
@@ -745,7 +744,7 @@ void BKE_nlastrips_clear_metas (ListBase *strips, short onlySel, short onlyTemp)
 	NlaStrip *strip, *stripn;
 	
 	/* sanity checks */
-	if ELEM(NULL, strips, strips->first)
+	if (ELEM(NULL, strips, strips->first))
 		return;
 	
 	/* remove meta-strips fitting the criteria of the arguments */
@@ -770,7 +769,7 @@ void BKE_nlastrips_clear_metas (ListBase *strips, short onlySel, short onlyTemp)
 short BKE_nlameta_add_strip (NlaStrip *mstrip, NlaStrip *strip)
 {
 	/* sanity checks */
-	if ELEM(NULL, mstrip, strip)
+	if (ELEM(NULL, mstrip, strip))
 		return 0;
 		
 	/* firstly, check if the meta-strip has space for this */
@@ -778,7 +777,7 @@ short BKE_nlameta_add_strip (NlaStrip *mstrip, NlaStrip *strip)
 		return 0;
 		
 	/* check if this would need to be added to the ends of the meta,
-	 * and subsequently, if the neighbouring strips allow us enough room
+	 * and subsequently, if the neighboring strips allow us enough room
 	 */
 	if (strip->start < mstrip->start) {
 		/* check if strip to the left (if it exists) ends before the 
@@ -828,7 +827,7 @@ void BKE_nlameta_flush_transforms (NlaStrip *mstrip)
 	 *	- strip must exist
 	 *	- strip must be a meta-strip with some contents
 	 */
-	if ELEM(NULL, mstrip, mstrip->strips.first)
+	if (ELEM(NULL, mstrip, mstrip->strips.first))
 		return;
 	if (mstrip->type != NLASTRIP_TYPE_META)
 		return;
@@ -841,7 +840,7 @@ void BKE_nlameta_flush_transforms (NlaStrip *mstrip)
 	oEnd= ((NlaStrip *)mstrip->strips.last)->end;
 	offset= mstrip->start - oStart;
 	
-	/* optimisation:
+	/* optimization:
 	 * don't flush if nothing changed yet
 	 *	TODO: maybe we need a flag to say always flush?
 	 */
@@ -900,7 +899,7 @@ NlaTrack *BKE_nlatrack_find_active (ListBase *tracks)
 	NlaTrack *nlt;
 	
 	/* sanity check */
-	if ELEM(NULL, tracks, tracks->first)
+	if (ELEM(NULL, tracks, tracks->first))
 		return NULL;
 		
 	/* try to find the first active track */
@@ -921,7 +920,7 @@ void BKE_nlatrack_solo_toggle (AnimData *adt, NlaTrack *nlt)
 	NlaTrack *nt;
 	
 	/* sanity check */
-	if ELEM(NULL, adt, adt->nla_tracks.first)
+	if (ELEM(NULL, adt, adt->nla_tracks.first))
 		return;
 		
 	/* firstly, make sure 'solo' flag for all tracks is disabled */
@@ -953,7 +952,7 @@ void BKE_nlatrack_set_active (ListBase *tracks, NlaTrack *nlt_a)
 	NlaTrack *nlt;
 	
 	/* sanity check */
-	if ELEM(NULL, tracks, tracks->first)
+	if (ELEM(NULL, tracks, tracks->first))
 		return;
 	
 	/* deactive all the rest */
@@ -991,7 +990,7 @@ short BKE_nlatrack_has_space (NlaTrack *nlt, float start, float end)
 void BKE_nlatrack_sort_strips (NlaTrack *nlt)
 {
 	/* sanity checks */
-	if ELEM(NULL, nlt, nlt->strips.first)
+	if (ELEM(NULL, nlt, nlt->strips.first))
 		return;
 	
 	/* sort the strips with a more generic function */
@@ -1004,7 +1003,7 @@ void BKE_nlatrack_sort_strips (NlaTrack *nlt)
 short BKE_nlatrack_add_strip (NlaTrack *nlt, NlaStrip *strip)
 {
 	/* sanity checks */
-	if ELEM(NULL, nlt, strip)
+	if (ELEM(NULL, nlt, strip))
 		return 0;
 		
 	/* try to add the strip to the track using a more generic function */
@@ -1018,14 +1017,14 @@ short BKE_nlatrack_get_bounds (NlaTrack *nlt, float bounds[2])
 {
 	NlaStrip *strip;
 	
-	/* initialise bounds */
+	/* initialize bounds */
 	if (bounds)
 		bounds[0] = bounds[1] = 0.0f;
 	else
 		return 0;
 	
 	/* sanity checks */
-	if ELEM(NULL, nlt, nlt->strips.first)
+	if (ELEM(NULL, nlt, nlt->strips.first))
 		return 0;
 		
 	/* lower bound is first strip's start frame */
@@ -1048,7 +1047,7 @@ NlaStrip *BKE_nlastrip_find_active (NlaTrack *nlt)
 	NlaStrip *strip;
 	
 	/* sanity check */
-	if ELEM(NULL, nlt, nlt->strips.first)
+	if (ELEM(NULL, nlt, nlt->strips.first))
 		return NULL;
 		
 	/* try to find the first active strip */
@@ -1073,7 +1072,7 @@ void BKE_nlastrip_set_active (AnimData *adt, NlaStrip *strip)
 	
 	/* loop over tracks, deactivating*/
 	for (nlt= adt->nla_tracks.first; nlt; nlt= nlt->next) {
-		for (nls= nlt->strips.first; nls; nls= nls->next)  {
+		for (nls= nlt->strips.first; nls; nls= nls->next) {
 			if (nls != strip)
 				nls->flag &= ~NLASTRIP_FLAG_ACTIVE;
 			else
@@ -1147,7 +1146,7 @@ static short nlastrip_is_first (AnimData *adt, NlaStrip *strip)
 	NlaStrip *ns;
 	
 	/* sanity checks */
-	if ELEM(NULL, adt, strip)
+	if (ELEM(NULL, adt, strip))
 		return 0;
 		
 	/* check if strip has any strips before it */
@@ -1177,7 +1176,7 @@ short BKE_nlatrack_has_animated_strips (NlaTrack *nlt)
 	NlaStrip *strip;
 	
 	/* sanity checks */
-	if ELEM(NULL, nlt, nlt->strips.first)
+	if (ELEM(NULL, nlt, nlt->strips.first))
 		return 0;
 		
 	/* check each strip for F-Curves only (don't care about whether the flags are set) */
@@ -1196,7 +1195,7 @@ short BKE_nlatracks_have_animated_strips (ListBase *tracks)
 	NlaTrack *nlt;
 	
 	/* sanity checks */
-	if ELEM(NULL, tracks, tracks->first)
+	if (ELEM(NULL, tracks, tracks->first))
 		return 0;
 		
 	/* check each track, stopping on the first hit */
@@ -1235,7 +1234,7 @@ void BKE_nlastrip_validate_fcurves (NlaStrip *strip)
 			/* store path - make copy, and store that */
 			fcu->rna_path= BLI_strdupn("influence", 9);
 			
-			// TODO: insert a few keyframes to ensure default behaviour?
+			// TODO: insert a few keyframes to ensure default behavior?
 		}
 	}
 	
@@ -1256,7 +1255,7 @@ void BKE_nlastrip_validate_fcurves (NlaStrip *strip)
 			/* store path - make copy, and store that */
 			fcu->rna_path= BLI_strdupn("strip_time", 10);
 			
-			// TODO: insert a few keyframes to ensure default behaviour?
+			// TODO: insert a few keyframes to ensure default behavior?
 		}
 	}
 }
@@ -1280,7 +1279,7 @@ void BKE_nlastrip_validate_name (AnimData *adt, NlaStrip *strip)
 	NlaTrack *nlt;
 	
 	/* sanity checks */
-	if ELEM(NULL, adt, strip)
+	if (ELEM(NULL, adt, strip))
 		return;
 		
 	/* give strip a default name if none already */
@@ -1377,7 +1376,7 @@ static void BKE_nlastrip_validate_autoblends (NlaTrack *nlt, NlaStrip *nls)
 	float *ns=NULL, *ne=NULL;
 	
 	/* sanity checks */
-	if ELEM(NULL, nls, nlt)
+	if (ELEM(NULL, nls, nlt))
 		return;
 	if ((nlt->prev == NULL) && (nlt->next == NULL))
 		return;
@@ -1395,8 +1394,7 @@ static void BKE_nlastrip_validate_autoblends (NlaTrack *nlt, NlaStrip *nls)
 	 *	  is directly followed/preceeded by another strip, forming an 
 	 *	  'island' of continuous strips
 	 */
-	if ( (ps || ns) && ((nls->prev == NULL) || IS_EQF(nls->prev->end, nls->start)==0) )
-	{
+	if ((ps || ns) && ((nls->prev == NULL) || IS_EQF(nls->prev->end, nls->start)==0)) {
 		/* start overlaps - pick the largest overlap */
 		if ( ((ps && ns) && (*ps > *ns)) || (ps) )
 			nls->blendin= *ps - nls->start;
@@ -1406,8 +1404,7 @@ static void BKE_nlastrip_validate_autoblends (NlaTrack *nlt, NlaStrip *nls)
 	else /* no overlap allowed/needed */
 		nls->blendin= 0.0f;
 		
-	if ( (pe || ne) && ((nls->next == NULL) || IS_EQF(nls->next->start, nls->end)==0) )
-	{
+	if ((pe || ne) && ((nls->next == NULL) || IS_EQF(nls->next->start, nls->end)==0)) {
 		/* end overlaps - pick the largest overlap */
 		if ( ((pe && ne) && (*pe > *ne)) || (pe) )
 			nls->blendout= nls->end - *pe;
@@ -1425,7 +1422,7 @@ void BKE_nla_validate_state (AnimData *adt)
 	NlaTrack *nlt;
 	
 	/* sanity checks */
-	if ELEM(NULL, adt, adt->nla_tracks.first)
+	if (ELEM(NULL, adt, adt->nla_tracks.first))
 		return;
 		
 	/* adjust blending values for auto-blending, and also do an initial pass to find the earliest strip */
@@ -1479,7 +1476,7 @@ void BKE_nla_action_pushdown (AnimData *adt)
 	
 	/* sanity checks */
 	// TODO: need to report the error for this
-	if ELEM(NULL, adt, adt->action) 
+	if (ELEM(NULL, adt, adt->action))
 		return;
 		
 	/* if the action is empty, we also shouldn't try to add to stack, 
@@ -1487,7 +1484,7 @@ void BKE_nla_action_pushdown (AnimData *adt)
 	 */
 	// TODO: what about modifiers?
 	if (action_has_motion(adt->action) == 0) {
-		printf("BKE_nla_action_pushdown(): action has no data \n");
+		printf("BKE_nla_action_pushdown(): action has no data\n");
 		return;
 	}
 	
@@ -1527,7 +1524,7 @@ short BKE_nla_tweakmode_enter (AnimData *adt)
 	NlaStrip *strip, *activeStrip=NULL;
 	
 	/* verify that data is valid */
-	if ELEM(NULL, adt, adt->nla_tracks.first)
+	if (ELEM(NULL, adt, adt->nla_tracks.first))
 		return 0;
 		
 	/* if block is already in tweakmode, just leave, but we should report 
@@ -1578,10 +1575,10 @@ short BKE_nla_tweakmode_enter (AnimData *adt)
 		}
 	}
 	
-	if ELEM3(NULL, activeTrack, activeStrip, activeStrip->act) {
-		if (G.f & G_DEBUG) {
-			printf("NLA tweakmode enter - neither active requirement found \n");
-			printf("\tactiveTrack = %p, activeStrip = %p \n", (void *)activeTrack, (void *)activeStrip);
+	if (ELEM3(NULL, activeTrack, activeStrip, activeStrip->act)) {
+		if (G.debug & G_DEBUG) {
+			printf("NLA tweakmode enter - neither active requirement found\n");
+			printf("\tactiveTrack = %p, activeStrip = %p\n", (void *)activeTrack, (void *)activeStrip);
 		}
 		return 0;
 	}
@@ -1628,7 +1625,7 @@ void BKE_nla_tweakmode_exit (AnimData *adt)
 	NlaTrack *nlt;
 	
 	/* verify that data is valid */
-	if ELEM(NULL, adt, adt->nla_tracks.first)
+	if (ELEM(NULL, adt, adt->nla_tracks.first))
 		return;
 		
 	/* hopefully the flag is correct - skip if not on */
@@ -1670,7 +1667,7 @@ static void UNUSED_FUNCTION(BKE_nla_bake) (Scene *scene, ID *UNUSED(id), AnimDat
 	 *	1) Scene and AnimData must be provided 
 	 *	2) there must be tracks to merge...
 	 */
-	if ELEM3(NULL, scene, adt, adt->nla_tracks.first)
+	if (ELEM3(NULL, scene, adt, adt->nla_tracks.first))
 		return;
 	
 	/* if animdata currently has an action, 'push down' this onto the stack first */
