@@ -170,7 +170,7 @@ static float gaussRand (void)
 }
 
 /**
- * Som usefull functions
+ * Some useful functions
  * */
 MINLINE float lerp(float a,float b,float f)
 {
@@ -355,7 +355,8 @@ void BKE_ocean_eval_uv(struct Ocean *oc, struct OceanResult *ocr, float u,float
 		if (oc->_do_chop) {
 			ocr->disp[0] = BILERP(oc->_disp_x);
 			ocr->disp[2] = BILERP(oc->_disp_z);
-		} else {
+		}
+		else {
 			ocr->disp[0] = 0.0;
 			ocr->disp[2] = 0.0;
 		}
@@ -422,7 +423,7 @@ void BKE_ocean_eval_uv_catrom(struct Ocean *oc, struct OceanResult *ocr, float u
 	{
 		if (oc->_do_disp_y)
 		{
-			ocr->disp[1] = INTERP(oc->_disp_y) ;
+			ocr->disp[1] = INTERP(oc->_disp_y);
 		}
 		if (oc->_do_normals)
 		{
@@ -435,8 +436,7 @@ void BKE_ocean_eval_uv_catrom(struct Ocean *oc, struct OceanResult *ocr, float u
 			ocr->disp[0] = INTERP(oc->_disp_x);
 			ocr->disp[2] = INTERP(oc->_disp_z);
 		}
-		else
-		{
+		else {
 			ocr->disp[0] = 0.0;
 			ocr->disp[2] = 0.0;
 		}
@@ -479,8 +479,7 @@ void BKE_ocean_eval_ij(struct Ocean *oc, struct OceanResult *ocr, int i,int j)
 		ocr->disp[0] = oc->_disp_x[i*oc->_N+j];
 		ocr->disp[2] = oc->_disp_z[i*oc->_N+j];
 	}
-	else
-	{
+	else {
 		ocr->disp[0] = 0.0f;
 		ocr->disp[2] = 0.0f;
 	}
@@ -726,14 +725,14 @@ void BKE_simulate_ocean(struct Ocean *o, float t, float scale, float chop_amount
 				}
 				fftw_execute(o->_N_z_plan);
 
-			/*for ( i = 0 ; i  < o->_M ; ++i)
-			 {
-			 for ( j  = 0 ; j  < o->_N ; ++j)
-			 {
-			 o->_N_y[i*o->_N+j] = 1.0f/scale;
-			 }
-			 }
-			 (MEM01)*/
+#if 0
+				for ( i = 0 ; i  < o->_M ; ++i) {
+					for ( j  = 0 ; j  < o->_N ; ++j) {
+						o->_N_y[i*o->_N+j] = 1.0f/scale;
+					}
+				}
+				(MEM01)
+#endif
 			o->_N_y = 1.0f/scale;
 			}
 		} // section 8
@@ -762,7 +761,7 @@ static void set_height_normalize_factor(struct Ocean *oc)
 	{
 		for (j = 0; j < oc->_N; ++j)
 		{
-			if( max_h < fabsf(oc->_disp_y[i*oc->_N+j]))
+			if ( max_h < fabsf(oc->_disp_y[i*oc->_N+j]))
 			{
 				max_h = fabsf(oc->_disp_y[i*oc->_N+j]);
 			}
@@ -869,12 +868,12 @@ void BKE_init_ocean(struct Ocean* o, int M,int N, float Lx, float Lz, float V, f
 	o->_fft_in = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in");
 	o->_htilda = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_htilda");
 
-	if (o->_do_disp_y){
+	if (o->_do_disp_y) {
 		o->_disp_y = (double*) MEM_mallocN(o->_M * o->_N * sizeof(double), "ocean_disp_y");
 		o->_disp_y_plan = fftw_plan_dft_c2r_2d(o->_M,o->_N, o->_fft_in, o->_disp_y, FFTW_ESTIMATE);
 	}
 
-	if (o->_do_normals){
+	if (o->_do_normals) {
 		o->_fft_in_nx = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_nx");
 		o->_fft_in_nz = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_nz");
 
@@ -886,7 +885,7 @@ void BKE_init_ocean(struct Ocean* o, int M,int N, float Lx, float Lz, float V, f
 		o->_N_z_plan = fftw_plan_dft_c2r_2d(o->_M,o->_N, o->_fft_in_nz, o->_N_z, FFTW_ESTIMATE);
 	}
 
-	if (o->_do_chop){
+	if (o->_do_chop) {
 		o->_fft_in_x = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_x");
 		o->_fft_in_z = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_z");
 
@@ -896,7 +895,7 @@ void BKE_init_ocean(struct Ocean* o, int M,int N, float Lx, float Lz, float V, f
 		o->_disp_x_plan = fftw_plan_dft_c2r_2d(o->_M,o->_N, o->_fft_in_x, o->_disp_x, FFTW_ESTIMATE);
 		o->_disp_z_plan = fftw_plan_dft_c2r_2d(o->_M,o->_N, o->_fft_in_z, o->_disp_z, FFTW_ESTIMATE);
 	}
-	if (o->_do_jacobian){
+	if (o->_do_jacobian) {
 		o->_fft_in_jxx = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_jxx");
 		o->_fft_in_jzz = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_jzz");
 		o->_fft_in_jxz = (fftw_complex*) MEM_mallocN(o->_M * (1+o->_N/2) * sizeof(fftw_complex), "ocean_fft_in_jxz");
@@ -918,7 +917,7 @@ void BKE_init_ocean(struct Ocean* o, int M,int N, float Lx, float Lz, float V, f
 
 void BKE_free_ocean_data(struct Ocean *oc)
 {
-	if(!oc) return;
+	if (!oc) return;
 
 	BLI_rw_mutex_lock(&oc->oceanmutex, THREAD_LOCK_WRITE);
 
@@ -965,7 +964,7 @@ void BKE_free_ocean_data(struct Ocean *oc)
 	if (oc->_fft_in)
 		MEM_freeN(oc->_fft_in);
 
-	/* check that ocean data has been initialised */
+	/* check that ocean data has been initialized */
 	if (oc->_htilda) {
 		MEM_freeN(oc->_htilda);
 		MEM_freeN(oc->_k);
@@ -980,7 +979,7 @@ void BKE_free_ocean_data(struct Ocean *oc)
 
 void BKE_free_ocean(struct Ocean *oc)
 {
-	if(!oc) return;
+	if (!oc) return;
 
 	BKE_free_ocean_data(oc);
 	BLI_rw_mutex_end(&oc->oceanmutex);
@@ -1174,18 +1173,18 @@ void BKE_simulate_ocean_cache(struct OceanCache *och, int frame)
 
 	cache_filename(string, och->bakepath, och->relbase, frame, CACHE_TYPE_DISPLACE);
 	och->ibufs_disp[f] = IMB_loadiffname(string, 0);
-	//if (och->ibufs_disp[f] == NULL) printf("error loading %s \n", string);
-	//else printf("loaded cache %s \n", string);
+	//if (och->ibufs_disp[f] == NULL) printf("error loading %s\n", string);
+	//else printf("loaded cache %s\n", string);
 
 	cache_filename(string, och->bakepath, och->relbase, frame, CACHE_TYPE_FOAM);
 	och->ibufs_foam[f] = IMB_loadiffname(string, 0);
-	//if (och->ibufs_foam[f] == NULL) printf("error loading %s \n", string);
-	//else printf("loaded cache %s \n", string);
+	//if (och->ibufs_foam[f] == NULL) printf("error loading %s\n", string);
+	//else printf("loaded cache %s\n", string);
 
 	cache_filename(string, och->bakepath, och->relbase, frame, CACHE_TYPE_NORMAL);
 	och->ibufs_norm[f] = IMB_loadiffname(string, 0);
-	//if (och->ibufs_norm[f] == NULL) printf("error loading %s \n", string);
-	//else printf("loaded cache %s \n", string);
+	//if (och->ibufs_norm[f] == NULL) printf("error loading %s\n", string);
+	//else printf("loaded cache %s\n", string);
 }
 
 
@@ -1260,12 +1259,12 @@ void BKE_bake_ocean(struct Ocean *o, struct OceanCache *och, void (*update_cb)(v
 					// break up the foam where height (Y) is low (wave valley),
 					// and X and Z displacement is greatest
 
-					/*
+#if 0
 					vec[0] = ocr.disp[0];
 					vec[1] = ocr.disp[2];
 					hor_stretch = len_v2(vec);
 					CLAMP(hor_stretch, 0.0, 1.0);
-					*/
+#endif
 
 					neg_disp = ocr.disp[1] < 0.0f ? 1.0f+ocr.disp[1] : 1.0f;
 					neg_disp = neg_disp < 0.0f ? 0.0f : neg_disp;
@@ -1301,18 +1300,18 @@ void BKE_bake_ocean(struct Ocean *o, struct OceanCache *och, void (*update_cb)(v
 
 		/* write the images */
 		cache_filename(string, och->bakepath, och->relbase, f, CACHE_TYPE_DISPLACE);
-		if(0 == BKE_write_ibuf(ibuf_disp, string, &imf))
+		if (0 == BKE_write_ibuf(ibuf_disp, string, &imf))
 			printf("Cannot save Displacement File Output to %s\n", string);
 
 		if (o->_do_jacobian) {
 			cache_filename(string, och->bakepath, och->relbase,  f, CACHE_TYPE_FOAM);
-			if(0 == BKE_write_ibuf(ibuf_foam, string, &imf))
+			if (0 == BKE_write_ibuf(ibuf_foam, string, &imf))
 				printf("Cannot save Foam File Output to %s\n", string);
 		}
 
 		if (o->_do_normals) {
 			cache_filename(string, och->bakepath,  och->relbase, f, CACHE_TYPE_NORMAL);
-			if(0 == BKE_write_ibuf(ibuf_normal, string, &imf))
+			if (0 == BKE_write_ibuf(ibuf_normal, string, &imf))
 				printf("Cannot save Normal File Output to %s\n", string);
 		}
 
@@ -1391,7 +1390,7 @@ void BKE_free_ocean_data(struct Ocean *UNUSED(oc))
 
 void BKE_free_ocean(struct Ocean *oc)
 {
-	if(!oc) return;
+	if (!oc) return;
 	MEM_freeN(oc);
 }
 
