@@ -86,12 +86,12 @@
 void free_avicodecdata(AviCodecData *acd)
 {
 	if (acd) {
-		if (acd->lpFormat){
+		if (acd->lpFormat) {
 			MEM_freeN(acd->lpFormat);
 			acd->lpFormat = NULL;
 			acd->cbFormat = 0;
 		}
-		if (acd->lpParms){
+		if (acd->lpParms) {
 			MEM_freeN(acd->lpParms);
 			acd->lpParms = NULL;
 			acd->cbParms = 0;
@@ -102,7 +102,7 @@ void free_avicodecdata(AviCodecData *acd)
 void free_qtcodecdata(QuicktimeCodecData *qcd)
 {
 	if (qcd) {
-		if (qcd->cdParms){
+		if (qcd->cdParms) {
 			MEM_freeN(qcd->cdParms);
 			qcd->cdParms = NULL;
 			qcd->cdSize = 0;
@@ -116,13 +116,19 @@ Scene *copy_scene(Scene *sce, int type)
 	ToolSettings *ts;
 	Base *base, *obase;
 	
-	if(type == SCE_COPY_EMPTY) {
+	if (type == SCE_COPY_EMPTY) {
 		ListBase lb;
 		scen= add_scene(sce->id.name+2);
 		
 		lb= scen->r.layers;
 		scen->r= sce->r;
 		scen->r.layers= lb;
+		scen->unit= sce->unit;
+		scen->physics_settings= sce->physics_settings;
+		scen->gm= sce->gm;
+		scen->audio= sce->audio;
+
+		MEM_freeN(scen->toolsettings);
 	}
 	else {
 		scen= copy_libblock(&sce->id);
@@ -137,72 +143,73 @@ Scene *copy_scene(Scene *sce, int type)
 		scen->ed= NULL;
 		scen->theDag= NULL;
 		scen->obedit= NULL;
-		scen->toolsettings= MEM_dupallocN(sce->toolsettings);
 		scen->stats= NULL;
 		scen->fps_info= NULL;
 
-		ts= scen->toolsettings;
-		if(ts) {
-			if(ts->vpaint) {
-				ts->vpaint= MEM_dupallocN(ts->vpaint);
-				ts->vpaint->paintcursor= NULL;
-				ts->vpaint->vpaint_prev= NULL;
-				ts->vpaint->wpaint_prev= NULL;
-				copy_paint(&ts->vpaint->paint, &ts->vpaint->paint);
-			}
-			if(ts->wpaint) {
-				ts->wpaint= MEM_dupallocN(ts->wpaint);
-				ts->wpaint->paintcursor= NULL;
-				ts->wpaint->vpaint_prev= NULL;
-				ts->wpaint->wpaint_prev= NULL;
-				copy_paint(&ts->wpaint->paint, &ts->wpaint->paint);
-			}
-			if(ts->sculpt) {
-				ts->sculpt= MEM_dupallocN(ts->sculpt);
-				copy_paint(&ts->sculpt->paint, &ts->sculpt->paint);
-			}
-
-			copy_paint(&ts->imapaint.paint, &ts->imapaint.paint);
-			ts->imapaint.paintcursor= NULL;
-
-			ts->particle.paintcursor= NULL;
-		}
-		
 		BLI_duplicatelist(&(scen->markers), &(sce->markers));
 		BLI_duplicatelist(&(scen->transform_spaces), &(sce->transform_spaces));
 		BLI_duplicatelist(&(scen->r.layers), &(sce->r.layers));
 		BKE_keyingsets_copy(&(scen->keyingsets), &(sce->keyingsets));
 
-		if(sce->nodetree) {
+		if (sce->nodetree) {
 			scen->nodetree= ntreeCopyTree(sce->nodetree); /* copies actions */
 			ntreeSwitchID(scen->nodetree, &sce->id, &scen->id);
 		}
 
 		obase= sce->base.first;
 		base= scen->base.first;
-		while(base) {
+		while (base) {
 			id_us_plus(&base->object->id);
-			if(obase==sce->basact) scen->basact= base;
+			if (obase==sce->basact) scen->basact= base;
 	
 			obase= obase->next;
 			base= base->next;
 		}
 	}
+
+	/* tool settings */
+	scen->toolsettings= MEM_dupallocN(sce->toolsettings);
+
+	ts= scen->toolsettings;
+	if (ts) {
+		if (ts->vpaint) {
+			ts->vpaint= MEM_dupallocN(ts->vpaint);
+			ts->vpaint->paintcursor= NULL;
+			ts->vpaint->vpaint_prev= NULL;
+			ts->vpaint->wpaint_prev= NULL;
+			copy_paint(&ts->vpaint->paint, &ts->vpaint->paint);
+		}
+		if (ts->wpaint) {
+			ts->wpaint= MEM_dupallocN(ts->wpaint);
+			ts->wpaint->paintcursor= NULL;
+			ts->wpaint->vpaint_prev= NULL;
+			ts->wpaint->wpaint_prev= NULL;
+			copy_paint(&ts->wpaint->paint, &ts->wpaint->paint);
+		}
+		if (ts->sculpt) {
+			ts->sculpt= MEM_dupallocN(ts->sculpt);
+			copy_paint(&ts->sculpt->paint, &ts->sculpt->paint);
+		}
+
+		copy_paint(&ts->imapaint.paint, &ts->imapaint.paint);
+		ts->imapaint.paintcursor= NULL;
+		ts->particle.paintcursor= NULL;
+	}
 	
 	/* make a private copy of the avicodecdata */
-	if(sce->r.avicodecdata) {
+	if (sce->r.avicodecdata) {
 		scen->r.avicodecdata = MEM_dupallocN(sce->r.avicodecdata);
 		scen->r.avicodecdata->lpFormat = MEM_dupallocN(scen->r.avicodecdata->lpFormat);
 		scen->r.avicodecdata->lpParms = MEM_dupallocN(scen->r.avicodecdata->lpParms);
 	}
 	
 	/* make a private copy of the qtcodecdata */
-	if(sce->r.qtcodecdata) {
+	if (sce->r.qtcodecdata) {
 		scen->r.qtcodecdata = MEM_dupallocN(sce->r.qtcodecdata);
 		scen->r.qtcodecdata->cdParms = MEM_dupallocN(scen->r.qtcodecdata->cdParms);
 	}
 	
-	if(sce->r.ffcodecdata.properties) { /* intentionally check scen not sce. */
+	if (sce->r.ffcodecdata.properties) { /* intentionally check scen not sce. */
 		scen->r.ffcodecdata.properties= IDP_CopyProperty(sce->r.ffcodecdata.properties);
 	}
 
@@ -210,7 +217,7 @@ Scene *copy_scene(Scene *sce, int type)
 	 * are done outside of blenkernel with ED_objects_single_users! */
 
 	/*  camera */
-	if(type == SCE_COPY_LINK_DATA || type == SCE_COPY_FULL) {
+	if (type == SCE_COPY_LINK_DATA || type == SCE_COPY_FULL) {
 		ID_NEW(scen->camera);
 	}
 	
@@ -218,15 +225,15 @@ Scene *copy_scene(Scene *sce, int type)
 	sound_create_scene(scen);
 
 	/* world */
-	if(type == SCE_COPY_FULL) {
+	if (type == SCE_COPY_FULL) {
 		BKE_copy_animdata_id_action((ID *)scen);
-		if(scen->world) {
+		if (scen->world) {
 			id_us_plus((ID *)scen->world);
 			scen->world= copy_world(scen->world);
 			BKE_copy_animdata_id_action((ID *)scen->world);
 		}
 
-		if(sce->ed) {
+		if (sce->ed) {
 			scen->ed= MEM_callocN( sizeof(Editing), "addseq");
 			scen->ed->seqbasep= &scen->ed->seqbase;
 			seqbase_dupli_recursive(sce, scen, &scen->ed->seqbase, &sce->ed->seqbase, SEQ_DUPE_ALL);
@@ -242,15 +249,15 @@ void free_scene(Scene *sce)
 	Base *base;
 
 	base= sce->base.first;
-	while(base) {
+	while (base) {
 		base->object->id.us--;
 		base= base->next;
 	}
 	/* do not free objects! */
 	
-	if(sce->gpd) {
+	if (sce->gpd) {
 #if 0   // removed since this can be invalid memory when freeing everything
-		// since the grease pencil data is free'd before the scene.
+		// since the grease pencil data is freed before the scene.
 		// since grease pencil data is not (yet?), shared between objects
 		// its probably safe not to do this, some save and reload will free this.
 		sce->gpd->id.us--;
@@ -284,20 +291,20 @@ void free_scene(Scene *sce)
 	BLI_freelistN(&sce->transform_spaces);
 	BLI_freelistN(&sce->r.layers);
 	
-	if(sce->toolsettings) {
-		if(sce->toolsettings->vpaint) {
+	if (sce->toolsettings) {
+		if (sce->toolsettings->vpaint) {
 			free_paint(&sce->toolsettings->vpaint->paint);
 			MEM_freeN(sce->toolsettings->vpaint);
 		}
-		if(sce->toolsettings->wpaint) {
+		if (sce->toolsettings->wpaint) {
 			free_paint(&sce->toolsettings->wpaint->paint);
 			MEM_freeN(sce->toolsettings->wpaint);
 		}
-		if(sce->toolsettings->sculpt) {
+		if (sce->toolsettings->sculpt) {
 			free_paint(&sce->toolsettings->sculpt->paint);
 			MEM_freeN(sce->toolsettings->sculpt);
 		}
-		if(sce->toolsettings->uvsculpt) {
+		if (sce->toolsettings->uvsculpt) {
 			free_paint(&sce->toolsettings->uvsculpt->paint);
 			MEM_freeN(sce->toolsettings->uvsculpt);
 		}
@@ -312,14 +319,14 @@ void free_scene(Scene *sce)
 		MEM_freeN(sce->theDag);
 	}
 	
-	if(sce->nodetree) {
+	if (sce->nodetree) {
 		ntreeFreeTree(sce->nodetree);
 		MEM_freeN(sce->nodetree);
 	}
 
-	if(sce->stats)
+	if (sce->stats)
 		MEM_freeN(sce->stats);
-	if(sce->fps_info)
+	if (sce->fps_info)
 		MEM_freeN(sce->fps_info);
 
 	sound_destroy_scene(sce);
@@ -396,10 +403,10 @@ Scene *add_scene(const char *name)
 	sce->r.simplify_shadowsamples= 16;
 	sce->r.simplify_aosss= 1.0f;
 
-	sce->r.border.xmin= 0.0f;
-	sce->r.border.ymin= 0.0f;
-	sce->r.border.xmax= 1.0f;
-	sce->r.border.ymax= 1.0f;
+	sce->r.border.xmin = 0.0f;
+	sce->r.border.ymin = 0.0f;
+	sce->r.border.xmax = 1.0f;
+	sce->r.border.ymax = 1.0f;
 	
 	sce->toolsettings = MEM_callocN(sizeof(struct ToolSettings),"Tool Settings Struct");
 	sce->toolsettings->cornertype=1;
@@ -411,7 +418,6 @@ Scene *add_scene(const char *name)
 	sce->toolsettings->segments = 32;
 	sce->toolsettings->rings = 32;
 	sce->toolsettings->vertices = 32;
-	sce->toolsettings->editbutflag = 1;
 	sce->toolsettings->uvcalc_radius = 1.0f;
 	sce->toolsettings->uvcalc_cubesize = 1.0f;
 	sce->toolsettings->uvcalc_mapdir = 1;
@@ -458,7 +464,7 @@ Scene *add_scene(const char *name)
 	pset->draw_step= 2;
 	pset->fade_frames= 2;
 	pset->selectmode= SCE_SELECT_PATH;
-	for(a=0; a<PE_TOT_BRUSH; a++) {
+	for (a=0; a<PE_TOT_BRUSH; a++) {
 		pset->brush[a].strength= 0.5;
 		pset->brush[a].size= 50;
 		pset->brush[a].step= 10;
@@ -543,8 +549,8 @@ Base *object_in_scene(Object *ob, Scene *sce)
 	Base *base;
 	
 	base= sce->base.first;
-	while(base) {
-		if(base->object == ob) return base;
+	while (base) {
+		if (base->object == ob) return base;
 		base= base->next;
 	}
 	return NULL;
@@ -563,18 +569,18 @@ void set_scene_bg(Main *bmain, Scene *scene)
 	scene_check_setscene(bmain, scene);
 	
 	/* can happen when switching modes in other scenes */
-	if(scene->obedit && !(scene->obedit->mode & OB_MODE_EDIT))
+	if (scene->obedit && !(scene->obedit->mode & OB_MODE_EDIT))
 		scene->obedit= NULL;
 
 	/* deselect objects (for dataselect) */
-	for(ob= bmain->object.first; ob; ob= ob->id.next)
+	for (ob= bmain->object.first; ob; ob= ob->id.next)
 		ob->flag &= ~(SELECT|OB_FROMGROUP);
 
 	/* group flags again */
-	for(group= bmain->group.first; group; group= group->id.next) {
+	for (group= bmain->group.first; group; group= group->id.next) {
 		go= group->gobject.first;
-		while(go) {
-			if(go->ob) go->ob->flag |= OB_FROMGROUP;
+		while (go) {
+			if (go->ob) go->ob->flag |= OB_FROMGROUP;
 			go= go->next;
 		}
 	}
@@ -583,12 +589,12 @@ void set_scene_bg(Main *bmain, Scene *scene)
 	DAG_scene_sort(bmain, scene);
 	
 	/* ensure dags are built for sets */
-	for(sce= scene->set; sce; sce= sce->set)
-		if(sce->theDag==NULL)
+	for (sce= scene->set; sce; sce= sce->set)
+		if (sce->theDag==NULL)
 			DAG_scene_sort(bmain, sce);
 
 	/* copy layers and flags from bases to objects */
-	for(base= scene->base.first; base; base= base->next) {
+	for (base= scene->base.first; base; base= base->next) {
 		ob= base->object;
 		ob->lay= base->lay;
 		
@@ -598,7 +604,7 @@ void set_scene_bg(Main *bmain, Scene *scene)
 		base->flag |= flag;
 		
 		/* not too nice... for recovering objects with lost data */
-		//if(ob->pose==NULL) base->flag &= ~OB_POSEMODE;
+		//if (ob->pose==NULL) base->flag &= ~OB_POSEMODE;
 		ob->flag= base->flag;
 		
 		ob->ctime= -1234567.0;	/* force ipo to be calculated later */
@@ -610,7 +616,7 @@ void set_scene_bg(Main *bmain, Scene *scene)
 Scene *set_scene_name(Main *bmain, const char *name)
 {
 	Scene *sce= (Scene *)find_id("SC", name);
-	if(sce) {
+	if (sce) {
 		set_scene_bg(bmain, sce);
 		printf("Scene switch: '%s' in file: '%s'\n", name, G.main->name);
 		return sce;
@@ -626,8 +632,8 @@ void unlink_scene(Main *bmain, Scene *sce, Scene *newsce)
 	bScreen *sc;
 
 	/* check all sets */
-	for(sce1= bmain->scene.first; sce1; sce1= sce1->id.next)
-		if(sce1->set == sce)
+	for (sce1= bmain->scene.first; sce1; sce1= sce1->id.next)
+		if (sce1->set == sce)
 			sce1->set= NULL;
 	
 	/* check all sequences */
@@ -637,8 +643,8 @@ void unlink_scene(Main *bmain, Scene *sce, Scene *newsce)
 	clear_scene_in_nodes(bmain, sce);
 	
 	/* al screens */
-	for(sc= bmain->screen.first; sc; sc= sc->id.next)
-		if(sc->scene == sce)
+	for (sc= bmain->screen.first; sc; sc= sc->id.next)
+		if (sc->scene == sce)
 			sc->scene= newsce;
 
 	free_libblock(&bmain->scene, sce);
@@ -655,14 +661,14 @@ int next_object(Scene **scene, int val, Base **base, Object **ob)
 	int run_again=1;
 	
 	/* init */
-	if(val==0) {
+	if (val==0) {
 		fase= F_START;
 		dupob= NULL;
 		
 		/* XXX particle systems with metas+dupligroups call this recursively */
 		/* see bug #18725 */
-		if(in_next_object) {
-			printf("ERROR: MetaBall generation called recursively, not supported\n");
+		if (in_next_object) {
+			printf("ERROR: Metaball generation called recursively, not supported\n");
 			
 			return F_ERROR;
 		}
@@ -671,21 +677,21 @@ int next_object(Scene **scene, int val, Base **base, Object **ob)
 		in_next_object= 1;
 		
 		/* run_again is set when a duplilist has been ended */
-		while(run_again) {
+		while (run_again) {
 			run_again= 0;
 
 			/* the first base */
-			if(fase==F_START) {
+			if (fase==F_START) {
 				*base= (*scene)->base.first;
-				if(*base) {
+				if (*base) {
 					*ob= (*base)->object;
 					fase= F_SCENE;
 				}
 				else {
 					/* exception: empty scene */
-					while((*scene)->set) {
+					while ((*scene)->set) {
 						(*scene)= (*scene)->set;
-						if((*scene)->base.first) {
+						if ((*scene)->base.first) {
 							*base= (*scene)->base.first;
 							*ob= (*base)->object;
 							fase= F_SCENE;
@@ -695,15 +701,15 @@ int next_object(Scene **scene, int val, Base **base, Object **ob)
 				}
 			}
 			else {
-				if(*base && fase!=F_DUPLI) {
+				if (*base && fase!=F_DUPLI) {
 					*base= (*base)->next;
-					if(*base) *ob= (*base)->object;
+					if (*base) *ob= (*base)->object;
 					else {
-						if(fase==F_SCENE) {
+						if (fase==F_SCENE) {
 							/* (*scene) is finished, now do the set */
-							while((*scene)->set) {
+							while ((*scene)->set) {
 								(*scene)= (*scene)->set;
-								if((*scene)->base.first) {
+								if ((*scene)->base.first) {
 									*base= (*scene)->base.first;
 									*ob= (*base)->object;
 									break;
@@ -714,25 +720,25 @@ int next_object(Scene **scene, int val, Base **base, Object **ob)
 				}
 			}
 			
-			if(*base == NULL) fase= F_START;
+			if (*base == NULL) fase= F_START;
 			else {
-				if(fase!=F_DUPLI) {
-					if( (*base)->object->transflag & OB_DUPLI) {
+				if (fase!=F_DUPLI) {
+					if ( (*base)->object->transflag & OB_DUPLI) {
 						/* groups cannot be duplicated for mballs yet, 
-						this enters eternal loop because of 
-						makeDispListMBall getting called inside of group_duplilist */
-						if((*base)->object->dup_group == NULL) {
+						 * this enters eternal loop because of 
+						 * makeDispListMBall getting called inside of group_duplilist */
+						if ((*base)->object->dup_group == NULL) {
 							duplilist= object_duplilist((*scene), (*base)->object);
 							
 							dupob= duplilist->first;
 
-							if(!dupob)
+							if (!dupob)
 								free_object_duplilist(duplilist);
 						}
 					}
 				}
 				/* handle dupli's */
-				if(dupob) {
+				if (dupob) {
 					
 					copy_m4_m4(dupob->ob->obmat, dupob->mat);
 					
@@ -742,11 +748,11 @@ int next_object(Scene **scene, int val, Base **base, Object **ob)
 					
 					dupob= dupob->next;
 				}
-				else if(fase==F_DUPLI) {
+				else if (fase==F_DUPLI) {
 					fase= F_SCENE;
 					(*base)->flag &= ~OB_FROMDUPLI;
 					
-					for(dupob= duplilist->first; dupob; dupob= dupob->next) {
+					for (dupob= duplilist->first; dupob; dupob= dupob->next) {
 						copy_m4_m4(dupob->ob->obmat, dupob->omat);
 					}
 					
@@ -757,10 +763,12 @@ int next_object(Scene **scene, int val, Base **base, Object **ob)
 			}
 		}
 	}
-	
-	/* if(ob && *ob) {
+
+#if 0
+	if (ob && *ob) {
 		printf("Scene: '%s', '%s'\n", (*scene)->id.name+2, (*ob)->id.name+2);
-	} */
+	}
+#endif
 
 	/* reset recursion test */
 	in_next_object= 0;
@@ -788,11 +796,11 @@ Object *scene_camera_switch_find(Scene *scene)
 	Object *camera= NULL;
 
 	for (m= scene->markers.first; m; m= m->next) {
-		if(m->camera && (m->camera->restrictflag & OB_RESTRICT_RENDER)==0 && (m->frame <= cfra) && (m->frame > frame)) {
+		if (m->camera && (m->camera->restrictflag & OB_RESTRICT_RENDER)==0 && (m->frame <= cfra) && (m->frame > frame)) {
 			camera= m->camera;
 			frame= m->frame;
 
-			if(frame == cfra)
+			if (frame == cfra)
 				break;
 
 		}
@@ -805,7 +813,7 @@ int scene_camera_switch_update(Scene *scene)
 {
 #ifdef DURIAN_CAMERA_SWITCH
 	Object *camera= scene_camera_switch_find(scene);
-	if(camera) {
+	if (camera) {
 		scene->camera= camera;
 		return 1;
 	}
@@ -836,7 +844,7 @@ char *scene_find_marker_name(Scene *scene, int frame)
 }
 
 /* return the current marker for this frame,
-we can have more then 1 marker per frame, this just returns the first :/ */
+ * we can have more then 1 marker per frame, this just returns the first :/ */
 char *scene_find_last_marker_name(Scene *scene, int frame)
 {
 	TimeMarker *marker, *best_marker = NULL;
@@ -880,8 +888,6 @@ void scene_deselect_all(Scene *sce)
 
 void scene_select_base(Scene *sce, Base *selbase)
 {
-	scene_deselect_all(sce);
-
 	selbase->flag |= SELECT;
 	selbase->object->flag= selbase->flag;
 
@@ -894,15 +900,15 @@ int scene_check_setscene(Main *bmain, Scene *sce)
 	Scene *scene;
 	int a, totscene;
 	
-	if(sce->set==NULL) return 1;
+	if (sce->set==NULL) return 1;
 	
 	totscene= 0;
-	for(scene= bmain->scene.first; scene; scene= scene->id.next)
+	for (scene= bmain->scene.first; scene; scene= scene->id.next)
 		totscene++;
 	
-	for(a=0, scene=sce; scene->set; scene=scene->set, a++) {
+	for (a=0, scene=sce; scene->set; scene=scene->set, a++) {
 		/* more iterations than scenes means we have a cycle */
-		if(a > totscene) {
+		if (a > totscene) {
 			/* the tested scene gets zero'ed, that's typically current scene */
 			sce->set= NULL;
 			return 0;
@@ -973,7 +979,7 @@ static void scene_update_tagged_recursive(Main *bmain, Scene *scene, Scene *scen
 	scene->customdata_mask= scene_parent->customdata_mask;
 
 	/* sets first, we allow per definition current scene to have
-	   dependencies on sets, but not the other way around. */
+	 * dependencies on sets, but not the other way around. */
 	if (scene->set)
 		scene_update_tagged_recursive(bmain, scene->set, scene_parent);
 	
@@ -983,7 +989,7 @@ static void scene_update_tagged_recursive(Main *bmain, Scene *scene, Scene *scen
 		
 		object_handle_update(scene_parent, ob);
 		
-		if(ob->dup_group && (ob->transflag & OB_DUPLIGROUP))
+		if (ob->dup_group && (ob->transflag & OB_DUPLIGROUP))
 			group_handle_recalc_and_update(scene_parent, ob, ob->dup_group);
 			
 		/* always update layer, so that animating layers works */
@@ -1009,10 +1015,10 @@ void scene_update_tagged(Main *bmain, Scene *scene)
 	scene->physics_settings.quick_cache_step= 0;
 
 	/* update all objects: drivers, matrices, displists, etc. flags set
-	   by depgraph or manual, no layer check here, gets correct flushed
-
-	   in the future this should handle updates for all datablocks, not
-	   only objects and scenes. - brecht */
+	 * by depgraph or manual, no layer check here, gets correct flushed
+	 *
+	 * in the future this should handle updates for all datablocks, not
+	 * only objects and scenes. - brecht */
 	scene_update_tagged_recursive(bmain, scene, scene);
 
 	/* extra call here to recalc scene animation (for sequencer) */
@@ -1051,18 +1057,18 @@ void scene_update_for_newframe(Main *bmain, Scene *sce, unsigned int lay)
 	/* clear animation overrides */
 	// XXX TODO...
 
-	for(sce_iter= sce; sce_iter; sce_iter= sce_iter->set) {
-		if(sce_iter->theDag==NULL)
+	for (sce_iter= sce; sce_iter; sce_iter= sce_iter->set) {
+		if (sce_iter->theDag==NULL)
 			DAG_scene_sort(bmain, sce_iter);
 	}
 
 	/* flush recalc flags to dependencies, if we were only changing a frame
-	   this would not be necessary, but if a user or a script has modified
-	   some datablock before scene_update_tagged was called, we need the flush */
+	 * this would not be necessary, but if a user or a script has modified
+	 * some datablock before scene_update_tagged was called, we need the flush */
 	DAG_ids_flush_tagged(bmain);
 
 	/* Following 2 functions are recursive
-	 * so dont call within 'scene_update_tagged_recursive' */
+	 * so don't call within 'scene_update_tagged_recursive' */
 	DAG_scene_update_flags(bmain, sce, lay, TRUE);   // only stuff that moves or needs display still
 
 	/* All 'standard' (i.e. without any dependencies) animation is handled here,
@@ -1092,7 +1098,7 @@ SceneRenderLayer *scene_add_render_layer(Scene *sce, const char *name)
 {
 	SceneRenderLayer *srl;
 
-	if(!name)
+	if (!name)
 		name= "RenderLayer";
 
 	srl= MEM_callocN(sizeof(SceneRenderLayer), "new render layer");
@@ -1128,14 +1134,14 @@ int scene_remove_render_layer(Main *bmain, Scene *scene, SceneRenderLayer *srl)
 
 	scene->r.actlay= 0;
 
-	for(sce = bmain->scene.first; sce; sce = sce->id.next) {
-		if(sce->nodetree) {
+	for (sce = bmain->scene.first; sce; sce = sce->id.next) {
+		if (sce->nodetree) {
 			bNode *node;
-			for(node = sce->nodetree->nodes.first; node; node = node->next) {
-				if(node->type==CMP_NODE_R_LAYERS && (Scene*)node->id==scene) {
-					if(node->custom1==act)
+			for (node = sce->nodetree->nodes.first; node; node = node->next) {
+				if (node->type==CMP_NODE_R_LAYERS && (Scene*)node->id==scene) {
+					if (node->custom1==act)
 						node->custom1= 0;
-					else if(node->custom1>act)
+					else if (node->custom1>act)
 						node->custom1--;
 				}
 			}
@@ -1149,7 +1155,7 @@ int scene_remove_render_layer(Main *bmain, Scene *scene, SceneRenderLayer *srl)
 
 int get_render_subsurf_level(RenderData *r, int lvl)
 {
-	if(r->mode & R_SIMPLIFY)
+	if (r->mode & R_SIMPLIFY)
 		return MIN2(r->simplify_subsurf, lvl);
 	else
 		return lvl;
@@ -1157,7 +1163,7 @@ int get_render_subsurf_level(RenderData *r, int lvl)
 
 int get_render_child_particle_number(RenderData *r, int num)
 {
-	if(r->mode & R_SIMPLIFY)
+	if (r->mode & R_SIMPLIFY)
 		return (int)(r->simplify_particles*num);
 	else
 		return num;
@@ -1165,7 +1171,7 @@ int get_render_child_particle_number(RenderData *r, int num)
 
 int get_render_shadow_samples(RenderData *r, int samples)
 {
-	if((r->mode & R_SIMPLIFY) && samples > 0)
+	if ((r->mode & R_SIMPLIFY) && samples > 0)
 		return MIN2(r->simplify_shadowsamples, samples);
 	else
 		return samples;
@@ -1173,7 +1179,7 @@ int get_render_shadow_samples(RenderData *r, int samples)
 
 float get_render_aosss_error(RenderData *r, float error)
 {
-	if(r->mode & R_SIMPLIFY)
+	if (r->mode & R_SIMPLIFY)
 		return ((1.0f-r->simplify_aosss)*10.0f + 1.0f)*error;
 	else
 		return error;
@@ -1182,19 +1188,19 @@ float get_render_aosss_error(RenderData *r, float error)
 /* helper function for the SETLOOPER macro */
 Base *_setlooper_base_step(Scene **sce_iter, Base *base)
 {
-	if(base && base->next) {
+	if (base && base->next) {
 		/* common case, step to the next */
 		return base->next;
 	}
-	else if(base==NULL && (*sce_iter)->base.first) {
+	else if (base==NULL && (*sce_iter)->base.first) {
 		/* first time looping, return the scenes first base */
 		return (Base *)(*sce_iter)->base.first;
 	}
 	else {
 		/* reached the end, get the next base in the set */
-		while((*sce_iter= (*sce_iter)->set)) {
+		while ((*sce_iter= (*sce_iter)->set)) {
 			base= (Base *)(*sce_iter)->base.first;
-			if(base) {
+			if (base) {
 				return base;
 			}
 		}
