@@ -25,36 +25,38 @@
  * ***** END GPL LICENSE BLOCK *****
  */
  
-#ifndef __WINSTUFF_H__
-#define __WINSTUFF_H__
+#ifndef __BLI_WINSTUFF_H__
+#define __BLI_WINSTUFF_H__
 
 /** \file BLI_winstuff.h
  *  \ingroup bli
  *  \brief Compatibility-like things for windows.
  */
 
-#ifdef _WIN32
-
-#ifndef FREE_WINDOWS
-#pragma warning(once: 4761 4305 4244 4018)
-#else
-#ifdef WINVER
-#undef WINVER
+#ifndef _WIN32
+#  error "This include is for Windows only!"
 #endif
 
+#ifndef FREE_WINDOWS
+#  pragma warning(once: 4761 4305 4244 4018)
+#else
+#  ifdef WINVER
+#    undef WINVER
+#  endif
+
 /* Some stuff requires WINVER 0x500, but mingw's default is 0x400 */
-#define WINVER 0x0501
+#  define WINVER 0x0501
 #endif
 
 #define WIN32_LEAN_AND_MEAN
 
 #ifndef WIN32_SKIP_HKEY_PROTECTION
-#undef HKEY
-#define HKEY WIN32_HKEY				// prevent competing definitions
-#include <windows.h>
-#undef HKEY
+#  undef HKEY
+#  define HKEY WIN32_HKEY				// prevent competing definitions
+#  include <windows.h>
+#  undef HKEY
 #else
-#include <windows.h>
+#  include <windows.h>
 #endif
 
 #undef near
@@ -83,10 +85,10 @@ extern "C" {
 #define MAXPATHLEN MAX_PATH
 
 #ifndef S_ISREG
-#define S_ISREG(x) (((x)&_S_IFREG) == _S_IFREG)
+#  define S_ISREG(x) (((x)&_S_IFREG) == _S_IFREG)
 #endif
 #ifndef S_ISDIR
-#define S_ISDIR(x) (((x)&_S_IFDIR) == _S_IFDIR)
+#  define S_ISDIR(x) (((x)&_S_IFDIR) == _S_IFDIR)
 #endif
 
 /* defines for using ISO C++ conformant names */
@@ -98,21 +100,23 @@ typedef unsigned int mode_t;
 
 /* use functions that take a 64 bit offset for files larger than 4GB */
 #ifndef FREE_WINDOWS
-#include <stdio.h>
-#define fseek(stream, offset, origin) _fseeki64(stream, offset, origin)
-#define ftell(stream) _ftelli64(stream)
-#define lseek(fd, offset, origin) _lseeki64(fd, offset, origin)
-#define tell(fd) _telli64(fd)
+#  include <stdio.h>
+#  define fseek(stream, offset, origin) _fseeki64(stream, offset, origin)
+#  define ftell(stream) _ftelli64(stream)
+#  define lseek(fd, offset, origin) _lseeki64(fd, offset, origin)
+#  define tell(fd) _telli64(fd)
 #endif
 
 /* mingw using _SSIZE_T_ to declare ssize_t type */
 #ifndef _SSIZE_T_
-#define _SSIZE_T_
+#  define _SSIZE_T_
 /* python uses HAVE_SSIZE_T */
-#ifndef HAVE_SSIZE_T
-#define HAVE_SSIZE_T 1
+#  ifndef HAVE_SSIZE_T
+#    define HAVE_SSIZE_T 1
+#    ifndef FREE_WINDOWS64
 typedef long ssize_t;
-#endif
+#    endif
+#  endif
 #endif
 
 struct dirent {
@@ -124,7 +128,7 @@ struct dirent {
 
 typedef struct _DIR {
 	HANDLE handle;
-	WIN32_FIND_DATA data;
+	WIN32_FIND_DATAW data;
 	char path[MAX_PATH];
 	long dd_loc;
 	long dd_size;
@@ -140,7 +144,7 @@ struct dirent *readdir(DIR *dp);
 int closedir (DIR *dp);
 void get_default_root(char *root);
 int check_file_chars(char *filename);
-char *dirname(char *path);
+const char *dirname(char *path);
 
 int BLI_getInstallationDir(char *str);
 
@@ -148,7 +152,5 @@ int BLI_getInstallationDir(char *str);
 }
 #endif
 
-#endif /* _WIN32 */
-
-#endif /* __WINSTUFF_H__ */
+#endif /* __BLI_WINSTUFF_H__ */
 
