@@ -45,7 +45,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-/* note: copied from BKE_utildefines.h, dont use here because we're in BLI */
+/* note: copied from BKE_utildefines.h, don't use here because we're in BLI */
 #ifdef __BIG_ENDIAN__
 /* Big Endian */
 #  define MAKE_ID(a,b,c,d) ( (int)(a)<<24 | (int)(b)<<16 | (c)<<8 | (d) )
@@ -71,120 +71,159 @@ struct BLI_mempool {
 	int esize;         /* element size in bytes */
 	int csize;         /* chunk size in bytes */
 	int pchunk;        /* number of elements per chunk */
-	short use_sysmalloc, allow_iter;
+	int flag;
 	/* keeps aligned to 16 bits */
 
-	BLI_freenode *free;	             /* free element list. Interleaved into chunk datas.*/
-	int totalloc, totused;           /* total number of elements allocated in total,
-	                                  * and currently in use*/
+	BLI_freenode *free;    /* free element list. Interleaved into chunk datas. */
+	int totalloc, totused; /* total number of elements allocated in total,
+	                        * and currently in use */
 };
 
 #define MEMPOOL_ELEM_SIZE_MIN (sizeof(void *) * 2)
 
-BLI_mempool *BLI_mempool_create(int esize, int tote, int pchunk,
-                                short use_sysmalloc, short allow_iter)
+BLI_mempool *BLI_mempool_create(int esize, int totelem, int pchunk, int flag)
 {
-	BLI_mempool  *pool = NULL;
+	BLI_mempool *pool = NULL;
 	BLI_freenode *lasttail = NULL, *curnode = NULL;
-	int i,j, maxchunks;
+	int i, j, maxchunks;
 	char *addr;
 
-	if (esize < MEMPOOL_ELEM_SIZE_MIN)
-		esize = MEMPOOL_ELEM_SIZE_MIN;
+	/* allocate the pool structure */
+	if (flag & BLI_MEMPOOL_SYSMALLOC) {
+		pool = malloc(sizeof(BLI_mempool));
+	}
+	else {
+		pool = MEM_mallocN(sizeof(BLI_mempool), "memory pool");
+	}
 
-	/*allocate the pool structure*/
-	pool = use_sysmalloc ? malloc(sizeof(BLI_mempool)) : MEM_mallocN(sizeof(BLI_mempool), "memory pool");
-	pool->esize = allow_iter ? MAX2(esize, sizeof(BLI_freenode)) : esize;
-	pool->use_sysmalloc = use_sysmalloc;
+	/* set the elem size */
+	if (esize < MEMPOOL_ELEM_SIZE_MIN) {
+		esize = MEMPOOL_ELEM_SIZE_MIN;
+	}
+
+	if (flag & BLI_MEMPOOL_ALLOW_ITER) {
+		pool->esize = MAX2(esize, sizeof(BLI_freenode));
+	}
+	else {
+		pool->esize = esize;
+	}
+
+	pool->flag = flag;
 	pool->pchunk = pchunk;
 	pool->csize = esize * pchunk;
 	pool->chunks.first = pool->chunks.last = NULL;
-	pool->totused= 0;
-	pool->allow_iter= allow_iter;
-	
-	maxchunks = tote / pchunk + 1;
-	if (maxchunks==0) maxchunks = 1;
+	pool->totused = 0;
 
-	/*allocate the actual chunks*/
-	for (i=0; i < maxchunks; i++) {
-		BLI_mempool_chunk *mpchunk = use_sysmalloc ? malloc(sizeof(BLI_mempool_chunk)) : MEM_mallocN(sizeof(BLI_mempool_chunk), "BLI_Mempool Chunk");
-		mpchunk->next = mpchunk->prev = NULL;
-		mpchunk->data = use_sysmalloc ? malloc(pool->csize) : MEM_mallocN(pool->csize, "BLI Mempool Chunk Data");
-		BLI_addtail(&(pool->chunks), mpchunk);
-		
-		if (i==0) {
-			pool->free = mpchunk->data; /*start of the list*/
-			if (pool->allow_iter)
-				pool->free->freeword = FREEWORD;
+	maxchunks = totelem / pchunk + 1;
+	if (maxchunks == 0) {
+		maxchunks = 1;
+	}
+
+	/* allocate the actual chunks */
+	for (i = 0; i < maxchunks; i++) {
+		BLI_mempool_chunk *mpchunk;
+
+		if (flag & BLI_MEMPOOL_SYSMALLOC) {
+			mpchunk = malloc(sizeof(BLI_mempool_chunk));
+			mpchunk->data = malloc(pool->csize);
+		}
+		else {
+			mpchunk = MEM_mallocN(sizeof(BLI_mempool_chunk), "BLI_Mempool Chunk");
+			mpchunk->data = MEM_mallocN(pool->csize, "BLI Mempool Chunk Data");
 		}
 
-		/*loop through the allocated data, building the pointer structures*/
-		for (addr = mpchunk->data, j=0; j < pool->pchunk; j++) {
-			curnode = ((BLI_freenode*)addr);
+		mpchunk->next = mpchunk->prev = NULL;
+		BLI_addtail(&(pool->chunks), mpchunk);
+
+		if (i == 0) {
+			pool->free = mpchunk->data; /* start of the list */
+			if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
+				pool->free->freeword = FREEWORD;
+			}
+		}
+
+		/* loop through the allocated data, building the pointer structures */
+		for (addr = mpchunk->data, j = 0; j < pool->pchunk; j++) {
+			curnode = ((BLI_freenode *)addr);
 			addr += pool->esize;
-			curnode->next = (BLI_freenode*)addr;
-			if (pool->allow_iter) {
-				if (j != pool->pchunk-1)
+			curnode->next = (BLI_freenode *)addr;
+			if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
+				if (j != pool->pchunk - 1)
 					curnode->next->freeword = FREEWORD;
 				curnode->freeword = FREEWORD;
 			}
 		}
-		/*final pointer in the previously allocated chunk is wrong.*/
+		/* final pointer in the previously allocated chunk is wrong */
 		if (lasttail) {
 			lasttail->next = mpchunk->data;
-			if (pool->allow_iter)
+			if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
 				lasttail->freeword = FREEWORD;
+			}
 		}
 
-		/*set the end of this chunks memoryy to the new tail for next iteration*/
+		/* set the end of this chunks memoryy to the new tail for next iteration */
 		lasttail = curnode;
 
 		pool->totalloc += pool->pchunk;
 	}
-	/*terminate the list*/
+	/* terminate the list */
 	curnode->next = NULL;
 	return pool;
 }
 
 void *BLI_mempool_alloc(BLI_mempool *pool)
 {
-	void *retval=NULL;
+	void *retval = NULL;
 
 	pool->totused++;
 
 	if (!(pool->free)) {
-		BLI_freenode *curnode=NULL;
+		BLI_freenode *curnode = NULL;
 		char *addr;
 		int j;
 
-		/*need to allocate a new chunk*/
-		BLI_mempool_chunk *mpchunk = pool->use_sysmalloc ? malloc(sizeof(BLI_mempool_chunk)) :  MEM_mallocN(sizeof(BLI_mempool_chunk), "BLI_Mempool Chunk");
+		/* need to allocate a new chunk */
+		BLI_mempool_chunk *mpchunk;
+
+		if (pool->flag & BLI_MEMPOOL_SYSMALLOC) {
+			mpchunk       = malloc(sizeof(BLI_mempool_chunk));
+			mpchunk->data = malloc(pool->csize);
+		}
+		else {
+			mpchunk       = MEM_mallocN(sizeof(BLI_mempool_chunk), "BLI_Mempool Chunk");
+			mpchunk->data = MEM_mallocN(pool->csize, "BLI_Mempool Chunk Data");
+		}
+
 		mpchunk->next = mpchunk->prev = NULL;
-		mpchunk->data = pool->use_sysmalloc ? malloc(pool->csize) : MEM_mallocN(pool->csize, "BLI_Mempool Chunk Data");
 		BLI_addtail(&(pool->chunks), mpchunk);
 
-		pool->free = mpchunk->data; /*start of the list*/
-		if (pool->allow_iter)
-			pool->free->freeword = FREEWORD;
-		for(addr = mpchunk->data, j=0; j < pool->pchunk; j++){
-			curnode = ((BLI_freenode*)addr);
-			addr += pool->esize;
-			curnode->next = (BLI_freenode*)addr;
+		pool->free = mpchunk->data; /* start of the list */
 
-			if (pool->allow_iter) {
+		if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
+			pool->free->freeword = FREEWORD;
+		}
+
+		for (addr = mpchunk->data, j = 0; j < pool->pchunk; j++) {
+			curnode = ((BLI_freenode *)addr);
+			addr += pool->esize;
+			curnode->next = (BLI_freenode *)addr;
+
+			if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
 				curnode->freeword = FREEWORD;
-				if (j != pool->pchunk-1)
+				if (j != pool->pchunk - 1)
 					curnode->next->freeword = FREEWORD;
 			}
 		}
-		curnode->next = NULL; /*terminate the list*/
+		curnode->next = NULL; /* terminate the list */
 
 		pool->totalloc += pool->pchunk;
 	}
 
 	retval = pool->free;
-	if (pool->allow_iter)
+
+	if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
 		pool->free->freeword = 0x7FFFFFFF;
+	}
 
 	pool->free = pool->free->next;
 	//memset(retval, 0, pool->esize);
@@ -193,57 +232,70 @@ void *BLI_mempool_alloc(BLI_mempool *pool)
 
 void *BLI_mempool_calloc(BLI_mempool *pool)
 {
-	void *retval= BLI_mempool_alloc(pool);
+	void *retval = BLI_mempool_alloc(pool);
 	memset(retval, 0, pool->esize);
 	return retval;
 }
 
-/* doesnt protect against double frees, dont be stupid! */
+/* doesnt protect against double frees, don't be stupid! */
 void BLI_mempool_free(BLI_mempool *pool, void *addr)
 {
 	BLI_freenode *newhead = addr;
 
-	if (pool->allow_iter)
+	if (pool->flag & BLI_MEMPOOL_ALLOW_ITER) {
 		newhead->freeword = FREEWORD;
+	}
+
 	newhead->next = pool->free;
 	pool->free = newhead;
 
 	pool->totused--;
 
-	/*nothing is in use; free all the chunks except the first*/
+	/* nothing is in use; free all the chunks except the first */
 	if (pool->totused == 0) {
-		BLI_freenode *curnode=NULL;
-		char *tmpaddr=NULL;
+		BLI_freenode *curnode = NULL;
+		char *tmpaddr = NULL;
 		int i;
 
-		BLI_mempool_chunk *mpchunk=NULL;
-		BLI_mempool_chunk *first= pool->chunks.first;
+		BLI_mempool_chunk *mpchunk = NULL;
+		BLI_mempool_chunk *first = pool->chunks.first;
 
 		BLI_remlink(&pool->chunks, first);
 
-		for (mpchunk = pool->chunks.first; mpchunk; mpchunk = mpchunk->next) {
-			if (pool->use_sysmalloc) free(mpchunk->data);
-			else                     MEM_freeN(mpchunk->data);
+		if (pool->flag & BLI_MEMPOOL_SYSMALLOC) {
+			for (mpchunk = pool->chunks.first; mpchunk; mpchunk = mpchunk->next) {
+				free(mpchunk->data);
+			}
+			BLI_freelist(&(pool->chunks));
+		}
+		else {
+			for (mpchunk = pool->chunks.first; mpchunk; mpchunk = mpchunk->next) {
+				MEM_freeN(mpchunk->data);
+			}
+			BLI_freelistN(&(pool->chunks));
 		}
 
-		pool->use_sysmalloc ? BLI_freelist(&(pool->chunks)) : BLI_freelistN(&(pool->chunks));
-		
 		BLI_addtail(&pool->chunks, first);
 		pool->totalloc = pool->pchunk;
 
-		pool->free = first->data; /*start of the list*/
-		for (tmpaddr = first->data, i=0; i < pool->pchunk; i++) {
-			curnode = ((BLI_freenode*)tmpaddr);
+		pool->free = first->data; /* start of the list */
+		for (tmpaddr = first->data, i = 0; i < pool->pchunk; i++) {
+			curnode = ((BLI_freenode *)tmpaddr);
 			tmpaddr += pool->esize;
-			curnode->next = (BLI_freenode*)tmpaddr;
+			curnode->next = (BLI_freenode *)tmpaddr;
 		}
-		curnode->next = NULL; /*terminate the list*/
+		curnode->next = NULL; /* terminate the list */
 	}
 }
 
+int BLI_mempool_count(BLI_mempool *pool)
+{
+	return pool->totused;
+}
+
 void *BLI_mempool_findelem(BLI_mempool *pool, int index)
 {
-	if (!pool->allow_iter) {
+	if (!(pool->flag & BLI_MEMPOOL_ALLOW_ITER)) {
 		fprintf(stderr, "%s: Error! you can't iterate over this mempool!\n", __func__);
 		return NULL;
 	}
@@ -252,7 +304,9 @@ void *BLI_mempool_findelem(BLI_mempool *pool, int index)
 		BLI_mempool_iter iter;
 		void *elem;
 		BLI_mempool_iternew(pool, &iter);
-		for (elem= BLI_mempool_iterstep(&iter); index-- != 0; elem= BLI_mempool_iterstep(&iter)) { };
+		for (elem = BLI_mempool_iterstep(&iter); index-- != 0; elem = BLI_mempool_iterstep(&iter)) {
+			/* do nothing */
+		};
 		return elem;
 	}
 
@@ -261,14 +315,14 @@ void *BLI_mempool_findelem(BLI_mempool *pool, int index)
 
 void BLI_mempool_iternew(BLI_mempool *pool, BLI_mempool_iter *iter)
 {
-	if (!pool->allow_iter) {
+	if (!(pool->flag & BLI_MEMPOOL_ALLOW_ITER)) {
 		fprintf(stderr, "%s: Error! you can't iterate over this mempool!\n", __func__);
 		iter->curchunk = NULL;
 		iter->curindex = 0;
-		
+
 		return;
 	}
-	
+
 	iter->pool = pool;
 	iter->curchunk = pool->chunks.first;
 	iter->curindex = 0;
@@ -280,29 +334,29 @@ void BLI_mempool_iternew(BLI_mempool *pool, BLI_mempool_iter *iter)
 static void *bli_mempool_iternext(BLI_mempool_iter *iter)
 {
 	void *ret = NULL;
-	
+
 	if (!iter->curchunk || !iter->pool->totused) return NULL;
-	
-	ret = ((char*)iter->curchunk->data) + iter->pool->esize*iter->curindex;
-	
+
+	ret = ((char *)iter->curchunk->data) + iter->pool->esize * iter->curindex;
+
 	iter->curindex++;
-	
+
 	if (iter->curindex >= iter->pool->pchunk) {
 		iter->curchunk = iter->curchunk->next;
 		iter->curindex = 0;
 	}
-	
+
 	return ret;
 }
 
 void *BLI_mempool_iterstep(BLI_mempool_iter *iter)
 {
 	BLI_freenode *ret;
-	
+
 	do {
 		ret = bli_mempool_iternext(iter);
 	} while (ret && ret->freeword == FREEWORD);
-	
+
 	return ret;
 }
 
@@ -320,7 +374,7 @@ void *BLI_mempool_iterstep(BLI_mempool_iter *iter)
 
 	do {
 		if (LIKELY(iter->curchunk)) {
-			ret = (BLI_freenode *)(((char*)iter->curchunk->data) + iter->pool->esize*iter->curindex);
+			ret = (BLI_freenode *)(((char *)iter->curchunk->data) + iter->pool->esize * iter->curindex);
 		}
 		else {
 			return NULL;
@@ -331,7 +385,7 @@ void *BLI_mempool_iterstep(BLI_mempool_iter *iter)
 			iter->curchunk = iter->curchunk->next;
 		}
 	} while (ret->freeword == FREEWORD);
-	
+
 	return ret;
 }
 
@@ -339,9 +393,9 @@ void *BLI_mempool_iterstep(BLI_mempool_iter *iter)
 
 void BLI_mempool_destroy(BLI_mempool *pool)
 {
-	BLI_mempool_chunk *mpchunk=NULL;
+	BLI_mempool_chunk *mpchunk = NULL;
 
-	if (pool->use_sysmalloc) {
+	if (pool->flag & BLI_MEMPOOL_SYSMALLOC) {
 		for (mpchunk = pool->chunks.first; mpchunk; mpchunk = mpchunk->next) {
 			free(mpchunk->data);
 		}
