@@ -44,13 +44,19 @@ struct DynamicLibrary {
 #ifdef WIN32
 
 #include <windows.h>
+#include "utf_winfunc.h"
+#include "utfconv.h"
 
 DynamicLibrary *BLI_dynlib_open(char *name)
 {
 	DynamicLibrary *lib;
-	void *handle= LoadLibrary(name);
+	void *handle;
 
-	if(!handle)
+	UTF16_ENCODE(name);
+	handle= LoadLibraryW(name_16);
+	UTF16_UN_ENCODE(name);
+
+	if (!handle)
 		return NULL;
 
 	lib= MEM_callocN(sizeof(*lib), "Dynamic Library");
@@ -70,13 +76,13 @@ char *BLI_dynlib_get_error_as_string(DynamicLibrary *lib)
 
 	/* if lib is NULL reset the last error code */
 	err= GetLastError();
-	if(!lib)
+	if (!lib)
 		SetLastError(ERROR_SUCCESS);
 
-	if(err) {
+	if (err) {
 		static char buf[1024];
 
-		if(FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM|FORMAT_MESSAGE_IGNORE_INSERTS, 
+		if (FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM|FORMAT_MESSAGE_IGNORE_INSERTS, 
 			NULL, err, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
 			buf, sizeof(buf), NULL))
 			return buf;
@@ -100,7 +106,7 @@ DynamicLibrary *BLI_dynlib_open(char *name)
 	DynamicLibrary *lib;
 	void *handle= dlopen(name, RTLD_LAZY);
 
-	if(!handle)
+	if (!handle)
 		return NULL;
 
 	lib= MEM_callocN(sizeof(*lib), "Dynamic Library");
