@@ -86,7 +86,7 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 	
 	// adjust font size
 	height= ((double) face->bbox.yMax - (double) face->bbox.yMin);
-	if(height != 0.0f)
+	if (height != 0.0f)
 		scale = 1.0f / height;
 	else
 		scale = 1.0f / 1000.0f;
@@ -99,8 +99,7 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 	err= FT_Load_Glyph(face, glyph_index, FT_LOAD_NO_SCALE | FT_LOAD_NO_BITMAP);
 	
 	// If loading succeeded, convert the FT glyph to the internal format
-	if(!err)
-	{
+	if (!err) {
 		int *npoints;
 		int *onpoints;
 		
@@ -117,36 +116,36 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 		che->width= glyph->advance.x * scale;
 		
 		// Start converting the FT data
-		npoints = (int *)MEM_callocN((ftoutline.n_contours)* sizeof(int),"endpoints") ;
-		onpoints = (int *)MEM_callocN((ftoutline.n_contours)* sizeof(int),"onpoints") ;
+		npoints = (int *)MEM_callocN((ftoutline.n_contours) * sizeof(int),"endpoints");
+		onpoints = (int *)MEM_callocN((ftoutline.n_contours) * sizeof(int),"onpoints");
 
 		// calculate total points of each contour
-		for(j = 0; j < ftoutline.n_contours; j++) {
-			if(j == 0)
+		for (j = 0; j < ftoutline.n_contours; j++) {
+			if (j == 0)
 				npoints[j] = ftoutline.contours[j] + 1;
 			else
 				npoints[j] = ftoutline.contours[j] - ftoutline.contours[j - 1];
 		}
 
 		// get number of on-curve points for beziertriples (including conic virtual on-points) 
-		for(j = 0; j < ftoutline.n_contours; j++) {
-			for(k = 0; k < npoints[j]; k++) {
-				if(j > 0) l = k + ftoutline.contours[j - 1] + 1; else l = k;
-					if(ftoutline.tags[l] == FT_Curve_Tag_On)
+		for (j = 0; j < ftoutline.n_contours; j++) {
+			for (k = 0; k < npoints[j]; k++) {
+				if (j > 0) l = k + ftoutline.contours[j - 1] + 1; else l = k;
+					if (ftoutline.tags[l] == FT_Curve_Tag_On)
 						onpoints[j]++;
 
-				if(k < npoints[j] - 1 )
-					if( ftoutline.tags[l]   == FT_Curve_Tag_Conic &&
+				if (k < npoints[j] - 1 )
+					if ( ftoutline.tags[l]   == FT_Curve_Tag_Conic &&
 						ftoutline.tags[l+1] == FT_Curve_Tag_Conic)
 						onpoints[j]++;
 			}
 		}
 
 		//contour loop, bezier & conic styles merged
-		for(j = 0; j < ftoutline.n_contours; j++) {
+		for (j = 0; j < ftoutline.n_contours; j++) {
 			// add new curve
-			nu  =  (Nurb*)MEM_callocN(sizeof(struct Nurb),"objfnt_nurb");
-			bezt = (BezTriple*)MEM_callocN((onpoints[j])* sizeof(BezTriple),"objfnt_bezt") ;
+			nu  =  (Nurb *)MEM_callocN(sizeof(struct Nurb), "objfnt_nurb");
+			bezt = (BezTriple *)MEM_callocN((onpoints[j]) * sizeof(BezTriple), "objfnt_bezt");
 			BLI_addtail(&che->nurbsbase, nu);
 
 			nu->type= CU_BEZIER;
@@ -157,14 +156,13 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 			nu->bezt = bezt;
 
 			//individual curve loop, start-end
-			for(k = 0; k < npoints[j]; k++) {
-				if(j > 0) l = k + ftoutline.contours[j - 1] + 1; else l = k;
-				if(k == 0) m = l;
+			for (k = 0; k < npoints[j]; k++) {
+				if (j > 0) l = k + ftoutline.contours[j - 1] + 1; else l = k;
+				if (k == 0) m = l;
 					
 				//virtual conic on-curve points
-				if(k < npoints[j] - 1 )
-				{
-					if( ftoutline.tags[l] == FT_Curve_Tag_Conic && ftoutline.tags[l+1] == FT_Curve_Tag_Conic) {
+				if (k < npoints[j] - 1) {
+					if (ftoutline.tags[l] == FT_Curve_Tag_Conic && ftoutline.tags[l+1] == FT_Curve_Tag_Conic) {
 						dx = (ftoutline.points[l].x + ftoutline.points[l+1].x)* scale / 2.0f;
 						dy = (ftoutline.points[l].y + ftoutline.points[l+1].y)* scale / 2.0f;
 
@@ -187,32 +185,37 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 				}
 
 				//on-curve points
-				if(ftoutline.tags[l] == FT_Curve_Tag_On) {
+				if (ftoutline.tags[l] == FT_Curve_Tag_On) {
 					//left handle
-					if(k > 0) {
-						if(ftoutline.tags[l - 1] == FT_Curve_Tag_Cubic) {
+					if (k > 0) {
+						if (ftoutline.tags[l - 1] == FT_Curve_Tag_Cubic) {
 							bezt->vec[0][0] = ftoutline.points[l-1].x* scale;
 							bezt->vec[0][1] = ftoutline.points[l-1].y* scale;
 							bezt->h1= HD_FREE;
-						} else if(ftoutline.tags[l - 1] == FT_Curve_Tag_Conic) {
+						}
+						else if (ftoutline.tags[l - 1] == FT_Curve_Tag_Conic) {
 							bezt->vec[0][0] = (ftoutline.points[l].x + (2 * ftoutline.points[l - 1].x))* scale / 3.0f;
 							bezt->vec[0][1] = (ftoutline.points[l].y + (2 * ftoutline.points[l - 1].y))* scale / 3.0f;
 							bezt->h1= HD_FREE;
-						} else {
+						}
+						else {
 							bezt->vec[0][0] = ftoutline.points[l].x* scale - (ftoutline.points[l].x - ftoutline.points[l-1].x)* scale / 3.0f;
 							bezt->vec[0][1] = ftoutline.points[l].y* scale - (ftoutline.points[l].y - ftoutline.points[l-1].y)* scale / 3.0f;
 							bezt->h1= HD_VECT;
 						}
-					} else { //first point on curve
-						if(ftoutline.tags[ftoutline.contours[j]] == FT_Curve_Tag_Cubic) {
+					}
+					else { //first point on curve
+						if (ftoutline.tags[ftoutline.contours[j]] == FT_Curve_Tag_Cubic) {
 							bezt->vec[0][0] = ftoutline.points[ftoutline.contours[j]].x * scale;
 							bezt->vec[0][1] = ftoutline.points[ftoutline.contours[j]].y * scale;
 							bezt->h1= HD_FREE;
-						} else if(ftoutline.tags[ftoutline.contours[j]] == FT_Curve_Tag_Conic) {
+						}
+						else if (ftoutline.tags[ftoutline.contours[j]] == FT_Curve_Tag_Conic) {
 							bezt->vec[0][0] = (ftoutline.points[l].x + (2 * ftoutline.points[ftoutline.contours[j]].x))* scale / 3.0f;
 							bezt->vec[0][1] = (ftoutline.points[l].y + (2 * ftoutline.points[ftoutline.contours[j]].y))* scale / 3.0f;
 							bezt->h1= HD_FREE;
-						} else {
+						}
+						else {
 							bezt->vec[0][0] = ftoutline.points[l].x* scale - (ftoutline.points[l].x - ftoutline.points[ftoutline.contours[j]].x)* scale / 3.0f;
 							bezt->vec[0][1] = ftoutline.points[l].y* scale - (ftoutline.points[l].y - ftoutline.points[ftoutline.contours[j]].y)* scale / 3.0f;
 							bezt->h1= HD_VECT;
@@ -224,30 +227,35 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 					bezt->vec[1][1] = ftoutline.points[l].y* scale;
 
 					//right handle
-					if(k < (npoints[j] - 1)) {
-						if(ftoutline.tags[l+1] == FT_Curve_Tag_Cubic) {
+					if (k < (npoints[j] - 1)) {
+						if (ftoutline.tags[l+1] == FT_Curve_Tag_Cubic) {
 							bezt->vec[2][0] = ftoutline.points[l+1].x* scale;
 							bezt->vec[2][1] = ftoutline.points[l+1].y* scale;
 							bezt->h2= HD_FREE;
-						} else if(ftoutline.tags[l+1] == FT_Curve_Tag_Conic) {
+						}
+						else if (ftoutline.tags[l+1] == FT_Curve_Tag_Conic) {
 							bezt->vec[2][0] = (ftoutline.points[l].x + (2 * ftoutline.points[l+1].x))* scale / 3.0f;
 							bezt->vec[2][1] = (ftoutline.points[l].y + (2 * ftoutline.points[l+1].y))* scale / 3.0f;
 							bezt->h2= HD_FREE;
-						} else {
+						}
+						else {
 							bezt->vec[2][0] = ftoutline.points[l].x* scale - (ftoutline.points[l].x - ftoutline.points[l+1].x)* scale / 3.0f;
 							bezt->vec[2][1] = ftoutline.points[l].y* scale - (ftoutline.points[l].y - ftoutline.points[l+1].y)* scale / 3.0f;
 							bezt->h2= HD_VECT;
 						}
-					} else { //last point on curve
-						if(ftoutline.tags[m] == FT_Curve_Tag_Cubic) {
+					}
+					else { //last point on curve
+						if (ftoutline.tags[m] == FT_Curve_Tag_Cubic) {
 							bezt->vec[2][0] = ftoutline.points[m].x* scale;
 							bezt->vec[2][1] = ftoutline.points[m].y* scale;
 							bezt->h2= HD_FREE;
-						} else if(ftoutline.tags[m] == FT_Curve_Tag_Conic) {
+						}
+						else if (ftoutline.tags[m] == FT_Curve_Tag_Conic) {
 							bezt->vec[2][0] = (ftoutline.points[l].x + (2 * ftoutline.points[m].x))* scale / 3.0f;
 							bezt->vec[2][1] = (ftoutline.points[l].y + (2 * ftoutline.points[m].y))* scale / 3.0f;
 							bezt->h2= HD_FREE;
-						} else {
+						}
+						else {
 							bezt->vec[2][0] = ftoutline.points[l].x* scale - (ftoutline.points[l].x - ftoutline.points[m].x)* scale / 3.0f;
 							bezt->vec[2][1] = ftoutline.points[l].y* scale - (ftoutline.points[l].y - ftoutline.points[m].y)* scale / 3.0f;
 							bezt->h2= HD_VECT;
@@ -259,7 +267,7 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 					// len_squared_v2v2, see if there's a distance between the three points
 					// len_squared_v2v2 again, to check the angle between the handles 
 					// finally, check if one of them is a vector handle 
-					if((dist_to_line_v2(bezt->vec[0],bezt->vec[1],bezt->vec[2]) < 0.001f) &&
+					if ((dist_to_line_v2(bezt->vec[0],bezt->vec[1],bezt->vec[2]) < 0.001f) &&
 						(len_squared_v2v2(bezt->vec[0], bezt->vec[1]) > 0.0001f*0.0001f) &&
 						(len_squared_v2v2(bezt->vec[1], bezt->vec[2]) > 0.0001f*0.0001f) &&
 						(len_squared_v2v2(bezt->vec[0], bezt->vec[2]) > 0.0002f*0.0001f) &&
@@ -273,8 +281,8 @@ static void freetypechar_to_vchar(FT_Face face, FT_ULong charcode, VFontData *vf
 				}
 			}
 		}
-		if(npoints) MEM_freeN(npoints);
-		if(onpoints) MEM_freeN(onpoints);	
+		if (npoints) MEM_freeN(npoints);
+		if (onpoints) MEM_freeN(onpoints);	
 	}
 }
 
@@ -288,11 +296,10 @@ static int objchr_to_ftvfontdata(VFont *vfont, FT_ULong charcode)
 	tf= vfont_find_tmpfont(vfont);
 	
 	// What, no font found. Something strange here
-	if(!tf) return FALSE;
+	if (!tf) return FALSE;
 	
 	// Load the font to memory
-	if(tf->pf)
-	{
+	if (tf->pf) {
 		err= FT_New_Memory_Face( library,
 			tf->pf->data,
 			tf->pf->size,
@@ -322,13 +329,13 @@ static VFontData *objfnt_to_ftvfontdata(PackedFile * pf)
 	const char *fontname;
 	VFontData *vfd;
 
-/*
+#if 0
 	FT_CharMap  found = 0;
 	FT_CharMap  charmap;
 	FT_UShort my_platform_id = TT_PLATFORM_MICROSOFT;
 	FT_UShort my_encoding_id = TT_MS_ID_UNICODE_CS;
 	int         n;
-*/
+#endif
 
 	// load the freetype font
 	err = FT_New_Memory_Face( library,
@@ -337,8 +344,9 @@ static VFontData *objfnt_to_ftvfontdata(PackedFile * pf)
 						0,
 						&face );
 
-	if(err) return NULL;
-/*
+	if (err) return NULL;
+
+#if 0
 	for ( n = 0; n < face->num_charmaps; n++ )
 	{
 		charmap = face->charmaps[n];
@@ -355,7 +363,7 @@ static VFontData *objfnt_to_ftvfontdata(PackedFile * pf)
 	// now, select the charmap for the face object
 	err = FT_Set_Charmap( face, found );
 	if ( err ) { return NULL; }
-*/
+#endif
 
 	// allocate blender font
 	vfd= MEM_callocN(sizeof(*vfd), "FTVFontData");
@@ -368,17 +376,14 @@ static VFontData *objfnt_to_ftvfontdata(PackedFile * pf)
 	lcode= charcode= FT_Get_First_Char(face, &glyph_index);
 
 	// No charmap found from the ttf so we need to figure it out
-	if(glyph_index == 0)
-	{
+	if (glyph_index == 0) {
 		FT_CharMap  found = NULL;
 		FT_CharMap  charmap;
 		int n;
 
-		for ( n = 0; n < face->num_charmaps; n++ )
-		{
+		for (n = 0; n < face->num_charmaps; n++) {
 			charmap = face->charmaps[n];
-			if (charmap->encoding == FT_ENCODING_APPLE_ROMAN)
-			{
+			if (charmap->encoding == FT_ENCODING_APPLE_ROMAN) {
 				found = charmap;
 				break;
 			}
@@ -386,14 +391,14 @@ static VFontData *objfnt_to_ftvfontdata(PackedFile * pf)
 
 		err = FT_Set_Charmap( face, found );
 
-		if( err ) 
+		if ( err ) 
 			return NULL;
 
 		lcode= charcode= FT_Get_First_Char(face, &glyph_index);
 	}
 
 	// Load characters
-	while(charcode < 256)
+	while (charcode < 256)
 	{
 		// Generate the font data
 		freetypechar_to_vchar(face, charcode, vfd);
@@ -402,7 +407,7 @@ static VFontData *objfnt_to_ftvfontdata(PackedFile * pf)
 		charcode = FT_Get_Next_Char(face, charcode, &glyph_index);
 
 		// Check that we won't start infinite loop
-		if(charcode <= lcode)
+		if (charcode <= lcode)
 			break;
 		lcode = charcode;
 	}
@@ -416,13 +421,13 @@ static int check_freetypefont(PackedFile * pf)
 	FT_Face			face;
 	FT_GlyphSlot	glyph;
 	FT_UInt			glyph_index;
-/*
+#if 0
 	FT_CharMap  charmap;
 	FT_CharMap  found;
 	FT_UShort my_platform_id = TT_PLATFORM_MICROSOFT;
 	FT_UShort my_encoding_id = TT_MS_ID_UNICODE_CS;
 	int         n;
-*/
+#endif
 	int success = 0;
 
 	err = FT_New_Memory_Face( library,
@@ -430,37 +435,37 @@ static int check_freetypefont(PackedFile * pf)
 							pf->size,
 							0,
 							&face );
-	if(err) {
+	if (err) {
 		success = 0;
 		//XXX error("This is not a valid font");
 	}
 	else {
-/*
-		for ( n = 0; n < face->num_charmaps; n++ )
-		{
-		  charmap = face->charmaps[n];
-		  if ( charmap->platform_id == my_platform_id &&
-			   charmap->encoding_id == my_encoding_id )
-		  {
-			found = charmap;
-			break;
-		  }
+
+#if 0
+		for ( n = 0; n < face->num_charmaps; n++) {
+			charmap = face->charmaps[n];
+			if (charmap->platform_id == my_platform_id && charmap->encoding_id == my_encoding_id) {
+				found = charmap;
+				break;
+			}
 		}
 
-		if ( !found ) { return 0; }
+		if (!found ) { return 0; }
 
 		// now, select the charmap for the face object 
 		err = FT_Set_Charmap( face, found );
 		if ( err ) { return 0; }
-*/
+#endif
+
 		glyph_index = FT_Get_Char_Index( face, 'A' );
 		err = FT_Load_Glyph(face, glyph_index, FT_LOAD_NO_SCALE | FT_LOAD_NO_BITMAP);
-		if(err) success = 0;
+		if (err) success = 0;
 		else {
 			glyph = face->glyph;
 			if (glyph->format == ft_glyph_format_outline ) {
 				success = 1;
-			} else {
+			}
+			else {
 				//XXX error("Selected Font has no outline data");
 				success = 0;
 			}
@@ -478,7 +483,7 @@ VFontData *BLI_vfontdata_from_freetypefont(PackedFile *pf)
 
 	//init Freetype	
 	err = FT_Init_FreeType( &library);
-	if(err) {
+	if (err) {
 		//XXX error("Failed to load the Freetype font library");
 		return NULL;
 	}
@@ -499,18 +504,18 @@ int BLI_vfontchar_from_freetypefont(VFont *vfont, unsigned long character)
 {
 	int success = FALSE;
 
-	if(!vfont) return FALSE;
+	if (!vfont) return FALSE;
 
 	// Init Freetype
 	err = FT_Init_FreeType(&library);
-	if(err) {
+	if (err) {
 		//XXX error("Failed to load the Freetype font library");
 		return 0;
 	}
 
 	// Load the character
 	success = objchr_to_ftvfontdata(vfont, character);
-	if(success == FALSE) return FALSE;
+	if (success == FALSE) return FALSE;
 
 	// Free Freetype
 	FT_Done_FreeType(library);
@@ -533,8 +538,7 @@ typedef struct  FT_Outline_
 	short*      contours;        /* the contour end points             */
 
 	int         flags;           /* outline masks                      */
-
-  } FT_Outline;
+} FT_Outline;
 
 #endif
 
