@@ -111,11 +111,19 @@ float rng_getFloat(RNG *rng)
 void rng_shuffleArray(RNG *rng, void *data, int elemSize, int numElems)
 {
 	int i = numElems;
-	void *temp = malloc(elemSize);
+	void *temp;
 
+	if (numElems <= 0) {
+		return;
+	}
+
+	temp = malloc(elemSize);
+
+	/* XXX Shouldn't it rather be "while (i--) {" ?
+	 *     Else we have no guaranty first (0) element has a chance to be shuffled... --mont29 */
 	while (--i) {
 		int j = rng_getInt(rng)%numElems;
-		if(i!=j) {
+		if (i!=j) {
 			void *iElem = (unsigned char*)data + i*elemSize;
 			void *jElem = (unsigned char*)data + j*elemSize;
 			memcpy(temp, iElem, elemSize);
@@ -131,7 +139,7 @@ void rng_skip(RNG *rng, int n)
 {
 	int i;
 
-	for(i=0; i<n; i++)
+	for (i=0; i<n; i++)
 		rng_getInt(rng);
 }
 
@@ -189,7 +197,7 @@ static RNG rng_tab[BLENDER_MAX_THREADS];
 
 void BLI_thread_srandom(int thread, unsigned int seed)
 {
-	if(thread >= BLENDER_MAX_THREADS)
+	if (thread >= BLENDER_MAX_THREADS)
 		thread= 0;
 	
 	rng_seed(&rng_tab[thread], seed + hash[seed & 255]);
