@@ -27,8 +27,8 @@
  */
 
  /** \file blender/blenlib/intern/string_utf8.c
- *  \ingroup bli
- */
+  *  \ingroup bli
+  */
 
 #include <string.h>
 #include <wchar.h>
@@ -41,9 +41,9 @@
  * http://svn.swish-e.org/libswish3/trunk/src/libswish3/utf8.c r3044 - campbell */
 
 /* based on the valid_utf8 routine from the PCRE library by Philip Hazel
-
-   length is in bytes, since without knowing whether the string is valid
-   it's hard to know how many characters there are! */
+ *
+ * length is in bytes, since without knowing whether the string is valid
+ * it's hard to know how many characters there are! */
 
 static const char trailingBytesForUTF8[256] = {
 	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
@@ -101,7 +101,7 @@ int BLI_utf8_invalid_byte(const char *str, int length)
 			break;
 
 			/* Check for leading 0xfe or 0xff,
-			   and then for 1111 1100, xx00 00xx */
+			 * and then for 1111 1100, xx00 00xx */
 		case 5:
 			if (c == 0xfe || c == 0xff ||
 				(c == 0xfc && (*p & 0x3c) == 0)) goto utf8_error;
@@ -126,11 +126,11 @@ int BLI_utf8_invalid_strip(char *str, int length)
 {
 	int bad_char, tot= 0;
 
-	while((bad_char= BLI_utf8_invalid_byte(str, length)) != -1) {
+	while ((bad_char= BLI_utf8_invalid_byte(str, length)) != -1) {
 		str += bad_char;
 		length -= bad_char;
 
-		if(length == 0) {
+		if (length == 0) {
 			/* last character bad, strip it */
 			*str= '\0';
 			tot++;
@@ -166,7 +166,7 @@ static const size_t utf8_skip_data[256] = {
 #define BLI_STR_UTF8_CPY(dst, src, maxncpy)                                   \
 	{                                                                         \
 		size_t utf8_size;                                                     \
-		while(*src != '\0' && (utf8_size= utf8_skip_data[*src]) < maxncpy) {  \
+		while (*src != '\0' && (utf8_size= utf8_skip_data[*src]) < maxncpy) {  \
 			maxncpy -= utf8_size;                                             \
 			switch(utf8_size) {                                               \
 				case 6: *dst ++ = *src ++;                                    \
@@ -184,7 +184,7 @@ char *BLI_strncpy_utf8(char *dst, const char *src, size_t maxncpy)
 {
 	char *dst_r= dst;
 
-	/* note: currently we dont attempt to deal with invalid utf8 chars */
+	/* note: currently we don't attempt to deal with invalid utf8 chars */
 	BLI_STR_UTF8_CPY(dst, src, maxncpy)
 
 	return dst_r;
@@ -210,7 +210,7 @@ char *BLI_strncat_utf8(char *dst, const char *src, size_t maxncpy)
 size_t BLI_strncpy_wchar_as_utf8(char *dst, const wchar_t *src, const size_t maxcpy)
 {
 	size_t len = 0;
-	while(*src && len < maxcpy) { /* XXX can still run over the buffer because utf8 size isnt known :| */
+	while (*src && len < maxcpy) { /* XXX can still run over the buffer because utf8 size isn't known :| */
 		len += BLI_str_utf8_from_unicode(*src++, dst+len);
 	}
 
@@ -224,7 +224,7 @@ size_t BLI_wstrlen_utf8(const wchar_t *src)
 {
 	size_t len = 0;
 
-	while(*src) {
+	while (*src) {
 		len += BLI_str_utf8_from_unicode(*src++, NULL);
 	}
 
@@ -236,15 +236,17 @@ size_t BLI_strlen_utf8(const char *strc)
 {
 	int len=0;
 
-	while(*strc) {
+	while (*strc) {
 		if ((*strc & 0xe0) == 0xc0) {
-			if((strc[1] & 0x80) && (strc[1] & 0x40) == 0x00)
+			if ((strc[1] & 0x80) && (strc[1] & 0x40) == 0x00)
 				strc++;
-		} else if ((*strc & 0xf0) == 0xe0) {
-			if((strc[1] & strc[2] & 0x80) && ((strc[1] | strc[2]) & 0x40) == 0x00)
+		}
+		else if ((*strc & 0xf0) == 0xe0) {
+			if ((strc[1] & strc[2] & 0x80) && ((strc[1] | strc[2]) & 0x40) == 0x00)
 				strc += 2;
-		} else if ((*strc & 0xf8) == 0xf0) {
-			if((strc[1] & strc[2] & strc[3] & 0x80) && ((strc[1] | strc[2] | strc[3]) & 0x40) == 0x00)
+		}
+		else if ((*strc & 0xf8) == 0xf0) {
+			if ((strc[1] & strc[2] & strc[3] & 0x80) && ((strc[1] | strc[2] | strc[3]) & 0x40) == 0x00)
 				strc += 3;
 		}
 
@@ -259,9 +261,9 @@ size_t BLI_strncpy_wchar_from_utf8(wchar_t *dst_w, const char *src_c, const size
 {
 	int len=0;
 
-	if(dst_w==NULL || src_c==NULL) return(0);
+	if (dst_w==NULL || src_c==NULL) return(0);
 
-	while(*src_c && len < maxcpy) {
+	while (*src_c && len < maxcpy) {
 		size_t step= 0;
 		unsigned int unicode= BLI_str_utf8_as_unicode_and_size(src_c, &step);
 		if (unicode != BLI_UTF8_ERR) {
@@ -284,7 +286,7 @@ size_t BLI_strncpy_wchar_from_utf8(wchar_t *dst_w, const char *src_c, const size
 /* copied from glib's gutf8.c */
 
 /* note, glib uses unsigned int for unicode, best we do the same,
- * though we dont typedef it - campbell */
+ * though we don't typedef it - campbell */
 
 #define UTF8_COMPUTE(Char, Mask, Len)                                         \
 	if (Char < 128) {                                                         \
@@ -345,7 +347,7 @@ int BLI_str_utf8_size(const char *p)
 /* was g_utf8_get_char */
 /**
  * BLI_str_utf8_as_unicode:
- * @p: a pointer to Unicode character encoded as UTF-8
+ * @p a pointer to Unicode character encoded as UTF-8
  *
  * Converts a sequence of bytes encoded as UTF-8 to a Unicode character.
  * If @p does not point to a valid UTF-8 encoded character, results are
@@ -357,19 +359,19 @@ int BLI_str_utf8_size(const char *p)
  **/
 unsigned int BLI_str_utf8_as_unicode(const char *p)
 {
-  int i, mask = 0, len;
-  unsigned int result;
-  unsigned char c = (unsigned char) *p;
+	int i, mask = 0, len;
+	unsigned int result;
+	unsigned char c = (unsigned char) *p;
 
-  UTF8_COMPUTE (c, mask, len);
-  if (len == -1)
-    return BLI_UTF8_ERR;
-  UTF8_GET (result, p, i, mask, len, BLI_UTF8_ERR);
+	UTF8_COMPUTE (c, mask, len);
+	if (len == -1)
+		return BLI_UTF8_ERR;
+	UTF8_GET (result, p, i, mask, len, BLI_UTF8_ERR);
 
-  return result;
+	return result;
 }
 
-/* varient that increments the length */
+/* variant that increments the length */
 unsigned int BLI_str_utf8_as_unicode_and_size(const char *p, size_t *index)
 {
 	int i, mask = 0, len;
@@ -384,7 +386,7 @@ unsigned int BLI_str_utf8_as_unicode_and_size(const char *p, size_t *index)
 	return result;
 }
 
-/* another varient that steps over the index,
+/* another variant that steps over the index,
  * note, currently this also falls back to latin1 for text drawing. */
 unsigned int BLI_str_utf8_as_unicode_step(const char *p, size_t *index)
 {
@@ -415,7 +417,7 @@ unsigned int BLI_str_utf8_as_unicode_step(const char *p, size_t *index)
 	 * this is added for text drawing because some filepaths can have latin1
 	 * characters */
 	UTF8_GET (result, p, i, mask, len, BLI_UTF8_ERR);
-	if(result == BLI_UTF8_ERR) {
+	if (result == BLI_UTF8_ERR) {
 		len= 1;
 		result= *p;
 	}
@@ -432,10 +434,10 @@ unsigned int BLI_str_utf8_as_unicode_step(const char *p, size_t *index)
 /* was g_unichar_to_utf8 */
 /**
  * BLI_str_utf8_from_unicode:
- * @c: a Unicode character code
- * @outbuf: output buffer, must have at least 6 bytes of space.
+ * @c a Unicode character code
+ * \param outbuf output buffer, must have at least 6 bytes of space.
  *       If %NULL, the length will be computed and returned
- *       and nothing will be written to @outbuf.
+ *       and nothing will be written to outbuf.
  *
  * Converts a single character to UTF-8.
  *
@@ -488,11 +490,11 @@ size_t BLI_str_utf8_from_unicode(unsigned int c, char *outbuf)
 /**
  * BLI_str_find_prev_char_utf8:
  * @str: pointer to the beginning of a UTF-8 encoded string
- * @p: pointer to some position within @str
+ * @p pointer to some position within @str
  *
  * Given a position @p with a UTF-8 encoded string @str, find the start
- * of the previous UTF-8 character starting before @p. Returns %NULL if no
- * UTF-8 characters are present in @str before @p.
+ * of the previous UTF-8 character starting before. @p Returns %NULL if no
+ * UTF-8 characters are present in @str before @p
  *
  * @p does not have to be at the beginning of a UTF-8 character. No check
  * is made to see if the character found is actually valid other than
@@ -513,11 +515,11 @@ char * BLI_str_find_prev_char_utf8(const char *str, const char *p)
 /* was g_utf8_find_next_char */
 /**
  * BLI_str_find_next_char_utf8:
- * @p: a pointer to a position within a UTF-8 encoded string
- * @end: a pointer to the byte following the end of the string,
+ * @p a pointer to a position within a UTF-8 encoded string
+ * @end a pointer to the byte following the end of the string,
  * or %NULL to indicate that the string is nul-terminated.
  *
- * Finds the start of the next UTF-8 character in the string after @p.
+ * Finds the start of the next UTF-8 character in the string after @p
  *
  * @p does not have to be at the beginning of a UTF-8 character. No check
  * is made to see if the character found is actually valid other than
@@ -545,9 +547,9 @@ char *BLI_str_find_next_char_utf8(const char *p, const char *end)
 /* was g_utf8_prev_char */
 /**
  * BLI_str_prev_char_utf8:
- * @p: a pointer to a position within a UTF-8 encoded string
+ * @p a pointer to a position within a UTF-8 encoded string
  *
- * Finds the previous UTF-8 character in the string before @p.
+ * Finds the previous UTF-8 character in the string before @p
  *
  * @p does not have to be at the beginning of a UTF-8 character. No check
  * is made to see if the character found is actually valid other than
