@@ -46,18 +46,22 @@
 
 #define WIN32_SKIP_HKEY_PROTECTION		// need to use HKEY
 #include "BLI_winstuff.h"
+#include "BLI_utildefines.h"
 
- /* FILE_MAX */
+#include "utf_winfunc.h"
+#include "utfconv.h"
 
-int BLI_getInstallationDir( char * str )
+ /* FILE_MAXDIR + FILE_MAXFILE */
+
+int BLI_getInstallationDir(char * str)
 {
 	char dir[FILE_MAXDIR];
 	int a;
-	
+	/*change to utf support*/
 	GetModuleFileName(NULL,str,FILE_MAX);
 	BLI_split_dir_part(str, dir, sizeof(dir)); /* shouldn't be relative */
 	a = strlen(dir);
-	if(dir[a-1] == '\\') dir[a-1]=0;
+	if (dir[a-1] == '\\') dir[a-1]=0;
 	
 	strcpy(str,dir);
 	
@@ -86,7 +90,7 @@ void RegisterBlendExtension(void)
 	char BlPath[MAX_PATH];
 	char InstallDir[FILE_MAXDIR];
 	char SysDir[FILE_MAXDIR];
-	const char* ThumbHandlerDLL;
+    const char *ThumbHandlerDLL;
 	char RegCmd[MAX_PATH*2];
 	char MBox[256];
 	BOOL IsWOW64;
@@ -96,8 +100,7 @@ void RegisterBlendExtension(void)
 
 	// root is HKLM by default
 	lresult = RegOpenKeyEx(HKEY_LOCAL_MACHINE, "Software\\Classes", 0, KEY_ALL_ACCESS, &root);
-	if (lresult != ERROR_SUCCESS)
-	{
+	if (lresult != ERROR_SUCCESS) {
 		// try HKCU on failure
 		usr_mode = TRUE;
 		lresult = RegOpenKeyEx(HKEY_CURRENT_USER, "Software\\Classes", 0, KEY_ALL_ACCESS, &root);
@@ -161,8 +164,7 @@ void RegisterBlendExtension(void)
 
 	RegCloseKey(root);
 	printf("success (%s)\n",usr_mode ? "user" : "system");
-	if (!G.background)
-	{
+	if (!G.background) {
 		sprintf(MBox,"File extension registered for %s.",usr_mode ? "the current user. To register for all users, run as an administrator" : "all users");
 		MessageBox(0,MBox,"Blender",MB_OK|MB_ICONINFORMATION);
 	}
@@ -171,7 +173,9 @@ void RegisterBlendExtension(void)
 
 DIR *opendir (const char *path)
 {
-	if (GetFileAttributes(path) & FILE_ATTRIBUTE_DIRECTORY) {
+    wchar_t *path_16 = alloc_utf16_from_8(path, 0);
+
+	if (GetFileAttributesW(path_16) & FILE_ATTRIBUTE_DIRECTORY) {
 		DIR *newd= MEM_mallocN(sizeof(DIR), "opendir");
 
 		newd->handle = INVALID_HANDLE_VALUE;
@@ -182,12 +186,37 @@ DIR *opendir (const char *path)
 		newd->direntry.d_reclen= 0;
 		newd->direntry.d_name= NULL;
 		
+		free(path_16);
 		return newd;
-	} else {
+	}
+	else {
+		free(path_16);
 		return NULL;
 	}
 }
 
+static char *BLI_alloc_utf_8_from_16(wchar_t *in16, size_t add)
+{
+	size_t bsize = count_utf_8_from_16(in16);
+    char *out8 = NULL;
+	if (!bsize) return NULL;
+	out8 = (char*)MEM_mallocN(sizeof(char) * (bsize + add),"UTF-8 String");
+	conv_utf_16_to_8(in16,out8, bsize);
+	return out8;
+}
+
+static wchar_t *UNUSED_FUNCTION(BLI_alloc_utf16_from_8)(char *in8, size_t add)
+{
+	size_t bsize = count_utf_16_from_8(in8);
+    wchar_t *out16 = NULL;
+	if (!bsize) return NULL;
+	out16 =(wchar_t*) MEM_mallocN(sizeof(wchar_t) * (bsize + add), "UTF-16 String");
+	conv_utf_8_to_16(in8,out16, bsize);
+	return out16;
+}
+
+
+
 struct dirent *readdir(DIR *dp)
 {
 	if (dp->direntry.d_name) {
@@ -196,18 +225,22 @@ struct dirent *readdir(DIR *dp)
 	}
 		
 	if (dp->handle==INVALID_HANDLE_VALUE) {
-		dp->handle= FindFirstFile(dp->path, &(dp->data));
+        wchar_t *path_16 = alloc_utf16_from_8(dp->path, 0);
+		dp->handle= FindFirstFileW(path_16, &(dp->data));
+		free(path_16);
 		if (dp->handle==INVALID_HANDLE_VALUE)
 			return NULL;
 			
-		dp->direntry.d_name= BLI_strdup(dp->data.cFileName);
+		dp->direntry.d_name= BLI_alloc_utf_8_from_16(dp->data.cFileName, 0);
+		
+		return &dp->direntry;
+	}
+	else if (FindNextFileW (dp->handle, &(dp->data))) {
+		dp->direntry.d_name= BLI_alloc_utf_8_from_16(dp->data.cFileName,0);
 
 		return &dp->direntry;
-	} else if (FindNextFile (dp->handle, &(dp->data))) {
-		dp->direntry.d_name= BLI_strdup(dp->data.cFileName);
-
-		return &dp->direntry;
-	} else {
+	}
+	else {
 		return NULL;
 	}
 }
@@ -222,28 +255,30 @@ int closedir (DIR *dp)
 	return 0;
 }
 
-void get_default_root(char* root)
+void get_default_root(char *root)
 {
 	char str[MAX_PATH+1];
 	
 	/* the default drive to resolve a directory without a specified drive 
-	   should be the Windows installation drive, since this was what the OS
-	   assumes. */
+	 * should be the Windows installation drive, since this was what the OS
+	 * assumes. */
 	if (GetWindowsDirectory(str,MAX_PATH+1)) {
 		root[0] = str[0];
 		root[1] = ':';
 		root[2] = '\\';
 		root[3] = '\0';
-	} else {		
+	}
+	else {
 		/* if GetWindowsDirectory fails, something has probably gone wrong, 
-		   we are trying the blender install dir though */
+		 * we are trying the blender install dir though */
 		if (GetModuleFileName(NULL,str,MAX_PATH+1)) {
 			printf("Error! Could not get the Windows Directory - Defaulting to Blender installation Dir!");
 			root[0] = str[0];
 			root[1] = ':';
 			root[2] = '\\';
 			root[3] = '\0';
-		} else {
+		}
+		else {
 			DWORD tmp;
 			int i;
 			int rc = 0;
@@ -300,18 +335,18 @@ int check_file_chars(char *filename)
  * is freely granted, provided that this notice is preserved.
  */
 #include <string.h>
-char* dirname(char *path)
+const char *dirname(char *path)
 {
 	char *p;
-	if( path == NULL || *path == '\0' )
+	if ( path == NULL || *path == '\0' )
 		return ".";
 	p = path + strlen(path) - 1;
-	while( *p == '/' ) {
-		if( p == path )
+	while ( *p == '/' ) {
+		if ( p == path )
 			return path;
 		*p-- = '\0';
 	}
-	while( p >= path && *p != '/' )
+	while ( p >= path && *p != '/' )
 		p--;
 	return
 		p < path ? "." :
