@@ -24,8 +24,8 @@
  *
  * ***** END GPL LICENSE BLOCK *****
  */
-#ifndef BLO_READFILE_H
-#define BLO_READFILE_H
+#ifndef __BLO_READFILE_H__
+#define __BLO_READFILE_H__
 
 /** \file BLO_readfile.h
  *  \ingroup blenloader
@@ -78,10 +78,10 @@ typedef struct BlendFileData {
 	 * returns NULL and sets a report in the list if
 	 * it cannot open the file.
 	 * 
-	 * @param filepath The path of the file to open.
-	 * @param reports If the return value is NULL, errors
+	 * \param filepath The path of the file to open.
+	 * \param reports If the return value is NULL, errors
 	 * indicating the cause of the failure.
-	 * @return The data of the file.
+	 * \return The data of the file.
 	 */
 BlendFileData*	BLO_read_from_file(const char *filepath, struct ReportList *reports);
 
@@ -90,11 +90,11 @@ BlendFileData*	BLO_read_from_file(const char *filepath, struct ReportList *repor
 	 * returns NULL and sets a report in the list if
 	 * it cannot open the file.
 	 * 
-	 * @param mem The file data.
-	 * @param memsize The length of @a mem.
-	 * @param reports If the return value is NULL, errors
+	 * \param mem The file data.
+	 * \param memsize The length of \a mem.
+	 * \param reports If the return value is NULL, errors
 	 * indicating the cause of the failure.
-	 * @return The data of the file.
+	 * \return The data of the file.
 	 */
 BlendFileData*	BLO_read_from_memory(void *mem, int memsize, struct ReportList *reports);
 
@@ -109,7 +109,7 @@ BlendFileData *BLO_read_from_memfile(struct Main *oldmain, const char *filename,
  * data associated with it (the userdef data, and
  * the main libblock data).
  * 
- * @param bfd The structure to free.
+ * \param bfd The structure to free.
  */
 	void
 BLO_blendfiledata_free(
@@ -118,9 +118,9 @@ BLO_blendfiledata_free(
 /**
  * Open a blendhandle from a file path.
  * 
- * @param file The file path to open.
- * @param reports Report errors in opening the file (can be NULL).
- * @return A handle on success, or NULL on failure.
+ * \param file The file path to open.
+ * \param reports Report errors in opening the file (can be NULL).
+ * \return A handle on success, or NULL on failure.
  */
 	BlendHandle*
 BLO_blendhandle_from_file(
@@ -130,9 +130,9 @@ BLO_blendhandle_from_file(
 /**
  * Open a blendhandle from memory.
  *
- * @param mem The data to load from.
- * @param memsize The size of the data.
- * @return A handle on success, or NULL on failure.
+ * \param mem The data to load from.
+ * \param memsize The size of the data.
+ * \return A handle on success, or NULL on failure.
  */
 
 	BlendHandle*
@@ -145,10 +145,10 @@ BLO_blendhandle_from_memory(
  * of a certain type (ie. All the scene names in
  * a file).
  * 
- * @param bh The blendhandle to access.
- * @param ofblocktype The type of names to get.
- * @param tot_names The length of the returned list.
- * @return A BLI_linklist of strings. The string links
+ * \param bh The blendhandle to access.
+ * \param ofblocktype The type of names to get.
+ * \param tot_names The length of the returned list.
+ * \return A BLI_linklist of strings. The string links
  * should be freed with malloc.
  */
 	struct LinkNode*
@@ -162,10 +162,10 @@ BLO_blendhandle_get_datablock_names(
  * of a certain type (ie. All the scene names in
  * a file).
  * 
- * @param bh The blendhandle to access.
- * @param ofblocktype The type of names to get.
- * @param tot_prev The length of the returned list.
- * @return A BLI_linklist of PreviewImage. The PreviewImage links
+ * \param bh The blendhandle to access.
+ * \param ofblocktype The type of names to get.
+ * \param tot_prev The length of the returned list.
+ * \return A BLI_linklist of PreviewImage. The PreviewImage links
  * should be freed with malloc.
  */
 	struct LinkNode*
@@ -179,8 +179,8 @@ BLO_blendhandle_get_previews(
  * file. (ie. file contains Scene, Mesh, and Lamp
  * datablocks).
  * 
- * @param bh The blendhandle to access.
- * @return A BLI_linklist of strings. The string links
+ * \param bh The blendhandle to access.
+ * \return A BLI_linklist of strings. The string links
  * should be freed with malloc.
  */
 	struct LinkNode*
@@ -191,7 +191,7 @@ BLO_blendhandle_get_linkable_groups(
  * Close and free a blendhandle. The handle
  * becomes invalid after this call.
  *
- * @param bh The handle to close.
+ * \param bh The handle to close.
  */
 	void
 BLO_blendhandle_close(
@@ -212,10 +212,10 @@ int BLO_is_a_library(const char *path, char *dir, char *group);
 /**
  * Initialize the BlendHandle for appending or linking library data.
  *
- * @param mainvar The current main database eg G.main or CTX_data_main(C).
- * @param bh A blender file handle as returned by BLO_blendhandle_from_file or BLO_blendhandle_from_memory.
- * @param filepath Used for relative linking, copied to the lib->name
- * @return the library Main, to be passed to BLO_library_append_named_part as mainl.
+ * \param mainvar The current main database eg G.main or CTX_data_main(C).
+ * \param bh A blender file handle as returned by BLO_blendhandle_from_file or BLO_blendhandle_from_memory.
+ * \param filepath Used for relative linking, copied to the lib->name
+ * \return the library Main, to be passed to BLO_library_append_named_part as mainl.
  */
 struct Main* BLO_library_append_begin(struct Main *mainvar, BlendHandle** bh, const char *filepath);
 
@@ -223,11 +223,11 @@ struct Main* BLO_library_append_begin(struct Main *mainvar, BlendHandle** bh, co
 /**
  * Link/Append a named datablock from an external blend file.
  *
- * @param mainl The main database to link from (not the active one).
- * @param bh The blender file handle.
- * @param idname The name of the datablock (without the 2 char ID prefix)
- * @param idcode The kind of datablock to link.
- * @return the appended ID when found.
+ * \param mainl The main database to link from (not the active one).
+ * \param bh The blender file handle.
+ * \param idname The name of the datablock (without the 2 char ID prefix)
+ * \param idcode The kind of datablock to link.
+ * \return the appended ID when found.
  */
 struct ID *BLO_library_append_named_part(struct Main *mainl, BlendHandle** bh, const char *idname, const int idcode);
 
@@ -235,13 +235,13 @@ struct ID *BLO_library_append_named_part(struct Main *mainl, BlendHandle** bh, c
  * Link/Append a named datablock from an external blend file.
  * optionally instance the object in the scene when the flags are set.
  *
- * @param C The context, when NULL instancing object in the scene isnt done.
- * @param mainl The main database to link from (not the active one).
- * @param bh The blender file handle.
- * @param idname The name of the datablock (without the 2 char ID prefix)
- * @param idcode The kind of datablock to link.
- * @param flag Options for linking, used for instancing.
- * @return the appended ID when found.
+ * \param C The context, when NULL instancing object in the scene isn't done.
+ * \param mainl The main database to link from (not the active one).
+ * \param bh The blender file handle.
+ * \param idname The name of the datablock (without the 2 char ID prefix)
+ * \param idcode The kind of datablock to link.
+ * \param flag Options for linking, used for instancing.
+ * \return the appended ID when found.
  */
 struct ID *BLO_library_append_named_part_ex(const struct bContext *C, struct Main *mainl, BlendHandle** bh, const char *idname, const int idcode, const short flag);
 
