@@ -30,8 +30,8 @@
  * SUCH DAMAGE.
  */
 
-#ifndef FLOATPATCH_H
-#define FLOATPATCH_H
+#ifndef __FLOATPATCH_H__
+#define __FLOATPATCH_H__
 
 /* floating point libs differ at systems... with these defines it comilies at all! */
 
@@ -88,5 +88,5 @@
 
 #endif
 
-#endif /* FLOATPATCH_H */
+#endif /* __FLOATPATCH_H__ */
 
