@@ -119,7 +119,7 @@ void AnimationImporter::animation_to_fcurves(COLLADAFW::AnimationCurve *curve)
 					bez.vec[1][1] = bc_get_float_value(output, j * dim + i);
 
 
-					if( curve->getInterpolationType() == COLLADAFW::AnimationCurve::INTERPOLATION_BEZIER ||
+					if ( curve->getInterpolationType() == COLLADAFW::AnimationCurve::INTERPOLATION_BEZIER ||
 						curve->getInterpolationType() == COLLADAFW::AnimationCurve::INTERPOLATION_STEP) 
 					{
 						COLLADAFW::FloatOrDoubleArray& intan = curve->getInTangentValues();
@@ -132,7 +132,7 @@ void AnimationImporter::animation_to_fcurves(COLLADAFW::AnimationCurve *curve)
 						// outtangent
 						bez.vec[2][0] = bc_get_float_value(outtan, (j * 2 * dim ) + (2 * i)) * fps;
 						bez.vec[2][1] = bc_get_float_value(outtan, (j * 2 * dim )+ (2 * i) + 1);
-						if(curve->getInterpolationType() == COLLADAFW::AnimationCurve::INTERPOLATION_BEZIER) 
+						if (curve->getInterpolationType() == COLLADAFW::AnimationCurve::INTERPOLATION_BEZIER) 
 							bez.ipo = BEZT_IPO_BEZ;
 						else 
 							bez.ipo = BEZT_IPO_CONST;
@@ -261,7 +261,7 @@ bool AnimationImporter::write_animation(const COLLADAFW::Animation* anim)
 		// XXX Don't know if it's necessary
 		// Should we check outPhysicalDimension?
 		if (curve->getInPhysicalDimension() != COLLADAFW::PHYSICAL_DIMENSION_TIME) {
-			fprintf(stderr, "Inputs physical dimension is not time. \n");
+			fprintf(stderr, "Inputs physical dimension is not time.\n");
 			return true;
 		}
 
@@ -439,6 +439,16 @@ void AnimationImporter::modify_fcurve(std::vector<FCurve*>* curves , const char*
 	}
 }
 
+void AnimationImporter::unused_fcurve(std::vector<FCurve*>* curves)
+{
+	// when an error happens and we can't actually use curve remove it from unused_curves
+	std::vector<FCurve*>::iterator it;
+	for (it = curves->begin(); it != curves->end(); it++) {
+		FCurve *fcu = *it;
+		unused_curves.erase(std::remove(unused_curves.begin(), unused_curves.end(), fcu), unused_curves.end());
+	}
+}
+
 void AnimationImporter::find_frames( std::vector<float>* frames , std::vector<FCurve*>* curves)
 {
 	std::vector<FCurve*>::iterator iter;
@@ -500,6 +510,7 @@ void AnimationImporter:: Assign_transform_animations(COLLADAFW::Transformation *
 			modify_fcurve(curves, rna_path, -1 );
 			break;
 		default:
+			unused_fcurve(curves);
 			fprintf(stderr, "AnimationClass %d is not supported for %s.\n",
 				binding->animationClass, loc ? "TRANSLATE" : "SCALE");
 				}
@@ -535,10 +546,13 @@ void AnimationImporter:: Assign_transform_animations(COLLADAFW::Transformation *
 			else if (COLLADABU::Math::Vector3::UNIT_Z == axis) {
 				modify_fcurve(curves, rna_path, 2 );
 			}
+			else
+				unused_fcurve(curves);
 			break;
 		case COLLADAFW::AnimationList::AXISANGLE:
 			// TODO convert axis-angle to quat? or XYZ?
 		default:
+			unused_fcurve(curves);
 			fprintf(stderr, "AnimationClass %d is not supported for ROTATE transformation.\n",
 				binding->animationClass);
 				}
@@ -554,9 +568,11 @@ void AnimationImporter:: Assign_transform_animations(COLLADAFW::Transformation *
 
 			}
 			}*/
+			unused_fcurve(curves);
 			break;
 		case COLLADAFW::Transformation::SKEW:
 		case COLLADAFW::Transformation::LOOKAT:
+			unused_fcurve(curves);
 			fprintf(stderr, "Animation of SKEW and LOOKAT transformations is not supported yet.\n");
 			break;
 	}
@@ -592,6 +608,7 @@ void AnimationImporter:: Assign_color_animations(const COLLADAFW::UniqueId& list
 			break;
 
 		default:
+			unused_fcurve(&animcurves);
 			fprintf(stderr, "AnimationClass %d is not supported for %s.\n",
 				bindings[j].animationClass, "COLOR" );
 		}
@@ -610,9 +627,10 @@ void AnimationImporter:: Assign_color_animations(const COLLADAFW::UniqueId& list
 void AnimationImporter:: Assign_float_animations(const COLLADAFW::UniqueId& listid, ListBase *AnimCurves, const char * anim_type)
 {
 	char rna_path[100];
-	if (animlist_map.find(listid) == animlist_map.end()) return ;
-	else 
-	{
+	if (animlist_map.find(listid) == animlist_map.end()) {
+		return;
+	}
+	else {
 		//anim_type has animations
 		const COLLADAFW::AnimationList *animlist = animlist_map[listid];
 		const COLLADAFW::AnimationList::AnimationBindings& bindings = animlist->getAnimationBindings();
@@ -665,7 +683,7 @@ void AnimationImporter::apply_matrix_curves( Object * ob, std::vector<FCurve*>&
 	}
 	// new curves to assign matrix transform animation
 	FCurve *newcu[10]; // if tm_type is matrix, then create 10 curves: 4 rot, 3 loc, 3 scale
-	unsigned int totcu = 10 ;
+	unsigned int totcu = 10;
 	const char *tm_str = NULL;
 	char rna_path[200];
 	for (int i = 0; i < totcu; i++) {
@@ -824,9 +842,10 @@ void AnimationImporter::translate_Animations ( COLLADAFW::Node * node ,
 			const COLLADAFW::UniqueId& listid = transform->getAnimationList();
 
 			//check if transformation has animations
-			if (animlist_map.find(listid) == animlist_map.end()) continue ; 
-			else 
-			{
+			if (animlist_map.find(listid) == animlist_map.end()) {
+				continue;
+			}
+			else {
 				//transformation has animations
 				const COLLADAFW::AnimationList *animlist = animlist_map[listid];
 				const COLLADAFW::AnimationList::AnimationBindings& bindings = animlist->getAnimationBindings();
@@ -834,34 +853,33 @@ void AnimationImporter::translate_Animations ( COLLADAFW::Node * node ,
 				std::vector<FCurve*> animcurves;
 				for (unsigned int j = 0; j < bindings.getCount(); j++) {
 					animcurves = curve_map[bindings[j].animation];
-					if ( is_matrix )
+					if ( is_matrix ) {
 						apply_matrix_curves(ob, animcurves, root , node,  transform  );
+					}
 					else {				
-						//calculate rnapaths and array index of fcurves according to transformation and animation class
-						Assign_transform_animations(transform, &bindings[j], &animcurves, is_joint, joint_path ); 
 
-						std::vector<FCurve*>::iterator iter;
-						//Add the curves of the current animation to the object
-						for (iter = animcurves.begin(); iter != animcurves.end(); iter++) {
-							FCurve * fcu = *iter;
-							if ((ob->type == OB_ARMATURE))
-								add_bone_fcurve( ob, node , fcu );
-							else 
-								BLI_addtail(AnimCurves, fcu);	
+						if (is_joint) {
+
+							add_bone_animation_sampled(ob, animcurves, root, node, transform);
 						}
+						else {
+							//calculate rnapaths and array index of fcurves according to transformation and animation class
+							Assign_transform_animations(transform, &bindings[j], &animcurves, is_joint, joint_path ); 
+
+							std::vector<FCurve*>::iterator iter;
+							//Add the curves of the current animation to the object
+							for (iter = animcurves.begin(); iter != animcurves.end(); iter++) {
+								FCurve * fcu = *iter;
+							
+								BLI_addtail(AnimCurves, fcu);
+							}
+						}
+						
 					}
 				}
 			}
-			if (is_rotation) {
-				if (is_joint) 
-				{
-					bPoseChannel *chan = get_pose_channel(ob->pose, bone_name);
-					chan->rotmode = ROT_MODE_EUL;
-				}
-				else 
-				{
-					ob->rotmode = ROT_MODE_EUL;
-				}
+			if (is_rotation && !is_joint) {
+				ob->rotmode = ROT_MODE_EUL;
 			}
 		}
 	}
@@ -947,7 +965,7 @@ void AnimationImporter::translate_Animations ( COLLADAFW::Node * node ,
 
 		}
 	}
-	if ( animType->material != 0){
+	if ( animType->material != 0) {
 		Material *ma = give_current_material(ob, 1);
 		if (!ma->adt || !ma->adt->action) act = verify_adt_action((ID*)&ma->id, 1);
 		else act = ma->adt->action;
@@ -963,25 +981,25 @@ void AnimationImporter::translate_Animations ( COLLADAFW::Node * node ,
 				if (ef != NULL) { /* can be NULL [#28909] */
 					const COLLADAFW::CommonEffectPointerArray& commonEffects  =  ef->getCommonEffects();
 					COLLADAFW::EffectCommon *efc = commonEffects[0];
-					if((animType->material & MATERIAL_SHININESS) != 0){
+					if ((animType->material & MATERIAL_SHININESS) != 0) {
 						const COLLADAFW::FloatOrParam *shin = &(efc->getShininess());
 						const COLLADAFW::UniqueId& listid =  shin->getAnimationList();
 						Assign_float_animations( listid, AnimCurves , "specular_hardness" );
 					}
 
-					if((animType->material & MATERIAL_IOR) != 0){
+					if ((animType->material & MATERIAL_IOR) != 0) {
 						const COLLADAFW::FloatOrParam *ior = &(efc->getIndexOfRefraction());
 						const COLLADAFW::UniqueId& listid =  ior->getAnimationList();
 						Assign_float_animations( listid, AnimCurves , "raytrace_transparency.ior" );
 					}
 
-					if((animType->material & MATERIAL_SPEC_COLOR) != 0){
+					if ((animType->material & MATERIAL_SPEC_COLOR) != 0) {
 						const COLLADAFW::ColorOrTexture *cot = &(efc->getSpecular());
 						const COLLADAFW::UniqueId& listid =  cot->getColor().getAnimationList();
 						Assign_color_animations( listid, AnimCurves , "specular_color" );
 					}
 
-					if((animType->material & MATERIAL_DIFF_COLOR) != 0){
+					if ((animType->material & MATERIAL_DIFF_COLOR) != 0) {
 						const COLLADAFW::ColorOrTexture *cot = &(efc->getDiffuse());
 						const COLLADAFW::UniqueId& listid =  cot->getColor().getAnimationList();
 						Assign_color_animations( listid, AnimCurves , "diffuse_color" );
@@ -992,6 +1010,136 @@ void AnimationImporter::translate_Animations ( COLLADAFW::Node * node ,
 	}
 }
 
+void AnimationImporter::add_bone_animation_sampled(Object * ob, std::vector<FCurve*>& animcurves, COLLADAFW::Node* root, COLLADAFW::Node* node, COLLADAFW::Transformation * tm)
+{
+	const char *bone_name = bc_get_joint_name(node);
+	char joint_path[200];
+	armature_importer->get_rna_path_for_joint(node, joint_path, sizeof(joint_path));
+
+	std::vector<float> frames;
+	find_frames(&frames, &animcurves);
+
+	// convert degrees to radians
+	if (tm->getTransformationType() == COLLADAFW::Transformation::ROTATE) {
+
+		std::vector<FCurve*>::iterator iter;
+		for (iter = animcurves.begin(); iter != animcurves.end(); iter++) {
+			FCurve* fcu = *iter;
+
+			fcurve_deg_to_rad(fcu);		 
+		}					
+	}
+
+
+	float irest_dae[4][4];
+	float rest[4][4], irest[4][4];
+
+	get_joint_rest_mat(irest_dae, root, node);
+	invert_m4(irest_dae);
+
+	Bone *bone = get_named_bone((bArmature*)ob->data, bone_name);
+	if (!bone) {
+		fprintf(stderr, "cannot find bone \"%s\"\n", bone_name);
+		return;
+	}
+
+	unit_m4(rest);
+	copy_m4_m4(rest, bone->arm_mat);
+	invert_m4_m4(irest, rest);
+
+	// new curves to assign matrix transform animation
+	FCurve *newcu[10]; // if tm_type is matrix, then create 10 curves: 4 rot, 3 loc, 3 scale
+	unsigned int totcu = 10;
+	const char *tm_str = NULL;
+	char rna_path[200];
+	for (int i = 0; i < totcu; i++) {
+
+		int axis = i;
+
+		if (i < 4) {
+			tm_str = "rotation_quaternion";
+			axis = i;
+		}
+		else if (i < 7) {
+			tm_str = "location";
+			axis = i - 4;
+		}
+		else {
+			tm_str = "scale";
+			axis = i - 7;
+		}
+
+
+		BLI_snprintf(rna_path, sizeof(rna_path), "%s.%s", joint_path, tm_str);
+
+		newcu[i] = create_fcurve(axis, rna_path);
+		newcu[i]->totvert = frames.size();
+	}
+
+	if (frames.size() == 0)
+		return;
+
+	std::sort(frames.begin(), frames.end());
+
+	std::vector<float>::iterator it;
+
+	// sample values at each frame
+	for (it = frames.begin(); it != frames.end(); it++) {
+		float fra = *it;
+
+		float mat[4][4];
+		float matfra[4][4];
+
+		unit_m4(matfra);
+
+		// calc object-space mat
+		evaluate_transform_at_frame(matfra, node, fra);
+
+
+		// for joints, we need a special matrix
+		// special matrix: iR * M * iR_dae * R
+		// where R, iR are bone rest and inverse rest mats in world space (Blender bones),
+		// iR_dae is joint inverse rest matrix (DAE) and M is an evaluated joint world-space matrix (DAE)
+		float temp[4][4], par[4][4];
+
+
+		// calc M
+		calc_joint_parent_mat_rest(par, NULL, root, node);
+		mult_m4_m4m4(temp, par, matfra);
+
+		// evaluate_joint_world_transform_at_frame(temp, NULL, , node, fra);
+
+		// calc special matrix
+		mul_serie_m4(mat, irest, temp, irest_dae, rest, NULL, NULL, NULL, NULL);
+
+		float  rot[4], loc[3], scale[3];
+
+		mat4_to_quat(rot, mat);
+		copy_v3_v3(loc, mat[3]);
+		mat4_to_size(scale, mat);
+
+		// add keys
+		for (int i = 0; i < totcu; i++) {
+			if (i < 4)
+				add_bezt(newcu[i], fra, rot[i]);
+			else if (i < 7)
+				add_bezt(newcu[i], fra, loc[i - 4]);
+			else
+				add_bezt(newcu[i], fra, scale[i - 7]);
+		}
+	}
+	verify_adt_action((ID*)&ob->id, 1);
+
+	// add curves
+	for (int i= 0; i < totcu; i++) {
+		add_bone_fcurve(ob, node, newcu[i]);
+	}
+
+	bPoseChannel *chan = get_pose_channel(ob->pose, bone_name);
+	chan->rotmode = ROT_MODE_QUAT;
+
+}
+
 
 //Check if object is animated by checking if animlist_map holds the animlist_id of node transforms
 AnimationImporter::AnimMix* AnimationImporter::get_animation_type ( const COLLADAFW::Node * node , 
@@ -1007,9 +1155,10 @@ AnimationImporter::AnimMix* AnimationImporter::get_animation_type ( const COLLAD
 		const COLLADAFW::UniqueId& listid = transform->getAnimationList();
 
 		//check if transformation has animations
-		if (animlist_map.find(listid) == animlist_map.end()) continue ;
-		else 
-		{
+		if (animlist_map.find(listid) == animlist_map.end()) {
+			continue;
+		}
+		else {
 			types->transform = types->transform|NODE_TRANSFORM;
 			break;
 		}
@@ -1053,7 +1202,7 @@ AnimationImporter::AnimMix* AnimationImporter::get_animation_type ( const COLLAD
 			const COLLADAFW::Effect *ef = (COLLADAFW::Effect *) (FW_object_map[matuid]);
 			if (ef != NULL) { /* can be NULL [#28909] */
 				const COLLADAFW::CommonEffectPointerArray& commonEffects = ef->getCommonEffects();
-				if(!commonEffects.empty()) {
+				if (!commonEffects.empty()) {
 					COLLADAFW::EffectCommon *efc = commonEffects[0];
 					types->material =  setAnimType(&(efc->getShininess()),(types->material), MATERIAL_SHININESS);
 					types->material =  setAnimType(&(efc->getSpecular().getColor()),(types->material), MATERIAL_SPEC_COLOR);
@@ -1406,12 +1555,10 @@ void AnimationImporter::evaluate_transform_at_frame(float mat[4][4], COLLADAFW::
 		float m[4][4];
 
 		unit_m4(m);
-		if ( type != COLLADAFW::Transformation::MATRIX )
-			continue;
 
 		std::string nodename = node->getName().size() ? node->getName() : node->getOriginalId();
 		if (!evaluate_animation(tm, m, fra, nodename.c_str())) {
-			/*switch (type) {
+			switch (type) {
 			case COLLADAFW::Transformation::ROTATE:
 				dae_rotate_to_mat4(tm, m);
 				break;
@@ -1426,8 +1573,8 @@ void AnimationImporter::evaluate_transform_at_frame(float mat[4][4], COLLADAFW::
 				break;
 			default:
 				fprintf(stderr, "unsupported transformation type %d\n", type);
-			}*/
-			dae_matrix_to_mat4(tm, m);
+			}
+			// dae_matrix_to_mat4(tm, m);
 			
 		}
 
@@ -1510,6 +1657,7 @@ bool AnimationImporter::evaluate_animation(COLLADAFW::Transformation *tm, float
 				}
 
 				COLLADABU::Math::Vector3& axis = ((COLLADAFW::Rotate*)tm)->getRotationAxis();
+
 				float ax[3] = {axis[0], axis[1], axis[2]};
 				float angle = evaluate_fcurve(curves[0], fra);
 				axis_angle_to_mat4(mat, ax, angle);
@@ -1636,9 +1784,7 @@ bool AnimationImporter::calc_joint_parent_mat_rest(float mat[4][4], float par[4]
 Object *AnimationImporter::get_joint_object(COLLADAFW::Node *root, COLLADAFW::Node *node, Object *par_job)
 {
 	if (joint_objects.find(node->getUniqueId()) == joint_objects.end()) {
-		Object *job = add_object(scene, OB_EMPTY);
-
-		rename_id((ID*)&job->id, (char*)get_joint_name(node));
+		Object *job = bc_add_object(scene, OB_EMPTY, (char*)get_joint_name(node));
 
 		job->lay = object_in_scene(job, scene)->lay = 2;
 
@@ -1740,7 +1886,7 @@ void AnimationImporter::add_bezt(FCurve *fcu, float fra, float value)
 	//float fps = (float)FPS;
 	BezTriple bez;
 	memset(&bez, 0, sizeof(BezTriple));
-	bez.vec[1][0] = fra ;
+	bez.vec[1][0] = fra;
 	bez.vec[1][1] = value;
 	bez.ipo = BEZT_IPO_LIN ;/* use default interpolation mode here... */
 	bez.f1 = bez.f2 = bez.f3 = SELECT;
