@@ -98,7 +98,7 @@ void ArmatureImporter::create_unskinned_bone( COLLADAFW::Node *node, EditBone *p
 	float angle = 0;
 
 	// get world-space
-	if (parent){
+	if (parent) {
 		mult_m4_m4m4(mat, parent_mat, obmat);
 
 	}
@@ -278,7 +278,7 @@ void ArmatureImporter::add_leaf_bone(float mat[][4], EditBone *bone,  COLLADAFW:
 	TagsMap::iterator etit;
 	ExtraTags *et = 0;
 	etit = uid_tags_map.find(node->getUniqueId().toAscii());
-	if(etit !=  uid_tags_map.end())
+	if (etit !=  uid_tags_map.end())
 	{
 		et = etit->second;
 		//else return;
@@ -306,7 +306,7 @@ void ArmatureImporter::fix_leaf_bones( )
 		float vec[3] = {0.0f, 0.0f, 0.1f};
 		
 		// if parent: take parent length and direction
-		if(leaf.bone->parent) sub_v3_v3v3(vec, leaf.bone->parent->tail, leaf.bone->parent->head);
+		if (leaf.bone->parent) sub_v3_v3v3(vec, leaf.bone->parent->tail, leaf.bone->parent->head);
 
 		copy_v3_v3(leaf.bone->tail, leaf.bone->head);
 		add_v3_v3v3(leaf.bone->tail, leaf.bone->head, vec);
@@ -368,7 +368,7 @@ Object *ArmatureImporter::get_empty_for_leaves()
 {
 	if (empty) return empty;
 	
-	empty = add_object(scene, OB_EMPTY);
+	empty = bc_add_object(scene, OB_EMPTY, NULL);
 	empty->empty_drawtype = OB_EMPTY_SPHERE;
 
 	return empty;
@@ -410,12 +410,16 @@ void ArmatureImporter::create_armature_bones( )
 	std::vector<COLLADAFW::Node*>::iterator ri;
 	//if there is an armature created for root_joint next root_joint
 	for (ri = root_joints.begin(); ri != root_joints.end(); ri++) {
-			if ( get_armature_for_joint(*ri) != NULL ) continue;
+		if ( get_armature_for_joint(*ri) != NULL ) continue;
 		
 		//add armature object for current joint
-		//Object *ob_arm = add_object(scene, OB_ARMATURE);
+		//Object *ob_arm = bc_add_object(scene, OB_ARMATURE, NULL);
 
 		Object *ob_arm = joint_parent_map[(*ri)->getUniqueId()];
+
+		if (!ob_arm)
+			continue;
+
 		//ob_arm->type = OB_ARMATURE;
 		ED_armature_to_edit(ob_arm);
 
@@ -423,24 +427,24 @@ void ArmatureImporter::create_armature_bones( )
 
 		// create unskinned bones
 		/*
-		   TODO:
-		   check if bones have already been created for a given joint
+		  TODO:
+		  check if bones have already been created for a given joint
 		*/
 		leaf_bone_length = FLT_MAX;
 		create_unskinned_bone(*ri, NULL, (*ri)->getChildNodes().getCount(), NULL, ob_arm);
 
 		fix_leaf_bones();
 
-	// exit armature edit mode
+		// exit armature edit mode
 	
-	unskinned_armature_map[(*ri)->getUniqueId()] = ob_arm;
+		unskinned_armature_map[(*ri)->getUniqueId()] = ob_arm;
 
-	ED_armature_from_edit(ob_arm);
+		ED_armature_from_edit(ob_arm);
 
-	set_pose(ob_arm , *ri, NULL, NULL ); 
+		set_pose(ob_arm , *ri, NULL, NULL ); 
 
-	ED_armature_edit_free(ob_arm);
-	DAG_id_tag_update(&ob_arm->id, OB_RECALC_OB|OB_RECALC_DATA);
+		ED_armature_edit_free(ob_arm);
+		DAG_id_tag_update(&ob_arm->id, OB_RECALC_OB|OB_RECALC_DATA);
 	}
 
 	
@@ -570,7 +574,7 @@ void ArmatureImporter::set_pose ( Object * ob_arm ,  COLLADAFW::Node * root_node
 { 
 	char * bone_name = (char *) bc_get_joint_name ( root_node);
 	float mat[4][4];
-   float obmat[4][4];
+	float obmat[4][4];
 
 	float ax[3];
 	float angle = 0.0f;
@@ -578,12 +582,12 @@ void ArmatureImporter::set_pose ( Object * ob_arm ,  COLLADAFW::Node * root_node
 	// object-space
 	get_node_mat(obmat, root_node, NULL, NULL);
 
-	//if(*edbone)
+	//if (*edbone)
 	bPoseChannel * pchan  = get_pose_channel(ob_arm -> pose ,  bone_name); 
 	//else fprintf ( "",
 
 	// get world-space
-	if (parentname){
+	if (parentname) {
 		mult_m4_m4m4(mat, parent_mat, obmat);
 		bPoseChannel *parchan = get_pose_channel(ob_arm->pose, parentname);
 
@@ -763,7 +767,7 @@ Object *ArmatureImporter::get_armature_for_joint(COLLADAFW::Node *node)
 
 	std::map<COLLADAFW::UniqueId, Object*>::iterator arm;
 	for (arm = unskinned_armature_map.begin(); arm != unskinned_armature_map.end(); arm++) {
-		if(arm->first == node->getUniqueId() )
+		if (arm->first == node->getUniqueId() )
 			return arm->second;
 	}
 	return NULL;
