@@ -137,7 +137,7 @@ static short actedit_get_context (bAnimContext *ac, SpaceAction *saction)
 				if (ac->obact && ac->obact->adt)
 					saction->action = ac->obact->adt->action;
 				else
-					saction->action= NULL;
+					saction->action = NULL;
 			}
 			
 			ac->datatype= ANIMCONT_ACTION;
@@ -150,6 +150,16 @@ static short actedit_get_context (bAnimContext *ac, SpaceAction *saction)
 			ac->datatype= ANIMCONT_SHAPEKEY;
 			ac->data= actedit_get_shapekeys(ac);
 			
+			/* if not pinned, sync with active object */
+			if (/*saction->pin == 0*/1) {
+				Key *key = (Key *)ac->data;
+				
+				if (key && key->adt)
+					saction->action = key->adt->action;
+				else
+					saction->action = NULL;
+			}
+			
 			ac->mode= saction->mode;
 			return 1;
 			
@@ -362,7 +372,10 @@ short ANIM_animdata_get_context (const bContext *C, bAnimContext *ac)
 		else {\
 			filter_mode |= ANIMFILTER_TMP_PEEK; \
 		} \
-		(void) _doSubChannels;
+		  \
+		{ \
+			(void) _doSubChannels; \
+		}
 		/* ... standard sub-channel filtering can go on here now ... */
 #define END_ANIMFILTER_SUBCHANNELS \
 		filter_mode = _filter; \
@@ -821,11 +834,14 @@ static bAnimListElem *make_new_animlistelem (void *data, short datatype, ID *own
  
 /* ----------------------------------------- */
 
-/* 'Only Selected' selected data filtering
+/* 'Only Selected' selected data and/or 'Include Hidden' filtering
  * NOTE: when this function returns true, the F-Curve is to be skipped 
  */
-static size_t skip_fcurve_selected_data (bDopeSheet *ads, FCurve *fcu, ID *owner_id, int filter_mode)
+static short skip_fcurve_selected_data (bDopeSheet *ads, FCurve *fcu, ID *owner_id, int filter_mode)
 {
+	/* hidden items should be skipped if we only care about visible data, but we aren't interested in hidden stuff */
+	short skip_hidden = (filter_mode & ANIMFILTER_DATA_VISIBLE) && !(ads->filterflag & ADS_FILTER_INCL_HIDDEN);
+	
 	if (GS(owner_id->name) == ID_OB) {
 		Object *ob= (Object *)owner_id;
 		
@@ -842,17 +858,22 @@ static size_t skip_fcurve_selected_data (bDopeSheet *ads, FCurve *fcu, ID *owner
 			/* check whether to continue or skip */
 			if ((pchan) && (pchan->bone)) {
 				/* if only visible channels, skip if bone not visible unless user wants channels from hidden data too */
-				if ((filter_mode & ANIMFILTER_DATA_VISIBLE) && !(ads->filterflag & ADS_FILTER_INCL_HIDDEN)) {
+				if (skip_hidden) {
 					bArmature *arm= (bArmature *)ob->data;
 					
+					/* skipping - not visible on currently visible layers */
 					if ((arm->layer & pchan->bone->layer) == 0)
 						return 1;
-					// TODO: manually hidden using flags
+					/* skipping - is currently hidden */
+					if (pchan->bone->flag & BONE_HIDDEN_P)
+						return 1;
 				}
 				
 				/* can only add this F-Curve if it is selected */
-				if ((pchan->bone->flag & BONE_SELECTED) == 0)
-					return 1;
+				if (ads->filterflag & ADS_FILTER_ONLYSEL) {
+					if ((pchan->bone->flag & BONE_SELECTED) == 0)
+						return 1;
+				}
 			}
 		}
 	}
@@ -871,14 +892,16 @@ static size_t skip_fcurve_selected_data (bDopeSheet *ads, FCurve *fcu, ID *owner
 			if (seq_name) MEM_freeN(seq_name);
 			
 			/* can only add this F-Curve if it is selected */
-			if (seq==NULL || (seq->flag & SELECT)==0)
-				return 1;
+			if (ads->filterflag & ADS_FILTER_ONLYSEL) {
+				if ((seq == NULL) || (seq->flag & SELECT)==0)
+					return 1;
+			}
 		}
 	}
 	else if (GS(owner_id->name) == ID_NT) {
 		bNodeTree *ntree = (bNodeTree *)owner_id;
 		
-		/* check for selected  nodes */
+		/* check for selected nodes */
 		if ((fcu->rna_path) && strstr(fcu->rna_path, "nodes")) {
 			bNode *node;
 			char *node_name;
@@ -889,8 +912,10 @@ static size_t skip_fcurve_selected_data (bDopeSheet *ads, FCurve *fcu, ID *owner
 			if (node_name) MEM_freeN(node_name);
 			
 			/* can only add this F-Curve if it is selected */
-			if ((node) && (node->flag & NODE_SELECT)==0)
-				return 1;
+			if (ads->filterflag & ADS_FILTER_ONLYSEL) {
+				if ((node) && (node->flag & NODE_SELECT)==0)
+					return 1;
+			}
 		}
 	}
 	return 0;
@@ -937,24 +962,26 @@ static FCurve *animfilter_fcurve_next (bDopeSheet *ads, FCurve *first, bActionGr
 	 */
 	for (fcu= first; ((fcu) && (fcu->grp==grp)); fcu= fcu->next) {
 		/* special exception for Pose-Channel/Sequence-Strip/Node Based F-Curves:
-		 *	- the 'Only Selected' data filter should be applied to Pose-Channel data too, but those are
-		 *	  represented as F-Curves. The way the filter for objects worked was to be the first check
-		 *	  after 'normal' visibility, so this is done first here too...
+		 *	- the 'Only Selected' and 'Include Hidden' data filters should be applied to sub-ID data which
+		 *	  can be independently selected/hidden, such as Pose-Channels, Sequence Strips, and Nodes.
+		 *	  Since these checks were traditionally done as first check for objects, we do the same here
 		 *	- we currently use an 'approximate' method for getting these F-Curves that doesn't require
 		 *	  carefully checking the entire path
 		 *	- this will also affect things like Drivers, and also works for Bone Constraints
 		 */
-		if ( ((ads) && (ads->filterflag & ADS_FILTER_ONLYSEL)) && (owner_id) ) {
-			if (skip_fcurve_selected_data(ads, fcu, owner_id, filter_mode))
-				continue;
-		}
+		if (ads && owner_id) {
+			if ((ads->filterflag & ADS_FILTER_ONLYSEL) || (ads->filterflag & ADS_FILTER_INCL_HIDDEN)==0) {
+				if (skip_fcurve_selected_data(ads, fcu, owner_id, filter_mode))
+					continue;
+			}
+		}	
 		
 		/* only include if visible (Graph Editor check, not channels check) */
 		if (!(filter_mode & ANIMFILTER_CURVE_VISIBLE) || (fcu->flag & FCURVE_VISIBLE)) {
 			/* only work with this channel and its subchannels if it is editable */
 			if (!(filter_mode & ANIMFILTER_FOREDIT) || EDITABLE_FCU(fcu)) {
 				/* only include this curve if selected in a way consistent with the filtering requirements */
-				if ( ANIMCHANNEL_SELOK(SEL_FCU(fcu)) && ANIMCHANNEL_SELEDITOK(SEL_FCU(fcu)) ) {
+				if (ANIMCHANNEL_SELOK(SEL_FCU(fcu)) && ANIMCHANNEL_SELEDITOK(SEL_FCU(fcu))) {
 					/* only include if this curve is active */
 					if (!(filter_mode & ANIMFILTER_ACTIVE) || (fcu->flag & FCURVE_ACTIVE)) {
 						/* name based filtering... */
@@ -1038,8 +1065,7 @@ static size_t animfilter_act_group (bAnimContext *ac, ListBase *anim_data, bDope
 			 * but to do this, we need to check that the group doesn't have it's not-visible flag set preventing 
 			 * all its sub-curves to be shown
 			 */
-			if ( !(filter_mode & ANIMFILTER_CURVE_VISIBLE) || !(agrp->flag & AGRP_NOTVISIBLE) )
-			{
+			if (!(filter_mode & ANIMFILTER_CURVE_VISIBLE) || !(agrp->flag & AGRP_NOTVISIBLE)) {
 				/* group must be editable for its children to be editable (if we care about this) */
 				if (!(filter_mode & ANIMFILTER_FOREDIT) || EDITABLE_AGRP(agrp)) {
 					/* get first F-Curve which can be used here */
@@ -1101,7 +1127,7 @@ static size_t animfilter_action (bAnimContext *ac, ListBase *anim_data, bDopeShe
 	}
 	
 	/* un-grouped F-Curves (only if we're not only considering those channels in the active group) */
-	if (!(filter_mode & ANIMFILTER_ACTGROUPED))  {
+	if (!(filter_mode & ANIMFILTER_ACTGROUPED)) {
 		FCurve *firstfcu = (lastchan)? (lastchan->next) : (act->curves.first);
 		items += animfilter_fcurves(anim_data, ads, firstfcu, NULL, filter_mode, owner_id);
 	}
@@ -1169,7 +1195,7 @@ static size_t animfilter_nla (bAnimContext *UNUSED(ac), ListBase *anim_data, bDo
 		/* only work with this channel and its subchannels if it is editable */
 		if (!(filter_mode & ANIMFILTER_FOREDIT) || EDITABLE_NLT(nlt)) {
 			/* only include this track if selected in a way consistent with the filtering requirements */
-			if ( ANIMCHANNEL_SELOK(SEL_NLT(nlt)) ) {
+			if (ANIMCHANNEL_SELOK(SEL_NLT(nlt))) {
 				/* only include if this track is active */
 				if (!(filter_mode & ANIMFILTER_ACTIVE) || (nlt->flag & NLATRACK_ACTIVE)) {
 					ANIMCHANNEL_NEW_CHANNEL(nlt, ANIMTYPE_NLATRACK, owner_id);
@@ -1189,7 +1215,7 @@ static size_t animfilter_block_data (bAnimContext *ac, ListBase *anim_data, bDop
 	size_t items = 0;
 
 	/* image object datablocks have no anim-data so check for NULL */
-	if(adt) {
+	if (adt) {
 		IdAdtTemplate *iat = (IdAdtTemplate*)id;
 
 		/* NOTE: this macro is used instead of inlining the logic here, since this sort of filtering is still needed
@@ -1229,7 +1255,7 @@ static size_t animdata_filter_shapekey (bAnimContext *ac, ListBase *anim_data, K
 		
 		/* loop through the channels adding ShapeKeys as appropriate */
 		for (kb= key->block.first; kb; kb= kb->next) {
-			/* skip the first one, since that's the non-animateable basis */
+			/* skip the first one, since that's the non-animatable basis */
 			// XXX maybe in future this may become handy?
 			if (kb == key->block.first) continue;
 			
@@ -1285,7 +1311,7 @@ static size_t animdata_filter_gpencil_data (ListBase *anim_data, bGPdata *gpd, i
 	return items;
 }
 
-/* Grab all Grase Pencil datablocks in file */
+/* Grab all Grease Pencil datablocks in file */
 // TODO: should this be amalgamated with the dopesheet filtering code?
 static size_t animdata_filter_gpencil (ListBase *anim_data, void *UNUSED(data), int filter_mode)
 {
@@ -1349,7 +1375,7 @@ static size_t animdata_filter_ds_nodetree (bAnimContext *ac, ListBase *anim_data
 		/* include data-expand widget first */
 		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 			/* check if filtering by active status */
-			if ANIMCHANNEL_ACTIVEOK(ntree) {
+			if (ANIMCHANNEL_ACTIVEOK(ntree)) {
 				ANIMCHANNEL_NEW_CHANNEL(ntree, ANIMTYPE_DSNTREE, owner_id);
 			}
 		}
@@ -1397,8 +1423,8 @@ static size_t animdata_filter_ds_textures (bAnimContext *ac, ListBase *anim_data
 		default: 
 		{
 			/* invalid/unsupported option */
-			if (G.f & G_DEBUG)
-				printf("ERROR: unsupported owner_id (i.e. texture stack) for filter textures - %s \n", owner_id->name);
+			if (G.debug & G_DEBUG)
+				printf("ERROR: unsupported owner_id (i.e. texture stack) for filter textures - %s\n", owner_id->name);
 			return 0;
 		}
 	}
@@ -1434,7 +1460,7 @@ static size_t animdata_filter_ds_textures (bAnimContext *ac, ListBase *anim_data
 			/* include texture-expand widget? */
 			if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 				/* check if filtering by active status */
-				if ANIMCHANNEL_ACTIVEOK(tex) {
+				if (ANIMCHANNEL_ACTIVEOK(tex)) {
 					ANIMCHANNEL_NEW_CHANNEL(tex, ANIMTYPE_DSTEX, owner_id);
 				}
 			}
@@ -1450,51 +1476,83 @@ static size_t animdata_filter_ds_textures (bAnimContext *ac, ListBase *anim_data
 	return items;
 }
 
+
+static size_t animdata_filter_ds_material (bAnimContext *ac, ListBase *anim_data, bDopeSheet *ads, Material *ma, int filter_mode)
+{
+	ListBase tmp_data = {NULL, NULL};
+	size_t tmp_items = 0;
+	size_t items = 0;
+	
+	/* add material's animation data to temp collection */
+	BEGIN_ANIMFILTER_SUBCHANNELS(FILTER_MAT_OBJD(ma))
+	{
+		/* material's animation data */
+		tmp_items += animfilter_block_data(ac, &tmp_data, ads, (ID *)ma, filter_mode);
+			
+		/* textures */
+		if (!(ads->filterflag & ADS_FILTER_NOTEX))
+			tmp_items += animdata_filter_ds_textures(ac, &tmp_data, ads, (ID *)ma, filter_mode);
+			
+		/* nodes */
+		if ((ma->nodetree) && !(ads->filterflag & ADS_FILTER_NONTREE)) 
+			tmp_items += animdata_filter_ds_nodetree(ac, &tmp_data, ads, (ID *)ma, ma->nodetree, filter_mode);
+	}
+	END_ANIMFILTER_SUBCHANNELS;
+	
+	/* did we find anything? */
+	if (tmp_items) {
+		/* include material-expand widget first */
+		// hmm... do we need to store the index of this material in the array anywhere?
+		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
+			/* check if filtering by active status */
+			if (ANIMCHANNEL_ACTIVEOK(ma)) {
+				ANIMCHANNEL_NEW_CHANNEL(ma, ANIMTYPE_DSMAT, ma);
+			}
+		}
+		
+		/* now add the list of collected channels */
+		BLI_movelisttolist(anim_data, &tmp_data);
+		BLI_assert((tmp_data.first == tmp_data.last) && (tmp_data.first == NULL));
+		items += tmp_items;
+	}
+	
+	return items;
+}
+
 static size_t animdata_filter_ds_materials (bAnimContext *ac, ListBase *anim_data, bDopeSheet *ads, Object *ob, int filter_mode)
 {
-	size_t items=0;
-	int a=0;
+	short has_nested = 0;
+	size_t items = 0;
+	int a = 0;
 	
-	/* firstly check that we actuallly have some materials, by gathering all materials in a temp list */
-	for (a=1; a <= ob->totcol; a++) {
-		Material *ma= give_current_material(ob, a);
-		ListBase tmp_data = {NULL, NULL};
-		size_t tmp_items = 0;
+	/* first pass: take the materials referenced via the Material slots of the object */
+	for (a = 1; a <= ob->totcol; a++) {
+		Material *ma = give_current_material(ob, a);
 		
-		/* if no material returned, skip - so that we don't get weird blank entries... */
-		if (ma == NULL) continue;
-		
-		/* add material's animation data to temp collection */
-		BEGIN_ANIMFILTER_SUBCHANNELS(FILTER_MAT_OBJD(ma))
-		{
-			/* material's animation data */
-			tmp_items += animfilter_block_data(ac, &tmp_data, ads, (ID *)ma, filter_mode);
-				
-			/* textures */
-			if (!(ads->filterflag & ADS_FILTER_NOTEX))
-				tmp_items += animdata_filter_ds_textures(ac, &tmp_data, ads, (ID *)ma, filter_mode);
-				
-			/* nodes */
-			if ((ma->nodetree) && !(ads->filterflag & ADS_FILTER_NONTREE)) 
-				tmp_items += animdata_filter_ds_nodetree(ac, &tmp_data, ads, (ID *)ma, ma->nodetree, filter_mode);
-		}
-		END_ANIMFILTER_SUBCHANNELS;
-		
-		/* did we find anything? */
-		if (tmp_items) {
-			/* include material-expand widget first */
-			// hmm... do we need to store the index of this material in the array anywhere?
-			if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
-				/* check if filtering by active status */
-				if ANIMCHANNEL_ACTIVEOK(ma) {
-					ANIMCHANNEL_NEW_CHANNEL(ma, ANIMTYPE_DSMAT, ma);
-				}
-			}
+		/* if material is valid, try to add relevant contents from here */
+		if (ma) {
+			/* add channels */
+			items += animdata_filter_ds_material(ac, anim_data, ads, ma, filter_mode);
 			
-			/* now add the list of collected channels */
-			BLI_movelisttolist(anim_data, &tmp_data);
-			BLI_assert((tmp_data.first == tmp_data.last) && (tmp_data.first == NULL));
-			items += tmp_items;
+			/* for optimising second pass - check if there's a nested material here to come back for */
+			if (has_nested == 0)
+				has_nested = give_node_material(ma) != NULL;
+		}
+	}
+	
+	/* second pass: go through a second time looking for "nested" materials (material.material references)
+	 *
+	 * NOTE: here we ignore the expanded status of the parent, as it could be too confusing as to why these are
+	 *       disappearing/not available, since the relationships between these is not that clear
+	 */
+	if (has_nested) {
+		for (a = 1; a <= ob->totcol; a++) {
+			Material *base = give_current_material(ob, a);
+			Material *ma   = give_node_material(base);
+			
+			/* add channels from the nested material if it exists */
+			if (ma)
+				items += animdata_filter_ds_material(ac, anim_data, ads, ma, filter_mode);
 		}
 	}
 	
@@ -1528,7 +1586,7 @@ static size_t animdata_filter_ds_particles (bAnimContext *ac, ListBase *anim_dat
 			/* include particle-expand widget first */
 			if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 				/* check if filtering by active status */
-				if ANIMCHANNEL_ACTIVEOK(psys->part) {
+				if (ANIMCHANNEL_ACTIVEOK(psys->part)) {
 					ANIMCHANNEL_NEW_CHANNEL(psys->part, ANIMTYPE_DSPART, psys->part);
 				}
 			}
@@ -1668,7 +1726,7 @@ static size_t animdata_filter_ds_obdata (bAnimContext *ac, ListBase *anim_data,
 		/* include data-expand widget first */
 		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 			/* check if filtering by active status */
-			if ANIMCHANNEL_ACTIVEOK(iat) {
+			if (ANIMCHANNEL_ACTIVEOK(iat)) {
 				ANIMCHANNEL_NEW_CHANNEL(iat, type, iat);
 			}
 		}
@@ -1702,7 +1760,7 @@ static size_t animdata_filter_ds_keyanim (bAnimContext *ac, ListBase *anim_data,
 	if (tmp_items) {
 		/* include key-expand widget first */
 		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
-			if ANIMCHANNEL_ACTIVEOK(key) {
+			if (ANIMCHANNEL_ACTIVEOK(key)) {
 				ANIMCHANNEL_NEW_CHANNEL(key, ANIMTYPE_DSSKEY, ob);
 			}
 		}
@@ -1819,7 +1877,7 @@ static size_t animdata_filter_dopesheet_ob (bAnimContext *ac, ListBase *anim_dat
 		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 			/* check if filtering by selection */
 			// XXX: double-check on this - most of the time, a lot of tools need to filter out these channels!
-			if ANIMCHANNEL_SELOK((base->flag & SELECT)) {
+			if (ANIMCHANNEL_SELOK((base->flag & SELECT))) {
 				/* check if filtering by active status */
 				if (ANIMCHANNEL_ACTIVEOK(ob)) {
 					ANIMCHANNEL_NEW_CHANNEL(base, ANIMTYPE_OBJECT, ob);
@@ -1864,7 +1922,7 @@ static size_t animdata_filter_ds_world (bAnimContext *ac, ListBase *anim_data, b
 		/* include data-expand widget first */
 		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 			/* check if filtering by active status */
-			if ANIMCHANNEL_ACTIVEOK(wo) {
+			if (ANIMCHANNEL_ACTIVEOK(wo)) {
 				ANIMCHANNEL_NEW_CHANNEL(wo, ANIMTYPE_DSWOR, sce);
 			}
 		}
@@ -1969,7 +2027,7 @@ static size_t animdata_filter_dopesheet_scene (bAnimContext *ac, ListBase *anim_
 		/* firstly add object expander if required */
 		if (filter_mode & ANIMFILTER_LIST_CHANNELS) {
 			/* check if filtering by selection */
-			if ANIMCHANNEL_SELOK((sce->flag & SCE_DS_SELECTED)) {
+			if (ANIMCHANNEL_SELOK((sce->flag & SCE_DS_SELECTED))) {
 				/* NOTE: active-status doesn't matter for this! */
 				ANIMCHANNEL_NEW_CHANNEL(sce, ANIMTYPE_SCENE, sce);
 			}
@@ -1995,8 +2053,8 @@ static size_t animdata_filter_dopesheet (bAnimContext *ac, ListBase *anim_data,
 	/* check that we do indeed have a scene */
 	if ((ads->source == NULL) || (GS(ads->source->name)!=ID_SCE)) {
 		printf("DopeSheet Error: Not scene!\n");
-		if (G.f & G_DEBUG)
-			printf("\tPointer = %p, Name = '%s' \n", (void *)ads->source, (ads->source)?ads->source->name:NULL);
+		if (G.debug & G_DEBUG)
+			printf("\tPointer = %p, Name = '%s'\n", (void *)ads->source, (ads->source)?ads->source->name:NULL);
 		return 0;
 	}
 	
@@ -2043,7 +2101,7 @@ static size_t animdata_filter_dopesheet (bAnimContext *ac, ListBase *anim_data,
 			}
 			
 			/* check selection and object type filters */
-			if ( (ads->filterflag & ADS_FILTER_ONLYSEL) && !((base->flag & SELECT) /*|| (base == sce->basact)*/) )  {
+			if ( (ads->filterflag & ADS_FILTER_ONLYSEL) && !((base->flag & SELECT) /*|| (base == sce->basact)*/) ) {
 				/* only selected should be shown */
 				continue;
 			}
