@@ -83,10 +83,10 @@ static ListBase *context_get_markers(Scene *scene, ScrArea *sa)
 			/* local markers can only be shown when there's only a single active action to grab them from 
 			 * 	- flag only takes effect when there's an action, otherwise it can get too confusing?
 			 */
-			if (ELEM(saction->mode, SACTCONT_ACTION, SACTCONT_SHAPEKEY) && (saction->action)) 
-			{
-				if (saction->flag & SACTION_POSEMARKERS_SHOW)
+			if (ELEM(saction->mode, SACTCONT_ACTION, SACTCONT_SHAPEKEY) && (saction->action)) {
+				if (saction->flag & SACTION_POSEMARKERS_SHOW) {
 					return &saction->action->markers;
+				}
 			}
 		}
 	}
@@ -201,7 +201,7 @@ void ED_markers_get_minmax (ListBase *markers, short sel, float *first, float *l
 	int selcount = 0;
 	
 	/* sanity check */
-	//printf("markers = %p -  %p, %p \n", markers, markers->first, markers->last);
+	//printf("markers = %p -  %p, %p\n", markers, markers->first, markers->last);
 	if (markers == NULL) {
 		*first = 0.0f;
 		*last = 0.0f;
@@ -232,7 +232,7 @@ void ED_markers_get_minmax (ListBase *markers, short sel, float *first, float *l
 		selcount= BLI_countlist(markers);
 	
 	/* if only selected are to be considered, only consider the selected ones
-	 * (optimisation for not searching list) 
+	 * (optimization for not searching list)
 	 */
 	if (selcount > 1) {
 		for (marker= markers->first; marker; marker= marker->next) {
@@ -323,7 +323,7 @@ TimeMarker *ED_markers_get_first_selected(ListBase *markers)
 /* --------------------------------- */
 
 /* Print debugging prints of list of markers 
- * BSI's: do NOT make static or put in if-defs as "unused code". That's too much trouble when we need to use for quick debuggging!
+ * BSI's: do NOT make static or put in if-defs as "unused code". That's too much trouble when we need to use for quick debugging!
  */
 void debug_markers_print_list(ListBase *markers)
 {
@@ -410,7 +410,7 @@ static void draw_marker(View2D *v2d, TimeMarker *marker, int cfra, int flag)
 		}
 		else {
 			UI_ThemeColor(TH_TEXT);
-			if((marker->frame <= cfra) && (marker->frame+5 > cfra)) {
+			if ((marker->frame <= cfra) && (marker->frame+5 > cfra)) {
 				x= xpos*xscale + 4.0f;
 				y= (ypixels <= 39.0f)? (ypixels - 10.0f) : 29.0f;
 			}
@@ -421,7 +421,7 @@ static void draw_marker(View2D *v2d, TimeMarker *marker, int cfra, int flag)
 		}
 
 #ifdef DURIAN_CAMERA_SWITCH
-		if(marker->camera && (marker->camera->restrictflag & OB_RESTRICT_RENDER)) {
+		if (marker->camera && (marker->camera->restrictflag & OB_RESTRICT_RENDER)) {
 			float col[4];
 			glGetFloatv(GL_CURRENT_COLOR, col);
 			col[3]= 0.4;
@@ -582,44 +582,43 @@ static int ed_marker_add(bContext *C, wmOperator *UNUSED(op))
 static void MARKER_OT_add(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Time Marker";
-	ot->description= "Add a new time marker";
-	ot->idname= "MARKER_OT_add";
+	ot->name = "Add Time Marker";
+	ot->description = "Add a new time marker";
+	ot->idname = "MARKER_OT_add";
 	
 	/* api callbacks */
-	ot->exec= ed_marker_add;
+	ot->exec = ed_marker_add;
 	ot->invoke = ed_markers_opwrap_invoke;
-	ot->poll= ED_operator_animview_active;
+	ot->poll = ED_operator_animview_active;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* ************************** transform markers *************************** */
 
-
 /* operator state vars used:  
-	frs: delta movement
-
-functions:
-
-	init()   check selection, add customdata with old values and some lookups
-
-	apply()  do the actual movement
-
-	exit()	cleanup, send notifier
-
-	cancel() to escape from modal
-
-callbacks:
-
-	exec()	calls init, apply, exit 
-
-	invoke() calls init, adds modal handler
-
-	modal()	accept modal events while doing it, ends with apply and exit, or cancel
-
-*/
+ *     frs: delta movement
+ * 
+ * functions:
+ * 
+ *     init()   check selection, add customdata with old values and some lookups
+ * 
+ *     apply()  do the actual movement
+ * 
+ *     exit()    cleanup, send notifier
+ * 
+ *     cancel() to escape from modal
+ * 
+ * callbacks:
+ * 
+ *     exec()    calls init, apply, exit 
+ * 
+ *     invoke() calls init, adds modal handler
+ * 
+ *     modal()    accept modal events while doing it, ends with apply and exit, or cancel
+ * 
+ */
 
 typedef struct MarkerMove {
 	SpaceLink *slink;
@@ -639,7 +638,7 @@ static int ed_marker_move_init(bContext *C, wmOperator *op)
 	int totmark=0;
 	int a;
 
-	if(markers == NULL) return 0;
+	if (markers == NULL) return 0;
 	
 	for (marker= markers->first; marker; marker= marker->next)
 		if (marker->flag & SELECT) totmark++;
@@ -682,7 +681,7 @@ static void ed_marker_move_exit(bContext *C, wmOperator *op)
 
 static int ed_marker_move_invoke(bContext *C, wmOperator *op, wmEvent *evt)
 {
-	if(ed_marker_move_init(C, op)) {
+	if (ed_marker_move_init(C, op)) {
 		MarkerMove *mm= op->customdata;
 		
 		mm->evtx= evt->x;
@@ -752,7 +751,7 @@ static int ed_marker_move_modal(bContext *C, wmOperator *op, wmEvent *evt)
 			return OPERATOR_CANCELLED;
 		
 		case RIGHTMOUSE:
-			/* press = user manually demands transform to be cancelled */
+			/* press = user manually demands transform to be canceled */
 			if (evt->val == KM_PRESS) {
 				ed_marker_move_cancel(C, op);
 				return OPERATOR_CANCELLED;
@@ -852,8 +851,7 @@ static int ed_marker_move_modal(bContext *C, wmOperator *op, wmEvent *evt)
 		float vec[3];
 		char str_tx[256];
 		
-		if (handleNumInput(&mm->num, evt))
-		{
+		if (handleNumInput(&mm->num, evt)) {
 			applyNumInput(&mm->num, vec);
 			outputNumInput(&mm->num, str_tx);
 			
@@ -874,7 +872,7 @@ static int ed_marker_move_modal(bContext *C, wmOperator *op, wmEvent *evt)
 
 static int ed_marker_move_exec(bContext *C, wmOperator *op)
 {
-	if(ed_marker_move_init(C, op)) {
+	if (ed_marker_move_init(C, op)) {
 		ed_marker_move_apply(op);
 		ed_marker_move_exit(C, op);
 		return OPERATOR_FINISHED;
@@ -885,19 +883,19 @@ static int ed_marker_move_exec(bContext *C, wmOperator *op)
 static void MARKER_OT_move(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Move Time Marker";
-	ot->description= "Move selected time marker(s)";
-	ot->idname= "MARKER_OT_move";
+	ot->name = "Move Time Marker";
+	ot->description = "Move selected time marker(s)";
+	ot->idname = "MARKER_OT_move";
 	
 	/* api callbacks */
-	ot->exec= ed_marker_move_exec;
-	ot->invoke= ed_marker_move_invoke_wrapper;
-	ot->modal= ed_marker_move_modal;
-	ot->poll= ed_markers_poll_selected_markers;
-	ot->cancel= ed_marker_move_cancel;
+	ot->exec = ed_marker_move_exec;
+	ot->invoke = ed_marker_move_invoke_wrapper;
+	ot->modal = ed_marker_move_modal;
+	ot->poll = ed_markers_poll_selected_markers;
+	ot->cancel = ed_marker_move_cancel;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO|OPTYPE_BLOCKING|OPTYPE_GRAB_POINTER;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO|OPTYPE_BLOCKING|OPTYPE_GRAB_POINTER;
 	
 	/* rna storage */
 	RNA_def_int(ot->srna, "frames", 0, INT_MIN, INT_MAX, "Frames", "", INT_MIN, INT_MAX);
@@ -905,23 +903,21 @@ static void MARKER_OT_move(wmOperatorType *ot)
 
 /* ************************** duplicate markers *************************** */
 
-/* operator state vars used:  
-	frs: delta movement
-
-functions:
-
-	apply()  do the actual duplicate
-
-callbacks:
-
-	exec()	calls apply, move_exec
-
-	invoke() calls apply, move_invoke
-
-	modal()	uses move_modal
-
-*/
-
+/* operator state vars used:
+ *     frs: delta movement
+ *
+ * functions:
+ *
+ *     apply()  do the actual duplicate
+ *
+ * callbacks:
+ *
+ *     exec()    calls apply, move_exec
+ *
+ *     invoke() calls apply, move_invoke
+ *
+ *     modal()    uses move_modal
+ */
 
 /* duplicate selected TimeMarkers */
 static void ed_marker_duplicate_apply(bContext *C)
@@ -933,7 +929,7 @@ static void ed_marker_duplicate_apply(bContext *C)
 		return;
 
 	/* go through the list of markers, duplicate selected markers and add duplicated copies
-	 * to the begining of the list (unselect original markers) 
+	 * to the beginning of the list (unselect original markers)
 	 */
 	for (marker= markers->first; marker; marker= marker->next) {
 		if (marker->flag & SELECT) {
@@ -950,7 +946,7 @@ static void ed_marker_duplicate_apply(bContext *C)
 			newmarker->camera= marker->camera;
 #endif
 
-			/* new marker is added to the begining of list */
+			/* new marker is added to the beginning of list */
 			// FIXME: bad ordering!
 			BLI_addhead(markers, newmarker);
 		}
@@ -980,19 +976,19 @@ static int ed_marker_duplicate_invoke_wrapper(bContext *C, wmOperator *op, wmEve
 static void MARKER_OT_duplicate(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Duplicate Time Marker";
-	ot->description= "Duplicate selected time marker(s)";
-	ot->idname= "MARKER_OT_duplicate";
+	ot->name = "Duplicate Time Marker";
+	ot->description = "Duplicate selected time marker(s)";
+	ot->idname = "MARKER_OT_duplicate";
 	
 	/* api callbacks */
-	ot->exec= ed_marker_duplicate_exec;
-	ot->invoke= ed_marker_duplicate_invoke_wrapper;
-	ot->modal= ed_marker_move_modal;
-	ot->poll= ed_markers_poll_selected_markers;
-	ot->cancel= ed_marker_move_cancel;
+	ot->exec = ed_marker_duplicate_exec;
+	ot->invoke = ed_marker_duplicate_invoke_wrapper;
+	ot->modal = ed_marker_move_modal;
+	ot->poll = ed_markers_poll_selected_markers;
+	ot->cancel = ed_marker_move_cancel;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* rna storage */
 	RNA_def_int(ot->srna, "frames", 0, INT_MIN, INT_MAX, "Frames", "", INT_MIN, INT_MAX);
@@ -1055,7 +1051,7 @@ static int ed_marker_select(bContext *C, wmEvent *evt, int extend, int camera)
 			scene_deselect_all(scene);
 		
 		for (marker= markers->first; marker; marker= marker->next) {
-			if(marker->frame==cfra) {
+			if (marker->frame==cfra) {
 				sel= (marker->flag & SELECT);
 				break;
 			}
@@ -1067,7 +1063,7 @@ static int ed_marker_select(bContext *C, wmEvent *evt, int extend, int camera)
 					base= object_in_scene(marker->camera, scene);
 					if (base) {
 						ED_base_object_select(base, sel);
-						if(sel)
+						if (sel)
 							ED_base_object_activate(C, base);
 					}
 				}
@@ -1105,18 +1101,18 @@ static int ed_marker_select_invoke_wrapper(bContext *C, wmOperator *op, wmEvent
 static void MARKER_OT_select(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select Time Marker";
-	ot->description= "Select time marker(s)";
-	ot->idname= "MARKER_OT_select";
+	ot->name = "Select Time Marker";
+	ot->description = "Select time marker(s)";
+	ot->idname = "MARKER_OT_select";
 	
 	/* api callbacks */
-	ot->invoke= ed_marker_select_invoke_wrapper;
-	ot->poll= ed_markers_poll_markers_exist;
+	ot->invoke = ed_marker_select_invoke_wrapper;
+	ot->poll = ed_markers_poll_markers_exist;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
-	RNA_def_boolean(ot->srna, "extend", 0, "Extend", "extend the selection");
+	RNA_def_boolean(ot->srna, "extend", 0, "Extend", "Extend the selection");
 #ifdef DURIAN_CAMERA_SWITCH
 	RNA_def_boolean(ot->srna, "camera", 0, "Camera", "Select the camera");
 #endif
@@ -1125,23 +1121,23 @@ static void MARKER_OT_select(wmOperatorType *ot)
 /* *************************** border select markers **************** */
 
 /* operator state vars used: (added by default WM callbacks)   
-	xmin, ymin     
-	xmax, ymax     
-
-customdata: the wmGesture pointer, with subwindow
-
-callbacks:
-
-	exec()	has to be filled in by user
-
-	invoke() default WM function
-			adds modal handler
-
-	modal()	default WM function 
-			accept modal events while doing it, calls exec(), handles ESC and border drawing
-
-	poll()	has to be filled in by user for context
-*/
+ * xmin, ymin
+ * xmax, ymax
+ *
+ * customdata: the wmGesture pointer, with subwindow
+ *
+ * callbacks:
+ *
+ * 	exec()	has to be filled in by user
+ *
+ * 	invoke() default WM function
+ * 			adds modal handler
+ *
+ * 	modal()	default WM function 
+ * 			accept modal events while doing it, calls exec(), handles ESC and border drawing
+ *
+ * 	poll()	has to be filled in by user for context
+ */
 
 static int ed_marker_border_select_exec(bContext *C, wmOperator *op)
 {
@@ -1193,20 +1189,20 @@ static int ed_marker_select_border_invoke_wrapper(bContext *C, wmOperator *op, w
 static void MARKER_OT_select_border(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Marker Border select";
-	ot->description= "Select all time markers using border selection";
-	ot->idname= "MARKER_OT_select_border";
+	ot->name = "Marker Border select";
+	ot->description = "Select all time markers using border selection";
+	ot->idname = "MARKER_OT_select_border";
 	
 	/* api callbacks */
-	ot->exec= ed_marker_border_select_exec;
-	ot->invoke= ed_marker_select_border_invoke_wrapper;
-	ot->modal= WM_border_select_modal;
-	ot->cancel= WM_border_select_cancel;
+	ot->exec = ed_marker_border_select_exec;
+	ot->invoke = ed_marker_select_border_invoke_wrapper;
+	ot->modal = WM_border_select_modal;
+	ot->cancel = WM_border_select_cancel;
 	
-	ot->poll= ed_markers_poll_markers_exist;
+	ot->poll = ed_markers_poll_markers_exist;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* rna */
 	WM_operator_properties_gesture_border(ot, TRUE);
@@ -1227,7 +1223,7 @@ static int ed_marker_select_all_exec(bContext *C, wmOperator *op)
 		action = (ED_markers_get_first_selected(markers) != NULL) ? SEL_DESELECT : SEL_SELECT;
 	}
 	
-	for(marker= markers->first; marker; marker= marker->next) {
+	for (marker= markers->first; marker; marker= marker->next) {
 		switch (action) {
 		case SEL_SELECT:
 			marker->flag |= SELECT;
@@ -1250,17 +1246,17 @@ static int ed_marker_select_all_exec(bContext *C, wmOperator *op)
 static void MARKER_OT_select_all(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "(De)select all markers";
-	ot->description= "Change selection of all time markers";
-	ot->idname= "MARKER_OT_select_all";
+	ot->name = "(De)select all markers";
+	ot->description = "Change selection of all time markers";
+	ot->idname = "MARKER_OT_select_all";
 	
 	/* api callbacks */
-	ot->exec= ed_marker_select_all_exec;
+	ot->exec = ed_marker_select_all_exec;
 	ot->invoke = ed_markers_opwrap_invoke;
-	ot->poll= ed_markers_poll_markers_exist;
+	ot->poll = ed_markers_poll_markers_exist;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* rna */
 	WM_operator_properties_select_all(ot);
@@ -1303,17 +1299,17 @@ static int ed_marker_delete_invoke_wrapper(bContext *C, wmOperator *op, wmEvent
 static void MARKER_OT_delete(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Delete Markers";
-	ot->description= "Delete selected time marker(s)";
-	ot->idname= "MARKER_OT_delete";
+	ot->name = "Delete Markers";
+	ot->description = "Delete selected time marker(s)";
+	ot->idname = "MARKER_OT_delete";
 	
 	/* api callbacks */
-	ot->invoke= ed_marker_delete_invoke_wrapper;
-	ot->exec= ed_marker_delete_exec;
-	ot->poll= ed_markers_poll_selected_markers;
+	ot->invoke = ed_marker_delete_invoke_wrapper;
+	ot->exec = ed_marker_delete_exec;
+	ot->poll = ed_markers_poll_selected_markers;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;	
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;	
 }
 
 
@@ -1339,7 +1335,7 @@ static int ed_marker_rename_exec(bContext *C, wmOperator *op)
 
 static int ed_marker_rename_invoke_wrapper(bContext *C, wmOperator *op, wmEvent *evt)
 {
-	/* must initialise the marker name first if there is a marker selected */
+	/* must initialize the marker name first if there is a marker selected */
 	TimeMarker *marker = ED_markers_get_first_selected(ED_context_get_markers(C));
 	if (marker)
 		RNA_string_set(op->ptr, "name", marker->name);
@@ -1351,17 +1347,17 @@ static int ed_marker_rename_invoke_wrapper(bContext *C, wmOperator *op, wmEvent
 static void MARKER_OT_rename(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Rename Marker";
-	ot->description= "Rename first selected time marker";
-	ot->idname= "MARKER_OT_rename";
+	ot->name = "Rename Marker";
+	ot->description = "Rename first selected time marker";
+	ot->idname = "MARKER_OT_rename";
 	
 	/* api callbacks */
-	ot->invoke= ed_marker_rename_invoke_wrapper;
-	ot->exec= ed_marker_rename_exec;
-	ot->poll= ed_markers_poll_selected_markers;
+	ot->invoke = ed_marker_rename_invoke_wrapper;
+	ot->exec = ed_marker_rename_exec;
+	ot->poll = ed_markers_poll_selected_markers;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;	
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;	
 	
 	/* properties */
 	ot->prop = RNA_def_string(ot->srna, "name", "RenamedMarker", sizeof(((TimeMarker *)NULL)->name), "Name", "New name for marker");
@@ -1404,22 +1400,22 @@ static void MARKER_OT_make_links_scene(wmOperatorType *ot)
 	PropertyRNA *prop;
 
 	/* identifiers */
-	ot->name= "Make Links to Scene";
-	ot->description= "Copy selected markers to another scene";
-	ot->idname= "MARKER_OT_make_links_scene";
+	ot->name = "Make Links to Scene";
+	ot->description = "Copy selected markers to another scene";
+	ot->idname = "MARKER_OT_make_links_scene";
 
 	/* api callbacks */
-	ot->exec= ed_marker_make_links_scene_exec;
+	ot->exec = ed_marker_make_links_scene_exec;
 	ot->invoke = ed_markers_opwrap_invoke;
-	ot->poll= ed_markers_poll_selected_markers;
+	ot->poll = ed_markers_poll_selected_markers;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	prop= RNA_def_enum(ot->srna, "scene", DummyRNA_NULL_items, 0, "Scene", "");
 	RNA_def_enum_funcs(prop, RNA_scene_itemf);
-	ot->prop= prop;
+	ot->prop = prop;
 
 }
 
@@ -1435,7 +1431,7 @@ static int ed_marker_camera_bind_exec(bContext *C, wmOperator *UNUSED(op))
 	TimeMarker *marker;
 
 	marker= ED_markers_get_first_selected(markers);
-	if(marker == NULL)
+	if (marker == NULL)
 		return OPERATOR_CANCELLED;
 
 	marker->camera= ob;
@@ -1454,17 +1450,17 @@ static int ed_marker_camera_bind_exec(bContext *C, wmOperator *UNUSED(op))
 static void MARKER_OT_camera_bind(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Bind Camera to Markers";
-	ot->description= "Bind the active camera to selected markers(s)";
-	ot->idname= "MARKER_OT_camera_bind";
+	ot->name = "Bind Camera to Markers";
+	ot->description = "Bind the active camera to selected markers(s)";
+	ot->idname = "MARKER_OT_camera_bind";
 
 	/* api callbacks */
-	ot->exec= ed_marker_camera_bind_exec;
+	ot->exec = ed_marker_camera_bind_exec;
 	ot->invoke = ed_markers_opwrap_invoke;
-	ot->poll= ed_markers_poll_selected_markers;
+	ot->poll = ed_markers_poll_selected_markers;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 #endif
 
@@ -1490,7 +1486,7 @@ void ED_operatortypes_marker(void)
 /* called in screen_ops.c:ED_keymap_screen() */
 void ED_marker_keymap(wmKeyConfig *keyconf)
 {
-	wmKeyMap *keymap= WM_keymap_find(keyconf, "Markers", 0, 0);
+	wmKeyMap *keymap = WM_keymap_find(keyconf, "Markers", 0, 0);
 	wmKeyMapItem *kmi;
 	
 	WM_keymap_verify_item(keymap, "MARKER_OT_add", MKEY, KM_PRESS, 0, 0);
@@ -1501,11 +1497,11 @@ void ED_marker_keymap(wmKeyConfig *keyconf)
 	RNA_boolean_set(kmi->ptr, "extend", TRUE);
 
 #ifdef DURIAN_CAMERA_SWITCH
-	kmi= WM_keymap_add_item(keymap, "MARKER_OT_select", SELECTMOUSE, KM_PRESS, KM_CTRL, 0);
+	kmi = WM_keymap_add_item(keymap, "MARKER_OT_select", SELECTMOUSE, KM_PRESS, KM_CTRL, 0);
 	RNA_boolean_set(kmi->ptr, "extend", FALSE);
 	RNA_boolean_set(kmi->ptr, "camera", TRUE);
 
-	kmi= WM_keymap_add_item(keymap, "MARKER_OT_select", SELECTMOUSE, KM_PRESS, KM_SHIFT|KM_CTRL, 0);
+	kmi = WM_keymap_add_item(keymap, "MARKER_OT_select", SELECTMOUSE, KM_PRESS, KM_SHIFT|KM_CTRL, 0);
 	RNA_boolean_set(kmi->ptr, "extend", TRUE);
 	RNA_boolean_set(kmi->ptr, "camera", TRUE);
 #else
