@@ -145,7 +145,7 @@ void duplicate_fcurve_keys(FCurve *fcu)
 	int i;
 	
 	/* this can only work when there is an F-Curve, and also when there are some BezTriples */
-	if ELEM(NULL, fcu, fcu->bezt)
+	if (ELEM(NULL, fcu, fcu->bezt))
 		return;
 	
 	for (i=0; i < fcu->totvert; i++) {
@@ -544,7 +544,7 @@ short copy_animedit_keys (bAnimContext *ac, ListBase *anim_data)
 				/* add to buffer */
 				newbuf= MEM_callocN(sizeof(BezTriple)*(aci->totvert+1), "copybuf beztriple");
 				
-				/* assume that since we are just resizing the array, just copy all existing data across */
+				/* assume that since we are just re-sizing the array, just copy all existing data across */
 				if (aci->bezt)
 					memcpy(newbuf, aci->bezt, sizeof(BezTriple)*(aci->totvert));
 				
@@ -574,7 +574,7 @@ short copy_animedit_keys (bAnimContext *ac, ListBase *anim_data)
 	if (ELEM(NULL, animcopybuf.first, animcopybuf.last))
 		return -1;
 
-	/* incase 'relative' paste method is used */
+	/* in case 'relative' paste method is used */
 	animcopy_cfra= CFRA;
 
 	/* everything went fine */
@@ -853,7 +853,7 @@ short paste_animedit_keys (bAnimContext *ac, ListBase *anim_data,
 				}
 			}
 			
-			/* dont continue if some fcurves were pasted */
+			/* don't continue if some fcurves were pasted */
 			if (totmatch)
 				break;
 		}
