@@ -43,7 +43,6 @@
 
 #include "BLI_blenlib.h"
 #include "BLI_math.h"
-#include "BLI_editVert.h"
 #include "BLI_utildefines.h"
 #include "BLI_ghash.h"
 #include "BLI_graph.h"
@@ -324,7 +323,7 @@ static RigGraph *newRigGraph(void)
 	rg->free_node = NULL;
 	
 #ifdef USE_THREADS
-//	if(G.scene->r.mode & R_FIXED_THREADS)
+//	if (G.scene->r.mode & R_FIXED_THREADS)
 //	{
 //		totthread = G.scene->r.threads;
 //	}
@@ -1009,7 +1008,7 @@ static void RIG_reconnectControlBones(RigGraph *rg)
 			/* look on deform bones first */
 			BLI_ghashIterator_init(&ghi, rg->bones_map);
 			
-			for( ; !BLI_ghashIterator_isDone(&ghi); BLI_ghashIterator_step(&ghi))
+			for ( ; !BLI_ghashIterator_isDone(&ghi); BLI_ghashIterator_step(&ghi))
 			{
 				EditBone *bone = (EditBone*)BLI_ghashIterator_getValue(&ghi);
 				
@@ -1299,7 +1298,7 @@ static void RIG_arcFromBoneChain(RigGraph *rg, ListBase *list, EditBone *root_bo
 	RigArc *arc = NULL;
 	int contain_head = 0;
 	
-	for(bone = root_bone; bone; bone = nextEditBoneChild(list, bone, 0))
+	for (bone = root_bone; bone; bone = nextEditBoneChild(list, bone, 0))
 	{
 		int nb_children;
 		
@@ -1551,7 +1550,7 @@ RigGraph *RIG_graphFromArmature(const bContext *C, Object *ob, bArmature *arm)
 	rg->ob = ob;
 
 	/* Do the rotations */
-	for (ebone = rg->editbones->first; ebone; ebone=ebone->next){
+	for (ebone = rg->editbones->first; ebone; ebone=ebone->next) {
 		if (ebone->parent == NULL)
 		{
 			RIG_arcFromBoneChain(rg, rg->editbones, ebone, NULL, 0);
@@ -1603,7 +1602,7 @@ static RigGraph *armatureSelectedToGraph(bContext *C, Object *ob, bArmature *arm
 	rg->ob = ob;
 
 	/* Do the rotations */
-	for (ebone = rg->editbones->first; ebone; ebone=ebone->next){
+	for (ebone = rg->editbones->first; ebone; ebone=ebone->next) {
 		if (ebone->parent == NULL)
 		{
 			RIG_arcFromBoneChain(rg, rg->editbones, ebone, NULL, 1);
@@ -2489,7 +2488,7 @@ static void markMultiResolutionChildArc(ReebNode *end_enode, ReebNode *enode)
 {
 	int i;
 	
-	for(i = 0; i < enode->degree; i++)
+	for (i = 0; i < enode->degree; i++)
 	{
 		ReebArc *earc = (ReebArc*)enode->arcs[i];
 		
@@ -2594,7 +2593,7 @@ static void findCorrespondingArc(RigGraph *rigg, RigArc *start_arc, RigNode *sta
 //		RIG_printArcBones(next_iarc);
 //	}
 	
-	for(i = 0; i < enode->degree; i++)
+	for (i = 0; i < enode->degree; i++)
 	{
 		next_earc = (ReebArc*)enode->arcs[i];
 		
@@ -2645,20 +2644,20 @@ static void findCorrespondingArc(RigGraph *rigg, RigArc *start_arc, RigNode *sta
 //		printf("flag %i -- level %i -- flag %i -- group %i\n", ARC_FREE, symmetry_level, symmetry_flag, symmetry_group);
 //		
 //		printf("CANDIDATES\n");
-//		for(i = 0; i < enode->degree; i++)
+//		for (i = 0; i < enode->degree; i++)
 //		{
 //			next_earc = (ReebArc*)enode->arcs[i];
 //			printf("flag %i -- level %i -- flag %i -- group %i\n", next_earc->flag, next_earc->symmetry_level, next_earc->symmetry_flag, next_earc->symmetry_group);
 //		}
 		
 		/* Emergency matching */
-		for(i = 0; i < enode->degree; i++)
+		for (i = 0; i < enode->degree; i++)
 		{
 			next_earc = (ReebArc*)enode->arcs[i];
 			
 			if (next_earc->flag == ARC_FREE && next_earc->symmetry_level == symmetry_level)
 			{
-//				printf("USING: \n");
+//				printf("USING:\n");
 //				printf("flag %i -- level %i -- flag %i -- group %i\n", next_earc->flag, next_earc->symmetry_level, next_earc->symmetry_flag, next_earc->symmetry_group);
 				matchMultiResolutionArc(rigg, start_node, next_iarc, next_earc);
 				break;
@@ -2688,7 +2687,7 @@ static void retargetSubgraph(bContext *C, RigGraph *rigg, RigArc *start_arc, Rig
 		matchMultiResolutionNode(rigg, inode, enode);
 	}
 	
-	for(i = 0; i < inode->degree; i++)
+	for (i = 0; i < inode->degree; i++)
 	{
 		RigArc *next_iarc = (RigArc*)inode->arcs[i];
 		
@@ -2902,12 +2901,10 @@ void BIF_retargetArc(bContext *C, ReebArc *earc, RigGraph *template_rigg)
 	char *num_string = scene->toolsettings->skgen_num_string;
 	int free_template = 0;
 	
-	if (template_rigg)
-	{
-		ob = template_rigg->ob; 	
+	if (template_rigg) {
+		ob = template_rigg->ob;
 	}
-	else
-	{
+	else {
 		free_template = 1;
 		ob = obedit;
 		template_rigg = armatureSelectedToGraph(C, ob, ob->data);
