@@ -109,7 +109,7 @@ void ED_armature_enter_posemode(bContext *C, Base *base)
 
 void ED_armature_exit_posemode(bContext *C, Base *base)
 {
-	if(base) {
+	if (base) {
 		Object *ob= base->object;
 		
 		ob->restore_mode = ob->mode;
@@ -154,18 +154,18 @@ static int pose_channel_in_IK_chain(Object *ob, bPoseChannel *pchan, int level)
 	
 	/* No need to check if constraint is active (has influence),
 	 * since all constraints with CONSTRAINT_IK_AUTO are active */
-	for(con= pchan->constraints.first; con; con= con->next) {
-		if(con->type==CONSTRAINT_TYPE_KINEMATIC) {
+	for (con= pchan->constraints.first; con; con= con->next) {
+		if (con->type==CONSTRAINT_TYPE_KINEMATIC) {
 			bKinematicConstraint *data= con->data;
-			if(data->rootbone == 0 || data->rootbone > level) {
-				if((data->flag & CONSTRAINT_IK_AUTO)==0)
+			if (data->rootbone == 0 || data->rootbone > level) {
+				if ((data->flag & CONSTRAINT_IK_AUTO)==0)
 					return 1;
 			}
 		}
 	}
-	for(bone= pchan->bone->childbase.first; bone; bone= bone->next) {
+	for (bone= pchan->bone->childbase.first; bone; bone= bone->next) {
 		pchan= get_pose_channel(ob->pose, bone->name);
-		if(pchan && pose_channel_in_IK_chain(ob, pchan, level + 1))
+		if (pchan && pose_channel_in_IK_chain(ob, pchan, level + 1))
 			return 1;
 	}
 	return 0;
@@ -197,24 +197,54 @@ void ED_pose_recalculate_paths(Scene *scene, Object *ob)
 	BLI_freelistN(&targets);
 }
 
+/* show popup to determine settings */
+static int pose_calculate_paths_invoke(bContext *C, wmOperator *op, wmEvent *evt)
+{	
+	Object *ob = object_pose_armature_get(CTX_data_active_object(C));
+	
+	if (ELEM(NULL, ob, ob->pose))
+		return OPERATOR_CANCELLED;
+	
+	/* set default settings from existing/stored settings */
+	{
+		bAnimVizSettings *avs = &ob->pose->avs;
+		PointerRNA avs_ptr;
+		
+		RNA_int_set(op->ptr, "start_frame", avs->path_sf);
+		RNA_int_set(op->ptr, "end_frame", avs->path_ef);
+		
+		RNA_pointer_create(NULL, &RNA_AnimVizMotionPaths, avs, &avs_ptr);
+		RNA_enum_set(op->ptr, "bake_location", RNA_enum_get(&avs_ptr, "bake_location"));
+	}
+	
+	/* show popup dialog to allow editing of range... */
+	// FIXME: hardcoded dimensions here are just arbitrary
+	return WM_operator_props_dialog_popup(C, op, 200, 200);
+}
+
 /* For the object with pose/action: create path curves for selected bones 
  * This recalculates the WHOLE path within the pchan->pathsf and pchan->pathef range
  */
-static int pose_calculate_paths_exec (bContext *C, wmOperator *op)
+static int pose_calculate_paths_exec(bContext *C, wmOperator *op)
 {
-	ScrArea *sa= CTX_wm_area(C);
+	Object *ob = object_pose_armature_get(CTX_data_active_object(C));
 	Scene *scene= CTX_data_scene(C);
-	Object *ob;
 	
-	/* since this call may also be used from the buttons window, we need to check for where to get the object */
-	if (sa->spacetype == SPACE_BUTS) 
-		ob= ED_object_context(C);
-	else
-		ob= object_pose_armature_get(CTX_data_active_object(C));
-		
 	if (ELEM(NULL, ob, ob->pose))
 		return OPERATOR_CANCELLED;
 	
+	/* grab baking settings from operator settings */
+	{
+		bAnimVizSettings *avs = &ob->pose->avs;
+		PointerRNA avs_ptr;
+		
+		avs->path_sf = RNA_int_get(op->ptr, "start_frame");
+		avs->path_ef = RNA_int_get(op->ptr, "end_frame");
+		
+		RNA_pointer_create(NULL, &RNA_AnimVizMotionPaths, avs, &avs_ptr);
+		RNA_enum_set(&avs_ptr, "bake_location", RNA_enum_get(op->ptr, "bake_location"));
+	}
+	
 	/* set up path data for bones being calculated */
 	CTX_DATA_BEGIN(C, bPoseChannel*, pchan, selected_pose_bones) 
 	{
@@ -228,7 +258,7 @@ static int pose_calculate_paths_exec (bContext *C, wmOperator *op)
 	ED_pose_recalculate_paths(scene, ob);
 	
 	/* notifiers for updates */
-	WM_event_add_notifier(C, NC_OBJECT|ND_POSE, ob);
+	WM_event_add_notifier(C, NC_OBJECT | ND_POSE, ob);
 	
 	return OPERATOR_FINISHED; 
 }
@@ -236,16 +266,27 @@ static int pose_calculate_paths_exec (bContext *C, wmOperator *op)
 void POSE_OT_paths_calculate (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Calculate Bone Paths";
-	ot->idname= "POSE_OT_paths_calculate";
-	ot->description= "Calculate paths for the selected bones";
+	ot->name = "Calculate Bone Paths";
+	ot->idname = "POSE_OT_paths_calculate";
+	ot->description = "Calculate paths for the selected bones";
 	
 	/* api callbacks */
-	ot->exec= pose_calculate_paths_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = pose_calculate_paths_invoke;
+	ot->exec = pose_calculate_paths_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
+	
+	/* properties */
+	RNA_def_int(ot->srna, "start_frame", 1, MINAFRAME, MAXFRAME, "Start", 
+	            "First frame to calculate bone paths on", MINFRAME, MAXFRAME/2.0);
+	RNA_def_int(ot->srna, "end_frame", 250, MINAFRAME, MAXFRAME, "End", 
+	            "Last frame to calculate bone paths on", MINFRAME, MAXFRAME/2.0);
+	
+	RNA_def_enum(ot->srna, "bake_location", motionpath_bake_location_items, 0, 
+	             "Bake Location", 
+				 "Which point on the bones is used when calculating paths");
 }
 
 /* --------- */
@@ -256,7 +297,7 @@ static void ED_pose_clear_paths(Object *ob)
 	bPoseChannel *pchan;
 	short skipped = 0;
 	
-	if ELEM(NULL, ob, ob->pose)
+	if (ELEM(NULL, ob, ob->pose))
 		return;
 	
 	/* free the motionpath blocks, but also take note of whether we skipped some... */
@@ -279,24 +320,17 @@ static void ED_pose_clear_paths(Object *ob)
 /* operator callback for this */
 static int pose_clear_paths_exec (bContext *C, wmOperator *UNUSED(op))
 {
-	ScrArea *sa= CTX_wm_area(C);
-	Object *ob;
-	
-	/* since this call may also be used from the buttons window, we need to check for where to get the object */
-	if (sa->spacetype == SPACE_BUTS) 
-		ob= ED_object_context(C);
-	else
-		ob= object_pose_armature_get(CTX_data_active_object(C));
+	Object *ob = object_pose_armature_get(CTX_data_active_object(C));
 		
 	/* only continue if there's an object */
-	if ELEM(NULL, ob, ob->pose)
+	if (ELEM(NULL, ob, ob->pose))
 		return OPERATOR_CANCELLED;
 	
 	/* use the backend function for this */
 	ED_pose_clear_paths(ob);
 	
 	/* notifiers for updates */
-	WM_event_add_notifier(C, NC_OBJECT|ND_POSE, ob);
+	WM_event_add_notifier(C, NC_OBJECT | ND_POSE, ob);
 	
 	return OPERATOR_FINISHED; 
 }
@@ -304,13 +338,13 @@ static int pose_clear_paths_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_paths_clear (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Clear Bone Paths";
-	ot->idname= "POSE_OT_paths_clear";
-	ot->description= "Clear path caches for selected bones";
+	ot->name = "Clear Bone Paths";
+	ot->idname = "POSE_OT_paths_clear";
+	ot->description = "Clear path caches for selected bones";
 	
 	/* api callbacks */
-	ot->exec= pose_clear_paths_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_clear_paths_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -338,7 +372,7 @@ static int pose_select_constraint_target_exec(bContext *C, wmOperator *UNUSED(op
 					for (ct= targets.first; ct; ct= ct->next) {
 						if ((ct->tar == ob) && (ct->subtarget[0])) {
 							bPoseChannel *pchanc= get_pose_channel(ob->pose, ct->subtarget);
-							if((pchanc) && !(pchanc->bone->flag & BONE_UNSELECTABLE)) {
+							if ((pchanc) && !(pchanc->bone->flag & BONE_UNSELECTABLE)) {
 								pchanc->bone->flag |= BONE_SELECTED|BONE_TIPSEL|BONE_ROOTSEL;
 								found= 1;
 							}
@@ -364,16 +398,16 @@ static int pose_select_constraint_target_exec(bContext *C, wmOperator *UNUSED(op
 void POSE_OT_select_constraint_target(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select Constraint Target";
-	ot->idname= "POSE_OT_select_constraint_target";
-	ot->description= "Select bones used as targets for the currently selected bones";
+	ot->name = "Select Constraint Target";
+	ot->idname = "POSE_OT_select_constraint_target";
+	ot->description = "Select bones used as targets for the currently selected bones";
 	
 	/* api callbacks */
-	ot->exec= pose_select_constraint_target_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_select_constraint_target_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* ******************* select hierarchy operator ************* */
@@ -407,8 +441,30 @@ static int pose_select_hierarchy_exec(bContext *C, wmOperator *op)
 					}
 				} 
 				else { /* direction == BONE_SELECT_CHILD */
+
+					/* the child member is only assigned to connected bones, see [#30340] */
+#if 0
 					if (pchan->child == NULL) continue;
 					else chbone = pchan->child->bone;
+#else
+					/* instead. find _any_ visible child bone, using the first one is a little arbitrary  - campbell */
+					chbone = pchan->child ? pchan->child->bone : NULL;
+					if (chbone == NULL) {
+						bPoseChannel *pchan_child;
+
+						for (pchan_child = ob->pose->chanbase.first; pchan_child; pchan_child = pchan_child->next) {
+							/* possible we have multiple children, some invisible */
+							if (PBONE_VISIBLE(arm, pchan_child->bone)) {
+								if (pchan_child->parent == pchan) {
+									chbone = pchan_child->bone;
+									break;
+								}
+							}
+						}
+					}
+
+					if (chbone == NULL) continue;
+#endif
 					
 					if (PBONE_VISIBLE(arm, chbone)) {
 						if (!add_to_sel) curbone->flag &= ~BONE_SELECTED;
@@ -441,19 +497,19 @@ void POSE_OT_select_hierarchy(wmOperatorType *ot)
 	};
 	
 	/* identifiers */
-	ot->name= "Select Hierarchy";
-	ot->idname= "POSE_OT_select_hierarchy";
-	ot->description= "Select immediate parent/children of selected bones";
+	ot->name = "Select Hierarchy";
+	ot->idname = "POSE_OT_select_hierarchy";
+	ot->description = "Select immediate parent/children of selected bones";
 	
 	/* api callbacks */
-	ot->exec= pose_select_hierarchy_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_select_hierarchy_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* props */
-	ot->prop= RNA_def_enum(ot->srna, "direction", direction_items, BONE_SELECT_PARENT, "Direction", "");
+	ot->prop = RNA_def_enum(ot->srna, "direction", direction_items, BONE_SELECT_PARENT, "Direction", "");
 	RNA_def_boolean(ot->srna, "extend", 0, "Add to Selection", "");
 	
 }
@@ -497,7 +553,7 @@ static short pose_select_same_group (bContext *C, Object *ob, short extend)
 	}
 	CTX_DATA_END;
 	
-	/* small optimisation: only loop through bones a second time if there are any groups tagged */
+	/* small optimization: only loop through bones a second time if there are any groups tagged */
 	if (tagged) {
 		/* only if group matches (and is not selected or current bone) */
 		CTX_DATA_BEGIN(C, bPoseChannel *, pchan, visible_pose_bones) 
@@ -661,21 +717,21 @@ void POSE_OT_select_grouped (wmOperatorType *ot)
 	};
 
 	/* identifiers */
-	ot->name= "Select Grouped";
+	ot->name = "Select Grouped";
 	ot->description = "Select all visible bones grouped by similar properties";
-	ot->idname= "POSE_OT_select_grouped";
+	ot->idname = "POSE_OT_select_grouped";
 	
 	/* api callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= pose_select_grouped_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = pose_select_grouped_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean(ot->srna, "extend", FALSE, "Extend", "Extend selection instead of deselecting everything first");
-	ot->prop= RNA_def_enum(ot->srna, "type", prop_select_grouped_types, 0, "Type", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", prop_select_grouped_types, 0, "Type", "");
 }
 
 
@@ -687,23 +743,23 @@ static int pose_bone_flip_active_exec (bContext *C, wmOperator *UNUSED(op))
 	Object *ob_act= CTX_data_active_object(C);
 	Object *ob= object_pose_armature_get(ob_act);
 
-	if(ob && (ob->mode & OB_MODE_POSE)) {
+	if (ob && (ob->mode & OB_MODE_POSE)) {
 		bArmature *arm= ob->data;
 
-		if(arm->act_bone) {
+		if (arm->act_bone) {
 			bPoseChannel *pchanf;
 			char name[MAXBONENAME];
 			flip_side_name(name, arm->act_bone->name, TRUE);
 
 			pchanf= get_pose_channel(ob->pose, name);
-			if(pchanf && pchanf->bone != arm->act_bone) {
+			if (pchanf && pchanf->bone != arm->act_bone) {
 				arm->act_bone->flag &= ~BONE_SELECTED;
 				pchanf->bone->flag |= BONE_SELECTED;
 
 				arm->act_bone= pchanf->bone;
 
 				/* in weightpaint we select the associated vertex group too */
-				if(ob_act->mode & OB_MODE_WEIGHT_PAINT) {
+				if (ob_act->mode & OB_MODE_WEIGHT_PAINT) {
 					ED_vgroup_select_by_name(ob_act, name);
 					DAG_id_tag_update(&ob_act->id, OB_RECALC_DATA);
 				}
@@ -721,13 +777,13 @@ static int pose_bone_flip_active_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_select_flip_active(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Flip Selected Active Bone";
-	ot->idname= "POSE_OT_select_flip_active";
-	ot->description= "Activate the bone with a flipped name";
+	ot->name = "Flip Selected Active Bone";
+	ot->idname = "POSE_OT_select_flip_active";
+	ot->description = "Activate the bone with a flipped name";
 	
 	/* api callbacks */
-	ot->exec= pose_bone_flip_active_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_bone_flip_active_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -755,7 +811,7 @@ static void pose_copy_menu(Scene *scene)
 	pchanact= pchan;
 	arm= ob->data;
 
-	/* if proxy-protected bones selected, some things (such as locks + displays) shouldn't be changable, 
+	/* if proxy-protected bones selected, some things (such as locks + displays) shouldn't be changeable,
 	 * but for constraints (just add local constraints)
 	 */
 	if (pose_has_protected_selected(ob, 0)) {
@@ -776,7 +832,7 @@ static void pose_copy_menu(Scene *scene)
 	if (nr <= 0) 
 		return;
 	
-	if (nr != 5)  {
+	if (nr != 5) {
 		for (pchan= ob->pose->chanbase.first; pchan; pchan= pchan->next) {
 			if ( (arm->layer & pchan->bone->layer) &&
 				 (pchan->bone->flag & BONE_SELECTED) &&
@@ -876,7 +932,7 @@ static void pose_copy_menu(Scene *scene)
 		BLI_duplicatelist(&const_copy, &(pchanact->constraints));
 		
 		/* build the puplist of constraints */
-		for (con = pchanact->constraints.first, i=0; con; con=con->next, i++){
+		for (con = pchanact->constraints.first, i=0; con; con=con->next, i++) {
 			const_toggle[i]= 1;
 //			add_numbut(i, TOG|INT, con->name, 0, 0, &(const_toggle[i]), "");
 		}
@@ -946,7 +1002,7 @@ void free_posebuf(void)
 		bPoseChannel *pchan;
 		
 		for (pchan= g_posebuf->chanbase.first; pchan; pchan= pchan->next) {
-			if(pchan->prop) {
+			if (pchan->prop) {
 				IDP_FreeProperty(pchan->prop);
 				MEM_freeN(pchan->prop);
 			}
@@ -968,8 +1024,8 @@ static void set_pose_keys (Object *ob)
 	bArmature *arm= ob->data;
 	bPoseChannel *chan;
 
-	if (ob->pose){
-		for (chan=ob->pose->chanbase.first; chan; chan=chan->next){
+	if (ob->pose) {
+		for (chan=ob->pose->chanbase.first; chan; chan=chan->next) {
 			Bone *bone= chan->bone;
 			if ((bone) && (bone->flag & BONE_SELECTED) && (arm->layer & bone->layer))
 				chan->flag |= POSE_KEY;	
@@ -1110,7 +1166,7 @@ static int pose_copy_exec (bContext *C, wmOperator *op)
 	Object *ob= object_pose_armature_get(CTX_data_active_object(C));
 	
 	/* sanity checking */
-	if ELEM(NULL, ob, ob->pose) {
+	if (ELEM(NULL, ob, ob->pose)) {
 		BKE_report(op->reports, RPT_ERROR, "No Pose to Copy");
 		return OPERATOR_CANCELLED;
 	}
@@ -1129,16 +1185,16 @@ static int pose_copy_exec (bContext *C, wmOperator *op)
 void POSE_OT_copy (wmOperatorType *ot) 
 {
 	/* identifiers */
-	ot->name= "Copy Pose";
-	ot->idname= "POSE_OT_copy";
-	ot->description= "Copies the current pose of the selected bones to copy/paste buffer";
+	ot->name = "Copy Pose";
+	ot->idname = "POSE_OT_copy";
+	ot->description = "Copies the current pose of the selected bones to copy/paste buffer";
 	
 	/* api callbacks */
-	ot->exec= pose_copy_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_copy_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flag */
-	ot->flag= OPTYPE_REGISTER;
+	ot->flag = OPTYPE_REGISTER;
 }
 
 /* ---- */
@@ -1155,7 +1211,7 @@ static int pose_paste_exec (bContext *C, wmOperator *op)
 	KeyingSet *ks = ANIM_get_keyingset_for_autokeying(scene, ANIM_KS_LOC_ROT_SCALE_ID);
 
 	/* sanity checks */
-	if ELEM(NULL, ob, ob->pose)
+	if (ELEM(NULL, ob, ob->pose))
 		return OPERATOR_CANCELLED;
 
 	if (g_posebuf == NULL) {
@@ -1164,7 +1220,7 @@ static int pose_paste_exec (bContext *C, wmOperator *op)
 	}
 	
 	/* if selOnly option is enabled, if user hasn't selected any bones, 
-	 * just go back to default behaviour to be more in line with other pose tools
+	 * just go back to default behavior to be more in line with other pose tools
 	 */
 	if (selOnly) {
 		if (CTX_DATA_COUNT(C, selected_pose_bones) == 0)
@@ -1195,20 +1251,24 @@ static int pose_paste_exec (bContext *C, wmOperator *op)
 
 void POSE_OT_paste (wmOperatorType *ot)
 {
+	PropertyRNA *prop;
+
 	/* identifiers */
-	ot->name= "Paste Pose";
-	ot->idname= "POSE_OT_paste";
-	ot->description= "Paste the stored pose on to the current pose";
+	ot->name = "Paste Pose";
+	ot->idname = "POSE_OT_paste";
+	ot->description = "Paste the stored pose on to the current pose";
 	
 	/* api callbacks */
-	ot->exec= pose_paste_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_paste_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flag */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
-	RNA_def_boolean(ot->srna, "flipped", FALSE, "Flipped on X-Axis", "Paste the stored pose flipped on to current pose");
+	prop = RNA_def_boolean(ot->srna, "flipped", FALSE, "Flipped on X-Axis", "Paste the stored pose flipped on to current pose");
+	RNA_def_property_flag(prop, PROP_SKIP_SAVE);
+
 	RNA_def_boolean(ot->srna, "selected_mask", FALSE, "On Selected Only", "Only paste the stored pose on to selected bones in the current pose");
 }
 
@@ -1242,13 +1302,13 @@ static int pose_group_add_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_group_add (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Bone Group";
-	ot->idname= "POSE_OT_group_add";
-	ot->description= "Add a new bone group";
+	ot->name = "Add Bone Group";
+	ot->idname = "POSE_OT_group_add";
+	ot->description = "Add a new bone group";
 	
 	/* api callbacks */
-	ot->exec= pose_group_add_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_group_add_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1282,13 +1342,13 @@ static int pose_group_remove_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_group_remove (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Remove Bone Group";
-	ot->idname= "POSE_OT_group_remove";
-	ot->description= "Removes the active bone group";
+	ot->name = "Remove Bone Group";
+	ot->idname = "POSE_OT_group_remove";
+	ot->description = "Removes the active bone group";
 	
 	/* api callbacks */
-	ot->exec= pose_group_remove_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_group_remove_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1397,14 +1457,14 @@ static int pose_group_assign_exec (bContext *C, wmOperator *op)
 void POSE_OT_group_assign (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Selected to Bone Group";
-	ot->idname= "POSE_OT_group_assign";
-	ot->description= "Add selected bones to the chosen bone group";
+	ot->name = "Add Selected to Bone Group";
+	ot->idname = "POSE_OT_group_assign";
+	ot->description = "Add selected bones to the chosen bone group";
 	
 	/* api callbacks */
-	ot->invoke= pose_groups_menu_invoke;
-	ot->exec= pose_group_assign_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = pose_groups_menu_invoke;
+	ot->exec = pose_group_assign_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1453,13 +1513,13 @@ static int pose_group_unassign_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_group_unassign (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Remove Selected from Bone Groups";
-	ot->idname= "POSE_OT_group_unassign";
-	ot->description= "Remove selected bones from all bone groups";
+	ot->name = "Remove Selected from Bone Groups";
+	ot->idname = "POSE_OT_group_unassign";
+	ot->description = "Remove selected bones from all bone groups";
 	
 	/* api callbacks */
-	ot->exec= pose_group_unassign_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_group_unassign_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1534,16 +1594,16 @@ void POSE_OT_group_move(wmOperatorType *ot)
 	};
 
 	/* identifiers */
-	ot->name= "Move Bone Group";
-	ot->idname= "POSE_OT_group_move";
-	ot->description= "Change position of active Bone Group in list of Bone Groups";
+	ot->name = "Move Bone Group";
+	ot->idname = "POSE_OT_group_move";
+	ot->description = "Change position of active Bone Group in list of Bone Groups";
 
 	/* api callbacks */
-	ot->exec= group_move_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = group_move_exec;
+	ot->poll = ED_operator_posemode;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	RNA_def_enum(ot->srna, "direction", group_slot_move, 0, "Direction", "Direction to move, UP or DOWN");
 }
@@ -1618,16 +1678,16 @@ static int group_sort_exec(bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_group_sort(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Sort Bone Groups";
-	ot->idname= "POSE_OT_group_sort";
-	ot->description= "Sort Bone Groups by their names in ascending order";
+	ot->name = "Sort Bone Groups";
+	ot->idname = "POSE_OT_group_sort";
+	ot->description = "Sort Bone Groups by their names in ascending order";
 
 	/* api callbacks */
-	ot->exec= group_sort_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = group_sort_exec;
+	ot->poll = ED_operator_posemode;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 static void pose_group_select(bContext *C, Object *ob, int select)
@@ -1676,13 +1736,13 @@ static int pose_group_select_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_group_select (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select Bones of Bone Group";
-	ot->idname= "POSE_OT_group_select";
-	ot->description= "Select bones in active Bone Group";
+	ot->name = "Select Bones of Bone Group";
+	ot->idname = "POSE_OT_group_select";
+	ot->description = "Select bones in active Bone Group";
 	
 	/* api callbacks */
-	ot->exec= pose_group_select_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_group_select_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1714,13 +1774,13 @@ static int pose_group_deselect_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_group_deselect (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Deselect Bone Group";
-	ot->idname= "POSE_OT_group_deselect";
-	ot->description= "Deselect bones of active Bone Group";
+	ot->name = "Deselect Bone Group";
+	ot->idname = "POSE_OT_group_deselect";
+	ot->description = "Deselect bones of active Bone Group";
 	
 	/* api callbacks */
-	ot->exec= pose_group_deselect_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_group_deselect_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1759,16 +1819,16 @@ static int pose_flip_names_exec (bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_flip_names (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Flip Names";
-	ot->idname= "POSE_OT_flip_names";
-	ot->description= "Flips (and corrects) the axis suffixes of the the names of selected bones";
+	ot->name = "Flip Names";
+	ot->idname = "POSE_OT_flip_names";
+	ot->description = "Flips (and corrects) the axis suffixes of the the names of selected bones";
 	
 	/* api callbacks */
-	ot->exec= pose_flip_names_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_flip_names_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* ------------------ */
@@ -1789,7 +1849,7 @@ static int pose_autoside_names_exec (bContext *C, wmOperator *op)
 	CTX_DATA_BEGIN(C, bPoseChannel*, pchan, selected_pose_bones)
 	{
 		BLI_strncpy(newname, pchan->name, sizeof(newname));
-		if(bone_autoside_name(newname, 1, axis, pchan->bone->head[axis], pchan->bone->tail[axis]))
+		if (bone_autoside_name(newname, 1, axis, pchan->bone->head[axis], pchan->bone->tail[axis]))
 			ED_armature_bone_rename(arm, pchan->name, newname);
 	}
 	CTX_DATA_END;
@@ -1812,20 +1872,20 @@ void POSE_OT_autoside_names (wmOperatorType *ot)
 		{0, NULL, 0, NULL, NULL}};
 	
 	/* identifiers */
-	ot->name= "AutoName by Axis";
-	ot->idname= "POSE_OT_autoside_names";
-	ot->description= "Automatically renames the selected bones according to which side of the target axis they fall on";
+	ot->name = "AutoName by Axis";
+	ot->idname = "POSE_OT_autoside_names";
+	ot->description = "Automatically renames the selected bones according to which side of the target axis they fall on";
 	
 	/* api callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= pose_autoside_names_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = pose_autoside_names_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* settings */
-	ot->prop= RNA_def_enum(ot->srna, "axis", axis_items, 0, "Axis", "Axis tag names with");
+	ot->prop = RNA_def_enum(ot->srna, "axis", axis_items, 0, "Axis", "Axis tag names with");
 }
 
 /* ********************************************** */
@@ -1852,20 +1912,20 @@ static int pose_bone_rotmode_exec (bContext *C, wmOperator *op)
 void POSE_OT_rotation_mode_set (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Set Rotation Mode";
-	ot->idname= "POSE_OT_rotation_mode_set";
-	ot->description= "Set the rotation representation used by selected bones";
+	ot->name = "Set Rotation Mode";
+	ot->idname = "POSE_OT_rotation_mode_set";
+	ot->description = "Set the rotation representation used by selected bones";
 	
 	/* callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= pose_bone_rotmode_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = pose_bone_rotmode_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
-	ot->prop= RNA_def_enum(ot->srna, "type", posebone_rotmode_items, 0, "Rotation Mode", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", posebone_rotmode_items, 0, "Rotation Mode", "");
 }
 
 /* ********************************************** */
@@ -1911,16 +1971,16 @@ static int pose_armature_layers_showall_exec (bContext *C, wmOperator *op)
 void ARMATURE_OT_layers_show_all (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Show All Layers";
-	ot->idname= "ARMATURE_OT_layers_show_all";
-	ot->description= "Make all armature layers visible";
+	ot->name = "Show All Layers";
+	ot->idname = "ARMATURE_OT_layers_show_all";
+	ot->description = "Make all armature layers visible";
 	
 	/* callbacks */
-	ot->exec= pose_armature_layers_showall_exec;
-	ot->poll= pose_armature_layers_showall_poll;
+	ot->exec = pose_armature_layers_showall_exec;
+	ot->poll = pose_armature_layers_showall_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	ot->prop = RNA_def_boolean(ot->srna, "all", 1, "All Layers", "Enable all layers or just the first 16 (top row)");
@@ -1977,17 +2037,17 @@ static int pose_armature_layers_exec (bContext *C, wmOperator *op)
 void POSE_OT_armature_layers (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Change Armature Layers";
-	ot->idname= "POSE_OT_armature_layers";
-	ot->description= "Change the visible armature layers";
+	ot->name = "Change Armature Layers";
+	ot->idname = "POSE_OT_armature_layers";
+	ot->description = "Change the visible armature layers";
 	
 	/* callbacks */
-	ot->invoke= pose_armature_layers_invoke;
-	ot->exec= pose_armature_layers_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = pose_armature_layers_invoke;
+	ot->exec = pose_armature_layers_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean_layer_member(ot->srna, "layers", 32, NULL, "Layer", "Armature layers to make visible");
@@ -1996,17 +2056,17 @@ void POSE_OT_armature_layers (wmOperatorType *ot)
 void ARMATURE_OT_armature_layers (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Change Armature Layers";
-	ot->idname= "ARMATURE_OT_armature_layers";
-	ot->description= "Change the visible armature layers";
+	ot->name = "Change Armature Layers";
+	ot->idname = "ARMATURE_OT_armature_layers";
+	ot->description = "Change the visible armature layers";
 	
 	/* callbacks */
-	ot->invoke= pose_armature_layers_invoke;
-	ot->exec= pose_armature_layers_exec;
-	ot->poll= ED_operator_editarmature;
+	ot->invoke = pose_armature_layers_invoke;
+	ot->exec = pose_armature_layers_exec;
+	ot->poll = ED_operator_editarmature;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean_layer_member(ot->srna, "layers", 32, NULL, "Layer", "Armature layers to make visible");
@@ -2046,7 +2106,7 @@ static int pose_bone_layers_exec (bContext *C, wmOperator *op)
 	PointerRNA ptr;
 	int layers[32]; /* hardcoded for now - we can only have 32 armature layers, so this should be fine... */
 
-	if(ob==NULL || ob->data==NULL) {
+	if (ob==NULL || ob->data==NULL) {
 		return OPERATOR_CANCELLED;
 	}
 
@@ -2071,17 +2131,17 @@ static int pose_bone_layers_exec (bContext *C, wmOperator *op)
 void POSE_OT_bone_layers (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Change Bone Layers";
-	ot->idname= "POSE_OT_bone_layers";
-	ot->description= "Change the layers that the selected bones belong to";
+	ot->name = "Change Bone Layers";
+	ot->idname = "POSE_OT_bone_layers";
+	ot->description = "Change the layers that the selected bones belong to";
 	
 	/* callbacks */
-	ot->invoke= pose_bone_layers_invoke;
-	ot->exec= pose_bone_layers_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = pose_bone_layers_invoke;
+	ot->exec = pose_bone_layers_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean_layer_member(ot->srna, "layers", 32, NULL, "Layer", "Armature layers that bone belongs to");
@@ -2143,17 +2203,17 @@ static int armature_bone_layers_exec (bContext *C, wmOperator *op)
 void ARMATURE_OT_bone_layers (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Change Bone Layers";
-	ot->idname= "ARMATURE_OT_bone_layers";
-	ot->description= "Change the layers that the selected bones belong to";
+	ot->name = "Change Bone Layers";
+	ot->idname = "ARMATURE_OT_bone_layers";
+	ot->description = "Change the layers that the selected bones belong to";
 	
 	/* callbacks */
-	ot->invoke= armature_bone_layers_invoke;
-	ot->exec= armature_bone_layers_exec;
-	ot->poll= ED_operator_editarmature;
+	ot->invoke = armature_bone_layers_invoke;
+	ot->exec = armature_bone_layers_exec;
+	ot->poll = ED_operator_editarmature;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean_layer_member(ot->srna, "layers", 32, NULL, "Layer", "Armature layers that bone belongs to");
@@ -2192,15 +2252,15 @@ void POSE_OT_quaternions_flip (wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Flip Quats";
-	ot->idname= "POSE_OT_quaternions_flip";
-	ot->description= "Flip quaternion values to achieve desired rotations, while maintaining the same orientations";
+	ot->idname = "POSE_OT_quaternions_flip";
+	ot->description = "Flip quaternion values to achieve desired rotations, while maintaining the same orientations";
 	
 	/* callbacks */
-	ot->exec= pose_flip_quats_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_flip_quats_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* ********************************************** */
@@ -2268,14 +2328,14 @@ void POSE_OT_user_transforms_clear (wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Clear User Transforms";
-	ot->idname= "POSE_OT_user_transforms_clear";
-	ot->description= "Reset pose on selected bones to keyframed state";
+	ot->idname = "POSE_OT_user_transforms_clear";
+	ot->description = "Reset pose on selected bones to keyframed state";
 	
 	/* callbacks */
-	ot->exec= pose_clear_user_transforms_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_clear_user_transforms_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
