@@ -29,8 +29,8 @@
  */
 
 /* Note: this is included twice with different #defines for DEF_ICON
-   once from UI_resources.h for the internal icon enum and
-   once for interface_api.c for the definition of the RNA enum for the icons */
+ * once from UI_resources.h for the internal icon enum and
+ * once for interface_api.c for the definition of the RNA enum for the icons */
 
 /* ICON_ prefix added */
 DEF_ICON(NONE)
@@ -843,17 +843,13 @@ DEF_ICON(LONGDISPLAY)
 DEF_ICON(SHORTDISPLAY)
 DEF_ICON(GHOST)
 DEF_ICON(IMGDISPLAY)
-#ifndef DEF_ICON_BLANK_SKIP
-	DEF_ICON(BLANK284)
-	DEF_ICON(BLANK285)
-#endif
+DEF_ICON(SAVE_AS)
+DEF_ICON(SAVE_COPY)
 DEF_ICON(BOOKMARKS)
 DEF_ICON(FONTPREVIEW)
 DEF_ICON(FILTER)
 DEF_ICON(NEWFOLDER)
-#ifndef DEF_ICON_BLANK_SKIP
-	DEF_ICON(BLANK285F)
-#endif
+DEF_ICON(OPEN_RECENT)
 DEF_ICON(FILE_PARENT)
 DEF_ICON(FILE_REFRESH)
 DEF_ICON(FILE_FOLDER)
@@ -864,26 +860,26 @@ DEF_ICON(FILE_MOVIE)
 DEF_ICON(FILE_SCRIPT)
 DEF_ICON(FILE_SOUND)
 DEF_ICON(FILE_FONT)
-#ifndef DEF_ICON_BLANK_SKIP
-	DEF_ICON(BLANK291b)
+DEF_ICON(FILE_TEXT)
 
-	/* available */
-	DEF_ICON(BLANK292)
-	DEF_ICON(BLANK293)
-	DEF_ICON(BLANK294)
-	DEF_ICON(BLANK295)
-	DEF_ICON(BLANK296)
-	DEF_ICON(BLANK297)
-	DEF_ICON(BLANK298)
-	DEF_ICON(BLANK299)
+	/* FILE SELECT */
+DEF_ICON(RECOVER_AUTO)
+DEF_ICON(SAVE_PREFS)
+DEF_ICON(LINK_BLEND)
+DEF_ICON(APPEND_BLEND)
+DEF_ICON(IMPORT)
+DEF_ICON(EXPORT)
+DEF_ICON(EXTERNAL_DATA)
+DEF_ICON(LOAD_FACTORY)
+#ifndef DEF_ICON_BLANK_SKIP
 	DEF_ICON(BLANK300)
 	DEF_ICON(BLANK301)
 	DEF_ICON(BLANK302)
 	DEF_ICON(BLANK303)
 	DEF_ICON(BLANK304)
-	DEF_ICON(BLANK305)
-	DEF_ICON(BLANK306)
 #endif
+DEF_ICON(LOOP_BACK)
+DEF_ICON(LOOP_FORWARDS)
 DEF_ICON(BACK)
 DEF_ICON(FORWARD)
 #ifndef DEF_ICON_BLANK_SKIP
@@ -968,6 +964,7 @@ DEF_ICON(BRUSH_ADD)
 DEF_ICON(BRUSH_BLOB)
 DEF_ICON(BRUSH_BLUR)
 DEF_ICON(BRUSH_CLAY)
+DEF_ICON(BRUSH_CLAY_STRIPS)
 DEF_ICON(BRUSH_CLONE)
 DEF_ICON(BRUSH_CREASE)
 DEF_ICON(BRUSH_DARKEN)
