@@ -33,12 +33,13 @@
 #include <string.h>
 
 #ifndef WIN32
-#include <unistd.h>
+#  include <unistd.h>
 #else
-#include <io.h>
-#include <direct.h>
-#include "BLI_winstuff.h"
-#endif   
+#  include <io.h>
+#  include <direct.h>
+#  include "BLI_winstuff.h"
+#endif
+
 #include "MEM_guardedalloc.h"
 
 #include "GPU_extensions.h"
@@ -75,15 +76,15 @@
 #include "interface_intern.h"
 
 
-#define ICON_IMAGE_W		600
-#define ICON_IMAGE_H		640
+#define ICON_IMAGE_W        600
+#define ICON_IMAGE_H        640
 
-#define ICON_GRID_COLS		26
-#define ICON_GRID_ROWS		30
+#define ICON_GRID_COLS      26
+#define ICON_GRID_ROWS      30
 
-#define ICON_GRID_MARGIN	5
-#define ICON_GRID_W		16
-#define ICON_GRID_H		16
+#define ICON_GRID_MARGIN    5
+#define ICON_GRID_W         16
+#define ICON_GRID_H         16
 
 typedef struct IconImage {
 	int w;
@@ -93,10 +94,10 @@ typedef struct IconImage {
 
 typedef void (*VectorDrawFunc)(int x, int y, int w, int h, float alpha);
 
-#define ICON_TYPE_PREVIEW	0
-#define ICON_TYPE_TEXTURE	1
-#define ICON_TYPE_BUFFER	2
-#define ICON_TYPE_VECTOR	3
+#define ICON_TYPE_PREVIEW   0
+#define ICON_TYPE_TEXTURE   1
+#define ICON_TYPE_BUFFER    2
+#define ICON_TYPE_VECTOR    3
 
 typedef struct DrawInfo {
 	int type;
@@ -107,7 +108,7 @@ typedef struct DrawInfo {
 			VectorDrawFunc func;
 		} vector;
 		struct {
-			IconImage* image;
+			IconImage *image;
 		} buffer;
 		struct {
 			int x, y, w, h;
@@ -145,24 +146,24 @@ static void def_internal_icon(ImBuf *bbuf, int icon_id, int xofs, int yofs, int
 	new_icon->type = 0;	
 
 	di = MEM_callocN(sizeof(DrawInfo), "drawinfo");
-	di->type= type;
+	di->type = type;
 
-	if(type == ICON_TYPE_TEXTURE) {
-		di->data.texture.x= xofs;
-		di->data.texture.y= yofs;
-		di->data.texture.w= size;
-		di->data.texture.h= size;
+	if (type == ICON_TYPE_TEXTURE) {
+		di->data.texture.x = xofs;
+		di->data.texture.y = yofs;
+		di->data.texture.w = size;
+		di->data.texture.h = size;
 	}
-	else if(type == ICON_TYPE_BUFFER) {
+	else if (type == ICON_TYPE_BUFFER) {
 		iimg = MEM_mallocN(sizeof(IconImage), "icon_img");
-		iimg->rect = MEM_mallocN(size*size*sizeof(unsigned int), "icon_rect");
+		iimg->rect = MEM_mallocN(size * size * sizeof(unsigned int), "icon_rect");
 		iimg->w = size;
 		iimg->h = size;
 
 		/* Here we store the rect in the icon - same as before */
 		imgsize = bbuf->x;
-		for (y=0; y<size; y++) {
-			memcpy(&iimg->rect[y*size], &bbuf->rect[(y+yofs)*imgsize+xofs], size*sizeof(int));
+		for (y = 0; y < size; y++) {
+			memcpy(&iimg->rect[y * size], &bbuf->rect[(y + yofs) * imgsize + xofs], size * sizeof(int));
 		}
 
 		di->data.buffer.image = iimg;
@@ -174,10 +175,10 @@ static void def_internal_icon(ImBuf *bbuf, int icon_id, int xofs, int yofs, int
 	BKE_icon_set(icon_id, new_icon);
 }
 
-static void def_internal_vicon( int icon_id, VectorDrawFunc drawFunc)
+static void def_internal_vicon(int icon_id, VectorDrawFunc drawFunc)
 {
 	Icon *new_icon = NULL;
-	DrawInfo* di;
+	DrawInfo *di;
 
 	new_icon = MEM_callocN(sizeof(Icon), "texicon");
 
@@ -185,8 +186,8 @@ static void def_internal_vicon( int icon_id, VectorDrawFunc drawFunc)
 	new_icon->type = 0;
 
 	di = MEM_callocN(sizeof(DrawInfo), "drawinfo");
-	di->type= ICON_TYPE_VECTOR;
-	di->data.vector.func =drawFunc;
+	di->type = ICON_TYPE_VECTOR;
+	di->data.vector.func = drawFunc;
 
 	new_icon->drawinfo_free = NULL;
 	new_icon->drawinfo = di;
@@ -196,7 +197,7 @@ static void def_internal_vicon( int icon_id, VectorDrawFunc drawFunc)
 
 /* Vector Icon Drawing Routines */
 
-	/* Utilities */
+/* Utilities */
 
 static void viconutil_set_point(GLint pt[2], int x, int y)
 {
@@ -204,7 +205,7 @@ static void viconutil_set_point(GLint pt[2], int x, int y)
 	pt[1] = y;
 }
 
-static void viconutil_draw_tri(GLint (*pts)[2])
+static void viconutil_draw_tri(GLint(*pts)[2])
 {
 	glBegin(GL_TRIANGLES);
 	glVertex2iv(pts[0]);
@@ -213,41 +214,41 @@ static void viconutil_draw_tri(GLint (*pts)[2])
 	glEnd();
 }
 
-static void viconutil_draw_lineloop(GLint (*pts)[2], int numPoints)
+static void viconutil_draw_lineloop(GLint(*pts)[2], int numPoints)
 {
 	int i;
 
 	glBegin(GL_LINE_LOOP);
-	for (i=0; i<numPoints; i++) {
+	for (i = 0; i < numPoints; i++) {
 		glVertex2iv(pts[i]);
 	}
 	glEnd();
 }
 
-static void viconutil_draw_lineloop_smooth(GLint (*pts)[2], int numPoints)
+static void viconutil_draw_lineloop_smooth(GLint(*pts)[2], int numPoints)
 {
 	glEnable(GL_LINE_SMOOTH);
 	viconutil_draw_lineloop(pts, numPoints);
 	glDisable(GL_LINE_SMOOTH);
 }
 
-static void viconutil_draw_points(GLint (*pts)[2], int numPoints, int pointSize)
+static void viconutil_draw_points(GLint(*pts)[2], int numPoints, int pointSize)
 {
 	int i;
 
 	glBegin(GL_QUADS);
-	for (i=0; i<numPoints; i++) {
+	for (i = 0; i < numPoints; i++) {
 		int x = pts[i][0], y = pts[i][1];
 
-		glVertex2i(x-pointSize,y-pointSize);
-		glVertex2i(x+pointSize,y-pointSize);
-		glVertex2i(x+pointSize,y+pointSize);
-		glVertex2i(x-pointSize,y+pointSize);
+		glVertex2i(x - pointSize, y - pointSize);
+		glVertex2i(x + pointSize, y - pointSize);
+		glVertex2i(x + pointSize, y + pointSize);
+		glVertex2i(x - pointSize, y + pointSize);
 	}
 	glEnd();
 }
 
-	/* Drawing functions */
+/* Drawing functions */
 
 static void vicon_x_draw(int x, int y, int w, int h, float alpha)
 {
@@ -256,48 +257,48 @@ static void vicon_x_draw(int x, int y, int w, int h, float alpha)
 	w -= 6;
 	h -= 6;
 
-	glEnable( GL_LINE_SMOOTH );
+	glEnable(GL_LINE_SMOOTH);
 
 	glLineWidth(2.5);
 	
 	glColor4f(0.0, 0.0, 0.0, alpha);
 	glBegin(GL_LINES);
-	glVertex2i(x  ,y  );
-	glVertex2i(x+w,y+h);
-	glVertex2i(x+w,y  );
-	glVertex2i(x  ,y+h);
+	glVertex2i(x, y);
+	glVertex2i(x + w, y + h);
+	glVertex2i(x + w, y);
+	glVertex2i(x, y + h);
 	glEnd();
 
 	glLineWidth(1.0);
 	
-	glDisable( GL_LINE_SMOOTH );
+	glDisable(GL_LINE_SMOOTH);
 }
 
 static void vicon_view3d_draw(int x, int y, int w, int h, float alpha)
 {
-	int cx = x + w/2;
-	int cy = y + h/2;
-	int d = MAX2(2, h/3);
+	int cx = x + w / 2;
+	int cy = y + h / 2;
+	int d = MAX2(2, h / 3);
 
 	glColor4f(0.5, 0.5, 0.5, alpha);
 	glBegin(GL_LINES);
-	glVertex2i(x  , cy-d);
-	glVertex2i(x+w, cy-d);
-	glVertex2i(x  , cy+d);
-	glVertex2i(x+w, cy+d);
+	glVertex2i(x, cy - d);
+	glVertex2i(x + w, cy - d);
+	glVertex2i(x, cy + d);
+	glVertex2i(x + w, cy + d);
 
-	glVertex2i(cx-d, y  );
-	glVertex2i(cx-d, y+h);
-	glVertex2i(cx+d, y  );
-	glVertex2i(cx+d, y+h);
+	glVertex2i(cx - d, y);
+	glVertex2i(cx - d, y + h);
+	glVertex2i(cx + d, y);
+	glVertex2i(cx + d, y + h);
 	glEnd();
 	
 	glColor4f(0.0, 0.0, 0.0, alpha);
 	glBegin(GL_LINES);
-	glVertex2i(x  , cy);
-	glVertex2i(x+w, cy);
-	glVertex2i(cx, y  );
-	glVertex2i(cx, y+h);
+	glVertex2i(x, cy);
+	glVertex2i(x + w, cy);
+	glVertex2i(cx, y);
+	glVertex2i(cx, y + h);
 	glEnd();
 }
 
@@ -305,10 +306,10 @@ static void vicon_edit_draw(int x, int y, int w, int h, float alpha)
 {
 	GLint pts[4][2];
 
-	viconutil_set_point(pts[0], x+3  , y+3  );
-	viconutil_set_point(pts[1], x+w-3, y+3  );
-	viconutil_set_point(pts[2], x+w-3, y+h-3);
-	viconutil_set_point(pts[3], x+3  , y+h-3);
+	viconutil_set_point(pts[0], x + 3,     y + 3);
+	viconutil_set_point(pts[1], x + w - 3, y + 3);
+	viconutil_set_point(pts[2], x + w - 3, y + h - 3);
+	viconutil_set_point(pts[3], x + 3,     y + h - 3);
 
 	glColor4f(0.0, 0.0, 0.0, alpha);
 	viconutil_draw_lineloop(pts, 4);
@@ -321,9 +322,9 @@ static void vicon_editmode_hlt_draw(int x, int y, int w, int h, float alpha)
 {
 	GLint pts[3][2];
 
-	viconutil_set_point(pts[0], x+w/2, y+h-2);
-	viconutil_set_point(pts[1], x+3, y+4);
-	viconutil_set_point(pts[2], x+w-3, y+4);
+	viconutil_set_point(pts[0], x + w / 2, y + h - 2);
+	viconutil_set_point(pts[1], x + 3,     y + 4);
+	viconutil_set_point(pts[2], x + w - 3, y + 4);
 
 	glColor4f(0.5, 0.5, 0.5, alpha);
 	viconutil_draw_tri(pts);
@@ -339,9 +340,9 @@ static void vicon_editmode_dehlt_draw(int x, int y, int w, int h, float UNUSED(a
 {
 	GLint pts[3][2];
 
-	viconutil_set_point(pts[0], x+w/2, y+h-2);
-	viconutil_set_point(pts[1], x+3, y+4);
-	viconutil_set_point(pts[2], x+w-3, y+4);
+	viconutil_set_point(pts[0], x + w / 2, y + h - 2);
+	viconutil_set_point(pts[1], x + 3,     y + 4);
+	viconutil_set_point(pts[2], x + w - 3, y + 4);
 
 	glColor4f(0.0f, 0.0f, 0.0f, 1);
 	viconutil_draw_lineloop_smooth(pts, 3);
@@ -353,13 +354,13 @@ static void vicon_editmode_dehlt_draw(int x, int y, int w, int h, float UNUSED(a
 static void vicon_disclosure_tri_right_draw(int x, int y, int w, int UNUSED(h), float alpha)
 {
 	GLint pts[3][2];
-	int cx = x+w/2;
-	int cy = y+w/2;
-	int d = w/3, d2 = w/5;
+	int cx = x + w / 2;
+	int cy = y + w / 2;
+	int d = w / 3, d2 = w / 5;
 
-	viconutil_set_point(pts[0], cx-d2, cy+d);
-	viconutil_set_point(pts[1], cx-d2, cy-d);
-	viconutil_set_point(pts[2], cx+d2, cy);
+	viconutil_set_point(pts[0], cx - d2, cy + d);
+	viconutil_set_point(pts[1], cx - d2, cy - d);
+	viconutil_set_point(pts[2], cx + d2, cy);
 
 	glShadeModel(GL_SMOOTH);
 	glBegin(GL_TRIANGLES);
@@ -378,13 +379,13 @@ static void vicon_disclosure_tri_right_draw(int x, int y, int w, int UNUSED(h),
 static void vicon_small_tri_right_draw(int x, int y, int w, int UNUSED(h), float alpha)
 {
 	GLint pts[3][2];
-	int cx = x+w/2-4;
-	int cy = y+w/2;
-	int d = w/5, d2 = w/7;
+	int cx = x + w / 2 - 4;
+	int cy = y + w / 2;
+	int d = w / 5, d2 = w / 7;
 
-	viconutil_set_point(pts[0], cx-d2, cy+d);
-	viconutil_set_point(pts[1], cx-d2, cy-d);
-	viconutil_set_point(pts[2], cx+d2, cy);
+	viconutil_set_point(pts[0], cx - d2, cy + d);
+	viconutil_set_point(pts[1], cx - d2, cy - d);
+	viconutil_set_point(pts[2], cx + d2, cy);
 
 	glColor4f(0.2f, 0.2f, 0.2f, alpha);
 
@@ -400,13 +401,13 @@ static void vicon_small_tri_right_draw(int x, int y, int w, int UNUSED(h), float
 static void vicon_disclosure_tri_down_draw(int x, int y, int w, int UNUSED(h), float alpha)
 {
 	GLint pts[3][2];
-	int cx = x+w/2;
-	int cy = y+w/2;
-	int d = w/3, d2 = w/5;
+	int cx = x + w / 2;
+	int cy = y + w / 2;
+	int d = w / 3, d2 = w / 5;
 
-	viconutil_set_point(pts[0], cx+d, cy+d2);
-	viconutil_set_point(pts[1], cx-d, cy+d2);
-	viconutil_set_point(pts[2], cx, cy-d2);
+	viconutil_set_point(pts[0], cx + d, cy + d2);
+	viconutil_set_point(pts[1], cx - d, cy + d2);
+	viconutil_set_point(pts[2], cx, cy - d2);
 
 	glShadeModel(GL_SMOOTH);
 	glBegin(GL_TRIANGLES);
@@ -424,16 +425,16 @@ static void vicon_disclosure_tri_down_draw(int x, int y, int w, int UNUSED(h), f
 
 static void vicon_move_up_draw(int x, int y, int w, int h, float UNUSED(alpha))
 {
-	int d=-2;
+	int d = -2;
 
 	glEnable(GL_LINE_SMOOTH);
 	glLineWidth(1);
 	glColor3f(0.0, 0.0, 0.0);
 
 	glBegin(GL_LINE_STRIP);
-	glVertex2i(x+w/2-d*2, y+h/2+d);
-	glVertex2i(x+w/2, y+h/2-d + 1);
-	glVertex2i(x+w/2+d*2, y+h/2+d);
+	glVertex2i(x + w / 2 - d * 2, y + h / 2 + d);
+	glVertex2i(x + w / 2, y + h / 2 - d + 1);
+	glVertex2i(x + w / 2 + d * 2, y + h / 2 + d);
 	glEnd();
 
 	glLineWidth(1.0);
@@ -442,16 +443,16 @@ static void vicon_move_up_draw(int x, int y, int w, int h, float UNUSED(alpha))
 
 static void vicon_move_down_draw(int x, int y, int w, int h, float UNUSED(alpha))
 {
-	int d=2;
+	int d = 2;
 
 	glEnable(GL_LINE_SMOOTH);
 	glLineWidth(1);
 	glColor3f(0.0, 0.0, 0.0);
 
 	glBegin(GL_LINE_STRIP);
-	glVertex2i(x+w/2-d*2, y+h/2+d);
-	glVertex2i(x+w/2, y+h/2-d - 1);
-	glVertex2i(x+w/2+d*2, y+h/2+d);
+	glVertex2i(x + w / 2 - d * 2, y + h / 2 + d);
+	glVertex2i(x + w / 2, y + h / 2 - d - 1);
+	glVertex2i(x + w / 2 + d * 2, y + h / 2 + d);
 	glEnd();
 
 	glLineWidth(1.0);
@@ -462,12 +463,15 @@ static void vicon_move_down_draw(int x, int y, int w, int h, float UNUSED(alpha)
 static void init_brush_icons(void)
 {
 
-#define INIT_BRUSH_ICON(icon_id, name)                                         \
-	bbuf = IMB_ibImageFromMemory((unsigned char*)datatoc_ ##name## _png,       \
-					 datatoc_ ##name## _png_size, IB_rect, "<brush icon>");    \
-	def_internal_icon(bbuf, icon_id, 0, 0, w, ICON_TYPE_BUFFER);               \
-	IMB_freeImBuf(bbuf);
-	// end INIT_BRUSH_ICON
+#define INIT_BRUSH_ICON(icon_id, name)                                        \
+	{                                                                         \
+		bbuf = IMB_ibImageFromMemory((unsigned char *)datatoc_ ##name## _png, \
+		                             datatoc_ ##name## _png_size,             \
+		                             IB_rect, "<brush icon>");                \
+		def_internal_icon(bbuf, icon_id, 0, 0, w, ICON_TYPE_BUFFER);          \
+		IMB_freeImBuf(bbuf);                                                  \
+	} (void)0
+	/* end INIT_BRUSH_ICON */
 
 	ImBuf *bbuf;
 	const int w = 96;
@@ -476,6 +480,7 @@ static void init_brush_icons(void)
 	INIT_BRUSH_ICON(ICON_BRUSH_BLOB, blob);
 	INIT_BRUSH_ICON(ICON_BRUSH_BLUR, blur);
 	INIT_BRUSH_ICON(ICON_BRUSH_CLAY, clay);
+	INIT_BRUSH_ICON(ICON_BRUSH_CLAY_STRIPS, claystrips);
 	INIT_BRUSH_ICON(ICON_BRUSH_CLONE, clone);
 	INIT_BRUSH_ICON(ICON_BRUSH_CREASE, crease);
 	INIT_BRUSH_ICON(ICON_BRUSH_DARKEN, darken);
@@ -506,45 +511,45 @@ static void init_brush_icons(void)
 
 static void init_internal_icons(void)
 {
-	bTheme *btheme= UI_GetTheme();
-	ImBuf *bbuf= NULL;
+	bTheme *btheme = UI_GetTheme();
+	ImBuf *bbuf = NULL;
 	int x, y, icontype;
 	char iconfilestr[FILE_MAX];
 	
-	if ((btheme!=NULL) && btheme->tui.iconfile[0]) {
-		char *icondir= BLI_get_folder(BLENDER_DATAFILES, "icons");
+	if ((btheme != NULL) && btheme->tui.iconfile[0]) {
+		char *icondir = BLI_get_folder(BLENDER_DATAFILES, "icons");
 		if (icondir) {
 			BLI_join_dirfile(iconfilestr, sizeof(iconfilestr), icondir, btheme->tui.iconfile);
 			bbuf = IMB_loadiffname(iconfilestr, IB_rect); /* if the image is missing bbuf will just be NULL */
-			if(bbuf && (bbuf->x < ICON_IMAGE_W || bbuf->y < ICON_IMAGE_H)) {
+			if (bbuf && (bbuf->x < ICON_IMAGE_W || bbuf->y < ICON_IMAGE_H)) {
 				printf("\n***WARNING***\nIcons file %s too small.\nUsing built-in Icons instead\n", iconfilestr);
 				IMB_freeImBuf(bbuf);
-				bbuf= NULL;
+				bbuf = NULL;
 			}
 		}
 		else {
 			printf("%s: 'icons' data path not found, continuing\n", __func__);
 		}
 	}
-	if(bbuf==NULL)
-		bbuf = IMB_ibImageFromMemory((unsigned char*)datatoc_blender_icons_png, datatoc_blender_icons_png_size, IB_rect, "<blender icons>");
+	if (bbuf == NULL)
+		bbuf = IMB_ibImageFromMemory((unsigned char *)datatoc_blender_icons_png, datatoc_blender_icons_png_size, IB_rect, "<blender icons>");
 
-	if(bbuf) {
+	if (bbuf) {
 		/* free existing texture if any */
-		if(icongltex.id) {
+		if (icongltex.id) {
 			glDeleteTextures(1, &icongltex.id);
-			icongltex.id= 0;
+			icongltex.id = 0;
 		}
 
 		/* we only use a texture for cards with non-power of two */
-		if(GPU_non_power_of_two_support()) {
+		if (GPU_non_power_of_two_support()) {
 			glGenTextures(1, &icongltex.id);
 
-			if(icongltex.id) {
+			if (icongltex.id) {
 				icongltex.w = bbuf->x;
 				icongltex.h = bbuf->y;
-				icongltex.invw = 1.0f/bbuf->x;
-				icongltex.invh = 1.0f/bbuf->y;
+				icongltex.invw = 1.0f / bbuf->x;
+				icongltex.invh = 1.0f / bbuf->y;
 
 				glBindTexture(GL_TEXTURE_2D, icongltex.id);
 				glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, bbuf->x, bbuf->y, 0, GL_RGBA, GL_UNSIGNED_BYTE, bbuf->rect);
@@ -552,26 +557,26 @@ static void init_internal_icons(void)
 				glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 				glBindTexture(GL_TEXTURE_2D, 0);
 
-				if(glGetError() == GL_OUT_OF_MEMORY) {
+				if (glGetError() == GL_OUT_OF_MEMORY) {
 					glDeleteTextures(1, &icongltex.id);
-					icongltex.id= 0;
+					icongltex.id = 0;
 				}
 			}
 		}
 	}
 
-	if(icongltex.id)
-		icontype= ICON_TYPE_TEXTURE;
+	if (icongltex.id)
+		icontype = ICON_TYPE_TEXTURE;
 	else
-		icontype= ICON_TYPE_BUFFER;
+		icontype = ICON_TYPE_BUFFER;
 	
-	if(bbuf) {
-		for (y=0; y<ICON_GRID_ROWS; y++) {
-			for (x=0; x<ICON_GRID_COLS; x++) {
-				def_internal_icon(bbuf, BIFICONID_FIRST + y*ICON_GRID_COLS + x,
-					x*(ICON_GRID_W+ICON_GRID_MARGIN)+ICON_GRID_MARGIN,
-					y*(ICON_GRID_H+ICON_GRID_MARGIN)+ICON_GRID_MARGIN, ICON_GRID_W,
-					icontype);
+	if (bbuf) {
+		for (y = 0; y < ICON_GRID_ROWS; y++) {
+			for (x = 0; x < ICON_GRID_COLS; x++) {
+				def_internal_icon(bbuf, BIFICONID_FIRST + y * ICON_GRID_COLS + x,
+				                  x * (ICON_GRID_W + ICON_GRID_MARGIN) + ICON_GRID_MARGIN,
+				                  y * (ICON_GRID_H + ICON_GRID_MARGIN) + ICON_GRID_MARGIN, ICON_GRID_W,
+				                  icontype);
 			}
 		}
 	}
@@ -596,47 +601,47 @@ static void init_iconfile_list(struct ListBase *list)
 	IconFile *ifile;
 	struct direntry *dir;
 	int restoredir = 1; /* restore to current directory */
-	int totfile, i, index=1;
+	int totfile, i, index = 1;
 	const char *icondir;
 	char olddir[FILE_MAX];
 
 	list->first = list->last = NULL;
 	icondir = BLI_get_folder(BLENDER_DATAFILES, "icons");
 
-	if(icondir==NULL)
+	if (icondir == NULL)
 		return;
 	
 	/* since BLI_dir_contents changes the current working directory, restore it 
-	   back to old value afterwards */
-	if(!BLI_current_working_dir(olddir, sizeof(olddir))) 
+	 * back to old value afterwards */
+	if (!BLI_current_working_dir(olddir, sizeof(olddir))) 
 		restoredir = 0;
 	totfile = BLI_dir_contents(icondir, &dir);
 	if (restoredir && !chdir(olddir)) {} /* fix warning about checking return value */
 
-	for(i=0; i<totfile; i++) {
-		if( (dir[i].type & S_IFREG) ) {
+	for (i = 0; i < totfile; i++) {
+		if ( (dir[i].type & S_IFREG) ) {
 			char *filename = dir[i].relname;
 			
-			if(BLI_testextensie(filename, ".png")) {
+			if (BLI_testextensie(filename, ".png")) {
 				/* loading all icons on file start is overkill & slows startup
 				 * its possible they change size after blender load anyway. */
 #if 0
 				int ifilex, ifiley;
-				char iconfilestr[FILE_MAX+16]; /* allow 256 chars for file+dir */
-				ImBuf *bbuf= NULL;
+				char iconfilestr[FILE_MAX + 16]; /* allow 256 chars for file+dir */
+				ImBuf *bbuf = NULL;
 				/* check to see if the image is the right size, continue if not */
 				/* copying strings here should go ok, assuming that we never get back
-				   a complete path to file longer than 256 chars */
+				 * a complete path to file longer than 256 chars */
 				BLI_join_dirfile(iconfilestr, sizeof(iconfilestr), icondir, filename);
-				bbuf= IMB_loadiffname(iconfilestr, IB_rect);
+				bbuf = IMB_loadiffname(iconfilestr, IB_rect);
 
-				if(bbuf) {
+				if (bbuf) {
 					ifilex = bbuf->x;
 					ifiley = bbuf->y;
 					IMB_freeImBuf(bbuf);
 				}
 				else {
-					ifilex= ifiley= 0;
+					ifilex = ifiley = 0;
 				}
 				
 				/* bad size or failed to load */
@@ -644,7 +649,7 @@ static void init_iconfile_list(struct ListBase *list)
 					printf("icon '%s' is wrong size %dx%d\n", iconfilestr, ifilex, ifiley);
 					continue;
 				}
-#endif			/* removed */
+#endif          /* removed */
 
 				/* found a potential icon file, so make an entry for it in the cache list */
 				ifile = MEM_callocN(sizeof(IconFile), "IconFile");
@@ -660,9 +665,9 @@ static void init_iconfile_list(struct ListBase *list)
 	}
 	
 	/* free temporary direntry structure that's been created by BLI_dir_contents() */
-	i= totfile-1;
+	i = totfile - 1;
 	
-	for(; i>=0; i--){
+	for (; i >= 0; i--) {
 		MEM_freeN(dir[i].relname);
 		MEM_freeN(dir[i].path);
 		if (dir[i].string) {
@@ -670,14 +675,14 @@ static void init_iconfile_list(struct ListBase *list)
 		}
 	}
 	free(dir);
-	dir= NULL;
+	dir = NULL;
 }
 
 static void free_iconfile_list(struct ListBase *list)
 {
-	IconFile *ifile=NULL, *next_ifile=NULL;
+	IconFile *ifile = NULL, *next_ifile = NULL;
 	
-	for(ifile=list->first; ifile; ifile=next_ifile) {
+	for (ifile = list->first; ifile; ifile = next_ifile) {
 		next_ifile = ifile->next;
 		BLI_freelinkN(list, ifile);
 	}
@@ -686,9 +691,9 @@ static void free_iconfile_list(struct ListBase *list)
 int UI_iconfile_get_index(const char *filename)
 {
 	IconFile *ifile;
-	ListBase *list=&(iconfilelist);
+	ListBase *list = &(iconfilelist);
 	
-	for(ifile=list->first; ifile; ifile=ifile->next) {
+	for (ifile = list->first; ifile; ifile = ifile->next) {
 		if (BLI_path_cmp(filename, ifile->filename) == 0) {
 			return ifile->index;
 		}
@@ -699,7 +704,7 @@ int UI_iconfile_get_index(const char *filename)
 
 ListBase *UI_iconfile_list(void)
 {
-	ListBase *list=&(iconfilelist);
+	ListBase *list = &(iconfilelist);
 	
 	return list;
 }
@@ -708,9 +713,9 @@ ListBase *UI_iconfile_list(void)
 void UI_icons_free(void)
 {
 #ifndef WITH_HEADLESS
-	if(icongltex.id) {
+	if (icongltex.id) {
 		glDeleteTextures(1, &icongltex.id);
-		icongltex.id= 0;
+		icongltex.id = 0;
 	}
 
 	free_iconfile_list(&iconfilelist);
@@ -722,9 +727,9 @@ void UI_icons_free_drawinfo(void *drawinfo)
 {
 	DrawInfo *di = drawinfo;
 
-	if(di) {
-		if(di->type == ICON_TYPE_BUFFER) {
-			if(di->data.buffer.image) {
+	if (di) {
+		if (di->type == ICON_TYPE_BUFFER) {
+			if (di->data.buffer.image) {
 				MEM_freeN(di->data.buffer.image->rect);
 				MEM_freeN(di->data.buffer.image);
 			}
@@ -739,7 +744,7 @@ static DrawInfo *icon_create_drawinfo(void)
 	DrawInfo *di = NULL;
 
 	di = MEM_callocN(sizeof(DrawInfo), "di_icon");
-	di->type= ICON_TYPE_PREVIEW;
+	di->type = ICON_TYPE_PREVIEW;
 
 	return di;
 }
@@ -752,8 +757,8 @@ int UI_icon_get_width(int icon_id)
 
 	icon = BKE_icon_get(icon_id);
 	
-	if (icon==NULL) {
-		if (G.f & G_DEBUG)
+	if (icon == NULL) {
+		if (G.debug & G_DEBUG)
 			printf("%s: Internal error, no icon for icon ID: %d\n", __func__, icon_id);
 		return 0;
 	}
@@ -777,13 +782,13 @@ int UI_icon_get_height(int icon_id)
 
 	icon = BKE_icon_get(icon_id);
 	
-	if (icon==NULL) {
-		if (G.f & G_DEBUG)
+	if (icon == NULL) {
+		if (G.debug & G_DEBUG)
 			printf("%s: Internal error, no icon for icon ID: %d\n", __func__, icon_id);
 		return 0;
 	}
 	
-	di = (DrawInfo*)icon->drawinfo;
+	di = (DrawInfo *)icon->drawinfo;
 
 	if (!di) {
 		di = icon_create_drawinfo();
@@ -813,7 +818,7 @@ void UI_icons_init(int first_dyn_id)
 static int preview_render_size(enum eIconSizes size)
 {
 	switch (size) {
-		case ICON_SIZE_ICON:	return 32;
+		case ICON_SIZE_ICON:    return 32;
 		case ICON_SIZE_PREVIEW: return PREVIEW_DEFAULT_HEIGHT;
 	}
 	return 0;
@@ -821,12 +826,12 @@ static int preview_render_size(enum eIconSizes size)
 
 /* Create rect for the icon
  */
-static void icon_create_rect(struct PreviewImage* prv_img, enum eIconSizes size) 
+static void icon_create_rect(struct PreviewImage *prv_img, enum eIconSizes size)
 {
 	unsigned int render_size = preview_render_size(size);
 
 	if (!prv_img) {
-		if (G.f & G_DEBUG)
+		if (G.debug & G_DEBUG)
 			printf("%s, error: requested preview image does not exist", __func__);
 	}
 	if (!prv_img->rect[size]) {
@@ -834,16 +839,16 @@ static void icon_create_rect(struct PreviewImage* prv_img, enum eIconSizes size)
 		prv_img->h[size] = render_size;
 		prv_img->changed[size] = 1;
 		prv_img->changed_timestamp[size] = 0;
-		prv_img->rect[size] = MEM_callocN(render_size*render_size*sizeof(unsigned int), "prv_rect"); 
+		prv_img->rect[size] = MEM_callocN(render_size * render_size * sizeof(unsigned int), "prv_rect");
 	}
 }
 
 /* only called when icon has changed */
 /* only call with valid pointer from UI_icon_draw */
-static void icon_set_image(bContext *C, ID *id, PreviewImage* prv_img, enum eIconSizes size)
+static void icon_set_image(bContext *C, ID *id, PreviewImage *prv_img, enum eIconSizes size)
 {
 	if (!prv_img) {
-		if (G.f & G_DEBUG)
+		if (G.debug & G_DEBUG)
 			printf("%s: no preview image for this ID: %s\n", __func__, id->name);
 		return;
 	}	
@@ -851,41 +856,41 @@ static void icon_set_image(bContext *C, ID *id, PreviewImage* prv_img, enum eIco
 	icon_create_rect(prv_img, size);
 
 	ED_preview_icon_job(C, prv_img, id, prv_img->rect[size],
-		prv_img->w[size], prv_img->h[size]);
+	                    prv_img->w[size], prv_img->h[size]);
 }
 
-static void icon_draw_rect(float x, float y, int w, int h, float UNUSED(aspect), int rw, int rh, unsigned int *rect, float alpha, float *rgb, short is_preview)
+static void icon_draw_rect(float x, float y, int w, int h, float UNUSED(aspect), int rw, int rh, unsigned int *rect, float alpha, const float rgb[3], short is_preview)
 {
-	ImBuf *ima= NULL;
+	ImBuf *ima = NULL;
 
 	/* sanity check */
-	if(w<=0 || h<=0 || w>2000 || h>2000) {
+	if (w <= 0 || h <= 0 || w > 2000 || h > 2000) {
 		printf("%s: icons are %i x %i pixels?\n", __func__, w, h);
 		BLI_assert(!"invalid icon size");
 		return;
 	}
 
 	/* modulate color */
-	if(alpha != 1.0f)
+	if (alpha != 1.0f)
 		glPixelTransferf(GL_ALPHA_SCALE, alpha);
 
-	if(rgb) {
+	if (rgb) {
 		glPixelTransferf(GL_RED_SCALE, rgb[0]);
 		glPixelTransferf(GL_GREEN_SCALE, rgb[1]);
 		glPixelTransferf(GL_BLUE_SCALE, rgb[2]);
 	}
 
 	/* rect contains image in 'rendersize', we only scale if needed */
-	if(rw!=w && rh!=h) {
+	if (rw != w && rh != h) {
 		/* first allocate imbuf for scaling and copy preview into it */
 		ima = IMB_allocImBuf(rw, rh, 32, IB_rect);
-		memcpy(ima->rect, rect, rw*rh*sizeof(unsigned int));	
+		memcpy(ima->rect, rect, rw * rh * sizeof(unsigned int));
 		IMB_scaleImBuf(ima, w, h); /* scale it */
-		rect= ima->rect;
+		rect = ima->rect;
 	}
 
 	/* draw */
-	if(is_preview) {
+	if (is_preview) {
 		glaDrawPixelsSafe(x, y, w, h, w, GL_RGBA, GL_UNSIGNED_BYTE, rect);
 	}
 	else {
@@ -893,31 +898,31 @@ static void icon_draw_rect(float x, float y, int w, int h, float UNUSED(aspect),
 		glDrawPixels(w, h, GL_RGBA, GL_UNSIGNED_BYTE, rect);
 	}
 
-	if(ima)
+	if (ima)
 		IMB_freeImBuf(ima);
 
 	/* restore color */
-	if(alpha != 0.0f)
+	if (alpha != 0.0f)
 		glPixelTransferf(GL_ALPHA_SCALE, 1.0f);
 	
-	if(rgb) {
+	if (rgb) {
 		glPixelTransferf(GL_RED_SCALE, 1.0f);
 		glPixelTransferf(GL_GREEN_SCALE, 1.0f);
 		glPixelTransferf(GL_BLUE_SCALE, 1.0f);
 	}
 }
 
-static void icon_draw_texture(float x, float y, float w, float h, int ix, int iy, int UNUSED(iw), int ih, float alpha, float *rgb)
+static void icon_draw_texture(float x, float y, float w, float h, int ix, int iy, int UNUSED(iw), int ih, float alpha, const float rgb[3])
 {
 	float x1, x2, y1, y2;
 
-	if(rgb) glColor4f(rgb[0], rgb[1], rgb[2], alpha);
+	if (rgb) glColor4f(rgb[0], rgb[1], rgb[2], alpha);
 	else glColor4f(1.0f, 1.0f, 1.0f, alpha);
 
-	x1= ix*icongltex.invw;
-	x2= (ix + ih)*icongltex.invw;
-	y1= iy*icongltex.invh;
-	y2= (iy + ih)*icongltex.invh;
+	x1 = ix * icongltex.invw;
+	x2 = (ix + ih) * icongltex.invw;
+	y1 = iy * icongltex.invh;
+	y2 = (iy + ih) * icongltex.invh;
 
 	glEnable(GL_TEXTURE_2D);
 	glBindTexture(GL_TEXTURE_2D, icongltex.id);
@@ -927,13 +932,13 @@ static void icon_draw_texture(float x, float y, float w, float h, int ix, int iy
 	glVertex2f(x, y);
 
 	glTexCoord2f(x2, y1);
-	glVertex2f(x+w, y);
+	glVertex2f(x + w, y);
 
 	glTexCoord2f(x2, y2);
-	glVertex2f(x+w, y+h);
+	glVertex2f(x + w, y + h);
 
 	glTexCoord2f(x1, y2);
-	glVertex2f(x, y+h);
+	glVertex2f(x, y + h);
 	glEnd();
 
 	glBindTexture(GL_TEXTURE_2D, 0);
@@ -950,25 +955,25 @@ static int get_draw_size(enum eIconSizes size)
 	return 0;
 }
 
-static void icon_draw_size(float x, float y, int icon_id, float aspect, float alpha, float *rgb, enum eIconSizes size, int draw_size, int UNUSED(nocreate), short is_preview)
+static void icon_draw_size(float x, float y, int icon_id, float aspect, float alpha, const float rgb[3], enum eIconSizes size, int draw_size, int UNUSED(nocreate), short is_preview)
 {
-	bTheme *btheme= UI_GetTheme();
+	bTheme *btheme = UI_GetTheme();
 	Icon *icon = NULL;
 	DrawInfo *di = NULL;
 	IconImage *iimg;
-	float fdraw_size= is_preview ? draw_size : (draw_size * UI_DPI_ICON_FAC);
+	float fdraw_size = is_preview ? draw_size : (draw_size * UI_DPI_ICON_FAC);
 	int w, h;
 	
 	icon = BKE_icon_get(icon_id);
 	alpha *= btheme->tui.icon_alpha;
 	
-	if (icon==NULL) {
-		if (G.f & G_DEBUG)
+	if (icon == NULL) {
+		if (G.debug & G_DEBUG)
 			printf("%s: Internal error, no icon for icon ID: %d\n", __func__, icon_id);
 		return;
 	}
 
-	di = (DrawInfo*)icon->drawinfo;
+	di = (DrawInfo *)icon->drawinfo;
 	
 	if (!di) {
 		di = icon_create_drawinfo();
@@ -978,32 +983,32 @@ static void icon_draw_size(float x, float y, int icon_id, float aspect, float al
 	}
 	
 	/* scale width and height according to aspect */
-	w = (int)(fdraw_size/aspect + 0.5f);
-	h = (int)(fdraw_size/aspect + 0.5f);
+	w = (int)(fdraw_size / aspect + 0.5f);
+	h = (int)(fdraw_size / aspect + 0.5f);
 	
-	if(di->type == ICON_TYPE_VECTOR) {
+	if (di->type == ICON_TYPE_VECTOR) {
 		/* vector icons use the uiBlock transformation, they are not drawn
-		with untransformed coordinates like the other icons */
+		 * with untransformed coordinates like the other icons */
 		di->data.vector.func((int)x, (int)y, ICON_DEFAULT_HEIGHT, ICON_DEFAULT_HEIGHT, 1.0f); 
 	} 
-	else if(di->type == ICON_TYPE_TEXTURE) {
+	else if (di->type == ICON_TYPE_TEXTURE) {
 		icon_draw_texture(x, y, (float)w, (float)h, di->data.texture.x, di->data.texture.y,
-			di->data.texture.w, di->data.texture.h, alpha, rgb);
+		                  di->data.texture.w, di->data.texture.h, alpha, rgb);
 	}
-	else if(di->type == ICON_TYPE_BUFFER) {
+	else if (di->type == ICON_TYPE_BUFFER) {
 		/* it is a builtin icon */		
-		iimg= di->data.buffer.image;
+		iimg = di->data.buffer.image;
 
-		if(!iimg->rect) return; /* something has gone wrong! */
+		if (!iimg->rect) return;  /* something has gone wrong! */
 
 		icon_draw_rect(x, y, w, h, aspect, iimg->w, iimg->h, iimg->rect, alpha, rgb, is_preview);
 	}
-	else if(di->type == ICON_TYPE_PREVIEW) {
-		PreviewImage* pi = BKE_previewimg_get((ID*)icon->obj); 
+	else if (di->type == ICON_TYPE_PREVIEW) {
+		PreviewImage *pi = BKE_previewimg_get((ID *)icon->obj);
 
-		if(pi) {			
+		if (pi) {			
 			/* no create icon on this level in code */
-			if(!pi->rect[size]) return; /* something has gone wrong! */
+			if (!pi->rect[size]) return;  /* something has gone wrong! */
 			
 			/* preview images use premul alpha ... */
 			glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
@@ -1013,21 +1018,25 @@ static void icon_draw_size(float x, float y, int icon_id, float aspect, float al
 	}
 }
 
+static void ui_id_preview_image_render_size(bContext *C, ID *id, PreviewImage *pi, int size)
+{
+	if ((pi->changed[size] || !pi->rect[size])) { /* changed only ever set by dynamic icons */
+		/* create the rect if necessary */
+		icon_set_image(C, id, pi, size);
+
+		pi->changed[size] = 0;
+	}
+}
+
 static void ui_id_icon_render(bContext *C, ID *id, int big)
 {
-	PreviewImage *pi = BKE_previewimg_get(id); 
-	
-	if (pi) {			
-		if ((pi->changed[0] ||!pi->rect[0])) /* changed only ever set by dynamic icons */
-		{
-			/* create the rect if necessary */				
-			
-			icon_set_image(C, id, pi, ICON_SIZE_ICON);		/* icon size */
-			if (big)
-				icon_set_image(C, id, pi, ICON_SIZE_PREVIEW);	/* bigger preview size */
-			
-			pi->changed[0] = 0;
-		}
+	PreviewImage *pi = BKE_previewimg_get(id);
+
+	if (pi) {
+		if (big)
+			ui_id_preview_image_render_size(C, id, pi, ICON_SIZE_PREVIEW);  /* bigger preview size */
+		else
+			ui_id_preview_image_render_size(C, id, pi, ICON_SIZE_ICON);     /* icon size */
 	}
 }
 
@@ -1036,13 +1045,13 @@ static void ui_id_brush_render(bContext *C, ID *id)
 	PreviewImage *pi = BKE_previewimg_get(id); 
 	enum eIconSizes i;
 	
-	if(!pi)
+	if (!pi)
 		return;
 	
-	for(i = 0; i < NUM_ICON_SIZES; i++) {
+	for (i = 0; i < NUM_ICON_SIZES; i++) {
 		/* check if rect needs to be created; changed
-		 only set by dynamic icons */
-		if((pi->changed[i] || !pi->rect[i])) {
+		 * only set by dynamic icons */
+		if ((pi->changed[i] || !pi->rect[i])) {
 			icon_set_image(C, id, pi, i);
 			pi->changed[i] = 0;
 		}
@@ -1052,9 +1061,9 @@ static void ui_id_brush_render(bContext *C, ID *id)
 
 static int ui_id_brush_get_icon(bContext *C, ID *id)
 {
-	Brush *br = (Brush*)id;
+	Brush *br = (Brush *)id;
 
-	if(br->flag & BRUSH_CUSTOM_ICON) {
+	if (br->flag & BRUSH_CUSTOM_ICON) {
 		BKE_icon_getid(id);
 		ui_id_brush_render(C, id);
 	}
@@ -1065,37 +1074,38 @@ static int ui_id_brush_get_icon(bContext *C, ID *id)
 		int tool, mode = 0;
 
 		/* XXX: this is not nice, should probably make brushes
-		   be strictly in one paint mode only to avoid
-		   checking various context stuff here */
+		 * be strictly in one paint mode only to avoid
+		 * checking various context stuff here */
 
-		if(CTX_wm_view3d(C) && ob) {
-			if(ob->mode & OB_MODE_SCULPT)
+		if (CTX_wm_view3d(C) && ob) {
+			if (ob->mode & OB_MODE_SCULPT)
 				mode = OB_MODE_SCULPT;
-			else if(ob->mode & (OB_MODE_VERTEX_PAINT|OB_MODE_WEIGHT_PAINT))
+			else if (ob->mode & (OB_MODE_VERTEX_PAINT | OB_MODE_WEIGHT_PAINT))
 				mode = OB_MODE_VERTEX_PAINT;
-			else if(ob->mode & OB_MODE_TEXTURE_PAINT)
+			else if (ob->mode & OB_MODE_TEXTURE_PAINT)
 				mode = OB_MODE_TEXTURE_PAINT;
 		}
-		else if((sima = CTX_wm_space_image(C)) &&
-			(sima->flag & SI_DRAWTOOL)) {
+		else if ((sima = CTX_wm_space_image(C)) &&
+		         (sima->flag & SI_DRAWTOOL))
+		{
 			mode = OB_MODE_TEXTURE_PAINT;
 		}
 
 		/* reset the icon */
-		if(mode == OB_MODE_SCULPT) {
+		if (mode == OB_MODE_SCULPT) {
 			items = brush_sculpt_tool_items;
 			tool = br->sculpt_tool;
 		}
-		else if(mode == OB_MODE_VERTEX_PAINT) {
+		else if (mode == OB_MODE_VERTEX_PAINT) {
 			items = brush_vertex_tool_items;
 			tool = br->vertexpaint_tool;
 		}
-		else if(mode == OB_MODE_TEXTURE_PAINT) {
+		else if (mode == OB_MODE_TEXTURE_PAINT) {
 			items = brush_image_tool_items;
 			tool = br->imagepaint_tool;
 		}
 
-		if(!items || !RNA_enum_icon_from_value(items, tool, &id->icon_id))
+		if (!items || !RNA_enum_icon_from_value(items, tool, &id->icon_id))
 			id->icon_id = 0;
 	}
 
@@ -1104,19 +1114,19 @@ static int ui_id_brush_get_icon(bContext *C, ID *id)
 
 int ui_id_icon_get(bContext *C, ID *id, int big)
 {
-	int iconid= 0;
+	int iconid = 0;
 	
 	/* icon */
-	switch(GS(id->name)) {
+	switch (GS(id->name)) {
 		case ID_BR:
-			iconid= ui_id_brush_get_icon(C, id);
+			iconid = ui_id_brush_get_icon(C, id);
 			break;
 		case ID_MA: /* fall through */
 		case ID_TE: /* fall through */
 		case ID_IM: /* fall through */
 		case ID_WO: /* fall through */
 		case ID_LA: /* fall through */
-			iconid= BKE_icon_getid(id);
+			iconid = BKE_icon_getid(id);
 			/* checks if not exists, or changed */
 			ui_id_icon_render(C, id, big);
 			break;
@@ -1138,7 +1148,7 @@ void UI_icon_draw_aspect(float x, float y, int icon_id, float aspect, float alph
 	icon_draw_at_size(x, y, icon_id, aspect, alpha, ICON_SIZE_ICON, 0);
 }
 
-void UI_icon_draw_aspect_color(float x, float y, int icon_id, float aspect, float *rgb)
+void UI_icon_draw_aspect_color(float x, float y, int icon_id, float aspect, const float rgb[3])
 {
 	int draw_size = get_draw_size(ICON_SIZE_ICON);
 	icon_draw_size(x, y, icon_id, aspect, 1.0f, rgb, ICON_SIZE_ICON, draw_size, FALSE, FALSE);
