@@ -78,7 +78,7 @@ static int eyedropper_init(bContext *C, wmOperator *op)
 {
 	Eyedropper *eye;
 	
-	op->customdata= eye= MEM_callocN(sizeof(Eyedropper), "Eyedropper");
+	op->customdata = eye = MEM_callocN(sizeof(Eyedropper), "Eyedropper");
 	
 	uiContextActiveProperty(C, &eye->ptr, &eye->prop, &eye->index);
 	
@@ -89,9 +89,9 @@ static void eyedropper_exit(bContext *C, wmOperator *op)
 {
 	WM_cursor_restore(CTX_wm_window(C));
 	
-	if(op->customdata)
+	if (op->customdata)
 		MEM_freeN(op->customdata);
-	op->customdata= NULL;
+	op->customdata = NULL;
 }
 
 static int eyedropper_cancel(bContext *C, wmOperator *op)
@@ -102,7 +102,7 @@ static int eyedropper_cancel(bContext *C, wmOperator *op)
 
 static void eyedropper_sample(bContext *C, Eyedropper *eye, int mx, int my)
 {
-	if(RNA_property_type(eye->prop) == PROP_FLOAT) {
+	if (RNA_property_type(eye->prop) == PROP_FLOAT) {
 		Scene *scene = CTX_data_scene(C);
 		const int color_manage = scene->r.color_mgt_flag & R_COLOR_MANAGEMENT;
 		float col[4];
@@ -130,12 +130,12 @@ static int eyedropper_modal(bContext *C, wmOperator *op, wmEvent *event)
 {
 	Eyedropper *eye = (Eyedropper *)op->customdata;
 	
-	switch(event->type) {
+	switch (event->type) {
 		case ESCKEY:
 		case RIGHTMOUSE:
 			return eyedropper_cancel(C, op);
 		case LEFTMOUSE:
-			if(event->val==KM_RELEASE) {
+			if (event->val == KM_RELEASE) {
 				eyedropper_sample(C, eye, event->x, event->y);
 				eyedropper_exit(C, op);
 				return OPERATOR_FINISHED;
@@ -157,14 +157,15 @@ static int eyedropper_invoke(bContext *C, wmOperator *op, wmEvent *UNUSED(event)
 		WM_event_add_modal_handler(C, op);
 		
 		return OPERATOR_RUNNING_MODAL;
-	} else {
+	}
+	else {
 		eyedropper_exit(C, op);
 		return OPERATOR_CANCELLED;
 	}
 }
 
 /* Repeat operator */
-static int eyedropper_exec (bContext *C, wmOperator *op)
+static int eyedropper_exec(bContext *C, wmOperator *op)
 {
 	/* init */
 	if (eyedropper_init(C, op)) {
@@ -175,7 +176,8 @@ static int eyedropper_exec (bContext *C, wmOperator *op)
 		eyedropper_exit(C, op);
 		
 		return OPERATOR_FINISHED;
-	} else {
+	}
+	else {
 		return OPERATOR_CANCELLED;
 	}
 }
@@ -189,19 +191,19 @@ static int eyedropper_poll(bContext *C)
 static void UI_OT_eyedropper(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Eyedropper";
-	ot->idname= "UI_OT_eyedropper";
-	ot->description= "Sample a color from the Blender Window to store in a property";
+	ot->name = "Eyedropper";
+	ot->idname = "UI_OT_eyedropper";
+	ot->description = "Sample a color from the Blender Window to store in a property";
 	
 	/* api callbacks */
-	ot->invoke= eyedropper_invoke;
-	ot->modal= eyedropper_modal;
-	ot->cancel= eyedropper_cancel;
-	ot->exec= eyedropper_exec;
-	ot->poll= eyedropper_poll;
+	ot->invoke = eyedropper_invoke;
+	ot->modal = eyedropper_modal;
+	ot->cancel = eyedropper_cancel;
+	ot->exec = eyedropper_exec;
+	ot->poll = eyedropper_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_BLOCKING;
+	ot->flag = OPTYPE_BLOCKING;
 	
 	/* properties */
 }
@@ -219,15 +221,15 @@ static int reset_default_theme_exec(bContext *C, wmOperator *UNUSED(op))
 static void UI_OT_reset_default_theme(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Reset to Default Theme";
-	ot->idname= "UI_OT_reset_default_theme";
-	ot->description= "Reset to the default theme colors";
+	ot->name = "Reset to Default Theme";
+	ot->idname = "UI_OT_reset_default_theme";
+	ot->description = "Reset to the default theme colors";
 	
 	/* callbacks */
-	ot->exec= reset_default_theme_exec;
+	ot->exec = reset_default_theme_exec;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER;
+	ot->flag = OPTYPE_REGISTER;
 }
 
 /* Copy Data Path Operator ------------------------ */
@@ -237,14 +239,14 @@ static int copy_data_path_button_exec(bContext *C, wmOperator *UNUSED(op))
 	PointerRNA ptr;
 	PropertyRNA *prop;
 	char *path;
-	int success= 0;
+	int success = 0;
 	int index;
 
 	/* try to create driver using property retrieved from UI */
 	uiContextActiveProperty(C, &ptr, &prop, &index);
 
 	if (ptr.id.data && ptr.data && prop) {
-		path= RNA_path_from_ID_to_property(&ptr, prop);
+		path = RNA_path_from_ID_to_property(&ptr, prop);
 		
 		if (path) {
 			WM_clipboard_text_set(path, FALSE);
@@ -253,22 +255,22 @@ static int copy_data_path_button_exec(bContext *C, wmOperator *UNUSED(op))
 	}
 
 	/* since we're just copying, we don't really need to do anything else...*/
-	return (success)? OPERATOR_FINISHED: OPERATOR_CANCELLED;
+	return (success) ? OPERATOR_FINISHED : OPERATOR_CANCELLED;
 }
 
 static void UI_OT_copy_data_path_button(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Copy Data Path";
-	ot->idname= "UI_OT_copy_data_path_button";
-	ot->description= "Copy the RNA data path for this property to the clipboard";
+	ot->name = "Copy Data Path";
+	ot->idname = "UI_OT_copy_data_path_button";
+	ot->description = "Copy the RNA data path for this property to the clipboard";
 
 	/* callbacks */
-	ot->exec= copy_data_path_button_exec;
+	ot->exec = copy_data_path_button_exec;
 	//op->poll= ??? // TODO: need to have some valid property before this can be done
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER;
+	ot->flag = OPTYPE_REGISTER;
 }
 
 /* Reset to Default Values Button Operator ------------------------ */
@@ -288,7 +290,7 @@ static int reset_default_button_exec(bContext *C, wmOperator *op)
 {
 	PointerRNA ptr;
 	PropertyRNA *prop;
-	int success= 0;
+	int success = 0;
 	int index, all = RNA_boolean_get(op->ptr, "all");
 
 	/* try to reset the nominated setting to its default value */
@@ -296,23 +298,23 @@ static int reset_default_button_exec(bContext *C, wmOperator *op)
 	
 	/* if there is a valid property that is editable... */
 	if (ptr.data && prop && RNA_property_editable(&ptr, prop)) {
-		if(RNA_property_reset(&ptr, prop, (all)? -1: index)) {
+		if (RNA_property_reset(&ptr, prop, (all) ? -1 : index)) {
 			/* perform updates required for this property */
 			RNA_property_update(C, &ptr, prop);
 
 			/* as if we pressed the button */
 			uiContextActivePropertyHandle(C);
 
-			success= 1;
+			success = 1;
 		}
 	}
 
-	/* Since we dont want to undo _all_ edits to settings, eg window
+	/* Since we don't want to undo _all_ edits to settings, eg window
 	 * edits on the screen or on operator settings.
 	 * it might be better to move undo's inline - campbell */
-	if(success) {
-		ID *id= ptr.id.data;
-		if(id && ID_CHECK_UNDO(id)) {
+	if (success) {
+		ID *id = ptr.id.data;
+		if (id && ID_CHECK_UNDO(id)) {
 			/* do nothing, go ahead with undo */
 		}
 		else {
@@ -321,22 +323,22 @@ static int reset_default_button_exec(bContext *C, wmOperator *op)
 	}
 	/* end hack */
 
-	return (success)? OPERATOR_FINISHED: OPERATOR_CANCELLED;
+	return (success) ? OPERATOR_FINISHED : OPERATOR_CANCELLED;
 }
 
 static void UI_OT_reset_default_button(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Reset to Default Value";
-	ot->idname= "UI_OT_reset_default_button";
-	ot->description= "Reset this property's value to its default value";
+	ot->name = "Reset to Default Value";
+	ot->idname = "UI_OT_reset_default_button";
+	ot->description = "Reset this property's value to its default value";
 
 	/* callbacks */
-	ot->poll= reset_default_button_poll;
-	ot->exec= reset_default_button_exec;
+	ot->poll = reset_default_button_poll;
+	ot->exec = reset_default_button_exec;
 
 	/* flags */
-	ot->flag= OPTYPE_UNDO;
+	ot->flag = OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean(ot->srna, "all", 1, "All", "Reset to default values all elements of the array");
@@ -344,41 +346,72 @@ static void UI_OT_reset_default_button(wmOperatorType *ot)
 
 /* Copy To Selected Operator ------------------------ */
 
-static int copy_to_selected_list(bContext *C, PointerRNA *ptr, ListBase *lb)
+static int copy_to_selected_list(bContext *C, PointerRNA *ptr, ListBase *lb, int *use_path)
 {
-	if(RNA_struct_is_a(ptr->type, &RNA_Object))
-		*lb = CTX_data_collection_get(C, "selected_editable_objects");
-	else if(RNA_struct_is_a(ptr->type, &RNA_EditBone))
+	*use_path = 0;
+
+	if (RNA_struct_is_a(ptr->type, &RNA_EditBone))
 		*lb = CTX_data_collection_get(C, "selected_editable_bones");
-	else if(RNA_struct_is_a(ptr->type, &RNA_PoseBone))
+	else if (RNA_struct_is_a(ptr->type, &RNA_PoseBone))
 		*lb = CTX_data_collection_get(C, "selected_pose_bones");
-	else if(RNA_struct_is_a(ptr->type, &RNA_Sequence))
+	else if (RNA_struct_is_a(ptr->type, &RNA_Sequence))
 		*lb = CTX_data_collection_get(C, "selected_editable_sequences");
-	else
-		return 0;
+	else {
+		ID *id = ptr->id.data;
+
+		if (id && GS(id->name) == ID_OB) {
+			*lb = CTX_data_collection_get(C, "selected_editable_objects");
+			*use_path = 1;
+		}
+		else
+			return 0;
+	}
 	
 	return 1;
 }
 
 static int copy_to_selected_button_poll(bContext *C)
 {
-	PointerRNA ptr;
-	PropertyRNA *prop;
-	int index, success= 0;
+	PointerRNA ptr, lptr, idptr;
+	PropertyRNA *prop, *lprop;
+	int index, success = 0;
 
 	uiContextActiveProperty(C, &ptr, &prop, &index);
 
 	if (ptr.data && prop) {
+		char *path = NULL;
+		int use_path;
 		CollectionPointerLink *link;
 		ListBase lb;
 
-		if(copy_to_selected_list(C, &ptr, &lb)) {
-			for(link= lb.first; link; link=link->next)
-				if(link->ptr.data != ptr.data && RNA_property_editable(&link->ptr, prop))
-					success= 1;
+		if (!copy_to_selected_list(C, &ptr, &lb, &use_path))
+			return success;
 
-			BLI_freelistN(&lb);
+		if (!use_path || (path = RNA_path_from_ID_to_property(&ptr, prop))) {
+			for (link = lb.first; link; link = link->next) {
+				if (link->ptr.data != ptr.data) {
+					if (use_path) {
+						lprop = NULL;
+						RNA_id_pointer_create(link->ptr.id.data, &idptr);
+						RNA_path_resolve(&idptr, path, &lptr, &lprop);
+					}
+					else {
+						lptr = link->ptr;
+						lprop = prop;
+					}
+
+					if (lprop == prop) {
+						if (RNA_property_editable(&lptr, prop))
+							success = 1;
+					}
+				}
+			}
+
+			if (path)
+				MEM_freeN(path);
 		}
+
+		BLI_freelistN(&lb);
 	}
 
 	return success;
@@ -386,9 +419,9 @@ static int copy_to_selected_button_poll(bContext *C)
 
 static int copy_to_selected_button_exec(bContext *C, wmOperator *op)
 {
-	PointerRNA ptr;
-	PropertyRNA *prop;
-	int success= 0;
+	PointerRNA ptr, lptr, idptr;
+	PropertyRNA *prop, *lprop;
+	int success = 0;
 	int index, all = RNA_boolean_get(op->ptr, "all");
 
 	/* try to reset the nominated setting to its default value */
@@ -396,39 +429,61 @@ static int copy_to_selected_button_exec(bContext *C, wmOperator *op)
 	
 	/* if there is a valid property that is editable... */
 	if (ptr.data && prop) {
+		char *path = NULL;
+		int use_path;
 		CollectionPointerLink *link;
 		ListBase lb;
 
-		if(copy_to_selected_list(C, &ptr, &lb)) {
-			for(link= lb.first; link; link=link->next) {
-				if(link->ptr.data != ptr.data && RNA_property_editable(&link->ptr, prop)) {
-					if(RNA_property_copy(&link->ptr, &ptr, prop, (all)? -1: index)) {
-						RNA_property_update(C, &link->ptr, prop);
-						success= 1;
+		if (!copy_to_selected_list(C, &ptr, &lb, &use_path))
+			return success;
+
+		if (!use_path || (path = RNA_path_from_ID_to_property(&ptr, prop))) {
+			for (link = lb.first; link; link = link->next) {
+				if (link->ptr.data != ptr.data) {
+					if (use_path) {
+						lprop = NULL;
+						RNA_id_pointer_create(link->ptr.id.data, &idptr);
+						RNA_path_resolve(&idptr, path, &lptr, &lprop);
+					}
+					else {
+						lptr = link->ptr;
+						lprop = prop;
+					}
+
+					if (lprop == prop) {
+						if (RNA_property_editable(&lptr, lprop)) {
+							if (RNA_property_copy(&lptr, &ptr, prop, (all) ? -1 : index)) {
+								RNA_property_update(C, &lptr, prop);
+								success = 1;
+							}
+						}
 					}
 				}
 			}
 
-			BLI_freelistN(&lb);
+			if (path)
+				MEM_freeN(path);
 		}
+
+		BLI_freelistN(&lb);
 	}
 	
-	return (success)? OPERATOR_FINISHED: OPERATOR_CANCELLED;
+	return (success) ? OPERATOR_FINISHED : OPERATOR_CANCELLED;
 }
 
 static void UI_OT_copy_to_selected_button(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Copy To Selected";
-	ot->idname= "UI_OT_copy_to_selected_button";
-	ot->description= "Copy property from this object to selected objects or bones";
+	ot->name = "Copy To Selected";
+	ot->idname = "UI_OT_copy_to_selected_button";
+	ot->description = "Copy property from this object to selected objects or bones";
 
 	/* callbacks */
-	ot->poll= copy_to_selected_button_poll;
-	ot->exec= copy_to_selected_button_exec;
+	ot->poll = copy_to_selected_button_poll;
+	ot->exec = copy_to_selected_button_exec;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER | OPTYPE_UNDO;
 
 	/* properties */
 	RNA_def_boolean(ot->srna, "all", 1, "All", "Reset to default values all elements of the array");
@@ -458,7 +513,7 @@ static int reports_to_text_exec(bContext *C, wmOperator *UNUSED(op))
 	 *	- if commandline debug option enabled, show debug reports too
 	 *	- otherwise, up to info (which is what users normally see)
 	 */
-	str = BKE_reports_string(reports, (G.f & G_DEBUG)? RPT_DEBUG : RPT_INFO);
+	str = BKE_reports_string(reports, (G.debug & G_DEBUG) ? RPT_DEBUG : RPT_INFO);
 
 	if (str) {
 		write_text(txt, str);
@@ -474,20 +529,20 @@ static int reports_to_text_exec(bContext *C, wmOperator *UNUSED(op))
 static void UI_OT_reports_to_textblock(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Reports to Text Block";
-	ot->idname= "UI_OT_reports_to_textblock";
-	ot->description= "Write the reports ";
+	ot->name = "Reports to Text Block";
+	ot->idname = "UI_OT_reports_to_textblock";
+	ot->description = "Write the reports ";
 	
 	/* callbacks */
-	ot->poll= reports_to_text_poll;
-	ot->exec= reports_to_text_exec;
+	ot->poll = reports_to_text_poll;
+	ot->exec = reports_to_text_exec;
 }
 
 #ifdef WITH_PYTHON
 
 /* ------------------------------------------------------------------------- */
 /* EditSource Utility funcs and operator,
- * note, this includes itility functions and button matching checks */
+ * note, this includes utility functions and button matching checks */
 
 struct uiEditSourceStore {
 	uiBut but_orig;
@@ -500,7 +555,7 @@ struct uiEditSourceButStore {
 } uiEditSourceButStore;
 
 /* should only ever be set while the edit source operator is running */
-static struct uiEditSourceStore *ui_editsource_info= NULL;
+static struct uiEditSourceStore *ui_editsource_info = NULL;
 
 int  UI_editsource_enable_check(void)
 {
@@ -511,7 +566,7 @@ static void ui_editsource_active_but_set(uiBut *but)
 {
 	BLI_assert(ui_editsource_info == NULL);
 
-	ui_editsource_info= MEM_callocN(sizeof(uiEditSourceStore), __func__);
+	ui_editsource_info = MEM_callocN(sizeof(uiEditSourceStore), __func__);
 	memcpy(&ui_editsource_info->but_orig, but, sizeof(uiBut));
 
 	ui_editsource_info->hash = BLI_ghash_new(BLI_ghashutil_ptrhash,
@@ -523,7 +578,7 @@ static void ui_editsource_active_but_clear(void)
 {
 	BLI_ghash_free(ui_editsource_info->hash, NULL, (GHashValFreeFP)MEM_freeN);
 	MEM_freeN(ui_editsource_info);
-	ui_editsource_info= NULL;
+	ui_editsource_info = NULL;
 }
 
 static int ui_editsource_uibut_match(uiBut *but_a, uiBut *but_b)
@@ -536,16 +591,16 @@ static int ui_editsource_uibut_match(uiBut *but_a, uiBut *but_b)
 	/* this just needs to be a 'good-enough' comparison so we can know beyond
 	 * reasonable doubt that these buttons are the same between redraws.
 	 * if this fails it only means edit-source fails - campbell */
-	if(     (but_a->x1 == but_b->x1) &&
-	        (but_a->x2 == but_b->x2) &&
-	        (but_a->y1 == but_b->y1) &&
-	        (but_a->y2 == but_b->y2) &&
-	        (but_a->type == but_b->type) &&
-	        (but_a->rnaprop == but_b->rnaprop) &&
-	        (but_a->optype == but_b->optype) &&
-	        (but_a->unit_type == but_b->unit_type) &&
-	        strncmp(but_a->drawstr, but_b->drawstr, UI_MAX_DRAW_STR) == 0
-	) {
+	if ((but_a->x1 == but_b->x1) &&
+	    (but_a->x2 == but_b->x2) &&
+	    (but_a->y1 == but_b->y1) &&
+	    (but_a->y2 == but_b->y2) &&
+	    (but_a->type == but_b->type) &&
+	    (but_a->rnaprop == but_b->rnaprop) &&
+	    (but_a->optype == but_b->optype) &&
+	    (but_a->unit_type == but_b->unit_type) &&
+	    (strncmp(but_a->drawstr, but_b->drawstr, UI_MAX_DRAW_STR) == 0))
+	{
 		return TRUE;
 	}
 	else {
@@ -557,10 +612,10 @@ void UI_editsource_active_but_test(uiBut *but)
 {
 	extern void PyC_FileAndNum_Safe(const char **filename, int *lineno);
 
-	struct uiEditSourceButStore *but_store= MEM_callocN(sizeof(uiEditSourceButStore), __func__);
+	struct uiEditSourceButStore *but_store = MEM_callocN(sizeof(uiEditSourceButStore), __func__);
 
 	const char *fn;
-	int lineno= -1;
+	int lineno = -1;
 
 #if 0
 	printf("comparing buttons: '%s' == '%s'\n",
@@ -571,12 +626,12 @@ void UI_editsource_active_but_test(uiBut *but)
 
 	if (lineno != -1) {
 		BLI_strncpy(but_store->py_dbg_fn, fn,
-					sizeof(but_store->py_dbg_fn));
-		but_store->py_dbg_ln= lineno;
+		            sizeof(but_store->py_dbg_fn));
+		but_store->py_dbg_ln = lineno;
 	}
 	else {
-		but_store->py_dbg_fn[0]= '\0';
-		but_store->py_dbg_ln= -1;
+		but_store->py_dbg_fn[0] = '\0';
+		but_store->py_dbg_ln = -1;
 	}
 
 	BLI_ghash_insert(ui_editsource_info->hash, but, but_store);
@@ -587,17 +642,17 @@ void UI_editsource_active_but_test(uiBut *but)
 static int editsource_text_edit(bContext *C, wmOperator *op,
                                 char filepath[FILE_MAX], int line)
 {
-	struct Main *bmain= CTX_data_main(C);
+	struct Main *bmain = CTX_data_main(C);
 	Text *text;
 
-	for (text=bmain->text.first; text; text=text->id.next) {
+	for (text = bmain->text.first; text; text = text->id.next) {
 		if (text->name && BLI_path_cmp(text->name, filepath) == 0) {
 			break;
 		}
 	}
 
 	if (text == NULL) {
-		text= add_text(filepath, bmain->name);
+		text = add_text(filepath, bmain->name);
 	}
 
 	if (text == NULL) {
@@ -608,10 +663,10 @@ static int editsource_text_edit(bContext *C, wmOperator *op,
 	else {
 		/* naughty!, find text area to set, not good behavior
 		 * but since this is a dev tool lets allow it - campbell */
-		ScrArea *sa= BKE_screen_find_big_area(CTX_wm_screen(C), SPACE_TEXT, 0);
-		if(sa) {
-			SpaceText *st= sa->spacedata.first;
-			st->text= text;
+		ScrArea *sa = BKE_screen_find_big_area(CTX_wm_screen(C), SPACE_TEXT, 0);
+		if (sa) {
+			SpaceText *st = sa->spacedata.first;
+			st->text = text;
 		}
 		else {
 			BKE_reportf(op->reports, RPT_INFO,
@@ -619,7 +674,7 @@ static int editsource_text_edit(bContext *C, wmOperator *op,
 		}
 
 		txt_move_toline(text, line - 1, FALSE);
-		WM_event_add_notifier(C, NC_TEXT|ND_CURSOR, text);
+		WM_event_add_notifier(C, NC_TEXT | ND_CURSOR, text);
 	}
 
 	return OPERATOR_FINISHED;
@@ -627,13 +682,13 @@ static int editsource_text_edit(bContext *C, wmOperator *op,
 
 static int editsource_exec(bContext *C, wmOperator *op)
 {
-	uiBut *but= uiContextActiveButton(C);
+	uiBut *but = uiContextActiveButton(C);
 
 	if (but) {
 		GHashIterator ghi;
-		struct uiEditSourceButStore *but_store= NULL;
+		struct uiEditSourceButStore *but_store = NULL;
 
-		ARegion *ar= CTX_wm_region(C);
+		ARegion *ar = CTX_wm_region(C);
 		int ret;
 
 		/* needed else the active button does not get tested */
@@ -647,13 +702,13 @@ static int editsource_exec(bContext *C, wmOperator *op)
 		/* redraw and get active button python info */
 		ED_region_do_draw(C, ar);
 
-		for(BLI_ghashIterator_init(&ghi, ui_editsource_info->hash);
-		    !BLI_ghashIterator_isDone(&ghi);
-		    BLI_ghashIterator_step(&ghi))
+		for (BLI_ghashIterator_init(&ghi, ui_editsource_info->hash);
+		     !BLI_ghashIterator_isDone(&ghi);
+		     BLI_ghashIterator_step(&ghi))
 		{
-			uiBut *but= BLI_ghashIterator_getKey(&ghi);
+			uiBut *but = BLI_ghashIterator_getKey(&ghi);
 			if (but && ui_editsource_uibut_match(&ui_editsource_info->but_orig, but)) {
-				but_store= BLI_ghashIterator_getValue(&ghi);
+				but_store = BLI_ghashIterator_getValue(&ghi);
 				break;
 			}
 
@@ -661,20 +716,20 @@ static int editsource_exec(bContext *C, wmOperator *op)
 
 		if (but_store) {
 			if (but_store->py_dbg_ln != -1) {
-				ret= editsource_text_edit(C, op,
-				                          but_store->py_dbg_fn,
-				                          but_store->py_dbg_ln);
+				ret = editsource_text_edit(C, op,
+				                           but_store->py_dbg_fn,
+				                           but_store->py_dbg_ln);
 			}
 			else {
 				BKE_report(op->reports, RPT_ERROR,
-						   "Active button isn't from a script, cant edit source.");
-				ret= OPERATOR_CANCELLED;
+				           "Active button isn't from a script, cant edit source.");
+				ret = OPERATOR_CANCELLED;
 			}
 		}
 		else {
 			BKE_report(op->reports, RPT_ERROR,
-					   "Active button match can't be found.");
-			ret= OPERATOR_CANCELLED;
+			           "Active button match can't be found.");
+			ret = OPERATOR_CANCELLED;
 		}
 
 
@@ -693,12 +748,12 @@ static int editsource_exec(bContext *C, wmOperator *op)
 static void UI_OT_editsource(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Reports to Text Block";
-	ot->idname= "UI_OT_editsource";
-	ot->description= "Edit source code for a button";
+	ot->name = "Reports to Text Block";
+	ot->idname = "UI_OT_editsource";
+	ot->description = "Edit source code for a button";
 
 	/* callbacks */
-	ot->exec= editsource_exec;
+	ot->exec = editsource_exec;
 }
 
 #endif /* WITH_PYTHON */
