@@ -142,6 +142,7 @@ bConstraint *get_active_constraint (Object *ob)
 }
 
 /* -------------- Constraint Management (Add New, Remove, Rename) -------------------- */
+#ifdef WITH_PYTHON
 /* ------------- PyConstraints ------------------ */
 
 /* this callback sets the text-file to be used for selected menu item */
@@ -160,7 +161,6 @@ static void validate_pyconstraint_cb (void *arg1, void *arg2)
 	data->text = text;
 }
 
-#ifdef WITH_PYTHON
 /* this returns a string for the list of usable pyconstraint script names */
 static char *buildmenu_pyconstraints (Text *con_text, int *pyconindex)
 {
@@ -391,8 +391,7 @@ static void test_constraints (Object *owner, bPoseChannel *pchan)
 				/* if the number of points does not match the amount required by the chain length,
 				 * free the points array and request a rebind...
 				 */
-				if ((data->points == NULL) || (data->numpoints != data->chainlen+1))
-				{
+				if ((data->points == NULL) || (data->numpoints != data->chainlen+1)) {
 					/* free the points array */
 					if (data->points) {
 						MEM_freeN(data->points);
@@ -406,17 +405,17 @@ static void test_constraints (Object *owner, bPoseChannel *pchan)
 			else if (curcon->type == CONSTRAINT_TYPE_FOLLOWTRACK) {
 				bFollowTrackConstraint *data = curcon->data;
 
-				if((data->flag&CAMERASOLVER_ACTIVECLIP)==0) {
-					if(data->clip != NULL && data->track[0]) {
+				if ((data->flag&CAMERASOLVER_ACTIVECLIP)==0) {
+					if (data->clip != NULL && data->track[0]) {
 						MovieTracking *tracking= &data->clip->tracking;
 						MovieTrackingObject *tracking_object;
 
-						if(data->object[0])
+						if (data->object[0])
 							tracking_object= BKE_tracking_named_object(tracking, data->object);
 						else
 							tracking_object= BKE_tracking_get_camera_object(tracking);
 
-						if(!tracking_object) {
+						if (!tracking_object) {
 							curcon->flag |= CONSTRAINT_DISABLE;
 						}
 						else {
@@ -430,13 +429,13 @@ static void test_constraints (Object *owner, bPoseChannel *pchan)
 			else if (curcon->type == CONSTRAINT_TYPE_CAMERASOLVER) {
 				bCameraSolverConstraint *data = curcon->data;
 
-				if((data->flag&CAMERASOLVER_ACTIVECLIP)==0 && data->clip == NULL)
+				if ((data->flag&CAMERASOLVER_ACTIVECLIP)==0 && data->clip == NULL)
 					curcon->flag |= CONSTRAINT_DISABLE;
 			}
 			else if (curcon->type == CONSTRAINT_TYPE_OBJECTSOLVER) {
 				bObjectSolverConstraint *data = curcon->data;
 
-				if((data->flag&CAMERASOLVER_ACTIVECLIP)==0 && data->clip == NULL)
+				if ((data->flag&CAMERASOLVER_ACTIVECLIP)==0 && data->clip == NULL)
 					curcon->flag |= CONSTRAINT_DISABLE;
 			}
 			
@@ -590,19 +589,19 @@ static bConstraint *edit_constraint_property_get(wmOperator *op, Object *ob, int
 		if (pchan)
 			list = &pchan->constraints;
 		else {
-			//if (G.f & G_DEBUG)
+			//if (G.debug & G_DEBUG)
 			//printf("edit_constraint_property_get: No active bone for object '%s'\n", (ob)? ob->id.name+2 : "<None>");
 			return NULL;
 		}
 	}
 	else {
-		//if (G.f & G_DEBUG)
+		//if (G.debug & G_DEBUG)
 		//printf("edit_constraint_property_get: defaulting to getting list in the standard way\n");
 		list = get_active_constraints(ob);
 	}
 	
 	con = constraints_findByName(list, constraint_name);
-	//if (G.f & G_DEBUG)
+	//if (G.debug & G_DEBUG)
 	//printf("constraint found = %p, %s\n", (void *)con, (con)?con->name:"<Not found>");
 
 	if (con && (type != 0) && (con->type != type))
@@ -645,16 +644,16 @@ static int stretchto_reset_invoke(bContext *C, wmOperator *op, wmEvent *UNUSED(e
 void CONSTRAINT_OT_stretchto_reset (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Reset Original Length";
-	ot->idname= "CONSTRAINT_OT_stretchto_reset";
-	ot->description= "Reset original length of bone for Stretch To Constraint";
+	ot->name = "Reset Original Length";
+	ot->idname = "CONSTRAINT_OT_stretchto_reset";
+	ot->description = "Reset original length of bone for Stretch To Constraint";
 	
-	ot->exec= stretchto_reset_exec;
-	ot->invoke= stretchto_reset_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = stretchto_reset_exec;
+	ot->invoke = stretchto_reset_invoke;
+	ot->poll = edit_constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	edit_constraint_properties(ot);
 }
 
@@ -688,16 +687,16 @@ static int limitdistance_reset_invoke(bContext *C, wmOperator *op, wmEvent *UNUS
 void CONSTRAINT_OT_limitdistance_reset (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Reset Distance";
-	ot->idname= "CONSTRAINT_OT_limitdistance_reset";
-	ot->description= "Reset limiting distance for Limit Distance Constraint";
+	ot->name = "Reset Distance";
+	ot->idname = "CONSTRAINT_OT_limitdistance_reset";
+	ot->description = "Reset limiting distance for Limit Distance Constraint";
 	
-	ot->exec= limitdistance_reset_exec;
-	ot->invoke= limitdistance_reset_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = limitdistance_reset_exec;
+	ot->invoke = limitdistance_reset_invoke;
+	ot->poll = edit_constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	edit_constraint_properties(ot);
 }
 
@@ -814,16 +813,16 @@ static int childof_set_inverse_invoke(bContext *C, wmOperator *op, wmEvent *UNUS
 void CONSTRAINT_OT_childof_set_inverse (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Set Inverse";
-	ot->idname= "CONSTRAINT_OT_childof_set_inverse";
-	ot->description= "Set inverse correction for ChildOf constraint";
+	ot->name = "Set Inverse";
+	ot->idname = "CONSTRAINT_OT_childof_set_inverse";
+	ot->description = "Set inverse correction for ChildOf constraint";
 	
-	ot->exec= childof_set_inverse_exec;
-	ot->invoke= childof_set_inverse_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = childof_set_inverse_exec;
+	ot->invoke = childof_set_inverse_invoke;
+	ot->poll = edit_constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	edit_constraint_properties(ot);
 }
 
@@ -834,7 +833,7 @@ static int childof_clear_inverse_exec (bContext *C, wmOperator *op)
 	bConstraint *con = edit_constraint_property_get(op, ob, CONSTRAINT_TYPE_CHILDOF);
 	bChildOfConstraint *data= (con) ? (bChildOfConstraint *)con->data : NULL;
 	
-	if(data==NULL) {
+	if (data==NULL) {
 		BKE_report(op->reports, RPT_ERROR, "Childof constraint not found");
 		return OPERATOR_CANCELLED;
 	}
@@ -858,16 +857,16 @@ static int childof_clear_inverse_invoke(bContext *C, wmOperator *op, wmEvent *UN
 void CONSTRAINT_OT_childof_clear_inverse (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Clear Inverse";
-	ot->idname= "CONSTRAINT_OT_childof_clear_inverse";
-	ot->description= "Clear inverse correction for ChildOf constraint";
+	ot->name = "Clear Inverse";
+	ot->idname = "CONSTRAINT_OT_childof_clear_inverse";
+	ot->description = "Clear inverse correction for ChildOf constraint";
 	
-	ot->exec= childof_clear_inverse_exec;
-	ot->invoke= childof_clear_inverse_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = childof_clear_inverse_exec;
+	ot->invoke = childof_clear_inverse_invoke;
+	ot->poll = edit_constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	edit_constraint_properties(ot);
 }
 
@@ -905,16 +904,16 @@ static int objectsolver_set_inverse_invoke(bContext *C, wmOperator *op, wmEvent
 void CONSTRAINT_OT_objectsolver_set_inverse (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Set Inverse";
-	ot->idname= "CONSTRAINT_OT_objectsolver_set_inverse";
-	ot->description= "Set inverse correction for ObjectSolver constraint";
+	ot->name = "Set Inverse";
+	ot->idname = "CONSTRAINT_OT_objectsolver_set_inverse";
+	ot->description = "Set inverse correction for ObjectSolver constraint";
 
-	ot->exec= objectsolver_set_inverse_exec;
-	ot->invoke= objectsolver_set_inverse_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = objectsolver_set_inverse_exec;
+	ot->invoke = objectsolver_set_inverse_invoke;
+	ot->poll = edit_constraint_poll;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	edit_constraint_properties(ot);
 }
 
@@ -924,7 +923,7 @@ static int objectsolver_clear_inverse_exec (bContext *C, wmOperator *op)
 	bConstraint *con = edit_constraint_property_get(op, ob, CONSTRAINT_TYPE_OBJECTSOLVER);
 	bObjectSolverConstraint *data= (con) ? (bObjectSolverConstraint *)con->data : NULL;
 
-	if(data==NULL) {
+	if (data==NULL) {
 		BKE_report(op->reports, RPT_ERROR, "Childof constraint not found");
 		return OPERATOR_CANCELLED;
 	}
@@ -948,16 +947,16 @@ static int objectsolver_clear_inverse_invoke(bContext *C, wmOperator *op, wmEven
 void CONSTRAINT_OT_objectsolver_clear_inverse (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Clear Inverse";
-	ot->idname= "CONSTRAINT_OT_objectsolver_clear_inverse";
-	ot->description= "Clear inverse correction for ObjectSolver constraint";
+	ot->name = "Clear Inverse";
+	ot->idname = "CONSTRAINT_OT_objectsolver_clear_inverse";
+	ot->description = "Clear inverse correction for ObjectSolver constraint";
 
-	ot->exec= objectsolver_clear_inverse_exec;
-	ot->invoke= objectsolver_clear_inverse_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = objectsolver_clear_inverse_exec;
+	ot->invoke = objectsolver_clear_inverse_invoke;
+	ot->poll = edit_constraint_poll;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	edit_constraint_properties(ot);
 }
 
@@ -978,11 +977,11 @@ void ED_object_constraint_set_active(Object *ob, bConstraint *con)
 void ED_object_constraint_update(Object *ob)
 {
 
-	if(ob->pose) update_pose_constraint_flags(ob->pose);
+	if (ob->pose) update_pose_constraint_flags(ob->pose);
 
 	object_test_constraints(ob);
 
-	if(ob->type==OB_ARMATURE) DAG_id_tag_update(&ob->id, OB_RECALC_DATA|OB_RECALC_OB);
+	if (ob->type==OB_ARMATURE) DAG_id_tag_update(&ob->id, OB_RECALC_DATA|OB_RECALC_OB);
 	else DAG_id_tag_update(&ob->id, OB_RECALC_OB);
 }
 
@@ -990,7 +989,7 @@ void ED_object_constraint_dependency_update(Main *bmain, Scene *scene, Object *o
 {
 	ED_object_constraint_update(ob);
 
-	if(ob->pose) ob->pose->flag |= POSE_RECALC;	// checks & sorts pose channels
+	if (ob->pose) ob->pose->flag |= POSE_RECALC;	// checks & sorts pose channels
 	DAG_scene_sort(bmain, scene);
 }
 
@@ -1016,7 +1015,7 @@ static int constraint_delete_exec (bContext *C, wmOperator *UNUSED(op))
 		ED_object_constraint_update(ob); /* needed to set the flags on posebones correctly */
 
 		/* ITASC needs to be rebuilt once a constraint is removed [#26920] */
-		if(is_ik) {
+		if (is_ik) {
 			BIK_clear_data(ob->pose);
 		}
 
@@ -1034,16 +1033,16 @@ static int constraint_delete_exec (bContext *C, wmOperator *UNUSED(op))
 void CONSTRAINT_OT_delete (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Delete Constraint";
-	ot->idname= "CONSTRAINT_OT_delete";
-	ot->description= "Remove constraint from constraint stack";
+	ot->name = "Delete Constraint";
+	ot->idname = "CONSTRAINT_OT_delete";
+	ot->description = "Remove constraint from constraint stack";
 	
 	/* callbacks */
-	ot->exec= constraint_delete_exec;
-	ot->poll= constraint_poll;
+	ot->exec = constraint_delete_exec;
+	ot->poll = constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO; 
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO; 
 }
 
 static int constraint_move_down_exec (bContext *C, wmOperator *op)
@@ -1079,17 +1078,17 @@ static int constraint_move_down_invoke(bContext *C, wmOperator *op, wmEvent *UNU
 void CONSTRAINT_OT_move_down (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Move Constraint Down";
-	ot->idname= "CONSTRAINT_OT_move_down";
-	ot->description= "Move constraint down in constraint stack";
+	ot->name = "Move Constraint Down";
+	ot->idname = "CONSTRAINT_OT_move_down";
+	ot->description = "Move constraint down in constraint stack";
 	
 	/* callbacks */
-	ot->exec= constraint_move_down_exec;
-	ot->invoke= constraint_move_down_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = constraint_move_down_exec;
+	ot->invoke = constraint_move_down_invoke;
+	ot->poll = edit_constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO; 
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO; 
 	edit_constraint_properties(ot);
 }
 
@@ -1126,17 +1125,17 @@ static int constraint_move_up_invoke(bContext *C, wmOperator *op, wmEvent *UNUSE
 void CONSTRAINT_OT_move_up (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Move Constraint Up";
-	ot->idname= "CONSTRAINT_OT_move_up";
-	ot->description= "Move constraint up in constraint stack";
+	ot->name = "Move Constraint Up";
+	ot->idname = "CONSTRAINT_OT_move_up";
+	ot->description = "Move constraint up in constraint stack";
 	
 	/* callbacks */
-	ot->exec= constraint_move_up_exec;
-	ot->invoke= constraint_move_up_invoke;
-	ot->poll= edit_constraint_poll;
+	ot->exec = constraint_move_up_exec;
+	ot->invoke = constraint_move_up_invoke;
+	ot->poll = edit_constraint_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO; 
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO; 
 	edit_constraint_properties(ot);
 }
 
@@ -1161,7 +1160,7 @@ static int pose_constraints_clear_exec(bContext *C, wmOperator *UNUSED(op))
 	/* force depsgraph to get recalculated since relationships removed */
 	DAG_scene_sort(bmain, scene);		/* sort order of objects */	
 	
-	/* note, calling BIK_clear_data() isnt needed here */
+	/* note, calling BIK_clear_data() isn't needed here */
 
 	/* do updates */
 	DAG_id_tag_update(&ob->id, OB_RECALC_DATA);
@@ -1174,12 +1173,12 @@ void POSE_OT_constraints_clear(wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Clear Pose Constraints";
-	ot->idname= "POSE_OT_constraints_clear";
-	ot->description= "Clear all the constraints for the selected bones";
+	ot->idname = "POSE_OT_constraints_clear";
+	ot->description = "Clear all the constraints for the selected bones";
 	
 	/* callbacks */
-	ot->exec= pose_constraints_clear_exec;
-	ot->poll= ED_operator_posemode; // XXX - do we want to ensure there are selected bones too?
+	ot->exec = pose_constraints_clear_exec;
+	ot->poll = ED_operator_posemode; // XXX - do we want to ensure there are selected bones too?
 }
 
 
@@ -1209,12 +1208,12 @@ void OBJECT_OT_constraints_clear(wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Clear Object Constraints";
-	ot->idname= "OBJECT_OT_constraints_clear";
-	ot->description= "Clear all the constraints for the active Object only";
+	ot->idname = "OBJECT_OT_constraints_clear";
+	ot->description = "Clear all the constraints for the active Object only";
 	
 	/* callbacks */
-	ot->exec= object_constraints_clear_exec;
-	ot->poll= ED_operator_object_active_editable;
+	ot->exec = object_constraints_clear_exec;
+	ot->poll = ED_operator_object_active_editable;
 }
 
 /************************ copy all constraints operators *********************/
@@ -1254,16 +1253,16 @@ static int pose_constraint_copy_exec(bContext *C, wmOperator *op)
 void POSE_OT_constraints_copy(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Copy Constraints to Selected";
-	ot->idname= "POSE_OT_constraints_copy";
+	ot->name = "Copy Constraints to Selected";
+	ot->idname = "POSE_OT_constraints_copy";
 	ot->description = "Copy constraints to other selected bones";
 	
 	/* api callbacks */
-	ot->exec= pose_constraint_copy_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_constraint_copy_exec;
+	ot->poll = ED_operator_posemode;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 static int object_constraint_copy_exec(bContext *C, wmOperator *UNUSED(op))
@@ -1295,16 +1294,16 @@ static int object_constraint_copy_exec(bContext *C, wmOperator *UNUSED(op))
 void OBJECT_OT_constraints_copy(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Copy Constraints to Selected";
-	ot->idname= "OBJECT_OT_constraints_copy";
+	ot->name = "Copy Constraints to Selected";
+	ot->idname = "OBJECT_OT_constraints_copy";
 	ot->description = "Copy constraints to other selected objects";
 	
 	/* api callbacks */
-	ot->exec= object_constraint_copy_exec;
-	ot->poll= ED_operator_object_active_editable;
+	ot->exec = object_constraint_copy_exec;
+	ot->poll = ED_operator_object_active_editable;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /************************ add constraint operators *********************/
@@ -1501,7 +1500,7 @@ static int constraint_add_exec(bContext *C, wmOperator *op, Object *ob, ListBase
 		/* get the target objects, adding them as need be */
 		if (get_new_constraint_target(C, type, &tar_ob, &tar_pchan, 1)) {
 			/* method of setting target depends on the type of target we've got 
-			 *	- by default, just set the first target (distinction here is only for multiple-targetted constraints)
+			 *	- by default, just set the first target (distinction here is only for multiple-targeted constraints)
 			 */
 			if (tar_pchan)
 				set_constraint_nth_target(con, tar_ob, tar_pchan->name, 0);
@@ -1610,77 +1609,77 @@ static int pose_constraint_add_exec(bContext *C, wmOperator *op)
 void OBJECT_OT_constraint_add(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Constraint";
+	ot->name = "Add Constraint";
 	ot->description = "Add a constraint to the active object";
-	ot->idname= "OBJECT_OT_constraint_add";
+	ot->idname = "OBJECT_OT_constraint_add";
 	
 	/* api callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= object_constraint_add_exec;
-	ot->poll= ED_operator_object_active_editable;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = object_constraint_add_exec;
+	ot->poll = ED_operator_object_active_editable;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
-	ot->prop= RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
 }
 
 void OBJECT_OT_constraint_add_with_targets(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Constraint (with Targets)";
+	ot->name = "Add Constraint (with Targets)";
 	ot->description = "Add a constraint to the active object, with target (where applicable) set to the selected Objects/Bones";
-	ot->idname= "OBJECT_OT_constraint_add_with_targets";
+	ot->idname = "OBJECT_OT_constraint_add_with_targets";
 	
 	/* api callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= object_constraint_add_exec;
-	ot->poll= ED_operator_object_active_editable;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = object_constraint_add_exec;
+	ot->poll = ED_operator_object_active_editable;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
-	ot->prop= RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
 }
 
 void POSE_OT_constraint_add(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Constraint";
+	ot->name = "Add Constraint";
 	ot->description = "Add a constraint to the active bone";
-	ot->idname= "POSE_OT_constraint_add";
+	ot->idname = "POSE_OT_constraint_add";
 	
 	/* api callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= pose_constraint_add_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = pose_constraint_add_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
-	ot->prop= RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
 }
 
 void POSE_OT_constraint_add_with_targets(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Constraint (with Targets)";
+	ot->name = "Add Constraint (with Targets)";
 	ot->description = "Add a constraint to the active bone, with target (where applicable) set to the selected Objects/Bones";
-	ot->idname= "POSE_OT_constraint_add_with_targets";
+	ot->idname = "POSE_OT_constraint_add_with_targets";
 	
 	/* api callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= pose_constraint_add_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = pose_constraint_add_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
-	ot->prop= RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", constraint_type_items, 0, "Type", "");
 }
 
 /************************ IK Constraint operators *********************/
@@ -1753,17 +1752,17 @@ static int pose_ik_add_exec(bContext *C, wmOperator *op)
 void POSE_OT_ik_add(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add IK to Bone";
-	ot->description= "Add IK Constraint to the active Bone";
-	ot->idname= "POSE_OT_ik_add";
+	ot->name = "Add IK to Bone";
+	ot->description = "Add IK Constraint to the active Bone";
+	ot->idname = "POSE_OT_ik_add";
 	
 	/* api callbacks */
-	ot->invoke= pose_ik_add_invoke;
-	ot->exec= pose_ik_add_exec;
-	ot->poll= ED_operator_posemode;
+	ot->invoke = pose_ik_add_invoke;
+	ot->exec = pose_ik_add_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_boolean(ot->srna, "with_targets", 1, "With Targets", "Assign IK Constraint with targets derived from the select bones/objects");
@@ -1804,15 +1803,15 @@ static int pose_ik_clear_exec(bContext *C, wmOperator *UNUSED(op))
 void POSE_OT_ik_clear(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Remove IK";
-	ot->description= "Remove all IK Constraints from selected bones";
-	ot->idname= "POSE_OT_ik_clear";
+	ot->name = "Remove IK";
+	ot->description = "Remove all IK Constraints from selected bones";
+	ot->idname = "POSE_OT_ik_clear";
 	
 	/* api callbacks */
-	ot->exec= pose_ik_clear_exec;
-	ot->poll= ED_operator_posemode;
+	ot->exec = pose_ik_clear_exec;
+	ot->poll = ED_operator_posemode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
