@@ -65,25 +65,30 @@ static int objects_add_active_exec(bContext *C, wmOperator *op)
 	Scene *scene= CTX_data_scene(C);
 	Object *ob= OBACT;
 	Group *group;
-	int ok = 0;
+	int ok = 0, cycle = 0;
 	
-	if(!ob) return OPERATOR_CANCELLED;
+	if (!ob) return OPERATOR_CANCELLED;
 	
 	/* linking to same group requires its own loop so we can avoid
-	   looking up the active objects groups each time */
+	 * looking up the active objects groups each time */
 
-	for(group= bmain->group.first; group; group=group->id.next) {
-		if(object_in_group(ob, group)) {
+	for (group= bmain->group.first; group; group=group->id.next) {
+		if (object_in_group(ob, group)) {
 			/* Assign groups to selected objects */
 			CTX_DATA_BEGIN(C, Base*, base, selected_editable_bases) {
-				add_to_group(group, base->object, scene, base);
+				if (base->object->dup_group != group)
+					add_to_group(group, base->object, scene, base);
+				else
+					cycle = 1;
 				ok = 1;
 			}
 			CTX_DATA_END;
 		}
 	}
 	
-	if(!ok) BKE_report(op->reports, RPT_ERROR, "Active Object contains no groups");
+	if (!ok) BKE_report(op->reports, RPT_ERROR, "Active Object contains no groups");
+	if (cycle)
+		BKE_report(op->reports, RPT_WARNING, "Skipped some groups because of cycle detected");
 	
 	DAG_scene_sort(bmain, scene);
 	WM_event_add_notifier(C, NC_GROUP|NA_EDITED, NULL);
@@ -94,16 +99,16 @@ static int objects_add_active_exec(bContext *C, wmOperator *op)
 void GROUP_OT_objects_add_active(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add Selected To Active Group";
+	ot->name = "Add Selected To Active Group";
 	ot->description = "Add the object to an object group that contains the active object";
-	ot->idname= "GROUP_OT_objects_add_active";
+	ot->idname = "GROUP_OT_objects_add_active";
 	
 	/* api callbacks */
-	ot->exec= objects_add_active_exec;	
-	ot->poll= ED_operator_objectmode;
+	ot->exec = objects_add_active_exec;	
+	ot->poll = ED_operator_objectmode;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 static int objects_remove_active_exec(bContext *C, wmOperator *op)
@@ -114,13 +119,13 @@ static int objects_remove_active_exec(bContext *C, wmOperator *op)
 	Group *group;
 	int ok = 0;
 	
-	if(!ob) return OPERATOR_CANCELLED;
+	if (!ob) return OPERATOR_CANCELLED;
 	
 	/* linking to same group requires its own loop so we can avoid
-	   looking up the active objects groups each time */
+	 * looking up the active objects groups each time */
 
-	for(group= bmain->group.first; group; group=group->id.next) {
-		if(object_in_group(ob, group)) {
+	for (group= bmain->group.first; group; group=group->id.next) {
+		if (object_in_group(ob, group)) {
 			/* Assign groups to selected objects */
 			CTX_DATA_BEGIN(C, Base*, base, selected_editable_bases) {
 				rem_from_group(group, base->object, scene, base);
@@ -130,7 +135,7 @@ static int objects_remove_active_exec(bContext *C, wmOperator *op)
 		}
 	}
 	
-	if(!ok) BKE_report(op->reports, RPT_ERROR, "Active Object contains no groups");
+	if (!ok) BKE_report(op->reports, RPT_ERROR, "Active Object contains no groups");
 	
 	DAG_scene_sort(bmain, scene);
 	WM_event_add_notifier(C, NC_GROUP|NA_EDITED, NULL);
@@ -141,16 +146,16 @@ static int objects_remove_active_exec(bContext *C, wmOperator *op)
 void GROUP_OT_objects_remove_active(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Remove Selected From Active Group";
+	ot->name = "Remove Selected From Active Group";
 	ot->description = "Remove the object from an object group that contains the active object";
-	ot->idname= "GROUP_OT_objects_remove_active";
+	ot->idname = "GROUP_OT_objects_remove_active";
 	
 	/* api callbacks */
-	ot->exec= objects_remove_active_exec;	
-	ot->poll= ED_operator_objectmode;
+	ot->exec = objects_remove_active_exec;	
+	ot->poll = ED_operator_objectmode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 static int group_objects_remove_exec(bContext *C, wmOperator *UNUSED(op))
@@ -161,7 +166,7 @@ static int group_objects_remove_exec(bContext *C, wmOperator *UNUSED(op))
 
 	CTX_DATA_BEGIN(C, Base*, base, selected_editable_bases) {
 		group = NULL;
-		while((group = find_group(base->object, group)))
+		while ((group = find_group(base->object, group)))
 			rem_from_group(group, base->object, scene, base);
 	}
 	CTX_DATA_END;
@@ -175,16 +180,16 @@ static int group_objects_remove_exec(bContext *C, wmOperator *UNUSED(op))
 void GROUP_OT_objects_remove(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Remove From Groups";
+	ot->name = "Remove From Groups";
 	ot->description = "Remove selected objects from all groups";
-	ot->idname= "GROUP_OT_objects_remove";
+	ot->idname = "GROUP_OT_objects_remove";
 	
 	/* api callbacks */
-	ot->exec= group_objects_remove_exec;	
-	ot->poll= ED_operator_objectmode;
+	ot->exec = group_objects_remove_exec;	
+	ot->poll = ED_operator_objectmode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 static int group_create_exec(bContext *C, wmOperator *op)
@@ -212,16 +217,16 @@ static int group_create_exec(bContext *C, wmOperator *op)
 void GROUP_OT_create(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Create New Group";
+	ot->name = "Create New Group";
 	ot->description = "Create an object group from selected objects";
-	ot->idname= "GROUP_OT_create";
+	ot->idname = "GROUP_OT_create";
 	
 	/* api callbacks */
-	ot->exec= group_create_exec;	
-	ot->poll= ED_operator_objectmode;
+	ot->exec = group_create_exec;	
+	ot->poll = ED_operator_objectmode;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	RNA_def_string(ot->srna, "name", "Group", MAX_ID_NAME-2, "Name", "Name of the new group");
 }
@@ -234,7 +239,7 @@ static int group_add_exec(bContext *C, wmOperator *UNUSED(op))
 	Object *ob= ED_object_context(C);
 	Group *group;
 
-	if(ob == NULL)
+	if (ob == NULL)
 		return OPERATOR_CANCELLED;
 
 	group= add_group("Group");
@@ -248,15 +253,15 @@ static int group_add_exec(bContext *C, wmOperator *UNUSED(op))
 void OBJECT_OT_group_add(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Add to Group";
-	ot->idname= "OBJECT_OT_group_add";
+	ot->name = "Add to Group";
+	ot->idname = "OBJECT_OT_group_add";
 	ot->description = "Add an object to a new group";
 	
 	/* api callbacks */
-	ot->exec= group_add_exec;
+	ot->exec = group_add_exec;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 static int group_link_exec(bContext *C, wmOperator *op)
@@ -265,7 +270,7 @@ static int group_link_exec(bContext *C, wmOperator *op)
 	Object *ob= ED_object_context(C);
 	Group *group= BLI_findlink(&CTX_data_main(C)->group, RNA_enum_get(op->ptr, "group"));
 
-	if(ELEM(NULL, ob, group))
+	if (ELEM(NULL, ob, group))
 		return OPERATOR_CANCELLED;
 
 	add_to_group(group, ob, scene, NULL);
@@ -280,21 +285,21 @@ void OBJECT_OT_group_link(wmOperatorType *ot)
 	PropertyRNA *prop;
 
 	/* identifiers */
-	ot->name= "Link to Group";
-	ot->idname= "OBJECT_OT_group_link";
+	ot->name = "Link to Group";
+	ot->idname = "OBJECT_OT_group_link";
 	ot->description = "Add an object to an existing group";
 	
 	/* api callbacks */
-	ot->exec= group_link_exec;
-	ot->invoke= WM_enum_search_invoke;
+	ot->exec = group_link_exec;
+	ot->invoke = WM_enum_search_invoke;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	prop= RNA_def_enum(ot->srna, "group", DummyRNA_NULL_items, 0, "Group", "");
 	RNA_def_enum_funcs(prop, RNA_group_local_itemf);
-	ot->prop= prop;
+	ot->prop = prop;
 }
 
 static int group_remove_exec(bContext *C, wmOperator *UNUSED(op))
@@ -303,7 +308,7 @@ static int group_remove_exec(bContext *C, wmOperator *UNUSED(op))
 	Object *ob= ED_object_context(C);
 	Group *group= CTX_data_pointer_get_type(C, "group", &RNA_Group).data;
 
-	if(!ob || !group)
+	if (!ob || !group)
 		return OPERATOR_CANCELLED;
 
 	rem_from_group(group, ob, scene, NULL); /* base will be used if found */
@@ -316,13 +321,13 @@ static int group_remove_exec(bContext *C, wmOperator *UNUSED(op))
 void OBJECT_OT_group_remove(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Remove Group";
-	ot->idname= "OBJECT_OT_group_remove";
+	ot->name = "Remove Group";
+	ot->idname = "OBJECT_OT_group_remove";
 	
 	/* api callbacks */
-	ot->exec= group_remove_exec;
+	ot->exec = group_remove_exec;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
