@@ -105,11 +105,11 @@ static int sound_open_exec(bContext *C, wmOperator *op)
 	RNA_string_get(op->ptr, "filepath", path);
 	sound = sound_new_file(bmain, path);
 
-	if(!op->customdata)
+	if (!op->customdata)
 		sound_open_init(C, op);
 
 	if (sound==NULL || sound->playback_handle == NULL) {
-		if(op->customdata) MEM_freeN(op->customdata);
+		if (op->customdata) MEM_freeN(op->customdata);
 		BKE_report(op->reports, RPT_ERROR, "Unsupported audio format");
 		return OPERATOR_CANCELLED;
 	}
@@ -118,12 +118,12 @@ static int sound_open_exec(bContext *C, wmOperator *op)
 
 	if (info.specs.channels == AUD_CHANNELS_INVALID) {
 		sound_delete(bmain, sound);
-		if(op->customdata) MEM_freeN(op->customdata);
+		if (op->customdata) MEM_freeN(op->customdata);
 		BKE_report(op->reports, RPT_ERROR, "Unsupported audio format");
 		return OPERATOR_CANCELLED;
 	}
 
-	if(RNA_boolean_get(op->ptr, "mono")) {
+	if (RNA_boolean_get(op->ptr, "mono")) {
 		sound->flags |= SOUND_FLAGS_MONO;
 		sound_load(bmain, sound);
 	}
@@ -135,7 +135,7 @@ static int sound_open_exec(bContext *C, wmOperator *op)
 	/* hook into UI */
 	pprop= op->customdata;
 
-	if(pprop->prop) {
+	if (pprop->prop) {
 		/* when creating new ID blocks, use is already 1, but RNA
 		 * pointer se also increases user, so this compensates it */
 		sound->id.us--;
@@ -145,7 +145,7 @@ static int sound_open_exec(bContext *C, wmOperator *op)
 		RNA_property_update(C, &pprop->ptr, pprop->prop);
 	}
 
-	if(op->customdata) MEM_freeN(op->customdata);
+	if (op->customdata) MEM_freeN(op->customdata);
 	return OPERATOR_FINISHED;
 }
 
@@ -162,7 +162,7 @@ static int sound_open_exec(bContext *UNUSED(C), wmOperator *op)
 
 static int sound_open_invoke(bContext *C, wmOperator *op, wmEvent *event)
 {
-	if(RNA_struct_property_is_set(op->ptr, "filepath"))
+	if (RNA_struct_property_is_set(op->ptr, "filepath"))
 		return sound_open_exec(C, op);
 
 	sound_open_init(C, op);
@@ -173,17 +173,17 @@ static int sound_open_invoke(bContext *C, wmOperator *op, wmEvent *event)
 static void SOUND_OT_open(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Open Sound";
-	ot->description= "Load a sound file";
-	ot->idname= "SOUND_OT_open";
+	ot->name = "Open Sound";
+	ot->description = "Load a sound file";
+	ot->idname = "SOUND_OT_open";
 
 	/* api callbacks */
-	ot->exec= sound_open_exec;
-	ot->invoke= sound_open_invoke;
-	ot->cancel= sound_open_cancel;
+	ot->exec = sound_open_exec;
+	ot->invoke = sound_open_invoke;
+	ot->cancel = sound_open_cancel;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	WM_operator_properties_filesel(ot, FOLDERFILE|SOUNDFILE|MOVIEFILE, FILE_SPECIAL, FILE_OPENFILE, WM_FILESEL_FILEPATH | WM_FILESEL_RELPATH, FILE_DEFAULTDISPLAY);
@@ -194,17 +194,17 @@ static void SOUND_OT_open(wmOperatorType *ot)
 static void SOUND_OT_open_mono(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Open Sound Mono";
-	ot->description= "Load a sound file as mono";
-	ot->idname= "SOUND_OT_open_mono";
+	ot->name = "Open Sound Mono";
+	ot->description = "Load a sound file as mono";
+	ot->idname = "SOUND_OT_open_mono";
 
 	/* api callbacks */
-	ot->exec= sound_open_exec;
-	ot->invoke= sound_open_invoke;
-	ot->cancel= sound_open_cancel;
+	ot->exec = sound_open_exec;
+	ot->invoke = sound_open_invoke;
+	ot->cancel = sound_open_cancel;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	WM_operator_properties_filesel(ot, FOLDERFILE|SOUNDFILE|MOVIEFILE, FILE_SPECIAL, FILE_OPENFILE, WM_FILESEL_FILEPATH | WM_FILESEL_RELPATH, FILE_DEFAULTDISPLAY);
@@ -223,19 +223,19 @@ static int sound_update_animation_flags_exec(bContext *C, wmOperator *UNUSED(op)
 
 	SEQ_BEGIN(scene->ed, seq) {
 		fcu = id_data_find_fcurve(&scene->id, seq, &RNA_Sequence, "volume", 0, &driven);
-		if(fcu || driven)
+		if (fcu || driven)
 			seq->flag |= SEQ_AUDIO_VOLUME_ANIMATED;
 		else
 			seq->flag &= ~SEQ_AUDIO_VOLUME_ANIMATED;
 
 		fcu = id_data_find_fcurve(&scene->id, seq, &RNA_Sequence, "pitch", 0, &driven);
-		if(fcu || driven)
+		if (fcu || driven)
 			seq->flag |= SEQ_AUDIO_PITCH_ANIMATED;
 		else
 			seq->flag &= ~SEQ_AUDIO_PITCH_ANIMATED;
 
 		fcu = id_data_find_fcurve(&scene->id, seq, &RNA_Sequence, "pan", 0, &driven);
-		if(fcu || driven)
+		if (fcu || driven)
 			seq->flag |= SEQ_AUDIO_PAN_ANIMATED;
 		else
 			seq->flag &= ~SEQ_AUDIO_PAN_ANIMATED;
@@ -243,7 +243,7 @@ static int sound_update_animation_flags_exec(bContext *C, wmOperator *UNUSED(op)
 	SEQ_END
 
 	fcu = id_data_find_fcurve(&scene->id, scene, &RNA_Scene, "audio_volume", 0, &driven);
-	if(fcu || driven)
+	if (fcu || driven)
 		scene->audio.flag |= AUDIO_VOLUME_ANIMATED;
 	else
 		scene->audio.flag &= ~AUDIO_VOLUME_ANIMATED;
@@ -254,22 +254,22 @@ static int sound_update_animation_flags_exec(bContext *C, wmOperator *UNUSED(op)
 static void SOUND_OT_update_animation_flags(wmOperatorType *ot)
 {
 	/*
-	  This operator is needed to set a correct state of the sound animation
-	  System. Unfortunately there's no really correct place to call the exec
-	  function, that's why I made it an operator that's only visible in the
-	  search menu. Apart from that the bake animation operator calls it too.
-	*/
+	 * This operator is needed to set a correct state of the sound animation
+	 * System. Unfortunately there's no really correct place to call the exec
+	 * function, that's why I made it an operator that's only visible in the
+	 * search menu. Apart from that the bake animation operator calls it too.
+	 */
 
 	/* identifiers */
-	ot->name= "Update animation";
-	ot->description= "Update animation flags";
-	ot->idname= "SOUND_OT_update_animation_flags";
+	ot->name = "Update animation";
+	ot->description = "Update animation flags";
+	ot->idname = "SOUND_OT_update_animation_flags";
 
 	/* api callbacks */
-	ot->exec= sound_update_animation_flags_exec;
+	ot->exec = sound_update_animation_flags_exec;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER;
+	ot->flag = OPTYPE_REGISTER;
 }
 
 /* ******************************************************* */
@@ -283,8 +283,7 @@ static int sound_bake_animation_exec(bContext *C, wmOperator *UNUSED(op))
 
 	sound_update_animation_flags_exec(C, NULL);
 
-	for(cfra = scene->r.sfra > 0 ? scene->r.sfra - 1 : 0; cfra <= scene->r.efra + 1; cfra++)
-	{
+	for (cfra = (scene->r.sfra > 0) ? (scene->r.sfra - 1) : 0; cfra <= scene->r.efra + 1; cfra++) {
 		scene->r.cfra = cfra;
 		scene_update_for_newframe(bmain, scene, scene->lay);
 	}
@@ -298,15 +297,15 @@ static int sound_bake_animation_exec(bContext *C, wmOperator *UNUSED(op))
 static void SOUND_OT_bake_animation(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Update animation cache";
-	ot->description= "Updates the audio animation cache so that it's up to date";
-	ot->idname= "SOUND_OT_bake_animation";
+	ot->name = "Update animation cache";
+	ot->description = "Update the audio animation cache";
+	ot->idname = "SOUND_OT_bake_animation";
 
 	/* api callbacks */
-	ot->exec= sound_bake_animation_exec;
+	ot->exec = sound_bake_animation_exec;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER;
+	ot->flag = OPTYPE_REGISTER;
 }
 
 
@@ -319,6 +318,7 @@ static int sound_mixdown_exec(bContext *C, wmOperator *op)
 	char filename[FILE_MAX];
 	Scene *scene;
 	Main *bmain;
+	int split;
 
 	int bitrate, accuracy;
 	AUD_DeviceSpecs specs;
@@ -334,6 +334,7 @@ static int sound_mixdown_exec(bContext *C, wmOperator *op)
 	specs.format = RNA_enum_get(op->ptr, "format");
 	container = RNA_enum_get(op->ptr, "container");
 	codec = RNA_enum_get(op->ptr, "codec");
+	split = RNA_boolean_get(op->ptr, "split_channels");
 	scene = CTX_data_scene(C);
 	bmain = CTX_data_main(C);
 	specs.channels = scene->r.ffcodecdata.audio_channels;
@@ -342,11 +343,14 @@ static int sound_mixdown_exec(bContext *C, wmOperator *op)
 	BLI_strncpy(filename, path, sizeof(filename));
 	BLI_path_abs(filename, bmain->name);
 
-	result = AUD_mixdown(scene->sound_scene, SFRA * specs.rate / FPS, (EFRA - SFRA) * specs.rate / FPS,
-						 accuracy, filename, specs, container, codec, bitrate);
+	if(split)
+		result = AUD_mixdown_per_channel(scene->sound_scene, SFRA * specs.rate / FPS, (EFRA - SFRA) * specs.rate / FPS,
+										 accuracy, filename, specs, container, codec, bitrate);
+	else
+		result = AUD_mixdown(scene->sound_scene, SFRA * specs.rate / FPS, (EFRA - SFRA) * specs.rate / FPS,
+							 accuracy, filename, specs, container, codec, bitrate);
 
-	if(result)
-	{
+	if (result) {
 		BKE_report(op->reports, RPT_ERROR, result);
 		return OPERATOR_CANCELLED;
 	}
@@ -359,7 +363,7 @@ static int sound_mixdown_exec(bContext *C, wmOperator *op)
 
 static int sound_mixdown_invoke(bContext *C, wmOperator *op, wmEvent *event)
 {
-	if(RNA_struct_property_is_set(op->ptr, "filepath"))
+	if (RNA_struct_property_is_set(op->ptr, "filepath"))
 		return sound_mixdown_exec(C, op);
 
 	return WM_operator_filesel(C, op, event);
@@ -572,19 +576,19 @@ static void SOUND_OT_mixdown(wmOperatorType *ot)
 #endif // WITH_AUDASPACE
 
 	/* identifiers */
-	ot->name= "Mixdown";
-	ot->description= "Mixes the scene's audio to a sound file";
-	ot->idname= "SOUND_OT_mixdown";
+	ot->name = "Mixdown";
+	ot->description = "Mixes the scene's audio to a sound file";
+	ot->idname = "SOUND_OT_mixdown";
 
 	/* api callbacks */
-	ot->exec= sound_mixdown_exec;
-	ot->invoke= sound_mixdown_invoke;
+	ot->exec = sound_mixdown_exec;
+	ot->invoke = sound_mixdown_invoke;
 
 #ifdef WITH_AUDASPACE
-	ot->ui= sound_mixdown_draw;
+	ot->ui = sound_mixdown_draw;
 #endif
 	/* flags */
-	ot->flag= OPTYPE_REGISTER;
+	ot->flag = OPTYPE_REGISTER;
 
 	/* properties */
 	WM_operator_properties_filesel(ot, FOLDERFILE|SOUNDFILE, FILE_SPECIAL, FILE_SAVE, WM_FILESEL_FILEPATH, FILE_DEFAULTDISPLAY);
@@ -594,6 +598,7 @@ static void SOUND_OT_mixdown(wmOperatorType *ot)
 	RNA_def_enum(ot->srna, "codec", codec_items, AUD_CODEC_FLAC, "Codec", "Audio Codec");
 	RNA_def_enum(ot->srna, "format", format_items, AUD_FORMAT_S16, "Format", "Sample format");
 	RNA_def_int(ot->srna, "bitrate", 192, 32, 512, "Bitrate", "Bitrate in kbit/s", 32, 512);
+	RNA_def_boolean(ot->srna, "split_channels", 0, "Split channels", "Each channel will be rendered into a mono file");
 #endif // WITH_AUDASPACE
 }
 
@@ -603,7 +608,7 @@ static int sound_poll(bContext *C)
 {
 	Editing* ed = CTX_data_scene(C)->ed;
 
-	if(!ed || !ed->act_seq || ed->act_seq->type != SEQ_SOUND)
+	if (!ed || !ed->act_seq || ed->act_seq->type != SEQ_SOUND)
 		return 0;
 
 	return 1;
@@ -616,12 +621,12 @@ static int sound_pack_exec(bContext *C, wmOperator *op)
 	Editing* ed = CTX_data_scene(C)->ed;
 	bSound* sound;
 
-	if(!ed || !ed->act_seq || ed->act_seq->type != SEQ_SOUND)
+	if (!ed || !ed->act_seq || ed->act_seq->type != SEQ_SOUND)
 		return OPERATOR_CANCELLED;
 
 	sound = ed->act_seq->sound;
 
-	if(!sound || sound->packedfile)
+	if (!sound || sound->packedfile)
 		return OPERATOR_CANCELLED;
 
 	sound->packedfile= newPackedFile(op->reports, sound->name, ID_BLEND_PATH(bmain, &sound->id));
@@ -633,16 +638,16 @@ static int sound_pack_exec(bContext *C, wmOperator *op)
 static void SOUND_OT_pack(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Pack Sound";
-	ot->description= "Pack the sound into the current blend file";
-	ot->idname= "SOUND_OT_pack";
+	ot->name = "Pack Sound";
+	ot->description = "Pack the sound into the current blend file";
+	ot->idname = "SOUND_OT_pack";
 
 	/* api callbacks */
-	ot->exec= sound_pack_exec;
-	ot->poll= sound_poll;
+	ot->exec = sound_pack_exec;
+	ot->poll = sound_poll;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /********************* unpack operator *********************/
@@ -659,10 +664,10 @@ static int sound_unpack_exec(bContext *C, wmOperator *op)
 		sound = BLI_findstring(&CTX_data_main(C)->sound, sndname, offsetof(ID, name) + 2);
 	}
 
-	if(!sound || !sound->packedfile)
+	if (!sound || !sound->packedfile)
 		return OPERATOR_CANCELLED;
 
-	if(G.fileflags & G_AUTOPACK)
+	if (G.fileflags & G_AUTOPACK)
 		BKE_report(op->reports, RPT_WARNING, "AutoPack is enabled, so image will be packed again on file save");
 
 	unpackSound(CTX_data_main(C), op->reports, sound, method);
@@ -675,18 +680,18 @@ static int sound_unpack_invoke(bContext *C, wmOperator *op, wmEvent *UNUSED(even
 	Editing* ed = CTX_data_scene(C)->ed;
 	bSound* sound;
 
-	if(RNA_struct_property_is_set(op->ptr, "id"))
+	if (RNA_struct_property_is_set(op->ptr, "id"))
 		return sound_unpack_exec(C, op);
 
-	if(!ed || !ed->act_seq || ed->act_seq->type != SEQ_SOUND)
+	if (!ed || !ed->act_seq || ed->act_seq->type != SEQ_SOUND)
 		return OPERATOR_CANCELLED;
 
 	sound = ed->act_seq->sound;
 
-	if(!sound || !sound->packedfile)
+	if (!sound || !sound->packedfile)
 		return OPERATOR_CANCELLED;
 
-	if(G.fileflags & G_AUTOPACK)
+	if (G.fileflags & G_AUTOPACK)
 		BKE_report(op->reports, RPT_WARNING, "AutoPack is enabled, so image will be packed again on file save");
 
 	unpack_menu(C, "SOUND_OT_unpack", sound->id.name+2, sound->name, "sounds", sound->packedfile);
@@ -697,17 +702,17 @@ static int sound_unpack_invoke(bContext *C, wmOperator *op, wmEvent *UNUSED(even
 static void SOUND_OT_unpack(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Unpack Sound";
-	ot->description= "Unpack the sound to the samples filename";
-	ot->idname= "SOUND_OT_unpack";
+	ot->name = "Unpack Sound";
+	ot->description = "Unpack the sound to the samples filename";
+	ot->idname = "SOUND_OT_unpack";
 
 	/* api callbacks */
-	ot->exec= sound_unpack_exec;
-	ot->invoke= sound_unpack_invoke;
-	ot->poll= sound_poll;
+	ot->exec = sound_unpack_exec;
+	ot->invoke = sound_unpack_invoke;
+	ot->poll = sound_poll;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	RNA_def_enum(ot->srna, "method", unpack_method_items, PF_USE_LOCAL, "Method", "How to unpack");
