@@ -62,51 +62,51 @@ void clip_graph_tracking_values_iterate_track(SpaceClip *sc, MovieTrackingTrack
 			void (*segment_start) (void *userdata, MovieTrackingTrack *track, int coord),
 			void (*segment_end) (void *userdata))
 {
-	MovieClip *clip= ED_space_clip(sc);
+	MovieClip *clip = ED_space_clip(sc);
 	int width, height, coord;
 
 	BKE_movieclip_get_size(clip, &sc->user, &width, &height);
 
-	for(coord= 0; coord<2; coord++) {
-		int i, open= 0, prevfra= 0;
-		float prevval= 0.0f;
+	for (coord = 0; coord < 2; coord++) {
+		int i, open = FALSE, prevfra = 0;
+		float prevval = 0.0f;
 
-		for(i= 0; i<track->markersnr; i++) {
-			MovieTrackingMarker *marker= &track->markers[i];
+		for (i = 0; i < track->markersnr; i++) {
+			MovieTrackingMarker *marker = &track->markers[i];
 			float val;
 
-			if(marker->flag&MARKER_DISABLED) {
-				if(open) {
-					if(segment_end)
+			if (marker->flag & MARKER_DISABLED) {
+				if (open) {
+					if (segment_end)
 						segment_end(userdata);
 
-					open= 0;
+					open = FALSE;
 				}
 
 				continue;
 			}
 
-			if(!open) {
-				if(segment_start)
+			if (!open) {
+				if (segment_start)
 					segment_start(userdata, track, coord);
 
-				open= 1;
-				prevval= marker->pos[coord];
+				open = TRUE;
+				prevval = marker->pos[coord];
 			}
 
 			/* value is a pixels per frame speed */
-			val= (marker->pos[coord] - prevval) * ((coord==0) ? (width) : (height));
-			val/= marker->framenr-prevfra;
+			val = (marker->pos[coord] - prevval) * ((coord == 0) ? (width) : (height));
+			val /= marker->framenr - prevfra;
 
-			if(func)
+			if (func)
 				func(userdata, track, marker, coord, val);
 
-			prevval= marker->pos[coord];
-			prevfra= marker->framenr;
+			prevval = marker->pos[coord];
+			prevfra = marker->framenr;
 		}
 
-		if(open) {
-			if(segment_end)
+		if (open) {
+			if (segment_end)
 				segment_end(userdata);
 		}
 	}
@@ -117,89 +117,89 @@ void clip_graph_tracking_values_iterate(SpaceClip *sc, void *userdata,
 			void (*segment_start) (void *userdata, MovieTrackingTrack *track, int coord),
 			void (*segment_end) (void *userdata))
 {
-	MovieClip *clip= ED_space_clip(sc);
-	MovieTracking *tracking= &clip->tracking;
-	ListBase *tracksbase= BKE_tracking_get_tracks(tracking);
+	MovieClip *clip = ED_space_clip(sc);
+	MovieTracking *tracking = &clip->tracking;
+	ListBase *tracksbase = BKE_tracking_get_tracks(tracking);
 	MovieTrackingTrack *track;
 
-	track= tracksbase->first;
-	while(track) {
-		if(TRACK_VIEW_SELECTED(sc, track)) {
+	track = tracksbase->first;
+	while (track) {
+		if (TRACK_VIEW_SELECTED(sc, track)) {
 			clip_graph_tracking_values_iterate_track(sc, track, userdata, func, segment_start, segment_end);
 		}
 
-		track= track->next;
+		track = track->next;
 	}
 }
 
 void clip_graph_tracking_iterate(SpaceClip *sc, void *userdata,
 			void (*func) (void *userdata, MovieTrackingMarker *marker))
 {
-	MovieClip *clip= ED_space_clip(sc);
-	MovieTracking *tracking= &clip->tracking;
-	ListBase *tracksbase= BKE_tracking_get_tracks(tracking);
+	MovieClip *clip = ED_space_clip(sc);
+	MovieTracking *tracking = &clip->tracking;
+	ListBase *tracksbase = BKE_tracking_get_tracks(tracking);
 	MovieTrackingTrack *track;
 
-	track= tracksbase->first;
-	while(track) {
-		if(TRACK_VIEW_SELECTED(sc, track)) {
+	track = tracksbase->first;
+	while (track) {
+		if (TRACK_VIEW_SELECTED(sc, track)) {
 			int i;
 
-			for(i= 0; i<track->markersnr; i++) {
-				MovieTrackingMarker *marker= &track->markers[i];
+			for (i = 0; i < track->markersnr; i++) {
+				MovieTrackingMarker *marker = &track->markers[i];
 
-				if(marker->flag&MARKER_DISABLED)
+				if (marker->flag & MARKER_DISABLED)
 					continue;
 
-				if(func)
+				if (func)
 					func(userdata, marker);
 			}
 		}
 
-		track= track->next;
+		track = track->next;
 	}
 }
 
 void clip_delete_track(bContext *C, MovieClip *clip, ListBase *tracksbase, MovieTrackingTrack *track)
 {
-	MovieTracking *tracking= &clip->tracking;
-	MovieTrackingStabilization *stab= &tracking->stabilization;
-	MovieTrackingTrack *act_track= BKE_tracking_active_track(tracking);
+	MovieTracking *tracking = &clip->tracking;
+	MovieTrackingStabilization *stab = &tracking->stabilization;
+	MovieTrackingTrack *act_track = BKE_tracking_active_track(tracking);
 
-	int has_bundle= 0, update_stab= 0;
+	int has_bundle = FALSE, update_stab = FALSE;
 
-	if(track==act_track)
-		tracking->act_track= NULL;
+	if (track==act_track)
+		tracking->act_track = NULL;
 
-	if(track==stab->rot_track) {
-		stab->rot_track= NULL;
+	if (track == stab->rot_track) {
+		stab->rot_track = NULL;
 
-		update_stab= 1;
+		update_stab = TRUE;
 	}
 
 	/* handle reconstruction display in 3d viewport */
-	if(track->flag&TRACK_HAS_BUNDLE)
-		has_bundle= 1;
+	if (track->flag & TRACK_HAS_BUNDLE)
+		has_bundle = TRUE;
 
 	BKE_tracking_free_track(track);
 	BLI_freelinkN(tracksbase, track);
 
 	WM_event_add_notifier(C, NC_MOVIECLIP|NA_EDITED, clip);
 
-	if(update_stab) {
-		tracking->stabilization.ok= 0;
+	if (update_stab) {
+		tracking->stabilization.ok = FALSE;
 
 		DAG_id_tag_update(&clip->id, 0);
 		WM_event_add_notifier(C, NC_MOVIECLIP|ND_DISPLAY, clip);
 	}
 
-	if(has_bundle)
+	if (has_bundle)
 		WM_event_add_notifier(C, NC_SPACE|ND_SPACE_VIEW3D, NULL);
 }
 
 void clip_delete_marker(bContext *C, MovieClip *clip, ListBase *tracksbase, MovieTrackingTrack *track, MovieTrackingMarker *marker)
 {
-	if(track->markersnr==1) {
+	if (track->markersnr == 1) {
 		clip_delete_track(C, clip, tracksbase, track);
 	}
 	else {
@@ -217,6 +217,6 @@ void clip_view_center_to_point(SpaceClip *sc, float x, float y)
 	ED_space_clip_size(sc, &width, &height);
 	ED_space_clip_aspect(sc, &aspx, &aspy);
 
-	sc->xof= (x-0.5f)*width*aspx;
-	sc->yof= (y-0.5f)*height*aspy;
+	sc->xof = (x - 0.5f) * width * aspx;
+	sc->yof = (y - 0.5f) * height * aspy;
 }
