@@ -113,7 +113,7 @@ static void file_free(SpaceLink *sl)
 {	
 	SpaceFile *sfile= (SpaceFile *) sl;
 	
-	if(sfile->files) {
+	if (sfile->files) {
 		// XXXXX would need to do thumbnails_stop here, but no context available
 		filelist_freelib(sfile->files);
 		filelist_free(sfile->files);
@@ -121,13 +121,13 @@ static void file_free(SpaceLink *sl)
 		sfile->files= NULL;
 	}
 
-	if(sfile->folders_prev) {
+	if (sfile->folders_prev) {
 		folderlist_free(sfile->folders_prev);
 		MEM_freeN(sfile->folders_prev);
 		sfile->folders_prev= NULL;
 	}
 
-	if(sfile->folders_next) {
+	if (sfile->folders_next) {
 		folderlist_free(sfile->folders_next);
 		MEM_freeN(sfile->folders_next);
 		sfile->folders_next= NULL;
@@ -151,7 +151,7 @@ static void file_init(struct wmWindowManager *UNUSED(wm), ScrArea *sa)
 	SpaceFile *sfile= (SpaceFile*)sa->spacedata.first;
 	//printf("file_init\n");
 
-	if(sfile->layout) sfile->layout->dirty= TRUE;
+	if (sfile->layout) sfile->layout->dirty= TRUE;
 }
 
 
@@ -169,10 +169,10 @@ static SpaceLink *file_duplicate(SpaceLink *sl)
 		filelist_setdir(sfilen->files, sfilen->params->dir);
 	}
 
-	if(sfileo->folders_prev)
+	if (sfileo->folders_prev)
 		sfilen->folders_prev = folderlist_duplicate(sfileo->folders_prev);
 
-	if(sfileo->folders_next)
+	if (sfileo->folders_next)
 		sfilen->folders_next = folderlist_duplicate(sfileo->folders_next);
 	
 	if (sfileo->layout) {
@@ -196,32 +196,35 @@ static void file_refresh(const bContext *C, ScrArea *UNUSED(sa))
 	filelist_hidedot(sfile->files, params->flag & FILE_HIDE_DOT);
 	filelist_setfilter(sfile->files, params->flag & FILE_FILTER ? params->filter : 0);	
 	filelist_setfilter_types(sfile->files, params->filter_glob);
-	if (filelist_empty(sfile->files))
-	{
+
+	if (filelist_empty(sfile->files)) {
 		thumbnails_stop(sfile->files, C);
 		filelist_readdir(sfile->files);
-		if(params->sort!=FILE_SORT_NONE) {
+		if (params->sort!=FILE_SORT_NONE) {
 			filelist_sort(sfile->files, params->sort);
 		}
 		BLI_strncpy(params->dir, filelist_dir(sfile->files), FILE_MAX);
-		if(params->display == FILE_IMGDISPLAY) {
+		if (params->display == FILE_IMGDISPLAY) {
 			thumbnails_start(sfile->files, C);
 		}
-	} else {
-		if(params->sort!=FILE_SORT_NONE) {
+	}
+	else {
+		if (params->sort!=FILE_SORT_NONE) {
 			thumbnails_stop(sfile->files, C);
 			filelist_sort(sfile->files, params->sort);
-			if(params->display == FILE_IMGDISPLAY) {
+			if (params->display == FILE_IMGDISPLAY) {
 				thumbnails_start(sfile->files, C);
 			}
-		} else {
-			if(params->display == FILE_IMGDISPLAY) {
+		}
+		else {
+			if (params->display == FILE_IMGDISPLAY) {
 				if (!thumbnails_running(sfile->files,C)) {
 					thumbnails_start(sfile->files, C);
 				}
-			} else {
+			}
+			else {
 				/* stop any running thumbnail jobs if we're not 
-				 displaying them - speedup for NFS */
+				 * displaying them - speedup for NFS */
 				thumbnails_stop(sfile->files, C);
 			}
 			filelist_filter(sfile->files);
@@ -272,10 +275,10 @@ static void file_main_area_init(wmWindowManager *wm, ARegion *ar)
 	UI_view2d_region_reinit(&ar->v2d, V2D_COMMONVIEW_LIST, ar->winx, ar->winy);
 	
 	/* own keymaps */
-	keymap= WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);
+	keymap = WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);
 	WM_event_add_keymap_handler_bb(&ar->handlers, keymap, &ar->v2d.mask, &ar->winrct);
 
-	keymap= WM_keymap_find(wm->defaultconf, "File Browser Main", SPACE_FILE, 0);
+	keymap = WM_keymap_find(wm->defaultconf, "File Browser Main", SPACE_FILE, 0);
 	WM_event_add_keymap_handler_bb(&ar->handlers, keymap, &ar->v2d.mask, &ar->winrct);
 							   
 
@@ -333,9 +336,9 @@ static void file_main_area_draw(const bContext *C, ARegion *ar)
 		
 		/* XXX this happens on scaling down Screen (like from startup.blend) */
 		/* view2d has no type specific for filewindow case, which doesnt scroll vertically */
-		if(v2d->cur.ymax < 0) {
+		if (v2d->cur.ymax < 0) {
 			v2d->cur.ymin -= v2d->cur.ymax;
-			v2d->cur.ymax= 0;
+			v2d->cur.ymax = 0;
 		}
 	}
 	/* v2d has initialized flag, so this call will only set the mask correct */
@@ -395,7 +398,7 @@ static void file_keymap(struct wmKeyConfig *keyconf)
 {
 	wmKeyMapItem *kmi;
 	/* keys for all areas */
-	wmKeyMap *keymap= WM_keymap_find(keyconf, "File Browser", SPACE_FILE, 0);
+	wmKeyMap *keymap = WM_keymap_find(keyconf, "File Browser", SPACE_FILE, 0);
 	WM_keymap_add_item(keymap, "FILE_OT_bookmark_toggle", NKEY, KM_PRESS, 0, 0);
 	WM_keymap_add_item(keymap, "FILE_OT_parent", PKEY, KM_PRESS, 0, 0);
 	WM_keymap_add_item(keymap, "FILE_OT_bookmark_add", BKEY, KM_PRESS, KM_CTRL, 0);
@@ -408,8 +411,8 @@ static void file_keymap(struct wmKeyConfig *keyconf)
 	WM_keymap_verify_item(keymap, "FILE_OT_smoothscroll", TIMER1, KM_ANY, KM_ANY, 0);
 
 	/* keys for main area */
-	keymap= WM_keymap_find(keyconf, "File Browser Main", SPACE_FILE, 0);
-	kmi= WM_keymap_add_item(keymap, "FILE_OT_execute", LEFTMOUSE, KM_DBL_CLICK, 0, 0);
+	keymap = WM_keymap_find(keyconf, "File Browser Main", SPACE_FILE, 0);
+	kmi = WM_keymap_add_item(keymap, "FILE_OT_execute", LEFTMOUSE, KM_DBL_CLICK, 0, 0);
 	RNA_boolean_set(kmi->ptr, "need_active", TRUE);
 	WM_keymap_add_item(keymap, "FILE_OT_select", LEFTMOUSE, KM_CLICK, 0, 0);
 	kmi = WM_keymap_add_item(keymap, "FILE_OT_select", LEFTMOUSE, KM_CLICK, KM_SHIFT, 0);
@@ -438,7 +441,7 @@ static void file_keymap(struct wmKeyConfig *keyconf)
 	
 	
 	/* keys for button area (top) */
-	keymap= WM_keymap_find(keyconf, "File Browser Buttons", SPACE_FILE, 0);
+	keymap = WM_keymap_find(keyconf, "File Browser Buttons", SPACE_FILE, 0);
 	kmi = WM_keymap_add_item(keymap, "FILE_OT_filenum", PADPLUSKEY, KM_PRESS, 0, 0);
 	RNA_int_set(kmi->ptr, "increment", 1);
 	kmi = WM_keymap_add_item(keymap, "FILE_OT_filenum", PADPLUSKEY, KM_PRESS, KM_SHIFT, 0);
@@ -461,7 +464,7 @@ static void file_channel_area_init(wmWindowManager *wm, ARegion *ar)
 	ED_region_panels_init(wm, ar);
 
 	/* own keymaps */
-	keymap= WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);	
+	keymap = WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);	
 	WM_event_add_keymap_handler_bb(&ar->handlers, keymap, &ar->v2d.mask, &ar->winrct);
 }
 
@@ -485,7 +488,7 @@ static void file_header_area_init(wmWindowManager *wm, ARegion *ar)
 	
 	ED_region_header_init(ar);
 	
-	keymap= WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);	
+	keymap = WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);	
 	WM_event_add_keymap_handler_bb(&ar->handlers, keymap, &ar->v2d.mask, &ar->winrct);
 }
 
@@ -502,10 +505,10 @@ static void file_ui_area_init(wmWindowManager *wm, ARegion *ar)
 	UI_view2d_region_reinit(&ar->v2d, V2D_COMMONVIEW_HEADER, ar->winx, ar->winy);
 
 	/* own keymap */
-	keymap= WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);
+	keymap = WM_keymap_find(wm->defaultconf, "File Browser", SPACE_FILE, 0);
 	WM_event_add_keymap_handler_bb(&ar->handlers, keymap, &ar->v2d.mask, &ar->winrct);
 
-	keymap= WM_keymap_find(wm->defaultconf, "File Browser Buttons", SPACE_FILE, 0);
+	keymap = WM_keymap_find(wm->defaultconf, "File Browser Buttons", SPACE_FILE, 0);
 	WM_event_add_keymap_handler_bb(&ar->handlers, keymap, &ar->v2d.mask, &ar->winrct);
 }
 
@@ -518,8 +521,8 @@ static void file_ui_area_draw(const bContext *C, ARegion *ar)
 	glClear(GL_COLOR_BUFFER_BIT);
 
 	/* scrolling here is just annoying, disable it */
-	ar->v2d.cur.ymax= ar->v2d.cur.ymax - ar->v2d.cur.ymin;
-	ar->v2d.cur.ymin= 0;
+	ar->v2d.cur.ymax = ar->v2d.cur.ymax - ar->v2d.cur.ymin;
+	ar->v2d.cur.ymin = 0;
 
 	/* set view2d view matrix for scrolling (without scrollers) */
 	UI_view2d_view_ortho(&ar->v2d);
