@@ -154,7 +154,7 @@ static int graphkeys_deselectall_exec(bContext *C, wmOperator *op)
 	if (ANIM_animdata_get_context(C, &ac) == 0)
 		return OPERATOR_CANCELLED;
 		
-	/* 'standard' behaviour - check if selected, then apply relevant selection */
+	/* 'standard' behavior - check if selected, then apply relevant selection */
 	if (RNA_boolean_get(op->ptr, "invert"))
 		deselect_graph_keys(&ac, 0, SELECT_INVERT, TRUE);
 	else
@@ -169,19 +169,19 @@ static int graphkeys_deselectall_exec(bContext *C, wmOperator *op)
 void GRAPH_OT_select_all_toggle (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select All";
-	ot->idname= "GRAPH_OT_select_all_toggle";
-	ot->description= "Toggle selection of all keyframes";
+	ot->name = "Select All";
+	ot->idname = "GRAPH_OT_select_all_toggle";
+	ot->description = "Toggle selection of all keyframes";
 	
 	/* api callbacks */
-	ot->exec= graphkeys_deselectall_exec;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->exec = graphkeys_deselectall_exec;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
+	ot->flag = OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
 	
 	/* props */
-	ot->prop= RNA_def_boolean(ot->srna, "invert", 0, "Invert", "");
+	ot->prop = RNA_def_boolean(ot->srna, "invert", 0, "Invert", "");
 }
 
 /* ******************** Border Select Operator **************************** */
@@ -193,7 +193,7 @@ void GRAPH_OT_select_all_toggle (wmOperatorType *ot)
  */
 
 /* Borderselect only selects keyframes now, as overshooting handles often get caught too,
- * which means that they may be inadvertantly moved as well. However, incl_handles overrides
+ * which means that they may be inadvertently moved as well. However, incl_handles overrides
  * this, and allow handles to be considered independently too.
  * Also, for convenience, handles should get same status as keyframe (if it was within bounds).
  */
@@ -316,16 +316,16 @@ static int graphkeys_borderselect_exec(bContext *C, wmOperator *op)
 	incl_handles = RNA_boolean_get(op->ptr, "include_handles");
 	
 	/* get settings from operator */
-	rect.xmin= RNA_int_get(op->ptr, "xmin");
-	rect.ymin= RNA_int_get(op->ptr, "ymin");
-	rect.xmax= RNA_int_get(op->ptr, "xmax");
-	rect.ymax= RNA_int_get(op->ptr, "ymax");
+	rect.xmin = RNA_int_get(op->ptr, "xmin");
+	rect.ymin = RNA_int_get(op->ptr, "ymin");
+	rect.xmax = RNA_int_get(op->ptr, "xmax");
+	rect.ymax = RNA_int_get(op->ptr, "ymax");
 	
 	/* selection 'mode' depends on whether borderselect region only matters on one axis */
 	if (RNA_boolean_get(op->ptr, "axis_range")) {
 		/* mode depends on which axis of the range is larger to determine which axis to use 
 		 *	- checking this in region-space is fine, as it's fundamentally still going to be a different rect size
-		 *	- the frame-range select option is favoured over the channel one (x over y), as frame-range one is often
+		 *	- the frame-range select option is favored over the channel one (x over y), as frame-range one is often
 		 *	  used for tweaking timing when "blocking", while channels is not that useful...
 		 */
 		if ((rect.xmax - rect.xmin) >= (rect.ymax - rect.ymin))
@@ -348,25 +348,25 @@ static int graphkeys_borderselect_exec(bContext *C, wmOperator *op)
 void GRAPH_OT_select_border(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Border Select";
-	ot->idname= "GRAPH_OT_select_border";
-	ot->description= "Select all keyframes within the specified region";
+	ot->name = "Border Select";
+	ot->idname = "GRAPH_OT_select_border";
+	ot->description = "Select all keyframes within the specified region";
 	
 	/* api callbacks */
-	ot->invoke= WM_border_select_invoke;
-	ot->exec= graphkeys_borderselect_exec;
-	ot->modal= WM_border_select_modal;
-	ot->cancel= WM_border_select_cancel;
+	ot->invoke = WM_border_select_invoke;
+	ot->exec = graphkeys_borderselect_exec;
+	ot->modal = WM_border_select_modal;
+	ot->cancel = WM_border_select_cancel;
 	
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
+	ot->flag = OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
 	
 	/* rna */
 	WM_operator_properties_gesture_border(ot, TRUE);
 	
-	ot->prop= RNA_def_boolean(ot->srna, "axis_range", 0, "Axis Range", "");
+	ot->prop = RNA_def_boolean(ot->srna, "axis_range", 0, "Axis Range", "");
 	RNA_def_boolean(ot->srna, "include_handles", 0, "Include Handles", "Are handles tested individually against the selection criteria");
 }
 
@@ -449,7 +449,7 @@ static void columnselect_graph_keys (bAnimContext *ac, short mode)
 	KeyframeEditFunc select_cb, ok_cb;
 	KeyframeEditData ked;
 	
-	/* initialise keyframe editing data */
+	/* initialize keyframe editing data */
 	memset(&ked, 0, sizeof(KeyframeEditData));
 	
 	/* build list of columns */
@@ -538,19 +538,19 @@ static int graphkeys_columnselect_exec(bContext *C, wmOperator *op)
 void GRAPH_OT_select_column (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select All";
-	ot->idname= "GRAPH_OT_select_column";
-	ot->description= "Select all keyframes on the specified frame(s)";
+	ot->name = "Select All";
+	ot->idname = "GRAPH_OT_select_column";
+	ot->description = "Select all keyframes on the specified frame(s)";
 	
 	/* api callbacks */
-	ot->exec= graphkeys_columnselect_exec;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->exec = graphkeys_columnselect_exec;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
+	ot->flag = OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
 	
 	/* props */
-	ot->prop= RNA_def_enum(ot->srna, "mode", prop_column_select_types, 0, "Mode", "");
+	ot->prop = RNA_def_enum(ot->srna, "mode", prop_column_select_types, 0, "Mode", "");
 }
 
 /* ******************** Select Linked Operator *********************** */
@@ -597,15 +597,15 @@ void GRAPH_OT_select_linked (wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Select Linked";
-	ot->idname= "GRAPH_OT_select_linked";
+	ot->idname = "GRAPH_OT_select_linked";
 	ot->description = "Select keyframes occurring in the same F-Curves as selected ones";
 	
 	/* api callbacks */
-	ot->exec= graphkeys_select_linked_exec;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->exec = graphkeys_select_linked_exec;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
+	ot->flag = OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
 }
 
 /* ******************** Select More/Less Operators *********************** */
@@ -675,15 +675,15 @@ void GRAPH_OT_select_more (wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Select More";
-	ot->idname= "GRAPH_OT_select_more";
+	ot->idname = "GRAPH_OT_select_more";
 	ot->description = "Select keyframes beside already selected ones";
 	
 	/* api callbacks */
-	ot->exec= graphkeys_select_more_exec;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->exec = graphkeys_select_more_exec;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
+	ot->flag = OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
 }
 
 /* ----------------- */
@@ -709,15 +709,15 @@ void GRAPH_OT_select_less (wmOperatorType *ot)
 {
 	/* identifiers */
 	ot->name = "Select Less";
-	ot->idname= "GRAPH_OT_select_less";
+	ot->idname = "GRAPH_OT_select_less";
 	ot->description = "Deselect keyframes on ends of selection islands";
 	
 	/* api callbacks */
-	ot->exec= graphkeys_select_less_exec;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->exec = graphkeys_select_less_exec;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
+	ot->flag = OPTYPE_REGISTER/*|OPTYPE_UNDO*/;
 }
 
 /* ******************** Select Left/Right Operator ************************* */
@@ -849,20 +849,20 @@ static int graphkeys_select_leftright_invoke (bContext *C, wmOperator *op, wmEve
 void GRAPH_OT_select_leftright (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select Left/Right";
-	ot->idname= "GRAPH_OT_select_leftright";
-	ot->description= "Select keyframes to the left or the right of the current frame";
+	ot->name = "Select Left/Right";
+	ot->idname = "GRAPH_OT_select_leftright";
+	ot->description = "Select keyframes to the left or the right of the current frame";
 	
 	/* api callbacks  */
 	ot->invoke=	graphkeys_select_leftright_invoke;
-	ot->exec= graphkeys_select_leftright_exec;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->exec = graphkeys_select_leftright_exec;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* id-props */
-	ot->prop= RNA_def_enum(ot->srna, "mode", prop_graphkeys_leftright_select_types, GRAPHKEYS_LRSEL_TEST, "Mode", "");
+	ot->prop = RNA_def_enum(ot->srna, "mode", prop_graphkeys_leftright_select_types, GRAPHKEYS_LRSEL_TEST, "Mode", "");
 	RNA_def_boolean(ot->srna, "extend", 0, "Extend Select", "");
 }
 
@@ -1006,14 +1006,12 @@ static void get_nearest_fcurve_verts_list (bAnimContext *ac, const int mval[2],
 				/* handles - only do them if they're visible */
 				if (fcurve_handle_sel_check(sipo, bezt1) && (fcu->totvert > 1)) {
 					/* first handle only visible if previous segment had handles */
-					if ( (!prevbezt && (bezt1->ipo==BEZT_IPO_BEZ)) || (prevbezt && (prevbezt->ipo==BEZT_IPO_BEZ)) )
-					{
+					if ((!prevbezt && (bezt1->ipo==BEZT_IPO_BEZ)) || (prevbezt && (prevbezt->ipo==BEZT_IPO_BEZ))) {
 						nearest_fcurve_vert_store(matches, v2d, fcu, bezt1, NULL, NEAREST_HANDLE_LEFT, mval);
 					}
 					
 					/* second handle only visible if this segment is bezier */
-					if (bezt1->ipo == BEZT_IPO_BEZ) 
-					{
+					if (bezt1->ipo == BEZT_IPO_BEZ) {
 						nearest_fcurve_vert_store(matches, v2d, fcu, bezt1, NULL, NEAREST_HANDLE_RIGHT, mval);
 					}
 				}
@@ -1180,7 +1178,7 @@ static void mouse_graph_keys (bAnimContext *ac, const int mval[2], short select_
 		KeyframeEditFunc select_cb;
 		KeyframeEditData ked;
 		
-		/* initialise keyframe editing data */
+		/* initialize keyframe editing data */
 		memset(&ked, 0, sizeof(KeyframeEditData));
 		
 		/* set up BezTriple edit callbacks */
@@ -1262,7 +1260,7 @@ static void graphkeys_mselect_column (bAnimContext *ac, const int mval[2], short
 		deselect_graph_keys(ac, 0, SELECT_SUBTRACT, FALSE);
 	}
 	
-	/* initialise keyframe editing data */
+	/* initialize keyframe editing data */
 	memset(&ked, 0, sizeof(KeyframeEditData));
 	
 	/* set up BezTriple edit callbacks */
@@ -1336,13 +1334,13 @@ static int graphkeys_clickselect_invoke(bContext *C, wmOperator *op, wmEvent *ev
 void GRAPH_OT_clickselect (wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Mouse Select Keys";
-	ot->idname= "GRAPH_OT_clickselect";
-	ot->description= "Select keyframes by clicking on them";
+	ot->name = "Mouse Select Keys";
+	ot->idname = "GRAPH_OT_clickselect";
+	ot->description = "Select keyframes by clicking on them";
 	
 	/* api callbacks */
-	ot->invoke= graphkeys_clickselect_invoke;
-	ot->poll= graphop_visible_keyframes_poll;
+	ot->invoke = graphkeys_clickselect_invoke;
+	ot->poll = graphop_visible_keyframes_poll;
 	
 	/* id-props */
 	RNA_def_boolean(ot->srna, "extend", 0, "Extend Select", ""); // SHIFTKEY
