@@ -79,15 +79,15 @@
 static void image_verify_buffer_float(Image *ima, ImBuf *ibuf, int color_manage)
 {
 	/* detect if we need to redo the curve map.
-	   ibuf->rect is zero for compositor and render results after change 
-	   convert to 32 bits always... drawing float rects isnt supported well (atis)
-	
-	   NOTE: if float buffer changes, we have to manually remove the rect
-	*/
+	 * ibuf->rect is zero for compositor and render results after change 
+	 * convert to 32 bits always... drawing float rects isn't supported well (atis)
+	 *
+	 * NOTE: if float buffer changes, we have to manually remove the rect
+	 */
 
-	if(ibuf->rect_float && (ibuf->rect==NULL || (ibuf->userflags & IB_RECT_INVALID)) ) {
-		if(color_manage) {
-			if(ima && ima->source == IMA_SRC_VIEWER)
+	if (ibuf->rect_float && (ibuf->rect == NULL || (ibuf->userflags & IB_RECT_INVALID)) ) {
+		if (color_manage) {
+			if (ima && ima->source == IMA_SRC_VIEWER)
 				ibuf->profile = IB_PROFILE_LINEAR_RGB;
 		}
 		else
@@ -101,9 +101,9 @@ static void draw_render_info(Scene *scene, Image *ima, ARegion *ar)
 {
 	RenderResult *rr;
 	
-	rr= BKE_image_acquire_renderresult(scene, ima);
+	rr = BKE_image_acquire_renderresult(scene, ima);
 
-	if(rr && rr->text) {
+	if (rr && rr->text) {
 		ED_region_info_draw(ar, rr->text, 1, 0.25);
 	}
 
@@ -115,7 +115,7 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
                         const unsigned char cp[4], const float fp[4], int *zp, float *zpf)
 {
 	char str[256];
-	float dx= 6;
+	float dx = 6;
 	/* text colors */
 	/* XXX colored text not allowed in Blender UI */
 	#if 0
@@ -127,10 +127,10 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 	unsigned char green[3] = {255, 255, 255};
 	unsigned char blue[3] = {255, 255, 255};
 	#endif
-	float hue=0, sat=0, val=0, lum=0, u=0, v=0;
+	float hue = 0, sat = 0, val = 0, lum = 0, u = 0, v = 0;
 	float col[4], finalcol[4];
 
-	glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	glEnable(GL_BLEND);
 
 	/* noisy, high contrast make impossible to read if lower alpha is used. */
@@ -147,14 +147,14 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 	BLF_draw_ascii(blf_mono_font, str, sizeof(str));
 	dx += BLF_width(blf_mono_font, str);
 
-	if(zp) {
+	if (zp) {
 		glColor3ub(255, 255, 255);
-		BLI_snprintf(str, sizeof(str), " Z:%-.4f |", 0.5f+0.5f*(((float)*zp)/(float)0x7fffffff));
+		BLI_snprintf(str, sizeof(str), " Z:%-.4f |", 0.5f + 0.5f * (((float)*zp) / (float)0x7fffffff));
 		BLF_position(blf_mono_font, dx, 6, 0);
 		BLF_draw_ascii(blf_mono_font, str, sizeof(str));
 		dx += BLF_width(blf_mono_font, str);
 	}
-	if(zpf) {
+	if (zpf) {
 		glColor3ub(255, 255, 255);
 		BLI_snprintf(str, sizeof(str), " Z:%-.3f |", *zpf);
 		BLF_position(blf_mono_font, dx, 6, 0);
@@ -162,7 +162,7 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 		dx += BLF_width(blf_mono_font, str);
 	}
 
-	if(channels >= 3) {
+	if (channels >= 3) {
 		glColor3ubv(red);
 		if (fp)
 			BLI_snprintf(str, sizeof(str), "  R:%-.4f", fp[0]);
@@ -196,7 +196,7 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 		BLF_draw_ascii(blf_mono_font, str, sizeof(str));
 		dx += BLF_width(blf_mono_font, str);
 		
-		if(channels == 4) {
+		if (channels == 4) {
 			glColor3ub(255, 255, 255);
 			if (fp)
 				BLI_snprintf(str, sizeof(str), "  A:%-.4f", fp[3]);
@@ -211,19 +211,19 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 	}
 	
 	/* color rectangle */
-	if (channels==1) {
+	if (channels == 1) {
 		if (fp) {
 			col[0] = col[1] = col[2] = fp[0];
 		}
 		else if (cp) {
-			col[0] = col[1] = col[2] = (float)cp[0]/255.0f;
+			col[0] = col[1] = col[2] = (float)cp[0] / 255.0f;
 		}
 		else {
 			col[0] = col[1] = col[2] = 0.0f;
 		}
 		col[3] = 1.0f;
 	}
-	else if (channels==3) {
+	else if (channels == 3) {
 		if (fp) {
 			copy_v3_v3(col, fp);
 		}
@@ -235,7 +235,7 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 		}
 		col[3] = 1.0f;
 	}
-	else if (channels==4) {
+	else if (channels == 4) {
 		if (fp)
 			copy_v4_v4(col, fp);
 		else if (cp) {
@@ -262,20 +262,30 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 	glBegin(GL_QUADS);
 	glVertex2f(dx, 3);
 	glVertex2f(dx, 17);
-	glVertex2f(dx+30, 17);
-	glVertex2f(dx+30, 3);
+	glVertex2f(dx + 30, 17);
+	glVertex2f(dx + 30, 3);
 	glEnd();
+
+	/* draw outline */
+	glColor3ub(128, 128, 128);
+	glBegin(GL_LINE_LOOP);
+	glVertex2f(dx, 3);
+	glVertex2f(dx, 17);
+	glVertex2f(dx + 30, 17);
+	glVertex2f(dx + 30, 3);
+	glEnd();
+
 	dx += 35;
 
 	glColor3ub(255, 255, 255);
-	if(channels == 1) {
+	if (channels == 1) {
 		if (fp) {
 			rgb_to_hsv(fp[0], fp[0], fp[0], &hue, &sat, &val);
 			rgb_to_yuv(fp[0], fp[0], fp[0], &lum, &u, &v);
 		}
 		else if (cp) {
-			rgb_to_hsv((float)cp[0]/255.0f, (float)cp[0]/255.0f, (float)cp[0]/255.0f, &hue, &sat, &val);
-			rgb_to_yuv((float)cp[0]/255.0f, (float)cp[0]/255.0f, (float)cp[0]/255.0f, &lum, &u, &v);
+			rgb_to_hsv((float)cp[0] / 255.0f, (float)cp[0] / 255.0f, (float)cp[0] / 255.0f, &hue, &sat, &val);
+			rgb_to_yuv((float)cp[0] / 255.0f, (float)cp[0] / 255.0f, (float)cp[0] / 255.0f, &lum, &u, &v);
 		}
 		
 		BLI_snprintf(str, sizeof(str), "V:%-.4f", val);
@@ -288,14 +298,14 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 		BLF_draw_ascii(blf_mono_font, str, sizeof(str));
 		dx += BLF_width(blf_mono_font, str);
 	}
-	else if(channels >= 3) {
+	else if (channels >= 3) {
 		if (fp) {
 			rgb_to_hsv(fp[0], fp[1], fp[2], &hue, &sat, &val);
 			rgb_to_yuv(fp[0], fp[1], fp[2], &lum, &u, &v);
 		}
 		else if (cp) {
-			rgb_to_hsv((float)cp[0]/255.0f, (float)cp[1]/255.0f, (float)cp[2]/255.0f, &hue, &sat, &val);
-			rgb_to_yuv((float)cp[0]/255.0f, (float)cp[1]/255.0f, (float)cp[2]/255.0f, &lum, &u, &v);
+			rgb_to_hsv((float)cp[0] / 255.0f, (float)cp[1] / 255.0f, (float)cp[2] / 255.0f, &hue, &sat, &val);
+			rgb_to_yuv((float)cp[0] / 255.0f, (float)cp[1] / 255.0f, (float)cp[2] / 255.0f, &lum, &u, &v);
 		}
 
 		BLI_snprintf(str, sizeof(str), "H:%-.4f", hue);
@@ -326,7 +336,7 @@ void ED_image_draw_info(ARegion *ar, int color_manage, int channels, int x, int
 
 static void draw_image_grid(ARegion *ar, float zoomx, float zoomy)
 {
-	float gridsize, gridstep= 1.0f/32.0f;
+	float gridsize, gridstep = 1.0f / 32.0f;
 	float fac, blendfac;
 	int x1, y1, x2, y2;
 	
@@ -338,80 +348,56 @@ static void draw_image_grid(ARegion *ar, float zoomx, float zoomy)
 	glRectf(x1, y1, x2, y2);
 
 	/* gridsize adapted to zoom level */
-	gridsize= 0.5f*(zoomx+zoomy);
-	if(gridsize<=0.0f) return;
+	gridsize = 0.5f * (zoomx + zoomy);
+	if (gridsize <= 0.0f) return;
 	
-	if(gridsize<1.0f) {
-		while(gridsize<1.0f) {
-			gridsize*= 4.0f;
-			gridstep*= 4.0f;
+	if (gridsize < 1.0f) {
+		while (gridsize < 1.0f) {
+			gridsize *= 4.0f;
+			gridstep *= 4.0f;
 		}
 	}
 	else {
-		while(gridsize>=4.0f) {
-			gridsize/= 4.0f;
-			gridstep/= 4.0f;
+		while (gridsize >= 4.0f) {
+			gridsize /= 4.0f;
+			gridstep /= 4.0f;
 		}
 	}
 	
 	/* the fine resolution level */
-	blendfac= 0.25f*gridsize - floorf(0.25f*gridsize);
+	blendfac = 0.25f * gridsize - floorf(0.25f * gridsize);
 	CLAMP(blendfac, 0.0f, 1.0f);
-	UI_ThemeColorShade(TH_BACK, (int)(20.0f*(1.0f-blendfac)));
+	UI_ThemeColorShade(TH_BACK, (int)(20.0f * (1.0f - blendfac)));
 	
-	fac= 0.0f;
+	fac = 0.0f;
 	glBegin(GL_LINES);
-	while(fac<1.0f) {
-		glVertex2f(x1, y1*(1.0f-fac) + y2*fac);
-		glVertex2f(x2, y1*(1.0f-fac) + y2*fac);
-		glVertex2f(x1*(1.0f-fac) + x2*fac, y1);
-		glVertex2f(x1*(1.0f-fac) + x2*fac, y2);
-		fac+= gridstep;
+	while (fac < 1.0f) {
+		glVertex2f(x1, y1 * (1.0f - fac) + y2 * fac);
+		glVertex2f(x2, y1 * (1.0f - fac) + y2 * fac);
+		glVertex2f(x1 * (1.0f - fac) + x2 * fac, y1);
+		glVertex2f(x1 * (1.0f - fac) + x2 * fac, y2);
+		fac += gridstep;
 	}
 	
 	/* the large resolution level */
 	UI_ThemeColor(TH_BACK);
 	
-	fac= 0.0f;
-	while(fac<1.0f) {
-		glVertex2f(x1, y1*(1.0f-fac) + y2*fac);
-		glVertex2f(x2, y1*(1.0f-fac) + y2*fac);
-		glVertex2f(x1*(1.0f-fac) + x2*fac, y1);
-		glVertex2f(x1*(1.0f-fac) + x2*fac, y2);
-		fac+= 4.0f*gridstep;
+	fac = 0.0f;
+	while (fac < 1.0f) {
+		glVertex2f(x1, y1 * (1.0f - fac) + y2 * fac);
+		glVertex2f(x2, y1 * (1.0f - fac) + y2 * fac);
+		glVertex2f(x1 * (1.0f - fac) + x2 * fac, y1);
+		glVertex2f(x1 * (1.0f - fac) + x2 * fac, y2);
+		fac += 4.0f * gridstep;
 	}
 	glEnd();
 }
 
-static void sima_draw_alpha_backdrop(float x1, float y1, float xsize, float ysize, float zoomx, float zoomy, unsigned char col1[3], unsigned char col2[3])
-{
-	GLubyte checker_stipple[32*32/8] =
-	{
-		255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,
-		255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,
-		255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,
-		255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,
-		0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,
-		0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,
-		0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,
-		0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,
-	};
-	
-	glColor3ubv(col1);
-	glRectf(x1, y1, x1 + zoomx*xsize, y1 + zoomy*ysize);
-	glColor3ubv(col2);
-
-	glEnable(GL_POLYGON_STIPPLE);
-	glPolygonStipple(checker_stipple);
-	glRectf(x1, y1, x1 + zoomx*xsize, y1 + zoomy*ysize);
-	glDisable(GL_POLYGON_STIPPLE);
-}
-
 static void sima_draw_alpha_pixels(float x1, float y1, int rectx, int recty, unsigned int *recti)
 {
 	
 	/* swap bytes, so alpha is most significant one, then just draw it as luminance int */
-	if(ENDIAN_ORDER == B_ENDIAN)
+	if (ENDIAN_ORDER == B_ENDIAN)
 		glPixelStorei(GL_UNPACK_SWAP_BYTES, 1);
 
 	glaDrawPixelsSafe(x1, y1, rectx, recty, rectx, GL_LUMINANCE, GL_UNSIGNED_INT, recti);
@@ -420,11 +406,11 @@ static void sima_draw_alpha_pixels(float x1, float y1, int rectx, int recty, uns
 
 static void sima_draw_alpha_pixelsf(float x1, float y1, int rectx, int recty, float *rectf)
 {
-	float *trectf= MEM_mallocN(rectx*recty*4, "temp");
+	float *trectf = MEM_mallocN(rectx * recty * 4, "temp");
 	int a, b;
 	
-	for(a= rectx*recty -1, b= 4*a+3; a>=0; a--, b-=4)
-		trectf[a]= rectf[b];
+	for (a = rectx * recty - 1, b = 4 * a + 3; a >= 0; a--, b -= 4)
+		trectf[a] = rectf[b];
 	
 	glaDrawPixelsSafe(x1, y1, rectx, recty, rectx, GL_LUMINANCE, GL_FLOAT, trectf);
 	MEM_freeN(trectf);
@@ -463,26 +449,26 @@ static void sima_draw_zbuffloat_pixels(Scene *scene, float x1, float y1, int rec
 	float bias, scale, *rectf, clipend;
 	int a;
 	
-	if(scene->camera && scene->camera->type==OB_CAMERA) {
-		bias= ((Camera *)scene->camera->data)->clipsta;
-		clipend= ((Camera *)scene->camera->data)->clipend;
-		scale= 1.0f/(clipend-bias);
+	if (scene->camera && scene->camera->type == OB_CAMERA) {
+		bias = ((Camera *)scene->camera->data)->clipsta;
+		clipend = ((Camera *)scene->camera->data)->clipend;
+		scale = 1.0f / (clipend - bias);
 	}
 	else {
-		bias= 0.1f;
-		scale= 0.01f;
-		clipend= 100.0f;
+		bias = 0.1f;
+		scale = 0.01f;
+		clipend = 100.0f;
 	}
 	
-	rectf= MEM_mallocN(rectx*recty*4, "temp");
-	for(a= rectx*recty -1; a>=0; a--) {
-		if(rect_float[a]>clipend)
-			rectf[a]= 0.0f;
-		else if(rect_float[a]<bias)
-			rectf[a]= 1.0f;
+	rectf = MEM_mallocN(rectx * recty * 4, "temp");
+	for (a = rectx * recty - 1; a >= 0; a--) {
+		if (rect_float[a] > clipend)
+			rectf[a] = 0.0f;
+		else if (rect_float[a] < bias)
+			rectf[a] = 1.0f;
 		else {
-			rectf[a]= 1.0f - (rect_float[a]-bias)*scale;
-			rectf[a]*= rectf[a];
+			rectf[a] = 1.0f - (rect_float[a] - bias) * scale;
+			rectf[a] *= rectf[a];
 		}
 	}
 	glaDrawPixelsSafe(x1, y1, rectx, recty, rectx, GL_LUMINANCE, GL_FLOAT, rectf);
@@ -502,24 +488,23 @@ static void draw_image_buffer(SpaceImage *sima, ARegion *ar, Scene *scene, Image
 	UI_view2d_to_region_no_clip(&ar->v2d, fx, fy, &x, &y);
 
 	/* this part is generic image display */
-	if(sima->flag & SI_SHOW_ALPHA) {
-		if(ibuf->rect)
+	if (sima->flag & SI_SHOW_ALPHA) {
+		if (ibuf->rect)
 			sima_draw_alpha_pixels(x, y, ibuf->x, ibuf->y, ibuf->rect);
-		else if(ibuf->rect_float && ibuf->channels==4)
+		else if (ibuf->rect_float && ibuf->channels == 4)
 			sima_draw_alpha_pixelsf(x, y, ibuf->x, ibuf->y, ibuf->rect_float);
 	}
-	else if(sima->flag & SI_SHOW_ZBUF && (ibuf->zbuf || ibuf->zbuf_float || (ibuf->channels==1))) {
-		if(ibuf->zbuf)
+	else if (sima->flag & SI_SHOW_ZBUF && (ibuf->zbuf || ibuf->zbuf_float || (ibuf->channels == 1))) {
+		if (ibuf->zbuf)
 			sima_draw_zbuf_pixels(x, y, ibuf->x, ibuf->y, ibuf->zbuf);
-		else if(ibuf->zbuf_float)
+		else if (ibuf->zbuf_float)
 			sima_draw_zbuffloat_pixels(scene, x, y, ibuf->x, ibuf->y, ibuf->zbuf_float);
-		else if(ibuf->channels==1)
+		else if (ibuf->channels == 1)
 			sima_draw_zbuffloat_pixels(scene, x, y, ibuf->x, ibuf->y, ibuf->rect_float);
 	}
 	else {
-		if(sima->flag & SI_USE_ALPHA) {
-			unsigned char col1[3]= {100, 100, 100}, col2[3]= {160, 160, 160};
-			sima_draw_alpha_backdrop(x, y, ibuf->x, ibuf->y, zoomx, zoomy, col1, col2);
+		if (sima->flag & SI_USE_ALPHA) {
+			fdrawcheckerboard(x, y, x + ibuf->x * zoomx, y + ibuf->y * zoomy);
 
 			glEnable(GL_BLEND);
 			glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -529,12 +514,14 @@ static void draw_image_buffer(SpaceImage *sima, ARegion *ar, Scene *scene, Image
 		 * convert them, and optionally apply curves */
 		image_verify_buffer_float(ima, ibuf, color_manage);
 
-		if(ibuf->rect)
+		if (ibuf->rect)
 			glaDrawPixelsSafe(x, y, ibuf->x, ibuf->y, ibuf->x, GL_RGBA, GL_UNSIGNED_BYTE, ibuf->rect);
-		/*else
-			glaDrawPixelsSafe(x, y, ibuf->x, ibuf->y, ibuf->x, GL_RGBA, GL_FLOAT, ibuf->rect_float);*/
+#if 0
+		else
+			glaDrawPixelsSafe(x, y, ibuf->x, ibuf->y, ibuf->x, GL_RGBA, GL_FLOAT, ibuf->rect_float);
+#endif
 		
-		if(sima->flag & SI_USE_ALPHA)
+		if (sima->flag & SI_USE_ALPHA)
 			glDisable(GL_BLEND);
 	}
 
@@ -549,17 +536,17 @@ static unsigned int *get_part_from_ibuf(ImBuf *ibuf, short startx, short starty,
 
 	/* the right offset in rectot */
 
-	rt= ibuf->rect+ (starty*ibuf->x+ startx);
+	rt = ibuf->rect + (starty * ibuf->x + startx);
 
-	len= (endx-startx);
-	heigth= (endy-starty);
+	len = (endx - startx);
+	heigth = (endy - starty);
 
-	rp=rectmain= MEM_mallocN(heigth*len*sizeof(int), "rect");
+	rp = rectmain = MEM_mallocN(heigth * len * sizeof(int), "rect");
 	
-	for(y=0; y<heigth; y++) {
-		memcpy(rp, rt, len*4);
-		rt+= ibuf->x;
-		rp+= len;
+	for (y = 0; y < heigth; y++) {
+		memcpy(rp, rt, len * 4);
+		rt += ibuf->x;
+		rp += len;
 	}
 	return rectmain;
 }
@@ -571,28 +558,28 @@ static void draw_image_buffer_tiled(SpaceImage *sima, ARegion *ar, Scene *scene,
 	int color_manage = scene->r.color_mgt_flag & R_COLOR_MANAGEMENT;
 
 	/* verify valid values, just leave this a while */
-	if(ima->xrep<1) return;
-	if(ima->yrep<1) return;
+	if (ima->xrep < 1) return;
+	if (ima->yrep < 1) return;
 	
 	glPixelZoom(zoomx, zoomy);
 
-	if(sima->curtile >= ima->xrep*ima->yrep) 
-		sima->curtile = ima->xrep*ima->yrep - 1; 
+	if (sima->curtile >= ima->xrep * ima->yrep)
+		sima->curtile = ima->xrep * ima->yrep - 1;
 	
 	/* create char buffer from float if needed */
 	image_verify_buffer_float(ima, ibuf, color_manage);
 
 	/* retrieve part of image buffer */
-	dx= ibuf->x/ima->xrep;
-	dy= ibuf->y/ima->yrep;
-	sx= (sima->curtile % ima->xrep)*dx;
-	sy= (sima->curtile / ima->xrep)*dy;
-	rect= get_part_from_ibuf(ibuf, sx, sy, sx+dx, sy+dy);
+	dx = ibuf->x / ima->xrep;
+	dy = ibuf->y / ima->yrep;
+	sx = (sima->curtile % ima->xrep) * dx;
+	sy = (sima->curtile / ima->xrep) * dy;
+	rect = get_part_from_ibuf(ibuf, sx, sy, sx + dx, sy + dy);
 	
 	/* draw repeated */
-	for(sy=0; sy+dy<=ibuf->y; sy+= dy) {
-		for(sx=0; sx+dx<=ibuf->x; sx+= dx) {
-			UI_view2d_to_region_no_clip(&ar->v2d, fx + (float)sx/(float)ibuf->x, fy + (float)sy/(float)ibuf->y, &x, &y);
+	for (sy = 0; sy + dy <= ibuf->y; sy += dy) {
+		for (sx = 0; sx + dx <= ibuf->x; sx += dx) {
+			UI_view2d_to_region_no_clip(&ar->v2d, fx + (float)sx / (float)ibuf->x, fy + (float)sy / (float)ibuf->y, &x, &y);
 
 			glaDrawPixelsSafe(x, y, dx, dy, dx, GL_RGBA, GL_UNSIGNED_BYTE, rect);
 		}
@@ -605,25 +592,25 @@ static void draw_image_buffer_tiled(SpaceImage *sima, ARegion *ar, Scene *scene,
 
 static void draw_image_buffer_repeated(SpaceImage *sima, ARegion *ar, Scene *scene, Image *ima, ImBuf *ibuf, float zoomx, float zoomy)
 {
-	const double time_current= PIL_check_seconds_timer();
+	const double time_current = PIL_check_seconds_timer();
 
-	const int xmax= ceil(ar->v2d.cur.xmax);
-	const int ymax= ceil(ar->v2d.cur.ymax);
-	const int xmin= floor(ar->v2d.cur.xmin);
-	const int ymin= floor(ar->v2d.cur.ymin);
+	const int xmax = ceil(ar->v2d.cur.xmax);
+	const int ymax = ceil(ar->v2d.cur.ymax);
+	const int xmin = floor(ar->v2d.cur.xmin);
+	const int ymin = floor(ar->v2d.cur.ymin);
 
 	int x;
 
-	for(x=xmin; x<xmax; x++) {
+	for (x = xmin; x < xmax; x++) {
 		int y;
-		for(y=ymin; y<ymax; y++) { 
-			if(ima && (ima->tpageflag & IMA_TILES))
+		for (y = ymin; y < ymax; y++) {
+			if (ima && (ima->tpageflag & IMA_TILES))
 				draw_image_buffer_tiled(sima, ar, scene, ima, ibuf, x, y, zoomx, zoomy);
 			else
 				draw_image_buffer(sima, ar, scene, ima, ibuf, x, y, zoomx, zoomy);
 
 			/* only draw until running out of time */
-			if((PIL_check_seconds_timer() - time_current) > 0.25)
+			if ((PIL_check_seconds_timer() - time_current) > 0.25)
 				return;
 		}
 	}
@@ -637,13 +624,13 @@ void draw_image_grease_pencil(bContext *C, short onlyv2d)
 	/* draw in View2D space? */
 	if (onlyv2d) {
 		/* assume that UI_view2d_ortho(C) has been called... */
-		SpaceImage *sima= (SpaceImage *)CTX_wm_space_data(C);
+		SpaceImage *sima = (SpaceImage *)CTX_wm_space_data(C);
 		void *lock;
-		ImBuf *ibuf= ED_space_image_acquire_buffer(sima, &lock);
+		ImBuf *ibuf = ED_space_image_acquire_buffer(sima, &lock);
 		
 		/* draw grease-pencil ('image' strokes) */
 		//if (sima->flag & SI_DISPGP)
-			draw_gpencil_2dimage(C, ibuf);
+		draw_gpencil_2dimage(C, ibuf);
 
 		ED_space_image_release_buffer(sima, lock);
 	}
@@ -653,7 +640,7 @@ void draw_image_grease_pencil(bContext *C, short onlyv2d)
 		
 		/* draw grease-pencil ('screen' strokes) */
 		//if (sima->flag & SI_DISPGP)
-			draw_gpencil_view2d(C, 0);
+		draw_gpencil_view2d(C, 0);
 	}
 }
 
@@ -661,24 +648,24 @@ void draw_image_grease_pencil(bContext *C, short onlyv2d)
 #if 0
 static void draw_image_view_tool(Scene *scene)
 {
-	ToolSettings *settings= scene->toolsettings;
-	Brush *brush= settings->imapaint.brush;
+	ToolSettings *settings = scene->toolsettings;
+	Brush *brush = settings->imapaint.brush;
 	int mval[2];
 	float radius;
-	int draw= 0;
+	int draw = 0;
 
-	if(brush) {
-		if(settings->imapaint.flag & IMAGEPAINT_DRAWING) {
-			if(settings->imapaint.flag & IMAGEPAINT_DRAW_TOOL_DRAWING)
-				draw= 1;
+	if (brush) {
+		if (settings->imapaint.flag & IMAGEPAINT_DRAWING) {
+			if (settings->imapaint.flag & IMAGEPAINT_DRAW_TOOL_DRAWING)
+				draw = 1;
 		}
-		else if(settings->imapaint.flag & IMAGEPAINT_DRAW_TOOL)
-			draw= 1;
+		else if (settings->imapaint.flag & IMAGEPAINT_DRAW_TOOL)
+			draw = 1;
 		
-		if(draw) {
+		if (draw) {
 			getmouseco_areawin(mval);
 
-			radius= brush_size(brush)*G.sima->zoom;
+			radius = brush_size(brush) * G.sima->zoom;
 			fdrawXORcirc(mval[0], mval[1], radius);
 
 			if (brush->innerradius != 1.0) {
@@ -697,27 +684,27 @@ static unsigned char *get_alpha_clone_image(Scene *scene, int *width, int *heigh
 	unsigned int size, alpha;
 	unsigned char *rect, *cp;
 
-	if(!brush || !brush->clone.image)
+	if (!brush || !brush->clone.image)
 		return NULL;
 	
-	ibuf= BKE_image_get_ibuf(brush->clone.image, NULL);
+	ibuf = BKE_image_get_ibuf(brush->clone.image, NULL);
 
-	if(!ibuf || !ibuf->rect)
+	if (!ibuf || !ibuf->rect)
 		return NULL;
 
-	rect= MEM_dupallocN(ibuf->rect);
-	if(!rect)
+	rect = MEM_dupallocN(ibuf->rect);
+	if (!rect)
 		return NULL;
 
-	*width= ibuf->x;
-	*height= ibuf->y;
+	*width = ibuf->x;
+	*height = ibuf->y;
 
-	size= (*width)*(*height);
-	alpha= (unsigned char)255*brush->clone.alpha;
-	cp= rect;
+	size = (*width) * (*height);
+	alpha = (unsigned char)255 * brush->clone.alpha;
+	cp = rect;
 
-	while(size-- > 0) {
-		cp[3]= alpha;
+	while (size-- > 0) {
+		cp[3] = alpha;
 		cp += 4;
 	}
 
@@ -730,14 +717,14 @@ static void draw_image_paint_helpers(ARegion *ar, Scene *scene, float zoomx, flo
 	int x, y, w, h;
 	unsigned char *clonerect;
 
-	brush= paint_brush(&scene->toolsettings->imapaint.paint);
+	brush = paint_brush(&scene->toolsettings->imapaint.paint);
 
-	if(brush && (brush->imagepaint_tool == PAINT_TOOL_CLONE)) {
+	if (brush && (brush->imagepaint_tool == PAINT_TOOL_CLONE)) {
 		/* this is not very efficient, but glDrawPixels doesn't allow
-		   drawing with alpha */
-		clonerect= get_alpha_clone_image(scene, &w, &h);
+		 * drawing with alpha */
+		clonerect = get_alpha_clone_image(scene, &w, &h);
 
-		if(clonerect) {
+		if (clonerect) {
 			UI_view2d_to_region_no_clip(&ar->v2d, brush->clone.offset[0], brush->clone.offset[1], &x, &y);
 
 			glPixelZoom(zoomx, zoomy);
@@ -768,54 +755,54 @@ void draw_image_main(SpaceImage *sima, ARegion *ar, Scene *scene)
 #if 0
 	what_image(sima);
 	
-	if(sima->image) {
+	if (sima->image) {
 		ED_image_aspect(sima->image, &xuser_asp, &yuser_asp);
 		
 		/* UGLY hack? until now iusers worked fine... but for flipbook viewer we need this */
-		if(sima->image->type==IMA_TYPE_COMPOSITE) {
-			ImageUser *iuser= ntree_get_active_iuser(scene->nodetree);
-			if(iuser) {
+		if (sima->image->type == IMA_TYPE_COMPOSITE) {
+			ImageUser *iuser = ntree_get_active_iuser(scene->nodetree);
+			if (iuser) {
 				BKE_image_user_calc_imanr(iuser, scene->r.cfra, 0);
-				sima->iuser= *iuser;
+				sima->iuser = *iuser;
 			}
 		}
 		/* and we check for spare */
-		ibuf= ED_space_image_buffer(sima);
+		ibuf = ED_space_image_buffer(sima);
 	}
 #endif
 
 	/* retrieve the image and information about it */
-	ima= ED_space_image(sima);
+	ima = ED_space_image(sima);
 	ED_space_image_zoom(sima, ar, &zoomx, &zoomy);
-	ibuf= ED_space_image_acquire_buffer(sima, &lock);
+	ibuf = ED_space_image_acquire_buffer(sima, &lock);
 
-	show_viewer= (ima && ima->source == IMA_SRC_VIEWER);
-	show_render= (show_viewer && ima->type == IMA_TYPE_R_RESULT);
+	show_viewer = (ima && ima->source == IMA_SRC_VIEWER);
+	show_render = (show_viewer && ima->type == IMA_TYPE_R_RESULT);
 
 	/* draw the image or grid */
-	if(ibuf==NULL)
+	if (ibuf == NULL)
 		draw_image_grid(ar, zoomx, zoomy);
-	else if(sima->flag & SI_DRAW_TILE)
+	else if (sima->flag & SI_DRAW_TILE)
 		draw_image_buffer_repeated(sima, ar, scene, ima, ibuf, zoomx, zoomy);
-	else if(ima && (ima->tpageflag & IMA_TILES))
+	else if (ima && (ima->tpageflag & IMA_TILES))
 		draw_image_buffer_tiled(sima, ar, scene, ima, ibuf, 0.0f, 0.0, zoomx, zoomy);
 	else
 		draw_image_buffer(sima, ar, scene, ima, ibuf, 0.0f, 0.0f, zoomx, zoomy);
 
 	/* paint helpers */
-	if(sima->flag & SI_DRAWTOOL)
+	if (sima->flag & SI_DRAWTOOL)
 		draw_image_paint_helpers(ar, scene, zoomx, zoomy);
 
 
 	/* XXX integrate this code */
 #if 0
-	if(ibuf) {
-		float xoffs=0.0f, yoffs= 0.0f;
+	if (ibuf) {
+		float xoffs = 0.0f, yoffs = 0.0f;
 		
-		if(image_preview_active(sa, &xim, &yim)) {
-			xoffs= scene->r.disprect.xmin;
-			yoffs= scene->r.disprect.ymin;
-			glColor3ub(0,0,0);
+		if (image_preview_active(sa, &xim, &yim)) {
+			xoffs = scene->r.disprect.xmin;
+			yoffs = scene->r.disprect.ymin;
+			glColor3ub(0, 0, 0);
 			calc_image_view(sima, 'f');	
 			myortho2(G.v2d->cur.xmin, G.v2d->cur.xmax, G.v2d->cur.ymin, G.v2d->cur.ymax);
 			glRectf(0.0f, 0.0f, 1.0f, 1.0f);
@@ -827,7 +814,7 @@ void draw_image_main(SpaceImage *sima, ARegion *ar, Scene *scene)
 	ED_space_image_release_buffer(sima, lock);
 
 	/* render info */
-	if(ima && show_render)
+	if (ima && show_render)
 		draw_render_info(scene, ima, ar);
 }
 
