@@ -62,7 +62,7 @@ static bNode *node_under_mouse(bNodeTree *ntree, int mx, int my)
 {
 	bNode *node;
 	
-	for(node=ntree->nodes.last; node; node=node->prev) {
+	for (node=ntree->nodes.last; node; node=node->prev) {
 		/* node body (header and scale are in other operators) */
 		if (BLI_in_rctf(&node->totr, mx, my))
 			return node;
@@ -173,13 +173,150 @@ static void node_sort(bNodeTree *ntree)
 	}
 }
 
+void node_select(bNode *node)
+{
+	node->flag |= SELECT;
+}
+
+void node_deselect(bNode *node)
+{
+	bNodeSocket *sock;
+	
+	node->flag &= ~SELECT;
+	
+	/* deselect sockets too */
+	for (sock=node->inputs.first; sock; sock=sock->next)
+		sock->flag &= ~SELECT;
+	for (sock=node->outputs.first; sock; sock=sock->next)
+		sock->flag &= ~SELECT;
+}
+
+static void node_toggle(bNode *node)
+{
+	if (node->flag & SELECT)
+		node_deselect(node);
+	else
+		node_select(node);
+}
+
+void node_socket_select(bNode *node, bNodeSocket *sock)
+{
+	sock->flag |= SELECT;
+	
+	/* select node too */
+	if (node)
+		node->flag |= SELECT;
+}
+
+void node_socket_deselect(bNode *node, bNodeSocket *sock, int deselect_node)
+{
+	sock->flag &= ~SELECT;
+	
+	if (node && deselect_node) {
+		int sel=0;
+		
+		/* if no selected sockets remain, also deselect the node */
+		for (sock=node->inputs.first; sock; sock=sock->next) {
+			if (sock->flag & SELECT) {
+				sel = 1;
+				break;
+			}
+		}
+		for (sock=node->outputs.first; sock; sock=sock->next) {
+			if (sock->flag & SELECT) {
+				sel = 1;
+				break;
+			}
+		}
+		
+		if (!sel)
+			node->flag &= ~SELECT;
+	}
+}
+
+static void node_socket_toggle(bNode *node, bNodeSocket *sock, int deselect_node)
+{
+	if (sock->flag & SELECT)
+		node_socket_deselect(node, sock, deselect_node);
+	else
+		node_socket_select(node, sock);
+}
+
 /* no undo here! */
 void node_deselect_all(SpaceNode *snode)
 {
 	bNode *node;
 	
-	for(node= snode->edittree->nodes.first; node; node= node->next)
-		node->flag &= ~SELECT;
+	for (node= snode->edittree->nodes.first; node; node= node->next)
+		node_deselect(node);
+}
+
+void node_deselect_all_input_sockets(SpaceNode *snode, int deselect_nodes)
+{
+	bNode *node;
+	bNodeSocket *sock;
+	
+	/* XXX not calling node_socket_deselect here each time, because this does iteration
+	 * over all node sockets internally to check if the node stays selected.
+	 * We can do that more efficiently here.
+	 */
+	
+	for (node= snode->edittree->nodes.first; node; node= node->next) {
+		int sel=0;
+		
+		for (sock= node->inputs.first; sock; sock=sock->next)
+			sock->flag &= ~SELECT;
+		
+		/* if no selected sockets remain, also deselect the node */
+		if (deselect_nodes) {
+			for (sock= node->outputs.first; sock; sock=sock->next) {
+				if (sock->flag & SELECT) {
+					sel = 1;
+					break;
+				}
+			}
+			
+			if (!sel)
+				node->flag &= ~SELECT;
+		}
+	}
+	
+	for (sock= snode->edittree->outputs.first; sock; sock=sock->next)
+		sock->flag &= ~SELECT;
+}
+
+void node_deselect_all_output_sockets(SpaceNode *snode, int deselect_nodes)
+{
+	bNode *node;
+	bNodeSocket *sock;
+	
+	/* XXX not calling node_socket_deselect here each time, because this does iteration
+	 * over all node sockets internally to check if the node stays selected.
+	 * We can do that more efficiently here.
+	 */
+	
+	for (node= snode->edittree->nodes.first; node; node= node->next) {
+		int sel=0;
+		
+		for (sock= node->outputs.first; sock; sock=sock->next)
+			sock->flag &= ~SELECT;
+		
+		/* if no selected sockets remain, also deselect the node */
+		if (deselect_nodes) {
+			for (sock= node->inputs.first; sock; sock=sock->next) {
+				if (sock->flag & SELECT) {
+					sel = 1;
+					break;
+				}
+			}
+			
+			if (!sel)
+				node->flag &= ~SELECT;
+		}
+	}
+	
+	for (sock= snode->edittree->inputs.first; sock; sock=sock->next)
+		sock->flag &= ~SELECT;
 }
 
 /* return 1 if we need redraw otherwise zero. */
@@ -203,12 +340,12 @@ int node_select_same_type(SpaceNode *snode)
 		if (p->type != nac->type && p->flag & SELECT) {
 			/* if it's selected but different type, unselect */
 			redraw= 1;
-			p->flag &= ~SELECT;
+			node_deselect(p);
 		}
 		else if (p->type == nac->type && (!(p->flag & SELECT))) {
 			/* if it's the same type and is not selected, select! */
 			redraw= 1;
-			p->flag |= SELECT;
+			node_select(p);
 		}
 	}
 	return(redraw);
@@ -219,7 +356,7 @@ int node_select_same_type(SpaceNode *snode)
  */
 int node_select_same_type_np(SpaceNode *snode, int dir)
 {
-	bNode *nac, *p;
+	bNode *nac, *p, *tnode;
 
 	/* search the active one. */
 	for (nac= snode->edittree->nodes.first; nac; nac= nac->next) {
@@ -248,8 +385,10 @@ int node_select_same_type_np(SpaceNode *snode, int dir)
 	}
 
 	if (p) {
-		node_deselect_all(snode);
-		p->flag |= SELECT;
+		for (tnode=snode->edittree->nodes.first; tnode; tnode=tnode->next)
+			if (tnode!=p)
+				node_deselect(tnode);
+		node_select(p);
 		return(1);
 	}
 	return(0);
@@ -259,9 +398,12 @@ void node_select_single(bContext *C, bNode *node)
 {
 	Main *bmain= CTX_data_main(C);
 	SpaceNode *snode= CTX_wm_space_node(C);
+	bNode *tnode;
 	
-	node_deselect_all(snode);
-	node->flag |= SELECT;
+	for (tnode=snode->edittree->nodes.first; tnode; tnode=tnode->next)
+		if (tnode!=node)
+			node_deselect(tnode);
+	node_select(node);
 	
 	ED_node_set_active(bmain, snode->edittree, node);
 	
@@ -272,34 +414,74 @@ void node_select_single(bContext *C, bNode *node)
 
 /* ****** Click Select ****** */
  
-static bNode *node_mouse_select(Main *bmain, SpaceNode *snode, ARegion *ar, const int mval[2], short extend)
+static int node_mouse_select(Main *bmain, SpaceNode *snode, ARegion *ar, const int mval[2], short extend)
 {
-	bNode *node;
+	bNode *node, *tnode;
+	bNodeSocket *sock, *tsock;
 	float mx, my;
+	int selected = 0;
 	
 	/* get mouse coordinates in view2d space */
-	mx= (float)mval[0];
-	my= (float)mval[1];
-	
 	UI_view2d_region_to_view(&ar->v2d, mval[0], mval[1], &mx, &my);
+	/* node_find_indicated_socket uses snode->mx/my */
+	snode->mx = mx;
+	snode->my = my;
 	
-	/* find the closest visible node */
-	node = node_under_mouse(snode->edittree, mx, my);
-	
-	if (node) {
-		if (extend == 0) {
-			node_deselect_all(snode);
-			node->flag |= SELECT;
+	if (extend) {
+		/* first do socket selection, these generally overlap with nodes.
+		 * socket selection only in extend mode.
+		 */
+		if (node_find_indicated_socket(snode, &node, &sock, SOCK_IN)) {
+			node_socket_toggle(node, sock, 1);
+			selected = 1;
+		}
+		else if (node_find_indicated_socket(snode, &node, &sock, SOCK_OUT)) {
+			if (sock->flag & SELECT) {
+				node_socket_deselect(node, sock, 1);
+			}
+			else {
+				/* only allow one selected output per node, for sensible linking.
+				 * allows selecting outputs from different nodes though.
+				 */
+				if (node) {
+					for (tsock=node->outputs.first; tsock; tsock=tsock->next)
+						node_socket_deselect(node, tsock, 1);
+				}
+				node_socket_select(node, sock);
+			}
+			selected = 1;
+		}
+		else {
+			/* find the closest visible node */
+			node = node_under_mouse(snode->edittree, mx, my);
+			
+			if (node) {
+				node_toggle(node);
+				
+				ED_node_set_active(bmain, snode->edittree, node);
+				selected = 1;
+			}
 		}
-		else
-			node->flag ^= SELECT;
-		
-		ED_node_set_active(bmain, snode->edittree, node);
-		
-		node_sort(snode->edittree);
 	}
-
-	return node;
+	else {	/* extend==0 */
+		
+		/* find the closest visible node */
+		node = node_under_mouse(snode->edittree, mx, my);
+		
+		if (node) {
+			for (tnode=snode->edittree->nodes.first; tnode; tnode=tnode->next)
+				node_deselect(tnode);
+			node_select(node);
+			ED_node_set_active(bmain, snode->edittree, node);
+			selected = 1;
+		}
+	}
+	
+	/* update node order */
+	if (selected)
+		node_sort(snode->edittree);
+	
+	return selected;
 }
 
 static int node_select_exec(bContext *C, wmOperator *op)
@@ -309,7 +491,6 @@ static int node_select_exec(bContext *C, wmOperator *op)
 	ARegion *ar= CTX_wm_region(C);
 	int mval[2];
 	short extend;
-	/* bNode *node= NULL; */ /* UNUSED */
 	
 	/* get settings from RNA properties for operator */
 	mval[0] = RNA_int_get(op->ptr, "mouse_x");
@@ -318,13 +499,17 @@ static int node_select_exec(bContext *C, wmOperator *op)
 	extend = RNA_boolean_get(op->ptr, "extend");
 	
 	/* perform the select */
-	/* node= */ /* UNUSED*/ node_mouse_select(bmain, snode, ar, mval, extend);
-	
-	/* send notifiers */
-	WM_event_add_notifier(C, NC_NODE|NA_SELECTED, NULL);
-	
-	/* allow tweak event to work too */
-	return OPERATOR_FINISHED|OPERATOR_PASS_THROUGH;
+	if (node_mouse_select(bmain, snode, ar, mval, extend)) {
+		/* send notifiers */
+		WM_event_add_notifier(C, NC_NODE|NA_SELECTED, NULL);
+		
+		/* allow tweak event to work too */
+		return OPERATOR_FINISHED|OPERATOR_PASS_THROUGH;
+	}
+	else {
+		/* allow tweak event to work too */
+		return OPERATOR_CANCELLED|OPERATOR_PASS_THROUGH;
+	}
 }
 
 static int node_select_invoke(bContext *C, wmOperator *op, wmEvent *event)
@@ -339,16 +524,16 @@ static int node_select_invoke(bContext *C, wmOperator *op, wmEvent *event)
 void NODE_OT_select(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Select";
-	ot->idname= "NODE_OT_select";
-	ot->description= "Select the node under the cursor";
+	ot->name = "Select";
+	ot->idname = "NODE_OT_select";
+	ot->description = "Select the node under the cursor";
 	
 	/* api callbacks */
-	ot->invoke= node_select_invoke;
-	ot->poll= ED_operator_node_active;
+	ot->invoke = node_select_invoke;
+	ot->poll = ED_operator_node_active;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* properties */
 	RNA_def_int(ot->srna, "mouse_x", 0, INT_MIN, INT_MAX, "Mouse X", "", INT_MIN, INT_MAX);
@@ -368,23 +553,23 @@ static int node_borderselect_exec(bContext *C, wmOperator *op)
 	int gesture_mode= RNA_int_get(op->ptr, "gesture_mode");
 	int extend= RNA_boolean_get(op->ptr, "extend");
 	
-	rect.xmin= RNA_int_get(op->ptr, "xmin");
-	rect.ymin= RNA_int_get(op->ptr, "ymin");
+	rect.xmin = RNA_int_get(op->ptr, "xmin");
+	rect.ymin = RNA_int_get(op->ptr, "ymin");
 	UI_view2d_region_to_view(&ar->v2d, rect.xmin, rect.ymin, &rectf.xmin, &rectf.ymin);
 	
-	rect.xmax= RNA_int_get(op->ptr, "xmax");
-	rect.ymax= RNA_int_get(op->ptr, "ymax");
+	rect.xmax = RNA_int_get(op->ptr, "xmax");
+	rect.ymax = RNA_int_get(op->ptr, "ymax");
 	UI_view2d_region_to_view(&ar->v2d, rect.xmax, rect.ymax, &rectf.xmax, &rectf.ymax);
 	
-	for(node= snode->edittree->nodes.first; node; node= node->next) {
-		if(BLI_isect_rctf(&rectf, &node->totr, NULL)) {
-			if(gesture_mode==GESTURE_MODAL_SELECT)
-				node->flag |= SELECT;
+	for (node= snode->edittree->nodes.first; node; node= node->next) {
+		if (BLI_isect_rctf(&rectf, &node->totr, NULL)) {
+			if (gesture_mode==GESTURE_MODAL_SELECT)
+				node_select(node);
 			else
-				node->flag &= ~SELECT;
+				node_deselect(node);
 		}
-		else if(!extend) {
-			node->flag &= ~SELECT;
+		else if (!extend) {
+			node_deselect(node);
 		}
 	}
 	
@@ -418,20 +603,20 @@ static int node_border_select_invoke(bContext *C, wmOperator *op, wmEvent *event
 void NODE_OT_select_border(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Border Select";
-	ot->idname= "NODE_OT_select_border";
-	ot->description= "Use box selection to select nodes";
+	ot->name = "Border Select";
+	ot->idname = "NODE_OT_select_border";
+	ot->description = "Use box selection to select nodes";
 	
 	/* api callbacks */
-	ot->invoke= node_border_select_invoke;
-	ot->exec= node_borderselect_exec;
-	ot->modal= WM_border_select_modal;
-	ot->cancel= WM_border_select_cancel;
+	ot->invoke = node_border_select_invoke;
+	ot->exec = node_borderselect_exec;
+	ot->modal = WM_border_select_modal;
+	ot->cancel = WM_border_select_cancel;
 	
-	ot->poll= ED_operator_node_active;
+	ot->poll = ED_operator_node_active;
 	
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 	
 	/* rna */
 	WM_operator_properties_gesture_border(ot, TRUE);
@@ -447,17 +632,17 @@ static int node_select_all_exec(bContext *C, wmOperator *UNUSED(op))
 	bNode *node;
 	int count= 0;
 
-	for(node=first; node; node=node->next)
-		if(node->flag & NODE_SELECT)
+	for (node=first; node; node=node->next)
+		if (node->flag & NODE_SELECT)
 			count++;
 
-	if(count) {
-		for(node=first; node; node=node->next)
-			node->flag &= ~NODE_SELECT;
+	if (count) {
+		for (node=first; node; node=node->next)
+			node_deselect(node);
 	}
 	else {
-		for(node=first; node; node=node->next)
-			node->flag |= NODE_SELECT;
+		for (node=first; node; node=node->next)
+			node_select(node);
 	}
 	
 	node_sort(snode->edittree);
@@ -469,7 +654,7 @@ static int node_select_all_exec(bContext *C, wmOperator *UNUSED(op))
 void NODE_OT_select_all(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name = "Select or Deselect All";
+	ot->name = "(De)select All";
 	ot->description = "(De)select all nodes";
 	ot->idname = "NODE_OT_select_all";
 	
@@ -499,7 +684,7 @@ static int node_select_linked_to_exec(bContext *C, wmOperator *UNUSED(op))
 	
 	for (node=snode->edittree->nodes.first; node; node=node->next) {
 		if (node->flag & NODE_TEST)
-			node->flag |= NODE_SELECT;
+			node_select(node);
 	}
 	
 	node_sort(snode->edittree);
@@ -531,17 +716,17 @@ static int node_select_linked_from_exec(bContext *C, wmOperator *UNUSED(op))
 	bNodeLink *link;
 	bNode *node;
 	
-	for(node=snode->edittree->nodes.first; node; node=node->next)
+	for (node=snode->edittree->nodes.first; node; node=node->next)
 		node->flag &= ~NODE_TEST;
 
-	for(link=snode->edittree->links.first; link; link=link->next) {
-		if(link->fromnode && link->tonode && (link->tonode->flag & NODE_SELECT))
+	for (link=snode->edittree->links.first; link; link=link->next) {
+		if (link->fromnode && link->tonode && (link->tonode->flag & NODE_SELECT))
 			link->fromnode->flag |= NODE_TEST;
 	}
 	
-	for(node=snode->edittree->nodes.first; node; node=node->next) {
-		if(node->flag & NODE_TEST)
-			node->flag |= NODE_SELECT;
+	for (node=snode->edittree->nodes.first; node; node=node->next) {
+		if (node->flag & NODE_TEST)
+			node_select(node);
 	}
 	
 	node_sort(snode->edittree);
