@@ -29,78 +29,39 @@
  *  \ingroup spoutliner
  */
 
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
-#include <stddef.h>
-
 #include "MEM_guardedalloc.h"
 
 #include "DNA_anim_types.h"
-#include "DNA_armature_types.h"
-#include "DNA_constraint_types.h"
-#include "DNA_camera_types.h"
 #include "DNA_group_types.h"
-#include "DNA_key_types.h"
-#include "DNA_lamp_types.h"
-#include "DNA_material_types.h"
-#include "DNA_mesh_types.h"
-#include "DNA_meta_types.h"
-#include "DNA_particle_types.h"
 #include "DNA_scene_types.h"
-#include "DNA_world_types.h"
-#include "DNA_sequence_types.h"
 #include "DNA_object_types.h"
 
 #include "BLI_blenlib.h"
 #include "BLI_utildefines.h"
-#include "BLI_math_base.h"
-
-#if defined WIN32 && !defined _LIBC
-# include "BLI_fnmatch.h" /* use fnmatch included in blenlib */
-#else
-#  ifndef _GNU_SOURCE
-#    define _GNU_SOURCE
-#  endif
-# include <fnmatch.h>
-#endif
 
+#include "BLF_translation.h"
 
 #include "BKE_animsys.h"
 #include "BKE_context.h"
-#include "BKE_deform.h"
 #include "BKE_depsgraph.h"
-#include "BKE_fcurve.h"
-#include "BKE_global.h"
-#include "BKE_group.h"
 #include "BKE_library.h"
 #include "BKE_main.h"
-#include "BKE_modifier.h"
 #include "BKE_report.h"
 #include "BKE_scene.h"
-#include "BKE_sequencer.h"
 
-#include "ED_armature.h"
 #include "ED_object.h"
 #include "ED_screen.h"
-#include "ED_util.h"
+#include "ED_keyframing.h"
 
 #include "WM_api.h"
 #include "WM_types.h"
 
-#include "BIF_gl.h"
-#include "BIF_glutil.h"
-
 #include "UI_interface.h"
-#include "UI_interface_icons.h"
 #include "UI_resources.h"
 #include "UI_view2d.h"
 
 #include "RNA_access.h"
 #include "RNA_define.h"
-#include "RNA_enum_types.h"
-
-#include "ED_keyframing.h"
 
 #include "outliner_intern.h"
 
@@ -158,24 +119,24 @@ static void outliner_open_reveal(SpaceOops *soops, ListBase *lb, TreeElement *te
 static int do_outliner_item_openclose(bContext *C, SpaceOops *soops, TreeElement *te, int all, const float mval[2])
 {
 	
-	if(mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
+	if (mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
 		TreeStoreElem *tselem= TREESTORE(te);
 		
 		/* all below close/open? */
-		if(all) {
+		if (all) {
 			tselem->flag &= ~TSE_CLOSED;
 			outliner_set_flag(soops, &te->subtree, TSE_CLOSED, !outliner_has_one_flag(soops, &te->subtree, TSE_CLOSED, 1));
 		}
 		else {
-			if(tselem->flag & TSE_CLOSED) tselem->flag &= ~TSE_CLOSED;
+			if (tselem->flag & TSE_CLOSED) tselem->flag &= ~TSE_CLOSED;
 			else tselem->flag |= TSE_CLOSED;
 		}
 		
 		return 1;
 	}
 	
-	for(te= te->subtree.first; te; te= te->next) {
-		if(do_outliner_item_openclose(C, soops, te, all, mval)) 
+	for (te= te->subtree.first; te; te= te->next) {
+		if (do_outliner_item_openclose(C, soops, te, all, mval)) 
 			return 1;
 	}
 	return 0;
@@ -193,8 +154,8 @@ static int outliner_item_openclose(bContext *C, wmOperator *op, wmEvent *event)
 	
 	UI_view2d_region_to_view(&ar->v2d, event->mval[0], event->mval[1], fmval, fmval+1);
 	
-	for(te= soops->tree.first; te; te= te->next) {
-		if(do_outliner_item_openclose(C, soops, te, all, fmval)) 
+	for (te= soops->tree.first; te; te= te->next) {
+		if (do_outliner_item_openclose(C, soops, te, all, fmval)) 
 			break;
 	}
 
@@ -205,13 +166,13 @@ static int outliner_item_openclose(bContext *C, wmOperator *op, wmEvent *event)
 
 void OUTLINER_OT_item_openclose(wmOperatorType *ot)
 {
-	ot->name= "Open/Close Item";
-	ot->idname= "OUTLINER_OT_item_openclose";
-	ot->description= "Toggle whether item under cursor is enabled or closed";
+	ot->name = "Open/Close Item";
+	ot->idname = "OUTLINER_OT_item_openclose";
+	ot->description = "Toggle whether item under cursor is enabled or closed";
 	
-	ot->invoke= outliner_item_openclose;
+	ot->invoke = outliner_item_openclose;
 	
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 	
 	RNA_def_boolean(ot->srna, "all", 1, "All", "Close or open all items");
 }
@@ -221,21 +182,21 @@ void OUTLINER_OT_item_openclose(wmOperatorType *ot)
 static void do_item_rename(ARegion *ar, TreeElement *te, TreeStoreElem *tselem, ReportList *reports)
 {
 	/* can't rename rna datablocks entries */
-	if(ELEM3(tselem->type, TSE_RNA_STRUCT, TSE_RNA_PROPERTY, TSE_RNA_ARRAY_ELEM)) {
+	if (ELEM3(tselem->type, TSE_RNA_STRUCT, TSE_RNA_PROPERTY, TSE_RNA_ARRAY_ELEM)) {
 			/* do nothing */;
 	}
-	else if(ELEM10(tselem->type, TSE_ANIM_DATA, TSE_NLA, TSE_DEFGROUP_BASE, TSE_CONSTRAINT_BASE, TSE_MODIFIER_BASE,
+	else if (ELEM10(tselem->type, TSE_ANIM_DATA, TSE_NLA, TSE_DEFGROUP_BASE, TSE_CONSTRAINT_BASE, TSE_MODIFIER_BASE,
 	                             TSE_SCRIPT_BASE, TSE_POSE_BASE, TSE_POSEGRP_BASE, TSE_R_LAYER_BASE, TSE_R_PASS))
 	{
 			BKE_report(reports, RPT_WARNING, "Cannot edit builtin name");
 	}
-	else if(ELEM3(tselem->type, TSE_SEQUENCE, TSE_SEQ_STRIP, TSE_SEQUENCE_DUP)) {
+	else if (ELEM3(tselem->type, TSE_SEQUENCE, TSE_SEQ_STRIP, TSE_SEQUENCE_DUP)) {
 		BKE_report(reports, RPT_WARNING, "Cannot edit sequence name");
 	}
-	else if(tselem->id->lib) {
+	else if (tselem->id->lib) {
 		// XXX						error_libdata();
 	} 
-	else if(te->idcode == ID_LI && te->parent) {
+	else if (te->idcode == ID_LI && te->parent) {
 		BKE_report(reports, RPT_WARNING, "Cannot edit the path of an indirectly linked library");
 	} 
 	else {
@@ -248,26 +209,26 @@ void item_rename_cb(bContext *C, Scene *UNUSED(scene), TreeElement *te, TreeStor
 {
 	ARegion *ar= CTX_wm_region(C);
 	ReportList *reports= CTX_wm_reports(C); // XXX
-	do_item_rename(ar, te, tselem, reports) ;
+	do_item_rename(ar, te, tselem, reports);
 }
 
 static int do_outliner_item_rename(bContext *C, ARegion *ar, SpaceOops *soops, TreeElement *te, const float mval[2])
 {	
 	ReportList *reports= CTX_wm_reports(C); // XXX
 	
-	if(mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
+	if (mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
 		TreeStoreElem *tselem= TREESTORE(te);
 		
 		/* name and first icon */
-		if(mval[0]>te->xs+UI_UNIT_X && mval[0]<te->xend) {
+		if (mval[0]>te->xs+UI_UNIT_X && mval[0]<te->xend) {
 			
-			do_item_rename(ar, te, tselem, reports) ;
+			do_item_rename(ar, te, tselem, reports);
 		}
 		return 1;
 	}
 	
-	for(te= te->subtree.first; te; te= te->next) {
-		if(do_outliner_item_rename(C, ar, soops, te, mval)) return 1;
+	for (te= te->subtree.first; te; te= te->next) {
+		if (do_outliner_item_rename(C, ar, soops, te, mval)) return 1;
 	}
 	return 0;
 }
@@ -281,8 +242,8 @@ static int outliner_item_rename(bContext *C, wmOperator *UNUSED(op), wmEvent *ev
 	
 	UI_view2d_region_to_view(&ar->v2d, event->mval[0], event->mval[1], fmval, fmval+1);
 	
-	for(te= soops->tree.first; te; te= te->next) {
-		if(do_outliner_item_rename(C, ar, soops, te, fmval)) break;
+	for (te= soops->tree.first; te; te= te->next) {
+		if (do_outliner_item_rename(C, ar, soops, te, fmval)) break;
 	}
 	
 	return OPERATOR_FINISHED;
@@ -291,13 +252,13 @@ static int outliner_item_rename(bContext *C, wmOperator *UNUSED(op), wmEvent *ev
 
 void OUTLINER_OT_item_rename(wmOperatorType *ot)
 {
-	ot->name= "Rename Item";
-	ot->idname= "OUTLINER_OT_item_rename";
-	ot->description= "Rename item under cursor";
+	ot->name = "Rename Item";
+	ot->idname = "OUTLINER_OT_item_rename";
+	ot->description = "Rename item under cursor";
 	
-	ot->invoke= outliner_item_rename;
+	ot->invoke = outliner_item_rename;
 	
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 }
 
 /* ************************************************************** */
@@ -313,10 +274,10 @@ static int outliner_count_levels(SpaceOops *soops, ListBase *lb, int curlevel)
 	TreeElement *te;
 	int level=curlevel, lev;
 	
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		
 		lev= outliner_count_levels(soops, &te->subtree, curlevel+1);
-		if(lev>level) level= lev;
+		if (lev>level) level= lev;
 	}
 	return level;
 }
@@ -327,12 +288,12 @@ int outliner_has_one_flag(SpaceOops *soops, ListBase *lb, short flag, short curl
 	TreeStoreElem *tselem;
 	int level;
 	
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(tselem->flag & flag) return curlevel;
+		if (tselem->flag & flag) return curlevel;
 		
 		level= outliner_has_one_flag(soops, &te->subtree, flag, curlevel+1);
-		if(level) return level;
+		if (level) return level;
 	}
 	return 0;
 }
@@ -342,9 +303,9 @@ void outliner_set_flag(SpaceOops *soops, ListBase *lb, short flag, short set)
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(set==0) tselem->flag &= ~flag;
+		if (set==0) tselem->flag &= ~flag;
 		else tselem->flag |= flag;
 		outliner_set_flag(soops, &te->subtree, flag, set);
 	}
@@ -385,10 +346,10 @@ void object_toggle_visibility_cb(bContext *C, Scene *scene, TreeElement *te, Tre
 	Object *ob = (Object *)tselem->id;
 	
 	/* add check for edit mode */
-	if(!common_restrict_check(C, ob)) return;
+	if (!common_restrict_check(C, ob)) return;
 	
-	if(base || (base= object_in_scene(ob, scene))) {
-		if((base->object->restrictflag ^= OB_RESTRICT_VIEW)) {
+	if (base || (base= object_in_scene(ob, scene))) {
+		if ((base->object->restrictflag ^= OB_RESTRICT_VIEW)) {
 			ED_base_object_select(base, BA_DESELECT);
 		}
 	}
@@ -417,15 +378,15 @@ static int outliner_toggle_visibility_exec(bContext *C, wmOperator *UNUSED(op))
 void OUTLINER_OT_visibility_toggle(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Toggle Visibility";
-	ot->idname= "OUTLINER_OT_visibility_toggle";
-	ot->description= "Toggle the visibility of selected items";
+	ot->name = "Toggle Visibility";
+	ot->idname = "OUTLINER_OT_visibility_toggle";
+	ot->description = "Toggle the visibility of selected items";
 	
 	/* callbacks */
-	ot->exec= outliner_toggle_visibility_exec;
-	ot->poll= ED_operator_outliner_active_no_editobject;
+	ot->exec = outliner_toggle_visibility_exec;
+	ot->poll = ED_operator_outliner_active_no_editobject;
 	
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* Toggle Selectability ---------------------------------------- */
@@ -434,8 +395,8 @@ void object_toggle_selectability_cb(bContext *UNUSED(C), Scene *scene, TreeEleme
 {
 	Base *base= (Base *)te->directdata;
 	
-	if(base==NULL) base= object_in_scene((Object *)tselem->id, scene);
-	if(base) {
+	if (base==NULL) base= object_in_scene((Object *)tselem->id, scene);
+	if (base) {
 		base->object->restrictflag^=OB_RESTRICT_SELECT;
 	}
 }
@@ -463,15 +424,15 @@ static int outliner_toggle_selectability_exec(bContext *C, wmOperator *UNUSED(op
 void OUTLINER_OT_selectability_toggle(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Toggle Selectability";
-	ot->idname= "OUTLINER_OT_selectability_toggle";
-	ot->description= "Toggle the selectability";
+	ot->name = "Toggle Selectability";
+	ot->idname = "OUTLINER_OT_selectability_toggle";
+	ot->description = "Toggle the selectability";
 	
 	/* callbacks */
-	ot->exec= outliner_toggle_selectability_exec;
-	ot->poll= ED_operator_outliner_active_no_editobject;
+	ot->exec = outliner_toggle_selectability_exec;
+	ot->poll = ED_operator_outliner_active_no_editobject;
 	
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* Toggle Renderability ---------------------------------------- */
@@ -480,8 +441,8 @@ void object_toggle_renderability_cb(bContext *UNUSED(C), Scene *scene, TreeEleme
 {
 	Base *base= (Base *)te->directdata;
 	
-	if(base==NULL) base= object_in_scene((Object *)tselem->id, scene);
-	if(base) {
+	if (base==NULL) base= object_in_scene((Object *)tselem->id, scene);
+	if (base) {
 		base->object->restrictflag^=OB_RESTRICT_RENDER;
 	}
 }
@@ -507,15 +468,15 @@ static int outliner_toggle_renderability_exec(bContext *C, wmOperator *UNUSED(op
 void OUTLINER_OT_renderability_toggle(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Toggle Renderability";
-	ot->idname= "OUTLINER_OT_renderability_toggle";
-	ot->description= "Toggle the renderability of selected items";
+	ot->name = "Toggle Renderability";
+	ot->idname = "OUTLINER_OT_renderability_toggle";
+	ot->description = "Toggle the renderability of selected items";
 	
 	/* callbacks */
-	ot->exec= outliner_toggle_renderability_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->exec = outliner_toggle_renderability_exec;
+	ot->poll = ED_operator_outliner_active;
 	
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 }
 
 /* =============================================== */
@@ -541,13 +502,13 @@ static int outliner_toggle_expanded_exec(bContext *C, wmOperator *UNUSED(op))
 void OUTLINER_OT_expanded_toggle(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Expand/Collapse All";
-	ot->idname= "OUTLINER_OT_expanded_toggle";
-	ot->description= "Expand/Collapse all items";
+	ot->name = "Expand/Collapse All";
+	ot->idname = "OUTLINER_OT_expanded_toggle";
+	ot->description = "Expand/Collapse all items";
 	
 	/* callbacks */
-	ot->exec= outliner_toggle_expanded_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->exec = outliner_toggle_expanded_exec;
+	ot->poll = ED_operator_outliner_active;
 	
 	/* no undo or registry, UI option */
 }
@@ -576,13 +537,13 @@ static int outliner_toggle_selected_exec(bContext *C, wmOperator *UNUSED(op))
 void OUTLINER_OT_selected_toggle(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Toggle Selected";
-	ot->idname= "OUTLINER_OT_selected_toggle";
-	ot->description= "Toggle the Outliner selection of items";
+	ot->name = "Toggle Selected";
+	ot->idname = "OUTLINER_OT_selected_toggle";
+	ot->description = "Toggle the Outliner selection of items";
 	
 	/* callbacks */
-	ot->exec= outliner_toggle_selected_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->exec = outliner_toggle_selected_exec;
+	ot->poll = ED_operator_outliner_active;
 	
 	/* no undo or registry, UI option */
 }
@@ -612,8 +573,8 @@ static int outliner_show_active_exec(bContext *C, wmOperator *UNUSED(op))
 		ytop= (int)(te->ys + (v2d->mask.ymax - v2d->mask.ymin)/2);
 		if (ytop>0) ytop= 0;
 		
-		v2d->cur.ymax= (float)ytop;
-		v2d->cur.ymin= (float)(ytop-(v2d->mask.ymax - v2d->mask.ymin));
+		v2d->cur.ymax = (float)ytop;
+		v2d->cur.ymin = (float)(ytop-(v2d->mask.ymax - v2d->mask.ymin));
 		
 		/* make te->xs ==> te->xend center of view */
 		xdelta = (int)(te->xs - v2d->cur.xmin);
@@ -631,13 +592,13 @@ static int outliner_show_active_exec(bContext *C, wmOperator *UNUSED(op))
 void OUTLINER_OT_show_active(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Show Active";
-	ot->idname= "OUTLINER_OT_show_active";
-	ot->description= "Adjust the view so that the active Object is shown centered";
+	ot->name = "Show Active";
+	ot->idname = "OUTLINER_OT_show_active";
+	ot->description = "Adjust the view so that the active Object is shown centered";
 	
 	/* callbacks */
-	ot->exec= outliner_show_active_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->exec = outliner_show_active_exec;
+	ot->poll = ED_operator_outliner_active;
 }
 
 /* View Panning --------------------------------------------------- */
@@ -648,10 +609,10 @@ static int outliner_scroll_page_exec(bContext *C, wmOperator *op)
 	int dy= ar->v2d.mask.ymax - ar->v2d.mask.ymin;
 	int up= 0;
 	
-	if(RNA_boolean_get(op->ptr, "up"))
+	if (RNA_boolean_get(op->ptr, "up"))
 		up= 1;
 
-	if(up == 0) dy= -dy;
+	if (up == 0) dy= -dy;
 	ar->v2d.cur.ymin+= dy;
 	ar->v2d.cur.ymax+= dy;
 	
@@ -664,13 +625,13 @@ static int outliner_scroll_page_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_scroll_page(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Scroll Page";
-	ot->idname= "OUTLINER_OT_scroll_page";
-	ot->description= "Scroll page up or down";
+	ot->name = "Scroll Page";
+	ot->idname = "OUTLINER_OT_scroll_page";
+	ot->description = "Scroll page up or down";
 	
 	/* callbacks */
-	ot->exec= outliner_scroll_page_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->exec = outliner_scroll_page_exec;
+	ot->poll = ED_operator_outliner_active;
 	
 	/* properties */
 	RNA_def_boolean(ot->srna, "up", 0, "Up", "Scroll up one page");
@@ -691,9 +652,9 @@ static void outliner_set_coordinates_element(SpaceOops *soops, TreeElement *te,
 	te->ys= (float)(*starty);
 	*starty-= UI_UNIT_Y;
 	
-	if(TSELEM_OPEN(tselem,soops)) {
+	if (TSELEM_OPEN(tselem,soops)) {
 		TreeElement *ten;
-		for(ten= te->subtree.first; ten; ten= ten->next) {
+		for (ten= te->subtree.first; ten; ten= ten->next) {
 			outliner_set_coordinates_element(soops, ten, startx+UI_UNIT_X, starty);
 		}
 	}
@@ -707,7 +668,7 @@ static void outliner_set_coordinates(ARegion *ar, SpaceOops *soops)
 	int starty= (int)(ar->v2d.tot.ymax)-UI_UNIT_Y;
 	int startx= 0;
 	
-	for(te= soops->tree.first; te; te= te->next) {
+	for (te= soops->tree.first; te; te= te->next) {
 		outliner_set_coordinates_element(soops, te, startx, &starty);
 	}
 }
@@ -720,7 +681,7 @@ static TreeElement *outliner_find_named(SpaceOops *soops, ListBase *lb, char *na
 	for (te= lb->first; te; te= te->next) {
 		int found = outliner_filter_has_name(te, name, flags);
 		
-		if(found) {
+		if (found) {
 			/* name is right, but is element the previous one? */
 			if (prev) {
 				if ((te != prev) && (*prevFound)) 
@@ -734,7 +695,7 @@ static TreeElement *outliner_find_named(SpaceOops *soops, ListBase *lb, char *na
 		}
 		
 		tes= outliner_find_named(soops, &te->subtree, name, flags, prev, prevFound);
-		if(tes) return tes;
+		if (tes) return tes;
 	}
 
 	/* nothing valid found */
@@ -781,7 +742,7 @@ static void outliner_find_panel(Scene *UNUSED(scene), ARegion *ar, SpaceOops *so
 		tselem= TREESTORE(te);
 		if (tselem) {
 			/* expand branches so that it will be visible, we need to get correct coordinates */
-			if( outliner_open_back(soops, te))
+			if ( outliner_open_back(soops, te))
 				outliner_set_coordinates(ar, soops);
 			
 			/* deselect all visible, and select found element */
@@ -790,9 +751,9 @@ static void outliner_find_panel(Scene *UNUSED(scene), ARegion *ar, SpaceOops *so
 			
 			/* make te->ys center of view */
 			ytop= (int)(te->ys + (ar->v2d.mask.ymax-ar->v2d.mask.ymin)/2);
-			if(ytop>0) ytop= 0;
-			ar->v2d.cur.ymax= (float)ytop;
-			ar->v2d.cur.ymin= (float)(ytop-(ar->v2d.mask.ymax-ar->v2d.mask.ymin));
+			if (ytop>0) ytop= 0;
+			ar->v2d.cur.ymax = (float)ytop;
+			ar->v2d.cur.ymin = (float)(ytop-(ar->v2d.mask.ymax-ar->v2d.mask.ymin));
 			
 			/* make te->xs ==> te->xend center of view */
 			xdelta = (int)(te->xs - ar->v2d.cur.xmin);
@@ -824,14 +785,14 @@ static void outliner_openclose_level(SpaceOops *soops, ListBase *lb, int curleve
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
 		
-		if(open) {
-			if(curlevel<=level) tselem->flag &= ~TSE_CLOSED;
+		if (open) {
+			if (curlevel<=level) tselem->flag &= ~TSE_CLOSED;
 		}
 		else {
-			if(curlevel>=level) tselem->flag |= TSE_CLOSED;
+			if (curlevel>=level) tselem->flag |= TSE_CLOSED;
 		}
 		
 		outliner_openclose_level(soops, &te->subtree, curlevel+1, level, open);
@@ -846,12 +807,12 @@ static int outliner_one_level_exec(bContext *C, wmOperator *op)
 	int level;
 	
 	level= outliner_has_one_flag(soops, &soops->tree, TSE_CLOSED, 1);
-	if(add==1) {
-		if(level) outliner_openclose_level(soops, &soops->tree, 1, level, 1);
+	if (add==1) {
+		if (level) outliner_openclose_level(soops, &soops->tree, 1, level, 1);
 	}
 	else {
-		if(level==0) level= outliner_count_levels(soops, &soops->tree, 0);
-		if(level) outliner_openclose_level(soops, &soops->tree, 1, level-1, 0);
+		if (level==0) level= outliner_count_levels(soops, &soops->tree, 0);
+		if (level) outliner_openclose_level(soops, &soops->tree, 1, level-1, 0);
 	}
 	
 	ED_region_tag_redraw(ar);
@@ -862,13 +823,13 @@ static int outliner_one_level_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_show_one_level(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Show/Hide One Level";
-	ot->idname= "OUTLINER_OT_show_one_level";
-	ot->description= "Expand/collapse all entries by one level";
+	ot->name = "Show/Hide One Level";
+	ot->idname = "OUTLINER_OT_show_one_level";
+	ot->description = "Expand/collapse all entries by one level";
 	
 	/* callbacks */
-	ot->exec= outliner_one_level_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->exec = outliner_one_level_exec;
+	ot->poll = ED_operator_outliner_active;
 	
 	/* no undo or registry, UI option */
 	
@@ -884,10 +845,10 @@ static int subtree_has_objects(SpaceOops *soops, ListBase *lb)
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(tselem->type==0 && te->idcode==ID_OB) return 1;
-		if( subtree_has_objects(soops, &te->subtree)) return 1;
+		if (tselem->type==0 && te->idcode==ID_OB) return 1;
+		if ( subtree_has_objects(soops, &te->subtree)) return 1;
 	}
 	return 0;
 }
@@ -899,22 +860,22 @@ static void tree_element_show_hierarchy(Scene *scene, SpaceOops *soops, ListBase
 	TreeStoreElem *tselem;
 
 	/* open all object elems, close others */
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
 		
-		if(tselem->type==0) {
-			if(te->idcode==ID_SCE) {
-				if(tselem->id!=(ID *)scene) tselem->flag |= TSE_CLOSED;
+		if (tselem->type==0) {
+			if (te->idcode==ID_SCE) {
+				if (tselem->id!=(ID *)scene) tselem->flag |= TSE_CLOSED;
 					else tselem->flag &= ~TSE_CLOSED;
 			}
-			else if(te->idcode==ID_OB) {
-				if(subtree_has_objects(soops, &te->subtree)) tselem->flag &= ~TSE_CLOSED;
+			else if (te->idcode==ID_OB) {
+				if (subtree_has_objects(soops, &te->subtree)) tselem->flag &= ~TSE_CLOSED;
 				else tselem->flag |= TSE_CLOSED;
 			}
 		}
 		else tselem->flag |= TSE_CLOSED;
 		
-		if(TSELEM_OPEN(tselem,soops)) tree_element_show_hierarchy(scene, soops, &te->subtree);
+		if (TSELEM_OPEN(tselem,soops)) tree_element_show_hierarchy(scene, soops, &te->subtree);
 	}
 }
 
@@ -936,13 +897,13 @@ static int outliner_show_hierarchy_exec(bContext *C, wmOperator *UNUSED(op))
 void OUTLINER_OT_show_hierarchy(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Show Hierarchy";
-	ot->idname= "OUTLINER_OT_show_hierarchy";
-	ot->description= "Open all object entries and close all others";
+	ot->name = "Show Hierarchy";
+	ot->idname = "OUTLINER_OT_show_hierarchy";
+	ot->description = "Open all object entries and close all others";
 	
 	/* callbacks */
-	ot->exec= outliner_show_hierarchy_exec;
-	ot->poll= ED_operator_outliner_active; //  TODO: shouldn't be allowed in RNA views...
+	ot->exec = outliner_show_hierarchy_exec;
+	ot->poll = ED_operator_outliner_active; //  TODO: shouldn't be allowed in RNA views...
 	
 	/* no undo or registry, UI option */
 }
@@ -978,7 +939,7 @@ static void tree_element_to_path(SpaceOops *soops, TreeElement *te, TreeStoreEle
 	PropertyRNA *prop;
 	char *newpath=NULL;
 	
-	/* optimise tricks:
+	/* optimize tricks:
 	 *	- Don't do anything if the selected item is a 'struct', but arrays are allowed
 	 */
 	if (tselem->type == TSE_RNA_STRUCT)
@@ -1013,12 +974,12 @@ static void tree_element_to_path(SpaceOops *soops, TreeElement *te, TreeStoreEle
 			/* just 'append' property to path 
 			 *	- to prevent memory leaks, we must write to newpath not path, then free old path + swap them
 			 */
-			if(tse->type == TSE_RNA_PROPERTY) {
-				if(RNA_property_type(prop) == PROP_POINTER) {
+			if (tse->type == TSE_RNA_PROPERTY) {
+				if (RNA_property_type(prop) == PROP_POINTER) {
 					/* for pointer we just append property name */
 					newpath= RNA_path_append(*path, ptr, prop, 0, NULL);
 				}
-				else if(RNA_property_type(prop) == PROP_COLLECTION) {
+				else if (RNA_property_type(prop) == PROP_COLLECTION) {
 					char buf[128], *name;
 					
 					temnext= (TreeElement*)(ld->next->data);
@@ -1027,19 +988,19 @@ static void tree_element_to_path(SpaceOops *soops, TreeElement *te, TreeStoreEle
 					nextptr= &temnext->rnaptr;
 					name= RNA_struct_name_get_alloc(nextptr, buf, sizeof(buf), NULL);
 					
-					if(name) {
+					if (name) {
 						/* if possible, use name as a key in the path */
 						newpath= RNA_path_append(*path, NULL, prop, 0, name);
 						
-						if(name != buf)
+						if (name != buf)
 							MEM_freeN(name);
 					}
 					else {
 						/* otherwise use index */
 						int index= 0;
 						
-						for(temsub=tem->subtree.first; temsub; temsub=temsub->next, index++)
-							if(temsub == temnext)
+						for (temsub=tem->subtree.first; temsub; temsub=temsub->next, index++)
+							if (temsub == temnext)
 								break;
 						
 						newpath= RNA_path_append(*path, NULL, prop, index, NULL);
@@ -1049,7 +1010,7 @@ static void tree_element_to_path(SpaceOops *soops, TreeElement *te, TreeStoreEle
 				}
 			}
 			
-			if(newpath) {
+			if (newpath) {
 				if (*path) MEM_freeN(*path);
 				*path= newpath;
 				newpath= NULL;
@@ -1059,11 +1020,11 @@ static void tree_element_to_path(SpaceOops *soops, TreeElement *te, TreeStoreEle
 			/* no ID, so check if entry is RNA-struct, and if that RNA-struct is an ID datablock to extract info from */
 			if (tse->type == TSE_RNA_STRUCT) {
 				/* ptr->data not ptr->id.data seems to be the one we want, since ptr->data is sometimes the owner of this ID? */
-				if(RNA_struct_is_ID(ptr->type)) {
+				if (RNA_struct_is_ID(ptr->type)) {
 					*id= (ID *)ptr->data;
 					
 					/* clear path */
-					if(*path) {
+					if (*path) {
 						MEM_freeN(*path);
 						path= NULL;
 					}
@@ -1128,7 +1089,7 @@ static void do_outliner_drivers_editop(SpaceOops *soops, ListBase *tree, ReportL
 			short flag= 0;
 			short groupmode= KSP_GROUP_KSNAME;
 			
-			/* check if RNA-property described by this selected element is an animateable prop */
+			/* check if RNA-property described by this selected element is an animatable prop */
 			if (ELEM(tselem->type, TSE_RNA_PROPERTY, TSE_RNA_ARRAY_ELEM) && RNA_property_animateable(&te->rnaptr, te->directdata)) {
 				/* get id + path + index info from the selected element */
 				tree_element_to_path(soops, te, tselem, 
@@ -1206,13 +1167,13 @@ static int outliner_drivers_addsel_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_drivers_add_selected(wmOperatorType *ot)
 {
 	/* api callbacks */
-	ot->idname= "OUTLINER_OT_drivers_add_selected";
-	ot->name= "Add Drivers for Selected";
-	ot->description= "Add drivers to selected items";
+	ot->idname = "OUTLINER_OT_drivers_add_selected";
+	ot->name = "Add Drivers for Selected";
+	ot->description = "Add drivers to selected items";
 	
 	/* api callbacks */
-	ot->exec= outliner_drivers_addsel_exec;
-	ot->poll= ed_operator_outliner_datablocks_active;
+	ot->exec = outliner_drivers_addsel_exec;
+	ot->poll = ed_operator_outliner_datablocks_active;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1241,13 +1202,13 @@ static int outliner_drivers_deletesel_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_drivers_delete_selected(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->idname= "OUTLINER_OT_drivers_delete_selected";
-	ot->name= "Delete Drivers for Selected";
-	ot->description= "Delete drivers assigned to selected items";
+	ot->idname = "OUTLINER_OT_drivers_delete_selected";
+	ot->name = "Delete Drivers for Selected";
+	ot->description = "Delete drivers assigned to selected items";
 	
 	/* api callbacks */
-	ot->exec= outliner_drivers_deletesel_exec;
-	ot->poll= ed_operator_outliner_datablocks_active;
+	ot->exec = outliner_drivers_deletesel_exec;
+	ot->poll = ed_operator_outliner_datablocks_active;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1283,7 +1244,7 @@ static KeyingSet *verify_active_keyingset(Scene *scene, short add)
 	/* add if none found */
 	// XXX the default settings have yet to evolve
 	if ((add) && (ks==NULL)) {
-		ks= BKE_keyingset_add(&scene->keyingsets, NULL, KEYINGSET_ABSOLUTE, 0);
+		ks= BKE_keyingset_add(&scene->keyingsets, NULL, NULL, KEYINGSET_ABSOLUTE, 0);
 		scene->active_keyingset= BLI_countlist(&scene->keyingsets);
 	}
 	
@@ -1307,7 +1268,7 @@ static void do_outliner_keyingset_editop(SpaceOops *soops, KeyingSet *ks, ListBa
 			short flag= 0;
 			short groupmode= KSP_GROUP_KSNAME;
 			
-			/* check if RNA-property described by this selected element is an animateable prop */
+			/* check if RNA-property described by this selected element is an animatable prop */
 			if (ELEM(tselem->type, TSE_RNA_PROPERTY, TSE_RNA_ARRAY_ELEM) && RNA_property_animateable(&te->rnaptr, te->directdata)) {
 				/* get id + path + index info from the selected element */
 				tree_element_to_path(soops, te, tselem, 
@@ -1380,13 +1341,13 @@ static int outliner_keyingset_additems_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_keyingset_add_selected(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->idname= "OUTLINER_OT_keyingset_add_selected";
-	ot->name= "Keying Set Add Selected";
-	ot->description= "Add selected items (blue-grey rows) to active Keying Set";
+	ot->idname = "OUTLINER_OT_keyingset_add_selected";
+	ot->name = "Keying Set Add Selected";
+	ot->description = "Add selected items (blue-grey rows) to active Keying Set";
 	
 	/* api callbacks */
-	ot->exec= outliner_keyingset_additems_exec;
-	ot->poll= ed_operator_outliner_datablocks_active;
+	ot->exec = outliner_keyingset_additems_exec;
+	ot->poll = ed_operator_outliner_datablocks_active;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1417,13 +1378,13 @@ static int outliner_keyingset_removeitems_exec(bContext *C, wmOperator *UNUSED(o
 void OUTLINER_OT_keyingset_remove_selected(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->idname= "OUTLINER_OT_keyingset_remove_selected";
-	ot->name= "Keying Set Remove Selected";
+	ot->idname = "OUTLINER_OT_keyingset_remove_selected";
+	ot->name = "Keying Set Remove Selected";
 	ot->description = "Remove selected items (blue-grey rows) from active Keying Set";
 	
 	/* api callbacks */
-	ot->exec= outliner_keyingset_removeitems_exec;
-	ot->poll= ed_operator_outliner_datablocks_active;
+	ot->exec = outliner_keyingset_removeitems_exec;
+	ot->poll = ed_operator_outliner_datablocks_active;
 	
 	/* flags */
 	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
@@ -1433,15 +1394,24 @@ void OUTLINER_OT_keyingset_remove_selected(wmOperatorType *ot)
 
 static int parent_drop_exec(bContext *C, wmOperator *op)
 {
-	Object *par = NULL;
+	Object *par = NULL, *ob = NULL;
+	Main *bmain= CTX_data_main(C);
+	Scene *scene= CTX_data_scene(C);
 	int partype = -1;
-	char parname[32];
+	char parname[MAX_ID_NAME], childname[MAX_ID_NAME];
 
 	partype= RNA_enum_get(op->ptr, "type");
 	RNA_string_get(op->ptr, "parent", parname);
 	par= (Object *)find_id("OB", parname);
+	RNA_string_get(op->ptr, "child", childname);
+	ob= (Object *)find_id("OB", childname);
 
-	ED_object_parent_set(C, op, par, partype);
+	ED_object_parent_set(op->reports, bmain, scene, ob, par, partype);
+
+	DAG_scene_sort(bmain, scene);
+	DAG_ids_flush_update(bmain, 0);
+	WM_event_add_notifier(C, NC_OBJECT|ND_TRANSFORM, NULL);
+	WM_event_add_notifier(C, NC_OBJECT|ND_PARENT, NULL);
 
 	return OPERATOR_FINISHED;
 }
@@ -1482,6 +1452,7 @@ static int parent_drop_invoke(bContext *C, wmOperator *op, wmEvent *event)
 	Object *ob= NULL;
 	SpaceOops *soops= CTX_wm_space_outliner(C);
 	ARegion *ar= CTX_wm_region(C);
+	Main *bmain= CTX_data_main(C);
 	Scene *scene= CTX_data_scene(C);
 	TreeElement *te= NULL;
 	TreeElement *te_found= NULL;
@@ -1498,7 +1469,7 @@ static int parent_drop_invoke(bContext *C, wmOperator *op, wmEvent *event)
 		if (te_found) break;
 	}
 
-	if(te_found) {
+	if (te_found) {
 		RNA_string_set(op->ptr, "parent", te_found->name);
 		/* Identify parent and child */
 		RNA_string_get(op->ptr, "child", childname);
@@ -1519,11 +1490,16 @@ static int parent_drop_invoke(bContext *C, wmOperator *op, wmEvent *event)
 			ED_base_object_select(object_in_scene(ob, scene), BA_SELECT);
 		
 		if ((par->type != OB_ARMATURE) && (par->type != OB_CURVE) && (par->type != OB_LATTICE)) {
-			ED_object_parent_set(C, op, par, partype);
+			if (ED_object_parent_set(op->reports, bmain, scene, ob, par, partype)) {
+				DAG_scene_sort(bmain, scene);
+				DAG_ids_flush_update(bmain, 0);
+				WM_event_add_notifier(C, NC_OBJECT|ND_TRANSFORM, NULL);
+				WM_event_add_notifier(C, NC_OBJECT|ND_PARENT, NULL);
+			}
 		}
 		else {
 			/* Menu creation */
-			uiPopupMenu *pup= uiPupMenuBegin(C, "Set Parent To", ICON_NONE);
+			uiPopupMenu *pup= uiPupMenuBegin(C, IFACE_("Set Parent To"), ICON_NONE);
 			uiLayout *layout= uiPupMenuLayout(pup);
 			
 			PointerRNA ptr;
@@ -1533,7 +1509,8 @@ static int parent_drop_invoke(bContext *C, wmOperator *op, wmEvent *event)
 			RNA_string_set(&ptr, "child", childname);
 			RNA_enum_set(&ptr, "type", PAR_OBJECT);
 			/* Cannot use uiItemEnumO()... have multiple properties to set. */
-			uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Object", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+			uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Object"),
+			            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 			
 			/* par becomes parent, make the associated menus */
 			if (par->type==OB_ARMATURE) {
@@ -1541,57 +1518,66 @@ static int parent_drop_invoke(bContext *C, wmOperator *op, wmEvent *event)
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_ARMATURE);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Armature Deform", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Armature Deform"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 				
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_ARMATURE_NAME);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "   With Empty Groups", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("   With Empty Groups"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 				
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_ARMATURE_ENVELOPE);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "   With Envelope Weights", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("   With Envelope Weights"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 				
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_ARMATURE_AUTO);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "   With Automatic Weights", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("   With Automatic Weights"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 				
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_BONE);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Bone", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Bone"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 			}
 			else if (par->type==OB_CURVE) {
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_CURVE);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Curve Deform", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Curve Deform"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 				
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_FOLLOW);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Follow Path", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Follow Path"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 				
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_PATH_CONST);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Path Constraint", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Path Constraint"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 			}
 			else if (par->type == OB_LATTICE) {
 				WM_operator_properties_create(&ptr, "OUTLINER_OT_parent_drop");
 				RNA_string_set(&ptr, "parent", parname);
 				RNA_string_set(&ptr, "child", childname);
 				RNA_enum_set(&ptr, "type", PAR_LATTICE);
-				uiItemFullO(layout, "OUTLINER_OT_parent_drop", "Lattice Deform", 0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
+				uiItemFullO(layout, "OUTLINER_OT_parent_drop", IFACE_("Lattice Deform"),
+				            0, ptr.data, WM_OP_EXEC_DEFAULT, 0);
 			}
 			
 			uiPupMenuEnd(C, pup);
@@ -1609,18 +1595,18 @@ static int parent_drop_invoke(bContext *C, wmOperator *op, wmEvent *event)
 void OUTLINER_OT_parent_drop(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Drop to Set Parent";
+	ot->name = "Drop to Set Parent";
 	ot->description = "Drag to parent in Outliner";
-	ot->idname= "OUTLINER_OT_parent_drop";
+	ot->idname = "OUTLINER_OT_parent_drop";
 
 	/* api callbacks */
-	ot->invoke= parent_drop_invoke;
-	ot->exec= parent_drop_exec;
+	ot->invoke = parent_drop_invoke;
+	ot->exec = parent_drop_exec;
 
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	RNA_def_string(ot->srna, "child", "Object", MAX_ID_NAME, "Child", "Child Object");
@@ -1687,17 +1673,17 @@ static int parent_clear_invoke(bContext *C, wmOperator *op, wmEvent *UNUSED(even
 void OUTLINER_OT_parent_clear(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Drop to Clear Parent";
+	ot->name = "Drop to Clear Parent";
 	ot->description = "Drag to clear parent in Outliner";
-	ot->idname= "OUTLINER_OT_parent_clear";
+	ot->idname = "OUTLINER_OT_parent_clear";
 
 	/* api callbacks */
-	ot->invoke= parent_clear_invoke;
+	ot->invoke = parent_clear_invoke;
 
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* properties */
 	RNA_def_string(ot->srna, "dragged_obj", "Object", MAX_ID_NAME, "Child", "Child Object");
