@@ -29,8 +29,8 @@
  */
 
 
-#ifndef ED_OUTLINER_INTERN_H
-#define ED_OUTLINER_INTERN_H
+#ifndef __OUTLINER_INTERN_H__
+#define __OUTLINER_INTERN_H__
 
 #include "RNA_types.h"
 
@@ -127,20 +127,20 @@ typedef struct TreeElement {
 
 
 /* Outliner Searching --
-
-   Are we looking for something in the outliner?
-   If so finding matches in child items makes it more useful
-
-	 - We want to flag parents to act as being open to filter child matches 
-	 - and also flag matches so we can highlight them
-	 - Flags are stored in TreeStoreElem->flag
-	 - Flag options defined in DNA_outliner_types.h
-	 - SO_SEARCH_RECURSIVE defined in DNA_space_types.h
-	 
-	 - NOT in datablocks view - searching all datablocks takes way too long 
-		to be useful
-	 - not searching into RNA items helps but isn't the complete solution
-	*/
+ *
+ * Are we looking for something in the outliner?
+ * If so finding matches in child items makes it more useful
+ *
+ * - We want to flag parents to act as being open to filter child matches 
+ * - and also flag matches so we can highlight them
+ * - Flags are stored in TreeStoreElem->flag
+ * - Flag options defined in DNA_outliner_types.h
+ * - SO_SEARCH_RECURSIVE defined in DNA_space_types.h
+ *
+ * - NOT in datablocks view - searching all datablocks takes way too long 
+ *   to be useful
+ * - not searching into RNA items helps but isn't the complete solution
+ */
 
 #define SEARCHING_OUTLINER(sov)   (sov->search_flags & SO_SEARCH_RECURSIVE)
 
@@ -237,4 +237,4 @@ void OUTLINER_OT_action_set(struct wmOperatorType *ot);
 void outliner_operatortypes(void);
 void outliner_keymap(struct wmKeyConfig *keyconf);
 
-#endif /* ED_OUTLINER_INTERN_H */
+#endif /* __OUTLINER_INTERN_H__ */
