@@ -29,54 +29,23 @@
  *  \ingroup spoutliner
  */
 
-#include <math.h>
-#include <string.h>
 #include <stdlib.h>
-#include <stddef.h>
 
 #include "MEM_guardedalloc.h"
 
-#include "DNA_anim_types.h"
 #include "DNA_armature_types.h"
-#include "DNA_constraint_types.h"
-#include "DNA_camera_types.h"
 #include "DNA_group_types.h"
-#include "DNA_key_types.h"
 #include "DNA_lamp_types.h"
 #include "DNA_material_types.h"
-#include "DNA_mesh_types.h"
-#include "DNA_meta_types.h"
-#include "DNA_particle_types.h"
-#include "DNA_scene_types.h"
-#include "DNA_world_types.h"
-#include "DNA_sequence_types.h"
 #include "DNA_object_types.h"
+#include "DNA_scene_types.h"
+#include "DNA_sequence_types.h"
+#include "DNA_world_types.h"
 
-#include "BLI_blenlib.h"
 #include "BLI_utildefines.h"
-#include "BLI_math_base.h"
 
-#if defined WIN32 && !defined _LIBC
-# include "BLI_fnmatch.h" /* use fnmatch included in blenlib */
-#else
-#  ifndef _GNU_SOURCE
-#    define _GNU_SOURCE
-#  endif
-# include <fnmatch.h>
-#endif
-
-
-#include "BKE_animsys.h"
 #include "BKE_context.h"
-#include "BKE_deform.h"
 #include "BKE_depsgraph.h"
-#include "BKE_fcurve.h"
-#include "BKE_global.h"
-#include "BKE_group.h"
-#include "BKE_library.h"
-#include "BKE_main.h"
-#include "BKE_modifier.h"
-#include "BKE_report.h"
 #include "BKE_scene.h"
 #include "BKE_sequencer.h"
 
@@ -88,12 +57,8 @@
 #include "WM_api.h"
 #include "WM_types.h"
 
-#include "BIF_gl.h"
-#include "BIF_glutil.h"
 
 #include "UI_interface.h"
-#include "UI_interface_icons.h"
-#include "UI_resources.h"
 #include "UI_view2d.h"
 
 #include "RNA_access.h"
@@ -159,11 +124,11 @@ static int tree_element_active_renderlayer(bContext *C, TreeElement *te, TreeSto
 	Scene *sce;
 	
 	/* paranoia check */
-	if(te->idcode!=ID_SCE)
+	if (te->idcode!=ID_SCE)
 		return 0;
 	sce= (Scene *)tselem->id;
 	
-	if(set) {
+	if (set) {
 		sce->r.actlay= tselem->nr;
 		WM_event_add_notifier(C, NC_SCENE|ND_RENDER_OPTIONS, sce);
 	}
@@ -181,25 +146,25 @@ static int  tree_element_set_active_object(bContext *C, Scene *scene, SpaceOops
 	Object *ob= NULL;
 	
 	/* if id is not object, we search back */
-	if(te->idcode==ID_OB) ob= (Object *)tselem->id;
+	if (te->idcode==ID_OB) ob= (Object *)tselem->id;
 	else {
 		ob= (Object *)outliner_search_back(soops, te, ID_OB);
-		if(ob==OBACT) return 0;
+		if (ob==OBACT) return 0;
 	}
-	if(ob==NULL) return 0;
+	if (ob==NULL) return 0;
 	
 	sce= (Scene *)outliner_search_back(soops, te, ID_SCE);
-	if(sce && scene != sce) {
-		ED_screen_set_scene(C, sce);
+	if (sce && scene != sce) {
+		ED_screen_set_scene(C, CTX_wm_screen(C), sce);
 	}
 	
 	/* find associated base in current scene */
 	base= object_in_scene(ob, scene);
 
-	if(base) {
-		if(set==2) {
+	if (base) {
+		if (set==2) {
 			/* swap select */
-			if(base->flag & SELECT)
+			if (base->flag & SELECT)
 				ED_base_object_select(base, BA_DESELECT);
 			else 
 				ED_base_object_select(base, BA_SELECT);
@@ -209,13 +174,13 @@ static int  tree_element_set_active_object(bContext *C, Scene *scene, SpaceOops
 			scene_deselect_all(scene);
 			ED_base_object_select(base, BA_SELECT);
 		}
-		if(C) {
+		if (C) {
 			ED_base_object_activate(C, base); /* adds notifier */
 			WM_event_add_notifier(C, NC_SCENE|ND_OB_SELECT, scene);
 		}
 	}
 	
-	if(ob!=scene->obedit) 
+	if (ob!=scene->obedit)
 		ED_object_exit_editmode(C, EM_FREEDATA|EM_FREEUNDO|EM_WAITCURSOR|EM_DO_UNDO);
 		
 	return 1;
@@ -229,32 +194,32 @@ static int tree_element_active_material(bContext *C, Scene *scene, SpaceOops *so
 	/* we search for the object parent */
 	ob= (Object *)outliner_search_back(soops, te, ID_OB);
 	// note: ob->matbits can be NULL when a local object points to a library mesh.
-	if(ob==NULL || ob!=OBACT || ob->matbits==NULL) return 0;	// just paranoia
+	if (ob==NULL || ob!=OBACT || ob->matbits==NULL) return 0;	// just paranoia
 	
 	/* searching in ob mat array? */
 	tes= te->parent;
-	if(tes->idcode==ID_OB) {
-		if(set) {
+	if (tes->idcode==ID_OB) {
+		if (set) {
 			ob->actcol= te->index+1;
 			ob->matbits[te->index]= 1;	// make ob material active too
 		}
 		else {
-			if(ob->actcol == te->index+1) 
-				if(ob->matbits[te->index]) return 1;
+			if (ob->actcol == te->index+1)
+				if (ob->matbits[te->index]) return 1;
 		}
 	}
 	/* or we search for obdata material */
 	else {
-		if(set) {
+		if (set) {
 			ob->actcol= te->index+1;
 			ob->matbits[te->index]= 0;	// make obdata material active too
 		}
 		else {
-			if(ob->actcol == te->index+1)
-				if(ob->matbits[te->index]==0) return 1;
+			if (ob->actcol == te->index+1)
+				if (ob->matbits[te->index]==0) return 1;
 		}
 	}
-	if(set) {
+	if (set) {
 		WM_event_add_notifier(C, NC_MATERIAL|ND_SHADING, NULL);
 	}
 	return 0;
@@ -267,7 +232,7 @@ static int tree_element_active_texture(bContext *C, Scene *scene, SpaceOops *soo
 	Object *ob=OBACT;
 	SpaceButs *sbuts=NULL;
 	
-	if(ob==NULL) return 0; // no active object
+	if (ob==NULL) return 0; // no active object
 	
 	/*tselem= TREESTORE(te);*/ /*UNUSED*/
 	
@@ -278,25 +243,25 @@ static int tree_element_active_texture(bContext *C, Scene *scene, SpaceOops *soo
 	tep= te->parent;
 	tselemp= TREESTORE(tep);
 	
-	if(tep->idcode==ID_WO) {
+	if (tep->idcode==ID_WO) {
 		World *wrld= (World *)tselemp->id;
 
-		if(set) {
-			if(sbuts) {
+		if (set) {
+			if (sbuts) {
 				// XXX sbuts->tabo= TAB_SHADING_TEX;	// hack from header_buttonswin.c
 				// XXX sbuts->texfrom= 1;
 			}
 // XXX			extern_set_butspace(F6KEY, 0);	// force shading buttons texture
 			wrld->texact= te->index;
 		}
-		else if(tselemp->id == (ID *)(scene->world)) {
-			if(wrld->texact==te->index) return 1;
+		else if (tselemp->id == (ID *)(scene->world)) {
+			if (wrld->texact==te->index) return 1;
 		}
 	}
-	else if(tep->idcode==ID_LA) {
+	else if (tep->idcode==ID_LA) {
 		Lamp *la= (Lamp *)tselemp->id;
-		if(set) {
-			if(sbuts) {
+		if (set) {
+			if (sbuts) {
 				// XXX sbuts->tabo= TAB_SHADING_TEX;	// hack from header_buttonswin.c
 				// XXX sbuts->texfrom= 2;
 			}
@@ -304,15 +269,15 @@ static int tree_element_active_texture(bContext *C, Scene *scene, SpaceOops *soo
 			la->texact= te->index;
 		}
 		else {
-			if(tselemp->id == ob->data) {
-				if(la->texact==te->index) return 1;
+			if (tselemp->id == ob->data) {
+				if (la->texact==te->index) return 1;
 			}
 		}
 	}
-	else if(tep->idcode==ID_MA) {
+	else if (tep->idcode==ID_MA) {
 		Material *ma= (Material *)tselemp->id;
-		if(set) {
-			if(sbuts) {
+		if (set) {
+			if (sbuts) {
 				//sbuts->tabo= TAB_SHADING_TEX;	// hack from header_buttonswin.c
 				// XXX sbuts->texfrom= 0;
 			}
@@ -322,12 +287,12 @@ static int tree_element_active_texture(bContext *C, Scene *scene, SpaceOops *soo
 			/* also set active material */
 			ob->actcol= tep->index+1;
 		}
-		else if(tep->flag & TE_ACTIVE) {	// this is active material
-			if(ma->texact==te->index) return 1;
+		else if (tep->flag & TE_ACTIVE) {	// this is active material
+			if (ma->texact==te->index) return 1;
 		}
 	}
 	
-	if(set)
+	if (set)
 		WM_event_add_notifier(C, NC_TEXTURE, NULL);
 
 	return 0;
@@ -340,9 +305,9 @@ static int tree_element_active_lamp(bContext *UNUSED(C), Scene *scene, SpaceOops
 	
 	/* we search for the object parent */
 	ob= (Object *)outliner_search_back(soops, te, ID_OB);
-	if(ob==NULL || ob!=OBACT) return 0;	// just paranoia
+	if (ob==NULL || ob!=OBACT) return 0;	// just paranoia
 	
-	if(set) {
+	if (set) {
 // XXX		extern_set_butspace(F5KEY, 0);
 	}
 	else return 1;
@@ -354,7 +319,7 @@ static int tree_element_active_camera(bContext *UNUSED(C), Scene *scene, SpaceOo
 {
 	Object *ob= (Object *)outliner_search_back(soops, te, ID_OB);
 
-	if(set)
+	if (set)
 		return 0;
 
 	return scene->camera == ob;
@@ -367,19 +332,19 @@ static int tree_element_active_world(bContext *C, Scene *scene, SpaceOops *soops
 	Scene *sce=NULL;
 	
 	tep= te->parent;
-	if(tep) {
+	if (tep) {
 		tselem= TREESTORE(tep);
 		sce= (Scene *)tselem->id;
 	}
 	
-	if(set) {	// make new scene active
-		if(sce && scene != sce) {
-			ED_screen_set_scene(C, sce);
+	if (set) {	// make new scene active
+		if (sce && scene != sce) {
+			ED_screen_set_scene(C, CTX_wm_screen(C), sce);
 		}
 	}
 	
-	if(tep==NULL || tselem->id == (ID *)scene) {
-		if(set) {
+	if (tep==NULL || tselem->id == (ID *)scene) {
+		if (set) {
 // XXX			extern_set_butspace(F8KEY, 0);
 		}
 		else {
@@ -395,7 +360,7 @@ static int tree_element_active_defgroup(bContext *C, Scene *scene, TreeElement *
 	
 	/* id in tselem is object */
 	ob= (Object *)tselem->id;
-	if(set) {
+	if (set) {
 		BLI_assert(te->index+1 >= 0);
 		ob->actdef= te->index+1;
 
@@ -403,8 +368,8 @@ static int tree_element_active_defgroup(bContext *C, Scene *scene, TreeElement *
 		WM_event_add_notifier(C, NC_OBJECT|ND_TRANSFORM, ob);
 	}
 	else {
-		if(ob==OBACT)
-			if(ob->actdef== te->index+1) return 1;
+		if (ob==OBACT)
+			if (ob->actdef== te->index+1) return 1;
 	}
 	return 0;
 }
@@ -413,14 +378,14 @@ static int tree_element_active_posegroup(bContext *C, Scene *scene, TreeElement
 {
 	Object *ob= (Object *)tselem->id;
 	
-	if(set) {
+	if (set) {
 		if (ob->pose) {
 			ob->pose->active_group= te->index+1;
 			WM_event_add_notifier(C, NC_OBJECT|ND_DRAW, ob);
 		}
 	}
 	else {
-		if(ob==OBACT && ob->pose) {
+		if (ob==OBACT && ob->pose) {
 			if (ob->pose->active_group== te->index+1) return 1;
 		}
 	}
@@ -433,15 +398,16 @@ static int tree_element_active_posechannel(bContext *C, Scene *scene, TreeElemen
 	bArmature *arm= ob->data;
 	bPoseChannel *pchan= te->directdata;
 	
-	if(set) {
-		if(!(pchan->bone->flag & BONE_HIDDEN_P)) {
+	if (set) {
+		if (!(pchan->bone->flag & BONE_HIDDEN_P)) {
 			
-			if(set==2) ED_pose_deselectall(ob, 2);	// 2 = clear active tag
+			if (set==2) ED_pose_deselectall(ob, 2);	// 2 = clear active tag
 			else ED_pose_deselectall(ob, 0);	// 0 = deselect 
 			
-			if(set==2 && (pchan->bone->flag & BONE_SELECTED)) {
+			if (set==2 && (pchan->bone->flag & BONE_SELECTED)) {
 				pchan->bone->flag &= ~BONE_SELECTED;
-			} else {
+			}
+			else {
 				pchan->bone->flag |= BONE_SELECTED;
 				arm->act_bone= pchan->bone;
 			}
@@ -451,7 +417,7 @@ static int tree_element_active_posechannel(bContext *C, Scene *scene, TreeElemen
 		}
 	}
 	else {
-		if(ob==OBACT && ob->pose) {
+		if (ob==OBACT && ob->pose) {
 			if (pchan->bone->flag & BONE_SELECTED) return 1;
 		}
 	}
@@ -463,14 +429,15 @@ static int tree_element_active_bone(bContext *C, Scene *scene, TreeElement *te,
 	bArmature *arm= (bArmature *)tselem->id;
 	Bone *bone= te->directdata;
 	
-	if(set) {
-		if(!(bone->flag & BONE_HIDDEN_P)) {
-			if(set==2) ED_pose_deselectall(OBACT, 2);	// 2 is clear active tag
+	if (set) {
+		if (!(bone->flag & BONE_HIDDEN_P)) {
+			if (set==2) ED_pose_deselectall(OBACT, 2);	// 2 is clear active tag
 			else ED_pose_deselectall(OBACT, 0);
 			
-			if(set==2 && (bone->flag & BONE_SELECTED)) {
+			if (set==2 && (bone->flag & BONE_SELECTED)) {
 				bone->flag &= ~BONE_SELECTED;
-			} else {
+			}
+			else {
 				bone->flag |= BONE_SELECTED;
 				arm->act_bone= bone;
 			}
@@ -481,7 +448,7 @@ static int tree_element_active_bone(bContext *C, Scene *scene, TreeElement *te,
 	else {
 		Object *ob= OBACT;
 		
-		if(ob && ob->data==arm) {
+		if (ob && ob->data==arm) {
 			if (bone->flag & BONE_SELECTED) return 1;
 		}
 	}
@@ -492,16 +459,16 @@ static int tree_element_active_bone(bContext *C, Scene *scene, TreeElement *te,
 /* ebones only draw in editmode armature */
 static void tree_element_active_ebone__sel(bContext *C, Scene *scene, bArmature *arm, EditBone *ebone, short sel)
 {
-	if(sel) {
+	if (sel) {
 		ebone->flag |= BONE_SELECTED|BONE_ROOTSEL|BONE_TIPSEL;
 		arm->act_edbone= ebone;
 		// flush to parent?
-		if(ebone->parent && (ebone->flag & BONE_CONNECTED)) ebone->parent->flag |= BONE_TIPSEL;
+		if (ebone->parent && (ebone->flag & BONE_CONNECTED)) ebone->parent->flag |= BONE_TIPSEL;
 	}
 	else {
 		ebone->flag &= ~(BONE_SELECTED|BONE_ROOTSEL|BONE_TIPSEL);
 		// flush to parent?
-		if(ebone->parent && (ebone->flag & BONE_CONNECTED)) ebone->parent->flag &= ~BONE_TIPSEL;
+		if (ebone->parent && (ebone->flag & BONE_CONNECTED)) ebone->parent->flag &= ~BONE_TIPSEL;
 	}
 
 	WM_event_add_notifier(C, NC_OBJECT|ND_BONE_ACTIVE, scene->obedit);
@@ -511,16 +478,16 @@ static int tree_element_active_ebone(bContext *C, Scene *scene, TreeElement *te,
 	bArmature *arm= scene->obedit->data;
 	EditBone *ebone= te->directdata;
 
-	if(set==1) {
-		if(!(ebone->flag & BONE_HIDDEN_A)) {
+	if (set==1) {
+		if (!(ebone->flag & BONE_HIDDEN_A)) {
 			ED_armature_deselect_all(scene->obedit, 0);	// deselect
 			tree_element_active_ebone__sel(C, scene, arm, ebone, TRUE);
 			return 1;
 		}
 	}
 	else if (set==2) {
-		if(!(ebone->flag & BONE_HIDDEN_A)) {
-			if(!(ebone->flag & BONE_SELECTED)) {
+		if (!(ebone->flag & BONE_HIDDEN_A)) {
+			if (!(ebone->flag & BONE_SELECTED)) {
 				tree_element_active_ebone__sel(C, scene, arm, ebone, TRUE);
 				return 1;
 			}
@@ -539,7 +506,7 @@ static int tree_element_active_ebone(bContext *C, Scene *scene, TreeElement *te,
 
 static int tree_element_active_modifier(bContext *C, TreeElement *UNUSED(te), TreeStoreElem *tselem, int set)
 {
-	if(set) {
+	if (set) {
 		Object *ob= (Object *)tselem->id;
 		
 		WM_event_add_notifier(C, NC_OBJECT|ND_MODIFIER, ob);
@@ -552,7 +519,7 @@ static int tree_element_active_modifier(bContext *C, TreeElement *UNUSED(te), Tr
 
 static int tree_element_active_psys(bContext *C, Scene *UNUSED(scene), TreeElement *UNUSED(te), TreeStoreElem *tselem, int set)
 {
-	if(set) {
+	if (set) {
 		Object *ob= (Object *)tselem->id;
 		
 		WM_event_add_notifier(C, NC_OBJECT|ND_PARTICLE|NA_EDITED, ob);
@@ -565,7 +532,7 @@ static int tree_element_active_psys(bContext *C, Scene *UNUSED(scene), TreeEleme
 
 static int tree_element_active_constraint(bContext *C, TreeElement *UNUSED(te), TreeStoreElem *tselem, int set)
 {
-	if(set) {
+	if (set) {
 		Object *ob= (Object *)tselem->id;
 		
 		WM_event_add_notifier(C, NC_OBJECT|ND_CONSTRAINT, ob);
@@ -586,17 +553,17 @@ static int tree_element_active_pose(bContext *C, Scene *scene, TreeElement *UNUS
 	Object *ob= (Object *)tselem->id;
 	Base *base= object_in_scene(ob, scene);
 	
-	if(set) {
-		if(scene->obedit) 
+	if (set) {
+		if (scene->obedit)
 			ED_object_exit_editmode(C, EM_FREEDATA|EM_FREEUNDO|EM_WAITCURSOR|EM_DO_UNDO);
 		
-		if(ob->mode & OB_MODE_POSE) 
+		if (ob->mode & OB_MODE_POSE)
 			ED_armature_exit_posemode(C, base);
 		else 
 			ED_armature_enter_posemode(C, base);
 	}
 	else {
-		if(ob->mode & OB_MODE_POSE) return 1;
+		if (ob->mode & OB_MODE_POSE) return 1;
 	}
 	return 0;
 }
@@ -605,11 +572,11 @@ static int tree_element_active_sequence(TreeElement *te, TreeStoreElem *UNUSED(t
 {
 	Sequence *seq= (Sequence*) te->directdata;
 
-	if(set) {
+	if (set) {
 // XXX		select_single_seq(seq, 1);
 	}
 	else {
-		if(seq->flag & SELECT)
+		if (seq->flag & SELECT)
 			return(1);
 	}
 	return(0);
@@ -621,21 +588,21 @@ static int tree_element_active_sequence_dup(Scene *scene, TreeElement *te, TreeS
 	Editing *ed= seq_give_editing(scene, FALSE);
 
 	seq= (Sequence*)te->directdata;
-	if(set==0) {
-		if(seq->flag & SELECT)
+	if (set==0) {
+		if (seq->flag & SELECT)
 			return(1);
 		return(0);
 	}
 
 // XXX	select_single_seq(seq, 1);
 	p= ed->seqbasep->first;
-	while(p) {
-		if((!p->strip) || (!p->strip->stripdata) || (!p->strip->stripdata->name)) {
+	while (p) {
+		if ((!p->strip) || (!p->strip->stripdata) || (!p->strip->stripdata->name)) {
 			p= p->next;
 			continue;
 		}
 
-//		if(!strcmp(p->strip->stripdata->name, seq->strip->stripdata->name))
+//		if (!strcmp(p->strip->stripdata->name, seq->strip->stripdata->name))
 // XXX			select_single_seq(p, 0);
 		p= p->next;
 	}
@@ -644,10 +611,10 @@ static int tree_element_active_sequence_dup(Scene *scene, TreeElement *te, TreeS
 
 static int tree_element_active_keymap_item(bContext *UNUSED(C), TreeElement *te, TreeStoreElem *UNUSED(tselem), int set)
 {
-	wmKeyMapItem *kmi= te->directdata;
+	wmKeyMapItem *kmi = te->directdata;
 	
-	if(set==0) {
-		if(kmi->flag & KMI_INACTIVE) return 0;
+	if (set==0) {
+		if (kmi->flag & KMI_INACTIVE) return 0;
 		return 1;
 	}
 	else {
@@ -664,7 +631,7 @@ int tree_element_active(bContext *C, Scene *scene, SpaceOops *soops, TreeElement
 
 	switch(te->idcode) {
 		/* Note: no ID_OB: objects are handled specially to allow multiple
-		   selection. See do_outliner_item_activate. */
+		 * selection. See do_outliner_item_activate. */
 		case ID_MA:
 			return tree_element_active_material(C, scene, soops, te, set);
 		case ID_WO:
@@ -695,8 +662,8 @@ int tree_element_type_active(bContext *C, Scene *scene, SpaceOops *soops, TreeEl
 		case TSE_MODIFIER:
 			return tree_element_active_modifier(C, te, tselem, set);
 		case TSE_LINKED_OB:
-			if(set) tree_element_set_active_object(C, scene, soops, te, set);
-			else if(tselem->id==(ID *)OBACT) return 1;
+			if (set) tree_element_set_active_object(C, scene, soops, te, set);
+			else if (tselem->id==(ID *)OBACT) return 1;
 			break;
 		case TSE_LINKED_PSYS:
 			return tree_element_active_psys(C, scene, te, tselem, set);
@@ -726,24 +693,24 @@ int tree_element_type_active(bContext *C, Scene *scene, SpaceOops *soops, TreeEl
 static int do_outliner_item_activate(bContext *C, Scene *scene, ARegion *ar, SpaceOops *soops, TreeElement *te, int extend, const float mval[2])
 {
 	
-	if(mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
+	if (mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
 		TreeStoreElem *tselem= TREESTORE(te);
 		int openclose= 0;
 		
 		/* open close icon */
-		if((te->flag & TE_ICONROW)==0) {				// hidden icon, no open/close
-			if( mval[0]>te->xs && mval[0]<te->xs+UI_UNIT_X) 
+		if ((te->flag & TE_ICONROW)==0) {				// hidden icon, no open/close
+			if ( mval[0]>te->xs && mval[0]<te->xs+UI_UNIT_X)
 				openclose= 1;
 		}
 		
-		if(openclose) {
+		if (openclose) {
 			/* all below close/open? */
-			if(extend) {
+			if (extend) {
 				tselem->flag &= ~TSE_CLOSED;
 				outliner_set_flag(soops, &te->subtree, TSE_CLOSED, !outliner_has_one_flag(soops, &te->subtree, TSE_CLOSED, 1));
 			}
 			else {
-				if(tselem->flag & TSE_CLOSED) tselem->flag &= ~TSE_CLOSED;
+				if (tselem->flag & TSE_CLOSED) tselem->flag &= ~TSE_CLOSED;
 				else tselem->flag |= TSE_CLOSED;
 				
 			}
@@ -751,50 +718,51 @@ static int do_outliner_item_activate(bContext *C, Scene *scene, ARegion *ar, Spa
 			return 1;
 		}
 		/* name and first icon */
-		else if(mval[0]>te->xs+UI_UNIT_X && mval[0]<te->xend) {
+		else if (mval[0]>te->xs+UI_UNIT_X && mval[0]<te->xend) {
 			
 			/* always makes active object */
-			if(tselem->type!=TSE_SEQUENCE && tselem->type!=TSE_SEQ_STRIP && tselem->type!=TSE_SEQUENCE_DUP)
+			if (tselem->type!=TSE_SEQUENCE && tselem->type!=TSE_SEQ_STRIP && tselem->type!=TSE_SEQUENCE_DUP)
 				tree_element_set_active_object(C, scene, soops, te, 1 + (extend!=0 && tselem->type==0));
 			
-			if(tselem->type==0) { // the lib blocks
+			if (tselem->type==0) { // the lib blocks
 				/* editmode? */
-				if(te->idcode==ID_SCE) {
-					if(scene!=(Scene *)tselem->id) {
-						ED_screen_set_scene(C, (Scene *)tselem->id);
+				if (te->idcode==ID_SCE) {
+					if (scene!=(Scene *)tselem->id) {
+						ED_screen_set_scene(C, CTX_wm_screen(C), (Scene *)tselem->id);
 					}
 				}
-				else if(te->idcode==ID_GR) {
+				else if (te->idcode==ID_GR) {
 					Group *gr= (Group *)tselem->id;
 					GroupObject *gob;
 					
-					if(extend) {
+					if (extend) {
 						int sel= BA_SELECT;
-						for(gob= gr->gobject.first; gob; gob= gob->next) {
-							if(gob->ob->flag & SELECT) {
+						for (gob= gr->gobject.first; gob; gob= gob->next) {
+							if (gob->ob->flag & SELECT) {
 								sel= BA_DESELECT;
 								break;
 							}
 						}
 						
-						for(gob= gr->gobject.first; gob; gob= gob->next) {
+						for (gob= gr->gobject.first; gob; gob= gob->next) {
 							ED_base_object_select(object_in_scene(gob->ob, scene), sel);
 						}
 					}
 					else {
 						scene_deselect_all(scene);
 						
-						for(gob= gr->gobject.first; gob; gob= gob->next) {
-							if((gob->ob->flag & SELECT) == 0)
+						for (gob= gr->gobject.first; gob; gob= gob->next) {
+							if ((gob->ob->flag & SELECT) == 0)
 								ED_base_object_select(object_in_scene(gob->ob, scene), BA_SELECT);
 						}
 					}
 					
 					WM_event_add_notifier(C, NC_SCENE|ND_OB_SELECT, scene);
 				}
-				else if(ELEM5(te->idcode, ID_ME, ID_CU, ID_MB, ID_LT, ID_AR)) {
+				else if (ELEM5(te->idcode, ID_ME, ID_CU, ID_MB, ID_LT, ID_AR)) {
 					WM_operator_name_call(C, "OBJECT_OT_editmode_toggle", WM_OP_INVOKE_REGION_WIN, NULL);
-				} else {	// rest of types
+				}
+				else {	// rest of types
 					tree_element_active(C, scene, soops, te, 1);
 				}
 				
@@ -805,8 +773,8 @@ static int do_outliner_item_activate(bContext *C, Scene *scene, ARegion *ar, Spa
 		}
 	}
 	
-	for(te= te->subtree.first; te; te= te->next) {
-		if(do_outliner_item_activate(C, scene, ar, soops, te, extend, mval)) return 1;
+	for (te= te->subtree.first; te; te= te->next) {
+		if (do_outliner_item_activate(C, scene, ar, soops, te, extend, mval)) return 1;
 	}
 	return 0;
 }
@@ -830,11 +798,11 @@ static int outliner_item_activate(bContext *C, wmOperator *op, wmEvent *event)
 		return OPERATOR_CANCELLED;
 	}
 
-	for(te= soops->tree.first; te; te= te->next) {
-		if(do_outliner_item_activate(C, scene, ar, soops, te, extend, fmval)) break;
+	for (te= soops->tree.first; te; te= te->next) {
+		if (do_outliner_item_activate(C, scene, ar, soops, te, extend, fmval)) break;
 	}
 	
-	if(te) {
+	if (te) {
 		ED_undo_push(C, "Outliner click event");
 	}
 	else {
@@ -846,7 +814,7 @@ static int outliner_item_activate(bContext *C, wmOperator *op, wmEvent *event)
 						fmval[0], fmval[1], NULL, &row);
 		
 		/* select relevant row */
-		if(outliner_select(soops, &soops->tree, &row, &selecting)) {
+		if (outliner_select(soops, &soops->tree, &row, &selecting)) {
 		
 			soops->storeflag |= SO_TREESTORE_REDRAW;
 		
@@ -863,13 +831,13 @@ static int outliner_item_activate(bContext *C, wmOperator *op, wmEvent *event)
 
 void OUTLINER_OT_item_activate(wmOperatorType *ot)
 {
-	ot->name= "Activate Item";
-	ot->idname= "OUTLINER_OT_item_activate";
-	ot->description= "Handle mouse clicks to activate/select items";
+	ot->name = "Activate Item";
+	ot->idname = "OUTLINER_OT_item_activate";
+	ot->description = "Handle mouse clicks to activate/select items";
 	
-	ot->invoke= outliner_item_activate;
+	ot->invoke = outliner_item_activate;
 	
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 	
 	RNA_def_boolean(ot->srna, "extend", 1, "Extend", "Extend selection for activation");
 }
@@ -909,15 +877,15 @@ static int outliner_border_select_exec(bContext *C, wmOperator *op)
 	rctf rectf;
 	int gesture_mode= RNA_int_get(op->ptr, "gesture_mode");
 
-	rect.xmin= RNA_int_get(op->ptr, "xmin");
-	rect.ymin= RNA_int_get(op->ptr, "ymin");
+	rect.xmin = RNA_int_get(op->ptr, "xmin");
+	rect.ymin = RNA_int_get(op->ptr, "ymin");
 	UI_view2d_region_to_view(&ar->v2d, rect.xmin, rect.ymin, &rectf.xmin, &rectf.ymin);
 
-	rect.xmax= RNA_int_get(op->ptr, "xmax");
-	rect.ymax= RNA_int_get(op->ptr, "ymax");
+	rect.xmax = RNA_int_get(op->ptr, "xmax");
+	rect.ymax = RNA_int_get(op->ptr, "ymax");
 	UI_view2d_region_to_view(&ar->v2d, rect.xmax, rect.ymax, &rectf.xmax, &rectf.ymax);
 
-	for(te= soops->tree.first; te; te= te->next) {
+	for (te= soops->tree.first; te; te= te->next) {
 		outliner_item_border_select(scene, soops, &rectf, te, gesture_mode);
 	}
 
@@ -930,20 +898,20 @@ static int outliner_border_select_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_select_border(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Border Select";
-	ot->idname= "OUTLINER_OT_select_border";
-	ot->description= "Use box selection to select tree elements";
+	ot->name = "Border Select";
+	ot->idname = "OUTLINER_OT_select_border";
+	ot->description = "Use box selection to select tree elements";
 
 	/* api callbacks */
-	ot->invoke= WM_border_select_invoke;
-	ot->exec= outliner_border_select_exec;
-	ot->modal= WM_border_select_modal;
-	ot->cancel= WM_border_select_cancel;
+	ot->invoke = WM_border_select_invoke;
+	ot->exec = outliner_border_select_exec;
+	ot->modal = WM_border_select_modal;
+	ot->cancel = WM_border_select_cancel;
 
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 
 	/* flags */
-	ot->flag= OPTYPE_REGISTER|OPTYPE_UNDO;
+	ot->flag = OPTYPE_REGISTER|OPTYPE_UNDO;
 
 	/* rna */
 	WM_operator_properties_gesture_border(ot, FALSE);
