@@ -29,56 +29,31 @@
  *  \ingroup spoutliner
  */
 
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
-#include <stddef.h>
-
 #include "MEM_guardedalloc.h"
 
 #include "DNA_anim_types.h"
 #include "DNA_armature_types.h"
-#include "DNA_constraint_types.h"
-#include "DNA_camera_types.h"
 #include "DNA_group_types.h"
-#include "DNA_key_types.h"
 #include "DNA_lamp_types.h"
 #include "DNA_material_types.h"
 #include "DNA_mesh_types.h"
 #include "DNA_meta_types.h"
-#include "DNA_particle_types.h"
 #include "DNA_scene_types.h"
 #include "DNA_world_types.h"
-#include "DNA_sequence_types.h"
 #include "DNA_object_types.h"
 
 #include "BLI_blenlib.h"
 #include "BLI_utildefines.h"
-#include "BLI_math_base.h"
-
-#if defined WIN32 && !defined _LIBC
-# include "BLI_fnmatch.h" /* use fnmatch included in blenlib */
-#else
-#  ifndef _GNU_SOURCE
-#    define _GNU_SOURCE
-#  endif
-# include <fnmatch.h>
-#endif
-
 
 #include "BKE_animsys.h"
 #include "BKE_context.h"
-#include "BKE_deform.h"
 #include "BKE_depsgraph.h"
 #include "BKE_fcurve.h"
-#include "BKE_global.h"
 #include "BKE_group.h"
 #include "BKE_library.h"
 #include "BKE_main.h"
-#include "BKE_modifier.h"
 #include "BKE_report.h"
 #include "BKE_scene.h"
-#include "BKE_sequencer.h"
 
 #include "ED_armature.h"
 #include "ED_object.h"
@@ -88,12 +63,7 @@
 #include "WM_api.h"
 #include "WM_types.h"
 
-#include "BIF_gl.h"
-#include "BIF_glutil.h"
-
 #include "UI_interface.h"
-#include "UI_interface_icons.h"
-#include "UI_resources.h"
 #include "UI_view2d.h"
 
 #include "RNA_access.h"
@@ -115,13 +85,13 @@ static void set_operation_types(SpaceOops *soops, ListBase *lb,
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te= lb->first; te; te= te->next) {
+	for (te= lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(tselem->flag & TSE_SELECTED) {
-			if(tselem->type) {
-				if(*datalevel==0) 
+		if (tselem->flag & TSE_SELECTED) {
+			if (tselem->type) {
+				if (*datalevel==0)
 					*datalevel= tselem->type;
-				else if(*datalevel!=tselem->type) 
+				else if (*datalevel!=tselem->type)
 					*datalevel= -1;
 			}
 			else {
@@ -139,13 +109,13 @@ static void set_operation_types(SpaceOops *soops, ListBase *lb,
 					case ID_MA: case ID_TE: case ID_IP: case ID_IM:
 					case ID_SO: case ID_KE: case ID_WO: case ID_AC:
 					case ID_NLA: case ID_TXT: case ID_GR:
-						if(*idlevel==0) *idlevel= idcode;
-						else if(*idlevel!=idcode) *idlevel= -1;
+						if (*idlevel==0) *idlevel= idcode;
+						else if (*idlevel!=idcode) *idlevel= -1;
 							break;
 				}
 			}
 		}
-		if(TSELEM_OPEN(tselem,soops)) {
+		if (TSELEM_OPEN(tselem,soops)) {
 			set_operation_types(soops, &te->subtree,
 								scenelevel, objectlevel, idlevel, datalevel);
 		}
@@ -163,29 +133,29 @@ static void unlink_material_cb(bContext *UNUSED(C), Scene *UNUSED(scene), TreeEl
 	Material **matar=NULL;
 	int a, totcol=0;
 	
-	if( GS(tsep->id->name)==ID_OB) {
+	if ( GS(tsep->id->name)==ID_OB) {
 		Object *ob= (Object *)tsep->id;
 		totcol= ob->totcol;
 		matar= ob->mat;
 	}
-	else if( GS(tsep->id->name)==ID_ME) {
+	else if ( GS(tsep->id->name)==ID_ME) {
 		Mesh *me= (Mesh *)tsep->id;
 		totcol= me->totcol;
 		matar= me->mat;
 	}
-	else if( GS(tsep->id->name)==ID_CU) {
+	else if ( GS(tsep->id->name)==ID_CU) {
 		Curve *cu= (Curve *)tsep->id;
 		totcol= cu->totcol;
 		matar= cu->mat;
 	}
-	else if( GS(tsep->id->name)==ID_MB) {
+	else if ( GS(tsep->id->name)==ID_MB) {
 		MetaBall *mb= (MetaBall *)tsep->id;
 		totcol= mb->totcol;
 		matar= mb->mat;
 	}
 
-	for(a=0; a<totcol; a++) {
-		if(a==te->index && matar[a]) {
+	for (a=0; a<totcol; a++) {
+		if (a==te->index && matar[a]) {
 			matar[a]->id.us--;
 			matar[a]= NULL;
 		}
@@ -197,23 +167,23 @@ static void unlink_texture_cb(bContext *UNUSED(C), Scene *UNUSED(scene), TreeEle
 	MTex **mtex= NULL;
 	int a;
 	
-	if( GS(tsep->id->name)==ID_MA) {
+	if ( GS(tsep->id->name)==ID_MA) {
 		Material *ma= (Material *)tsep->id;
 		mtex= ma->mtex;
 	}
-	else if( GS(tsep->id->name)==ID_LA) {
+	else if ( GS(tsep->id->name)==ID_LA) {
 		Lamp *la= (Lamp *)tsep->id;
 		mtex= la->mtex;
 	}
-	else if( GS(tsep->id->name)==ID_WO) {
+	else if ( GS(tsep->id->name)==ID_WO) {
 		World *wrld= (World *)tsep->id;
 		mtex= wrld->mtex;
 	}
 	else return;
 	
-	for(a=0; a<MAX_MTEX; a++) {
-		if(a==te->index && mtex[a]) {
-			if(mtex[a]->tex) {
+	for (a=0; a<MAX_MTEX; a++) {
+		if (a==te->index && mtex[a]) {
+			if (mtex[a]->tex) {
 				mtex[a]->tex->id.us--;
 				mtex[a]->tex= NULL;
 			}
@@ -225,8 +195,8 @@ static void unlink_group_cb(bContext *UNUSED(C), Scene *UNUSED(scene), TreeEleme
 {
 	Group *group= (Group *)tselem->id;
 	
-	if(tsep) {
-		if( GS(tsep->id->name)==ID_OB) {
+	if (tsep) {
+		if ( GS(tsep->id->name)==ID_OB) {
 			Object *ob= (Object *)tsep->id;
 			ob->dup_group= NULL;
 		}
@@ -252,15 +222,15 @@ static void outliner_do_libdata_operation(bContext *C, Scene *scene, SpaceOops *
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te=lb->first; te; te= te->next) {
+	for (te=lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(tselem->flag & TSE_SELECTED) {
-			if(tselem->type==0) {
+		if (tselem->flag & TSE_SELECTED) {
+			if (tselem->type==0) {
 				TreeStoreElem *tsep= TREESTORE(te->parent);
 				operation_cb(C, scene, te, tsep, tselem);
 			}
 		}
-		if(TSELEM_OPEN(tselem,soops)) {
+		if (TSELEM_OPEN(tselem,soops)) {
 			outliner_do_libdata_operation(C, scene, soops, &te->subtree, operation_cb);
 		}
 	}
@@ -272,8 +242,8 @@ static void object_select_cb(bContext *UNUSED(C), Scene *scene, TreeElement *te,
 {
 	Base *base= (Base *)te->directdata;
 	
-	if(base==NULL) base= object_in_scene((Object *)tselem->id, scene);
-	if(base && ((base->object->restrictflag & OB_RESTRICT_VIEW)==0)) {
+	if (base==NULL) base= object_in_scene((Object *)tselem->id, scene);
+	if (base && ((base->object->restrictflag & OB_RESTRICT_VIEW)==0)) {
 		base->flag |= SELECT;
 		base->object->flag |= SELECT;
 	}
@@ -283,8 +253,8 @@ static void object_deselect_cb(bContext *UNUSED(C), Scene *scene, TreeElement *t
 {
 	Base *base= (Base *)te->directdata;
 	
-	if(base==NULL) base= object_in_scene((Object *)tselem->id, scene);
-	if(base) {
+	if (base==NULL) base= object_in_scene((Object *)tselem->id, scene);
+	if (base) {
 		base->flag &= ~SELECT;
 		base->object->flag &= ~SELECT;
 	}
@@ -294,11 +264,11 @@ static void object_delete_cb(bContext *C, Scene *scene, TreeElement *te, TreeSto
 {
 	Base *base= (Base *)te->directdata;
 	
-	if(base==NULL) 
+	if (base==NULL)
 		base= object_in_scene((Object *)tselem->id, scene);
-	if(base) {
+	if (base) {
 		// check also library later
-		if(scene->obedit==base->object) 
+		if (scene->obedit==base->object)
 			ED_object_exit_editmode(C, EM_FREEDATA|EM_FREEUNDO|EM_WAITCURSOR|EM_DO_UNDO);
 		
 		ED_base_object_free_and_unlink(CTX_data_main(C), scene, base);
@@ -378,12 +348,13 @@ static void group_linkobs2scene_cb(bContext *UNUSED(C), Scene *scene, TreeElemen
 	GroupObject *gob;
 	Base *base;
 	
-	for(gob=group->gobject.first; gob; gob=gob->next) {
+	for (gob=group->gobject.first; gob; gob=gob->next) {
 		base= object_in_scene(gob->ob, scene);
 		if (base) {
 			base->object->flag |= SELECT;
 			base->flag |= SELECT;
-		} else {
+		}
+		else {
 			/* link to scene */
 			base= MEM_callocN( sizeof(Base), "add_base");
 			BLI_addhead(&scene->base, base);
@@ -391,7 +362,7 @@ static void group_linkobs2scene_cb(bContext *UNUSED(C), Scene *scene, TreeElemen
 			gob->ob->flag |= SELECT;
 			base->flag = gob->ob->flag;
 			base->object= gob->ob;
-			id_lib_extern((ID *)gob->ob); /* incase these are from a linked group */
+			id_lib_extern((ID *)gob->ob); /* in case these are from a linked group */
 		}
 	}
 }
@@ -402,22 +373,22 @@ void outliner_do_object_operation(bContext *C, Scene *scene_act, SpaceOops *soop
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te=lb->first; te; te= te->next) {
+	for (te=lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(tselem->flag & TSE_SELECTED) {
-			if(tselem->type==0 && te->idcode==ID_OB) {
+		if (tselem->flag & TSE_SELECTED) {
+			if (tselem->type==0 && te->idcode==ID_OB) {
 				// when objects selected in other scenes... dunno if that should be allowed
 				Scene *scene_owner= (Scene *)outliner_search_back(soops, te, ID_SCE);
-				if(scene_owner && scene_act != scene_owner) {
-					ED_screen_set_scene(C, scene_owner);
+				if (scene_owner && scene_act != scene_owner) {
+					ED_screen_set_scene(C, CTX_wm_screen(C), scene_owner);
 				}
 				/* important to use 'scene_owner' not scene_act else deleting objects can crash.
 				 * only use 'scene_act' when 'scene_owner' is NULL, which can happen when the
-				 * outliner isnt showing scenes: Visible Layer draw mode for eg. */
+				 * outliner isn't showing scenes: Visible Layer draw mode for eg. */
 				operation_cb(C, scene_owner ? scene_owner : scene_act, te, NULL, tselem);
 			}
 		}
-		if(TSELEM_OPEN(tselem,soops)) {
+		if (TSELEM_OPEN(tselem,soops)) {
 			outliner_do_object_operation(C, scene_act, soops, &te->subtree, operation_cb);
 		}
 	}
@@ -459,15 +430,15 @@ static void pchan_cb(int event, TreeElement *te, TreeStoreElem *UNUSED(tselem))
 {
 	bPoseChannel *pchan= (bPoseChannel *)te->directdata;
 	
-	if(event==1)
+	if (event==1)
 		pchan->bone->flag |= BONE_SELECTED;
-	else if(event==2)
+	else if (event==2)
 		pchan->bone->flag &= ~BONE_SELECTED;
-	else if(event==3) {
+	else if (event==3) {
 		pchan->bone->flag |= BONE_HIDDEN_P;
 		pchan->bone->flag &= ~BONE_SELECTED;
 	}
-	else if(event==4)
+	else if (event==4)
 		pchan->bone->flag &= ~BONE_HIDDEN_P;
 }
 
@@ -475,15 +446,15 @@ static void bone_cb(int event, TreeElement *te, TreeStoreElem *UNUSED(tselem))
 {
 	Bone *bone= (Bone *)te->directdata;
 	
-	if(event==1)
+	if (event==1)
 		bone->flag |= BONE_SELECTED;
-	else if(event==2)
+	else if (event==2)
 		bone->flag &= ~BONE_SELECTED;
-	else if(event==3) {
+	else if (event==3) {
 		bone->flag |= BONE_HIDDEN_P;
 		bone->flag &= ~BONE_SELECTED;
 	}
-	else if(event==4)
+	else if (event==4)
 		bone->flag &= ~BONE_HIDDEN_P;
 }
 
@@ -491,22 +462,22 @@ static void ebone_cb(int event, TreeElement *te, TreeStoreElem *UNUSED(tselem))
 {
 	EditBone *ebone= (EditBone *)te->directdata;
 	
-	if(event==1)
+	if (event==1)
 		ebone->flag |= BONE_SELECTED;
-	else if(event==2)
+	else if (event==2)
 		ebone->flag &= ~BONE_SELECTED;
-	else if(event==3) {
+	else if (event==3) {
 		ebone->flag |= BONE_HIDDEN_A;
 		ebone->flag &= ~BONE_SELECTED|BONE_TIPSEL|BONE_ROOTSEL;
 	}
-	else if(event==4)
+	else if (event==4)
 		ebone->flag &= ~BONE_HIDDEN_A;
 }
 
 static void sequence_cb(int event, TreeElement *UNUSED(te), TreeStoreElem *UNUSED(tselem))
 {
 //	Sequence *seq= (Sequence*) te->directdata;
-	if(event==1) {
+	if (event==1) {
 // XXX		select_single_seq(seq, 1);
 	}
 }
@@ -517,14 +488,14 @@ static void outliner_do_data_operation(SpaceOops *soops, int type, int event, Li
 	TreeElement *te;
 	TreeStoreElem *tselem;
 	
-	for(te=lb->first; te; te= te->next) {
+	for (te=lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
-		if(tselem->flag & TSE_SELECTED) {
-			if(tselem->type==type) {
+		if (tselem->flag & TSE_SELECTED) {
+			if (tselem->type==type) {
 				operation_cb(event, te, tselem);
 			}
 		}
-		if(TSELEM_OPEN(tselem,soops)) {
+		if (TSELEM_OPEN(tselem,soops)) {
 			outliner_do_data_operation(soops, type, event, &te->subtree, operation_cb);
 		}
 	}
@@ -557,55 +528,55 @@ static int outliner_object_operation_exec(bContext *C, wmOperator *op)
 	
 	event= RNA_enum_get(op->ptr, "type");
 
-	if(event==1) {
+	if (event==1) {
 		Scene *sce= scene;	// to be able to delete, scenes are set...
 		outliner_do_object_operation(C, scene, soops, &soops->tree, object_select_cb);
-		if(scene != sce) {
-			ED_screen_set_scene(C, sce);
+		if (scene != sce) {
+			ED_screen_set_scene(C, CTX_wm_screen(C), sce);
 		}
 		
 		str= "Select Objects";
 		WM_event_add_notifier(C, NC_SCENE|ND_OB_SELECT, scene);
 	}
-	else if(event==2) {
+	else if (event==2) {
 		outliner_do_object_operation(C, scene, soops, &soops->tree, object_deselect_cb);
 		str= "Deselect Objects";
 		WM_event_add_notifier(C, NC_SCENE|ND_OB_SELECT, scene);
 	}
-	else if(event==4) {
+	else if (event==4) {
 		outliner_do_object_operation(C, scene, soops, &soops->tree, object_delete_cb);
 
 		/* XXX: tree management normally happens from draw_outliner(), but when
-		        you're clicking to fast on Delete object from context menu in
-		        outliner several mouse events can be handled in one cycle without
-		        handling notifiers/redraw which leads to deleting the same object twice.
-		        cleanup tree here to prevent such cases. */
+		 *      you're clicking to fast on Delete object from context menu in
+		 *      outliner several mouse events can be handled in one cycle without
+		 *      handling notifiers/redraw which leads to deleting the same object twice.
+		 *      cleanup tree here to prevent such cases. */
 		outliner_cleanup_tree(soops);
 
 		DAG_scene_sort(bmain, scene);
 		str= "Delete Objects";
 		WM_event_add_notifier(C, NC_SCENE|ND_OB_ACTIVE, scene);
 	}
-	else if(event==5) {	/* disabled, see above enum (ton) */
+	else if (event==5) {	/* disabled, see above enum (ton) */
 		outliner_do_object_operation(C, scene, soops, &soops->tree, id_local_cb);
 		str= "Localized Objects";
 	}
-	else if(event==6) {
+	else if (event==6) {
 		outliner_do_object_operation(C, scene, soops, &soops->tree, object_toggle_visibility_cb);
 		str= "Toggle Visibility";
 		WM_event_add_notifier(C, NC_SCENE|ND_OB_VISIBLE, scene);
 	}
-	else if(event==7) {
+	else if (event==7) {
 		outliner_do_object_operation(C, scene, soops, &soops->tree, object_toggle_selectability_cb);
 		str= "Toggle Selectability";
 		WM_event_add_notifier(C, NC_SCENE|ND_OB_SELECT, scene);
 	}
-	else if(event==8) {
+	else if (event==8) {
 		outliner_do_object_operation(C, scene, soops, &soops->tree, object_toggle_renderability_cb);
 		str= "Toggle Renderability";
 		WM_event_add_notifier(C, NC_SCENE|ND_OB_RENDER, scene);
 	}
-	else if(event==9) {
+	else if (event==9) {
 		outliner_do_object_operation(C, scene, soops, &soops->tree, item_rename_cb);
 		str= "Rename Object";
 	}
@@ -619,18 +590,18 @@ static int outliner_object_operation_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_object_operation(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Outliner Object Operation";
-	ot->idname= "OUTLINER_OT_object_operation";
-	ot->description= "";
+	ot->name = "Outliner Object Operation";
+	ot->idname = "OUTLINER_OT_object_operation";
+	ot->description = "";
 	
 	/* callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= outliner_object_operation_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = outliner_object_operation_exec;
+	ot->poll = ED_operator_outliner_active;
 	
-	ot->flag= 0;
+	ot->flag = 0;
 
-	ot->prop= RNA_def_enum(ot->srna, "type", prop_object_op_types, 0, "Object Operation", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", prop_object_op_types, 0, "Object Operation", "");
 }
 
 /* **************************************** */
@@ -659,31 +630,31 @@ static int outliner_group_operation_exec(bContext *C, wmOperator *op)
 	
 	event= RNA_enum_get(op->ptr, "type");
 	
-	if(event==1) {
+	if (event==1) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, unlink_group_cb);
 		str= "Unlink group";
 	}
-	else if(event==2) {
+	else if (event==2) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, id_local_cb);
 		str= "Localized Data";
 	}
-	else if(event==3) {
+	else if (event==3) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, group_linkobs2scene_cb);
 		str= "Link Group Objects to Scene";
 	}
-	else if(event==4) {
+	else if (event==4) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, group_toggle_visibility_cb);
 		str= "Toggle Visibility";
 	}
-	else if(event==5) {
+	else if (event==5) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, group_toggle_selectability_cb);
 		str= "Toggle Selectability";
 	}
-	else if(event==6) {
+	else if (event==6) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, group_toggle_renderability_cb);
 		str= "Toggle Renderability";
 	}
-	else if(event==7) {
+	else if (event==7) {
 		outliner_do_libdata_operation(C, scene, soops, &soops->tree, item_rename_cb);
 		str= "Rename";
 	}
@@ -699,18 +670,18 @@ static int outliner_group_operation_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_group_operation(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Outliner Group Operation";
-	ot->idname= "OUTLINER_OT_group_operation";
-	ot->description= "";
+	ot->name = "Outliner Group Operation";
+	ot->idname = "OUTLINER_OT_group_operation";
+	ot->description = "";
 	
 	/* callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= outliner_group_operation_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = outliner_group_operation_exec;
+	ot->poll = ED_operator_outliner_active;
 	
-	ot->flag= 0;
+	ot->flag = 0;
 	
-	ot->prop= RNA_def_enum(ot->srna, "type", prop_group_op_types, 0, "Group Operation", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", prop_group_op_types, 0, "Group Operation", "");
 }
 
 /* **************************************** */
@@ -869,18 +840,18 @@ static int outliner_id_operation_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_id_operation(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Outliner ID data Operation";
-	ot->idname= "OUTLINER_OT_id_operation";
-	ot->description= "";
+	ot->name = "Outliner ID data Operation";
+	ot->idname = "OUTLINER_OT_id_operation";
+	ot->description = "";
 	
 	/* callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= outliner_id_operation_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = outliner_id_operation_exec;
+	ot->poll = ED_operator_outliner_active;
 	
-	ot->flag= 0;
+	ot->flag = 0;
 	
-	ot->prop= RNA_def_enum(ot->srna, "type", prop_id_op_types, 0, "ID data Operation", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", prop_id_op_types, 0, "ID data Operation", "");
 }
 
 /* **************************************** */
@@ -894,7 +865,7 @@ static void outliner_do_id_set_operation(SpaceOops *soops, int type, ListBase *l
 	for (te=lb->first; te; te= te->next) {
 		tselem= TREESTORE(te);
 		if (tselem->flag & TSE_SELECTED) {
-			if(tselem->type==type) {
+			if (tselem->type==type) {
 				TreeStoreElem *tsep = TREESTORE(te->parent);
 				operation_cb(te, tselem, tsep, newid);
 			}
@@ -972,23 +943,23 @@ void OUTLINER_OT_action_set(wmOperatorType *ot)
 	PropertyRNA *prop;
 
 	/* identifiers */
-	ot->name= "Outliner Set Action";
-	ot->idname= "OUTLINER_OT_action_set";
-	ot->description= "Change the active action used";
+	ot->name = "Outliner Set Action";
+	ot->idname = "OUTLINER_OT_action_set";
+	ot->description = "Change the active action used";
 	
 	/* api callbacks */
-	ot->invoke= WM_enum_search_invoke;
-	ot->exec= outliner_action_set_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->invoke = WM_enum_search_invoke;
+	ot->exec = outliner_action_set_exec;
+	ot->poll = ED_operator_outliner_active;
 	
 	/* flags */
-	ot->flag= 0;
+	ot->flag = 0;
 	
 	/* props */
 		// TODO: this would be nicer as an ID-pointer...
 	prop= RNA_def_enum(ot->srna, "action", DummyRNA_NULL_items, 0, "Action", "");
 	RNA_def_enum_funcs(prop, RNA_action_itemf);
-	ot->prop= prop;
+	ot->prop = prop;
 }
 
 /* **************************************** */
@@ -1087,18 +1058,18 @@ static int outliner_animdata_operation_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_animdata_operation(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Outliner Animation Data Operation";
-	ot->idname= "OUTLINER_OT_animdata_operation";
-	ot->description= "";
+	ot->name = "Outliner Animation Data Operation";
+	ot->idname = "OUTLINER_OT_animdata_operation";
+	ot->description = "";
 	
 	/* callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= outliner_animdata_operation_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = outliner_animdata_operation_exec;
+	ot->poll = ED_operator_outliner_active;
 	
-	ot->flag= 0;
+	ot->flag = 0;
 	
-	ot->prop= RNA_def_enum(ot->srna, "type", prop_animdata_op_types, 0, "Animation Operation", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", prop_animdata_op_types, 0, "Animation Operation", "");
 }
 
 /* **************************************** */
@@ -1124,29 +1095,29 @@ static int outliner_data_operation_exec(bContext *C, wmOperator *op)
 	event= RNA_enum_get(op->ptr, "type");
 	set_operation_types(soops, &soops->tree, &scenelevel, &objectlevel, &idlevel, &datalevel);
 	
-	if(datalevel==TSE_POSE_CHANNEL) {
-		if(event>0) {
+	if (datalevel==TSE_POSE_CHANNEL) {
+		if (event>0) {
 			outliner_do_data_operation(soops, datalevel, event, &soops->tree, pchan_cb);
 			WM_event_add_notifier(C, NC_OBJECT|ND_POSE, NULL);
 			ED_undo_push(C, "PoseChannel operation");
 		}
 	}
-	else if(datalevel==TSE_BONE) {
-		if(event>0) {
+	else if (datalevel==TSE_BONE) {
+		if (event>0) {
 			outliner_do_data_operation(soops, datalevel, event, &soops->tree, bone_cb);
 			WM_event_add_notifier(C, NC_OBJECT|ND_POSE, NULL);
 			ED_undo_push(C, "Bone operation");
 		}
 	}
-	else if(datalevel==TSE_EBONE) {
-		if(event>0) {
+	else if (datalevel==TSE_EBONE) {
+		if (event>0) {
 			outliner_do_data_operation(soops, datalevel, event, &soops->tree, ebone_cb);
 			WM_event_add_notifier(C, NC_OBJECT|ND_POSE, NULL);
 			ED_undo_push(C, "EditBone operation");
 		}
 	}
-	else if(datalevel==TSE_SEQUENCE) {
-		if(event>0) {
+	else if (datalevel==TSE_SEQUENCE) {
+		if (event>0) {
 			outliner_do_data_operation(soops, datalevel, event, &soops->tree, sequence_cb);
 		}
 	}
@@ -1158,18 +1129,18 @@ static int outliner_data_operation_exec(bContext *C, wmOperator *op)
 void OUTLINER_OT_data_operation(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name= "Outliner Data Operation";
-	ot->idname= "OUTLINER_OT_data_operation";
-	ot->description= "";
+	ot->name = "Outliner Data Operation";
+	ot->idname = "OUTLINER_OT_data_operation";
+	ot->description = "";
 	
 	/* callbacks */
-	ot->invoke= WM_menu_invoke;
-	ot->exec= outliner_data_operation_exec;
-	ot->poll= ED_operator_outliner_active;
+	ot->invoke = WM_menu_invoke;
+	ot->exec = outliner_data_operation_exec;
+	ot->poll = ED_operator_outliner_active;
 	
-	ot->flag= 0;
+	ot->flag = 0;
 	
-	ot->prop= RNA_def_enum(ot->srna, "type", prop_data_op_types, 0, "Data Operation", "");
+	ot->prop = RNA_def_enum(ot->srna, "type", prop_data_op_types, 0, "Data Operation", "");
 }
 
 
@@ -1180,7 +1151,7 @@ static int do_outliner_operation_event(bContext *C, Scene *scene, ARegion *ar, S
 {
 	ReportList *reports = CTX_wm_reports(C); // XXX...
 	
-	if(mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
+	if (mval[1]>te->ys && mval[1]<te->ys+UI_UNIT_Y) {
 		int scenelevel=0, objectlevel=0, idlevel=0, datalevel=0;
 		TreeStoreElem *tselem= TREESTORE(te);
 		
@@ -1198,15 +1169,15 @@ static int do_outliner_operation_event(bContext *C, Scene *scene, ARegion *ar, S
 		
 		set_operation_types(soops, &soops->tree, &scenelevel, &objectlevel, &idlevel, &datalevel);
 		
-		if(scenelevel) {
-			//if(objectlevel || datalevel || idlevel) error("Mixed selection");
+		if (scenelevel) {
+			//if (objectlevel || datalevel || idlevel) error("Mixed selection");
 			//else pupmenu("Scene Operations%t|Delete");
 		}
-		else if(objectlevel) {
+		else if (objectlevel) {
 			WM_operator_name_call(C, "OUTLINER_OT_object_operation", WM_OP_INVOKE_REGION_WIN, NULL);
 		}
-		else if(idlevel) {
-			if(idlevel==-1 || datalevel) BKE_report(reports, RPT_WARNING, "Mixed selection");
+		else if (idlevel) {
+			if (idlevel==-1 || datalevel) BKE_report(reports, RPT_WARNING, "Mixed selection");
 			else {
 				if (idlevel==ID_GR)
 					WM_operator_name_call(C, "OUTLINER_OT_group_operation", WM_OP_INVOKE_REGION_WIN, NULL);
@@ -1214,14 +1185,14 @@ static int do_outliner_operation_event(bContext *C, Scene *scene, ARegion *ar, S
 					WM_operator_name_call(C, "OUTLINER_OT_id_operation", WM_OP_INVOKE_REGION_WIN, NULL);
 			}
 		}
-		else if(datalevel) {
-			if(datalevel==-1) BKE_report(reports, RPT_WARNING, "Mixed selection");
+		else if (datalevel) {
+			if (datalevel==-1) BKE_report(reports, RPT_WARNING, "Mixed selection");
 			else {
 				if (datalevel == TSE_ANIM_DATA)
 					WM_operator_name_call(C, "OUTLINER_OT_animdata_operation", WM_OP_INVOKE_REGION_WIN, NULL);
 				else if (datalevel == TSE_DRIVER_BASE)
 					/* do nothing... no special ops needed yet */;
-				else if ELEM3(datalevel, TSE_R_LAYER_BASE, TSE_R_LAYER, TSE_R_PASS)
+				else if (ELEM3(datalevel, TSE_R_LAYER_BASE, TSE_R_LAYER, TSE_R_PASS))
 					/*WM_operator_name_call(C, "OUTLINER_OT_renderdata_operation", WM_OP_INVOKE_REGION_WIN, NULL)*/;
 				else
 					WM_operator_name_call(C, "OUTLINER_OT_data_operation", WM_OP_INVOKE_REGION_WIN, NULL);
@@ -1231,8 +1202,8 @@ static int do_outliner_operation_event(bContext *C, Scene *scene, ARegion *ar, S
 		return 1;
 	}
 	
-	for(te= te->subtree.first; te; te= te->next) {
-		if(do_outliner_operation_event(C, scene, ar, soops, te, event, mval)) 
+	for (te= te->subtree.first; te; te= te->next) {
+		if (do_outliner_operation_event(C, scene, ar, soops, te, event, mval))
 			return 1;
 	}
 	return 0;
@@ -1249,8 +1220,8 @@ static int outliner_operation(bContext *C, wmOperator *UNUSED(op), wmEvent *even
 	
 	UI_view2d_region_to_view(&ar->v2d, event->mval[0], event->mval[1], fmval, fmval+1);
 	
-	for(te= soops->tree.first; te; te= te->next) {
-		if(do_outliner_operation_event(C, scene, ar, soops, te, event, fmval)) break;
+	for (te= soops->tree.first; te; te= te->next) {
+		if (do_outliner_operation_event(C, scene, ar, soops, te, event, fmval)) break;
 	}
 	
 	return OPERATOR_FINISHED;
@@ -1259,13 +1230,13 @@ static int outliner_operation(bContext *C, wmOperator *UNUSED(op), wmEvent *even
 /* Menu only! Calls other operators */
 void OUTLINER_OT_operation(wmOperatorType *ot)
 {
-	ot->name= "Execute Operation";
-	ot->idname= "OUTLINER_OT_operation";
-	ot->description= "Context menu for item operations";
+	ot->name = "Execute Operation";
+	ot->idname = "OUTLINER_OT_operation";
+	ot->description = "Context menu for item operations";
 	
-	ot->invoke= outliner_operation;
+	ot->invoke = outliner_operation;
 	
-	ot->poll= ED_operator_outliner_active;
+	ot->poll = ED_operator_outliner_active;
 }
 
 /* ****************************************************** */
