@@ -44,11 +44,17 @@
 #include "DNA_space_types.h"
 #include "DNA_scene_types.h"
 #include "DNA_object_types.h"
+#include "DNA_mesh_types.h"
 #include "DNA_meshdata_types.h"
 #include "DNA_view3d_types.h"
 #include "DNA_modifier_types.h"
 #include "DNA_movieclip_types.h"
 
+#include "BLI_math.h"
+#include "BLI_blenlib.h"
+#include "BLI_rand.h"
+#include "BLI_utildefines.h"
+
 #include "RNA_access.h"
 
 //#include "BIF_screen.h"
@@ -71,6 +77,7 @@
 #include "BKE_mesh.h"
 #include "BKE_nla.h"
 #include "BKE_context.h"
+#include "BKE_tessmesh.h"
 #include "BKE_tracking.h"
 
 #include "ED_anim_api.h"
@@ -89,12 +96,6 @@
 
 //#include "BDR_unwrapper.h"
 
-#include "BLI_math.h"
-#include "BLI_blenlib.h"
-#include "BLI_editVert.h"
-#include "BLI_rand.h"
-#include "BLI_utildefines.h"
-
 #include "WM_types.h"
 #include "WM_api.h"
 
@@ -106,8 +107,6 @@
 
 #include "transform.h"
 
-extern ListBase editelems;
-
 /* ************************** Functions *************************** */
 
 void getViewVector(TransInfo *t, float coord[3], float vec[3])
@@ -148,17 +147,17 @@ static void clipMirrorModifier(TransInfo *t, Object *ob)
 		if ((md->type==eModifierType_Mirror) && (md->mode & eModifierMode_Realtime)) {
 			MirrorModifierData *mmd = (MirrorModifierData*) md;
 			
-			if(mmd->flag & MOD_MIR_CLIPPING) {
+			if (mmd->flag & MOD_MIR_CLIPPING) {
 				axis = 0;
-				if(mmd->flag & MOD_MIR_AXIS_X) {
+				if (mmd->flag & MOD_MIR_AXIS_X) {
 					axis |= 1;
 					tolerance[0] = mmd->tolerance;
 				}
-				if(mmd->flag & MOD_MIR_AXIS_Y) {
+				if (mmd->flag & MOD_MIR_AXIS_Y) {
 					axis |= 2;
 					tolerance[1] = mmd->tolerance;
 				}
-				if(mmd->flag & MOD_MIR_AXIS_Z) {
+				if (mmd->flag & MOD_MIR_AXIS_Z) {
 					axis |= 4;
 					tolerance[2] = mmd->tolerance;
 				}
@@ -175,7 +174,7 @@ static void clipMirrorModifier(TransInfo *t, Object *ob)
 						invert_m4_m4(imtx, mtx);
 					}
 					
-					for(i = 0 ; i < t->total; i++, td++) {
+					for (i = 0 ; i < t->total; i++, td++) {
 						int clip;
 						float loc[3], iloc[3];
 						
@@ -196,8 +195,8 @@ static void clipMirrorModifier(TransInfo *t, Object *ob)
 						}
 						
 						clip = 0;
-						if(axis & 1) {
-							if(fabsf(iloc[0])<=tolerance[0] ||
+						if (axis & 1) {
+							if (fabsf(iloc[0])<=tolerance[0] ||
 							   loc[0]*iloc[0]<0.0f)
 							{
 								loc[0]= 0.0f;
@@ -205,16 +204,16 @@ static void clipMirrorModifier(TransInfo *t, Object *ob)
 							}
 						}
 						
-						if(axis & 2) {
-							if(fabs(iloc[1])<=tolerance[1] ||
+						if (axis & 2) {
+							if (fabs(iloc[1])<=tolerance[1] ||
 							   loc[1]*iloc[1]<0.0f)
 							{
 								loc[1]= 0.0f;
 								clip = 1;
 							}
 						}
-						if(axis & 4) {
-							if(fabs(iloc[2])<=tolerance[2] ||
+						if (axis & 4) {
+							if (fabs(iloc[2])<=tolerance[2] ||
 							   loc[2]*iloc[2]<0.0f)
 							{
 								loc[2]= 0.0f;
@@ -236,13 +235,13 @@ static void clipMirrorModifier(TransInfo *t, Object *ob)
 }
 
 /* assumes obedit set to mesh object */
-static void editmesh_apply_to_mirror(TransInfo *t)
+static void editbmesh_apply_to_mirror(TransInfo *t)
 {
 	TransData *td = t->data;
-	EditVert *eve;
+	BMVert *eve;
 	int i;
 	
-	for(i = 0 ; i < t->total; i++, td++) {
+	for (i = 0 ; i < t->total; i++, td++) {
 		if (td->flag & TD_NOACTION)
 			break;
 		if (td->loc==NULL)
@@ -270,7 +269,7 @@ static void animrecord_check_state (Scene *scene, ID *id, wmTimer *animtimer)
 	ScreenAnimData *sad= (animtimer) ? animtimer->customdata : NULL;
 	
 	/* sanity checks */
-	if ELEM3(NULL, scene, id, sad)
+	if (ELEM3(NULL, scene, id, sad))
 		return;
 	
 	/* check if we need a new strip if:
@@ -338,7 +337,7 @@ static void recalcData_actedit(TransInfo *t)
 	bAnimListElem *ale;
 	int filter;
 	
-	/* initialise relevant anim-context 'context' data from TransInfo data */
+	/* initialize relevant anim-context 'context' data from TransInfo data */
 		/* NOTE: sync this with the code in ANIM_animdata_get_context() */
 	ac.scene= t->scene;
 	ac.obact= OBACT;
@@ -374,7 +373,6 @@ static void recalcData_actedit(TransInfo *t)
 		BLI_freelistN(&anim_data);
 	}
 }
-
 /* helper for recalcData() - for Graph Editor transforms */
 static void recalcData_graphedit(TransInfo *t)
 {
@@ -389,7 +387,7 @@ static void recalcData_graphedit(TransInfo *t)
 	int dosort = 0;
 	
 	
-	/* initialise relevant anim-context 'context' data from TransInfo data */
+	/* initialize relevant anim-context 'context' data from TransInfo data */
 		/* NOTE: sync this with the code in ANIM_animdata_get_context() */
 	scene= ac.scene= t->scene;
 	ac.obact= OBACT;
@@ -469,7 +467,7 @@ static void recalcData_nla(TransInfo *t)
 		if ((snla->flag & SNLA_NOREALTIMEUPDATES) == 0)
 			ANIM_id_update(t->scene, tdn->id);
 		
-		/* if cancelling transform, just write the values without validating, then move on */
+		/* if canceling transform, just write the values without validating, then move on */
 		if (t->state == TRANS_CANCEL) {
 			/* clear the values by directly overwriting the originals, but also need to restore
 			 * endpoints of neighboring transition-strips
@@ -500,7 +498,7 @@ static void recalcData_nla(TransInfo *t)
 			continue;
 		}
 		
-		/* firstly, check if the proposed transform locations would overlap with any neighbouring strips
+		/* firstly, check if the proposed transform locations would overlap with any neighboring strips
 		 * (barring transitions) which are absolute barriers since they are not being moved
 		 *
 		 * this is done as a iterative procedure (done 5 times max for now)
@@ -512,7 +510,7 @@ static void recalcData_nla(TransInfo *t)
 			if ((pExceeded && nExceeded) || (iter == 4) ) {
 				/* both endpoints exceeded (or iteration ping-pong'd meaning that we need a compromise)
 				 *	- simply crop strip to fit within the bounds of the strips bounding it
-				 *	- if there were no neighbours, clear the transforms (make it default to the strip's current values)
+				 *	- if there were no neighbors, clear the transforms (make it default to the strip's current values)
 				 */
 				if (strip->prev && strip->next) {
 					tdn->h1[0]= strip->prev->end;
@@ -629,7 +627,7 @@ static void recalcData_image(TransInfo *t)
 		SpaceImage *sima= t->sa->spacedata.first;
 		
 		flushTransUVs(t);
-		if(sima->flag & SI_LIVE_UNWRAP)
+		if (sima->flag & SI_LIVE_UNWRAP)
 			ED_uvedit_live_unwrap_re_solve();
 		
 		DAG_id_tag_update(t->obedit->data, 0);
@@ -639,31 +637,31 @@ static void recalcData_image(TransInfo *t)
 /* helper for recalcData() - for Movie Clip transforms */
 static void recalcData_clip(TransInfo *t)
 {
-	SpaceClip *sc= t->sa->spacedata.first;
-	MovieClip *clip= ED_space_clip(sc);
-	ListBase *tracksbase= BKE_tracking_get_tracks(&clip->tracking);
+	SpaceClip *sc = t->sa->spacedata.first;
+	MovieClip *clip = ED_space_clip(sc);
+	ListBase *tracksbase = BKE_tracking_get_tracks(&clip->tracking);
 	MovieTrackingTrack *track;
 	
 	flushTransTracking(t);
 	
-	track= tracksbase->first;
-	while(track) {
-		if(TRACK_VIEW_SELECTED(sc, track) && (track->flag & TRACK_LOCKED)==0) {
+	track = tracksbase->first;
+	while (track) {
+		if (TRACK_VIEW_SELECTED(sc, track) && (track->flag & TRACK_LOCKED)==0) {
 			if (t->mode == TFM_TRANSLATION) {
-				if(TRACK_AREA_SELECTED(track, TRACK_AREA_PAT))
+				if (TRACK_AREA_SELECTED(track, TRACK_AREA_PAT))
 					BKE_tracking_clamp_track(track, CLAMP_PAT_POS);
-				if(TRACK_AREA_SELECTED(track, TRACK_AREA_SEARCH))
+				if (TRACK_AREA_SELECTED(track, TRACK_AREA_SEARCH))
 					BKE_tracking_clamp_track(track, CLAMP_SEARCH_POS);
 			}
 			else if (t->mode == TFM_RESIZE) {
-				if(TRACK_AREA_SELECTED(track, TRACK_AREA_PAT))
+				if (TRACK_AREA_SELECTED(track, TRACK_AREA_PAT))
 					BKE_tracking_clamp_track(track, CLAMP_PAT_DIM);
-				if(TRACK_AREA_SELECTED(track, TRACK_AREA_SEARCH))
+				if (TRACK_AREA_SELECTED(track, TRACK_AREA_SEARCH))
 					BKE_tracking_clamp_track(track, CLAMP_SEARCH_DIM);
 			}
 		}
 		
-		track= track->next;
+		track = track->next;
 	}
 	
 	DAG_id_tag_update(&clip->id, 0);
@@ -675,12 +673,12 @@ static void recalcData_view3d(TransInfo *t)
 	Base *base = t->scene->basact;
 	
 	if (t->obedit) {
-		if ELEM(t->obedit->type, OB_CURVE, OB_SURF) {
+		if (ELEM(t->obedit->type, OB_CURVE, OB_SURF)) {
 			Curve *cu= t->obedit->data;
 			ListBase *nurbs= curve_editnurbs(cu);
 			Nurb *nu= nurbs->first;
 			
-			if(t->state != TRANS_CANCEL) {
+			if (t->state != TRANS_CANCEL) {
 				clipMirrorModifier(t, t->obedit);
 				applyProject(t);
 			}
@@ -688,85 +686,86 @@ static void recalcData_view3d(TransInfo *t)
 			DAG_id_tag_update(t->obedit->data, 0);  /* sets recalc flags */
 				
 			if (t->state == TRANS_CANCEL) {
-				while(nu) {
+				while (nu) {
 					calchandlesNurb(nu); /* Cant do testhandlesNurb here, it messes up the h1 and h2 flags */
 					nu= nu->next;
 				}
 			} 
 			else {
 				/* Normal updating */
-				while(nu) {
+				while (nu) {
 					test2DNurb(nu);
 					calchandlesNurb(nu);
 					nu= nu->next;
 				}
 			}
 		}
-		else if(t->obedit->type==OB_LATTICE) {
+		else if (t->obedit->type==OB_LATTICE) {
 			Lattice *la= t->obedit->data;
 			
-			if(t->state != TRANS_CANCEL) {
+			if (t->state != TRANS_CANCEL) {
 				applyProject(t);
 			}
 			
 			DAG_id_tag_update(t->obedit->data, 0);  /* sets recalc flags */
 			
-			if(la->editlatt->latt->flag & LT_OUTSIDE) outside_lattice(la->editlatt->latt);
+			if (la->editlatt->latt->flag & LT_OUTSIDE) outside_lattice(la->editlatt->latt);
 		}
 		else if (t->obedit->type == OB_MESH) {
-			EditMesh *em = ((Mesh*)t->obedit->data)->edit_mesh;
+			BMEditMesh *em = BMEdit_FromObject(t->obedit);
 			/* mirror modifier clipping? */
-			if(t->state != TRANS_CANCEL) {
+			if (t->state != TRANS_CANCEL) {
 				/* apply clipping after so we never project past the clip plane [#25423] */
 				applyProject(t);
 				clipMirrorModifier(t, t->obedit);
 			}
-			if((t->options & CTX_NO_MIRROR) == 0 && (t->flag & T_MIRROR))
-				editmesh_apply_to_mirror(t);
+			if ((t->options & CTX_NO_MIRROR) == 0 && (t->flag & T_MIRROR))
+				editbmesh_apply_to_mirror(t);
 				
 			DAG_id_tag_update(t->obedit->data, 0);  /* sets recalc flags */
 			
-			recalc_editnormals(em);
+			EDBM_mesh_normals_update(em);
+			BMEdit_RecalcTessellation(em);
 		}
-		else if(t->obedit->type==OB_ARMATURE) { /* no recalc flag, does pose */
+		else if (t->obedit->type==OB_ARMATURE) { /* no recalc flag, does pose */
 			bArmature *arm= t->obedit->data;
 			ListBase *edbo = arm->edbo;
 			EditBone *ebo;
 			TransData *td = t->data;
 			int i;
 			
-			if(t->state != TRANS_CANCEL) {
+			if (t->state != TRANS_CANCEL) {
 				applyProject(t);
 			}
 			
 			/* Ensure all bones are correctly adjusted */
-			for (ebo = edbo->first; ebo; ebo = ebo->next){
+			for (ebo = edbo->first; ebo; ebo = ebo->next) {
 				
-				if ((ebo->flag & BONE_CONNECTED) && ebo->parent){
+				if ((ebo->flag & BONE_CONNECTED) && ebo->parent) {
 					/* If this bone has a parent tip that has been moved */
-					if (ebo->parent->flag & BONE_TIPSEL){
+					if (ebo->parent->flag & BONE_TIPSEL) {
 						copy_v3_v3 (ebo->head, ebo->parent->tail);
-						if(t->mode==TFM_BONE_ENVELOPE) ebo->rad_head= ebo->parent->rad_tail;
+						if (t->mode==TFM_BONE_ENVELOPE) ebo->rad_head= ebo->parent->rad_tail;
 					}
 					/* If this bone has a parent tip that has NOT been moved */
-					else{
+					else {
 						copy_v3_v3 (ebo->parent->tail, ebo->head);
-						if(t->mode==TFM_BONE_ENVELOPE) ebo->parent->rad_tail= ebo->rad_head;
+						if (t->mode==TFM_BONE_ENVELOPE) ebo->parent->rad_tail= ebo->rad_head;
 					}
 				}
 				
 				/* on extrude bones, oldlength==0.0f, so we scale radius of points */
 				ebo->length= len_v3v3(ebo->head, ebo->tail);
-				if(ebo->oldlength==0.0f) {
+				if (ebo->oldlength==0.0f) {
 					ebo->rad_head= 0.25f*ebo->length;
 					ebo->rad_tail= 0.10f*ebo->length;
 					ebo->dist= 0.25f*ebo->length;
-					if(ebo->parent) {
-						if(ebo->rad_head > ebo->parent->rad_tail)
+					if (ebo->parent) {
+						if (ebo->rad_head > ebo->parent->rad_tail)
 							ebo->rad_head= ebo->parent->rad_tail;
 					}
 				}
-				else if(t->mode!=TFM_BONE_ENVELOPE) {
+				else if (t->mode!=TFM_BONE_ENVELOPE) {
 					/* if bones change length, lets do that for the deform distance as well */
 					ebo->dist*= ebo->length/ebo->oldlength;
 					ebo->rad_head*= ebo->length/ebo->oldlength;
@@ -779,7 +778,7 @@ static void recalcData_view3d(TransInfo *t)
 			if (t->mode != TFM_BONE_ROLL)
 			{
 				/* fix roll */
-				for(i = 0; i < t->total; i++, td++)
+				for (i = 0; i < t->total; i++, td++)
 				{
 					if (td->extra)
 					{
@@ -796,8 +795,7 @@ static void recalcData_view3d(TransInfo *t)
 							rotation_between_vecs_to_quat(qrot, td->axismtx[1], vec);
 							mul_qt_v3(qrot, up_axis);
 						}
-						else
-						{
+						else {
 							mul_m3_v3(t->mat, up_axis);
 						}
 						
@@ -806,19 +804,18 @@ static void recalcData_view3d(TransInfo *t)
 				}
 			}
 			
-			if(arm->flag & ARM_MIRROR_EDIT)
+			if (arm->flag & ARM_MIRROR_EDIT)
 				transform_armature_mirror_update(t->obedit);
 			
 		}
-		else
-		{
-			if(t->state != TRANS_CANCEL) {
+		else {
+			if (t->state != TRANS_CANCEL) {
 				applyProject(t);
 			}
 			DAG_id_tag_update(t->obedit->data, 0);  /* sets recalc flags */
 		}
 	}
-	else if( (t->flag & T_POSE) && t->poseobj) {
+	else if ( (t->flag & T_POSE) && t->poseobj) {
 		Object *ob= t->poseobj;
 		bArmature *arm= ob->data;
 		
@@ -843,8 +840,8 @@ static void recalcData_view3d(TransInfo *t)
 		else
 			where_is_pose(t->scene, ob);
 	}
-	else if(base && (base->object->mode & OB_MODE_PARTICLE_EDIT) && PE_get_current(t->scene, base->object)) {
-		if(t->state != TRANS_CANCEL) {
+	else if (base && (base->object->mode & OB_MODE_PARTICLE_EDIT) && PE_get_current(t->scene, base->object)) {
+		if (t->state != TRANS_CANCEL) {
 			applyProject(t);
 		}
 		flushTransParticles(t);
@@ -852,7 +849,7 @@ static void recalcData_view3d(TransInfo *t)
 	else {
 		int i;
 		
-		if(t->state != TRANS_CANCEL) {
+		if (t->state != TRANS_CANCEL) {
 			applyProject(t);
 		}
 		
@@ -924,7 +921,7 @@ void drawLine(TransInfo *t, float *center, float *dir, char axis, short options)
 		
 		glPushMatrix();
 		
-		//if(t->obedit) glLoadMatrixf(t->obedit->obmat);	// sets opengl viewing
+		//if (t->obedit) glLoadMatrixf(t->obedit->obmat);	// sets opengl viewing
 		
 		
 		copy_v3_v3(v3, dir);
@@ -968,8 +965,8 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 	
 	/* moving: is shown in drawobject() (transform color) */
 //  TRANSFORM_FIX_ME
-//	if(obedit || (t->flag & T_POSE) ) G.moving= G_TRANSFORM_EDIT;
-//	else if(G.f & G_PARTICLEEDIT) G.moving= G_TRANSFORM_PARTICLE;
+//	if (obedit || (t->flag & T_POSE) ) G.moving= G_TRANSFORM_EDIT;
+//	else if (G.f & G_PARTICLEEDIT) G.moving= G_TRANSFORM_PARTICLE;
 //	else G.moving= G_TRANSFORM_OBJ;
 	
 	t->scene = sce;
@@ -992,8 +989,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 		copy_v2_v2_int(t->imval, event->mval);
 		t->event_type = event->type;
 	}
-	else
-	{
+	else {
 		t->imval[0] = 0;
 		t->imval[1] = 0;
 	}
@@ -1033,7 +1029,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 
 
 	/* Assign the space type, some exceptions for running in different mode */
-	if(sa == NULL) {
+	if (sa == NULL) {
 		/* background mode */
 		t->spacetype= SPACE_EMPTY;
 	}
@@ -1047,7 +1043,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 	}
 
 
-	if(t->spacetype == SPACE_VIEW3D)
+	if (t->spacetype == SPACE_VIEW3D)
 	{
 		View3D *v3d = sa->spacedata.first;
 		
@@ -1061,7 +1057,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 			v3d->twtype = 0;
 		}
 
-		if(v3d->flag & V3D_ALIGN) t->flag |= T_V3D_ALIGN;
+		if (v3d->flag & V3D_ALIGN) t->flag |= T_V3D_ALIGN;
 		t->around = v3d->around;
 		
 		if (op && RNA_struct_find_property(op->ptr, "constraint_orientation") && RNA_struct_property_is_set(op->ptr, "constraint_orientation"))
@@ -1073,22 +1069,21 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 				t->current_orientation = V3D_MANIP_GLOBAL;
 			}
 		}
-		else
-		{
+		else {
 			t->current_orientation = v3d->twmode;
 		}
 
 		/* exceptional case */
-		if(t->around==V3D_LOCAL && (t->settings->selectmode & SCE_SELECT_FACE)) {
-			if(ELEM3(t->mode, TFM_ROTATION, TFM_RESIZE, TFM_TRACKBALL)) {
+		if (t->around==V3D_LOCAL && (t->settings->selectmode & SCE_SELECT_FACE)) {
+			if (ELEM3(t->mode, TFM_ROTATION, TFM_RESIZE, TFM_TRACKBALL)) {
 				t->options |= CTX_NO_PET;
 			}
 		}
 
 		/* initialize UV transform from */
 		if (op && RNA_struct_find_property(op->ptr, "correct_uv")) {
-			if(RNA_struct_property_is_set(op->ptr, "correct_uv")) {
-				if(RNA_boolean_get(op->ptr, "correct_uv")) {
+			if (RNA_struct_property_is_set(op->ptr, "correct_uv")) {
+				if (RNA_boolean_get(op->ptr, "correct_uv")) {
 					t->settings->uvcalc_flag |= UVCALC_TRANSFORM_CORRECT;
 				}
 				else {
@@ -1101,28 +1096,24 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 		}
 
 	}
-	else if(t->spacetype==SPACE_IMAGE)
-	{
+	else if (t->spacetype==SPACE_IMAGE) {
 		SpaceImage *sima = sa->spacedata.first;
 		// XXX for now, get View2D from the active region
 		t->view = &ar->v2d;
 		t->around = sima->around;
 	}
-	else if(t->spacetype==SPACE_NODE)
-	{
+	else if (t->spacetype==SPACE_NODE) {
 		// XXX for now, get View2D from the active region
 		t->view = &ar->v2d;
 		t->around = V3D_CENTER;
 	}
-	else if(t->spacetype==SPACE_IPO) 
-	{
+	else if (t->spacetype==SPACE_IPO) {
 		SpaceIpo *sipo= sa->spacedata.first;
 		t->view = &ar->v2d;
 		t->around = sipo->around;
 	}
-	else
-	{
-		if(ar) {
+	else {
+		if (ar) {
 			// XXX for now, get View2D  from the active region
 			t->view = &ar->v2d;
 			// XXX for now, the center point is the midpoint of the data
@@ -1140,10 +1131,8 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 			t->flag |= T_RELEASE_CONFIRM;
 		}
 	}
-	else
-	{
-		if (U.flag & USER_RELEASECONFIRM)
-		{
+	else {
+		if (U.flag & USER_RELEASECONFIRM) {
 			t->flag |= T_RELEASE_CONFIRM;
 		}
 	}
@@ -1157,8 +1146,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 		}
 	}
 	// Need stuff to take it from edit mesh or whatnot here
-	else if (t->spacetype == SPACE_VIEW3D)
-	{
+	else if (t->spacetype == SPACE_VIEW3D) {
 		if (t->obedit && t->obedit->type == OB_MESH && (((Mesh *)t->obedit->data)->editflag & ME_EDIT_MIRROR_X))
 		{
 			t->flag |= T_MIRROR;
@@ -1180,22 +1168,18 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 				break;
 			}
 		}
-		else
-		{
+		else {
 			/* use settings from scene only if modal */
-			if (t->flag & T_MODAL)
-			{
-				if ((t->options & CTX_NO_PET) == 0)
-				{
-					if (t->obedit && ts->proportional != PROP_EDIT_OFF)
-					{
+			if (t->flag & T_MODAL) {
+				if ((t->options & CTX_NO_PET) == 0) {
+					if (t->obedit && ts->proportional != PROP_EDIT_OFF) {
 						t->flag |= T_PROP_EDIT;
 
-						if(ts->proportional == PROP_EDIT_CONNECTED)
+						if (ts->proportional == PROP_EDIT_CONNECTED) {
 							t->flag |= T_PROP_CONNECTED;
+						}
 					}
-					else if (t->obedit == NULL && ts->proportional_objects)
-					{
+					else if (t->obedit == NULL && ts->proportional_objects) {
 						t->flag |= T_PROP_EDIT;
 					}
 				}
@@ -1206,8 +1190,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 		{
 			t->prop_size = RNA_float_get(op->ptr, "proportional_size");
 		}
-		else
-		{
+		else {
 			t->prop_size = ts->proportional_size;
 		}
 		
@@ -1223,8 +1206,7 @@ int initTransInfo (bContext *C, TransInfo *t, wmOperator *op, wmEvent *event)
 		{
 			t->prop_mode = RNA_enum_get(op->ptr, "proportional_edit_falloff");
 		}
-		else
-		{
+		else {
 			t->prop_mode = ts->prop_mode;
 		}
 	}
@@ -1263,7 +1245,7 @@ void postTrans (bContext *C, TransInfo *t)
 		/* Can take over freeing t->data and data2d etc... */
 		t->customFree(t);
 	}
-	else if (t->customData) {
+	else if ((t->customData != NULL) && (t->flag & T_FREE_CUSTOMDATA)) {
 		MEM_freeN(t->customData);
 	}
 
@@ -1272,7 +1254,7 @@ void postTrans (bContext *C, TransInfo *t)
 		int a;
 		
 		/* free data malloced per trans-data */
-		for(a=0, td= t->data; a<t->total; a++, td++) {
+		for (a=0, td= t->data; a<t->total; a++, td++) {
 			if (td->flag & TD_BEZTRIPLE) 
 				MEM_freeN(td->hdata);
 		}
@@ -1287,12 +1269,12 @@ void postTrans (bContext *C, TransInfo *t)
 		t->data2d= NULL;
 	}
 	
-	if(t->spacetype==SPACE_IMAGE) {
+	if (t->spacetype==SPACE_IMAGE) {
 		SpaceImage *sima= t->sa->spacedata.first;
-		if(sima->flag & SI_LIVE_UNWRAP)
+		if (sima->flag & SI_LIVE_UNWRAP)
 			ED_uvedit_live_unwrap_end(t->state == TRANS_CANCEL);
 	}
-	else if(t->spacetype==SPACE_VIEW3D) {
+	else if (t->spacetype==SPACE_VIEW3D) {
 		View3D *v3d = t->sa->spacedata.first;
 		/* restore manipulator */
 		if (t->flag & T_MODAL) {
@@ -1336,10 +1318,10 @@ static void restoreElement(TransData *td)
 		if (td->ext->rot) {
 			copy_v3_v3(td->ext->rot, td->ext->irot);
 		}
-		if(td->ext->rotAngle) {
+		if (td->ext->rotAngle) {
 			*td->ext->rotAngle= td->ext->irotAngle;
 		}
-		if(td->ext->rotAxis) {
+		if (td->ext->rotAxis) {
 			copy_v3_v3(td->ext->rotAxis, td->ext->irotAxis);
 		}
 		/* XXX, drotAngle & drotAxis not used yet */
@@ -1423,7 +1405,7 @@ void calculateCenterCursor2D(TransInfo *t)
 	float aspx=1.0, aspy=1.0;
 	float *cursor= NULL;
 	
-	if(t->spacetype==SPACE_IMAGE) {
+	if (t->spacetype==SPACE_IMAGE) {
 		SpaceImage *sima= (SpaceImage *)t->sa->spacedata.first;
 		/* only space supported right now but may change */
 		ED_space_image_uv_aspect(sima, &aspx, &aspy);
@@ -1456,7 +1438,7 @@ void calculateCenterMedian(TransInfo *t)
 	int total = 0;
 	int i;
 	
-	for(i = 0; i < t->total; i++) {
+	for (i = 0; i < t->total; i++) {
 		if (t->data[i].flag & TD_SELECTED) {
 			if (!(t->data[i].flag & TD_NOCENTER))
 			{
@@ -1466,13 +1448,13 @@ void calculateCenterMedian(TransInfo *t)
 		}
 		else {
 			/*
-			   All the selected elements are at the head of the array
-			   which means we can stop when it finds unselected data
-			*/
+			 * All the selected elements are at the head of the array
+			 * which means we can stop when it finds unselected data
+			 */
 			break;
 		}
 	}
-	if(i)
+	if (i)
 		mul_v3_fl(partial, 1.0f / total);
 	copy_v3_v3(t->center, partial);
 	
@@ -1484,7 +1466,7 @@ void calculateCenterBound(TransInfo *t)
 	float max[3];
 	float min[3];
 	int i;
-	for(i = 0; i < t->total; i++) {
+	for (i = 0; i < t->total; i++) {
 		if (i) {
 			if (t->data[i].flag & TD_SELECTED) {
 				if (!(t->data[i].flag & TD_NOCENTER))
@@ -1492,9 +1474,9 @@ void calculateCenterBound(TransInfo *t)
 			}
 			else {
 				/*
-				   All the selected elements are at the head of the array
-				   which means we can stop when it finds unselected data
-				*/
+				 * All the selected elements are at the head of the array
+				 * which means we can stop when it finds unselected data
+				 */
 				break;
 			}
 		}
@@ -1519,9 +1501,9 @@ void calculateCenter(TransInfo *t)
 		calculateCenterMedian(t);
 		break;
 	case V3D_CURSOR:
-		if(t->spacetype==SPACE_IMAGE)
+		if (t->spacetype==SPACE_IMAGE)
 			calculateCenterCursor2D(t);
-		else if(t->spacetype==SPACE_IPO)
+		else if (t->spacetype==SPACE_IPO)
 			calculateCenterCursorGraph2D(t);
 		else
 			calculateCenterCursor(t);
@@ -1537,12 +1519,12 @@ void calculateCenter(TransInfo *t)
 		/* EDIT MODE ACTIVE EDITMODE ELEMENT */
 
 		if (t->obedit) {
-			if(t->obedit->type == OB_MESH) {
-				EditSelection ese;
-				EditMesh *em = BKE_mesh_get_editmesh(t->obedit->data);
+			if (t->obedit && t->obedit->type == OB_MESH) {
+				BMEditSelection ese;
+				BMEditMesh *em = BMEdit_FromObject(t->obedit);
 
-				if (EM_get_actSelection(em, &ese)) {
-					EM_editselection_center(t->center, &ese);
+				if (BM_select_history_active_get(em->bm, &ese)) {
+					BM_editselection_center(&ese, t->center);
 					calculateCenter2D(t);
 					break;
 				}
@@ -1560,12 +1542,11 @@ void calculateCenter(TransInfo *t)
 		} /* END EDIT MODE ACTIVE ELEMENT */
 
 		calculateCenterMedian(t);
-		if((t->flag & (T_EDIT|T_POSE))==0)
+		if ((t->flag & (T_EDIT|T_POSE))==0)
 		{
 			Scene *scene = t->scene;
 			Object *ob= OBACT;
-			if(ob)
-			{
+			if (ob) {
 				copy_v3_v3(t->center, ob->obmat[3]);
 				projectIntView(t, t->center, t->center2d);
 			}
@@ -1576,23 +1557,19 @@ void calculateCenter(TransInfo *t)
 	
 	/* setting constraint center */
 	copy_v3_v3(t->con.center, t->center);
-	if(t->flag & (T_EDIT|T_POSE))
-	{
+	if (t->flag & (T_EDIT|T_POSE)) {
 		Object *ob= t->obedit?t->obedit:t->poseobj;
 		mul_m4_v3(ob->obmat, t->con.center);
 	}
 	
 	/* for panning from cameraview */
-	if(t->flag & T_OBJECT)
-	{
-		if(t->spacetype==SPACE_VIEW3D && t->ar && t->ar->regiontype == RGN_TYPE_WINDOW)
-		{
+	if (t->flag & T_OBJECT) {
+		if (t->spacetype==SPACE_VIEW3D && t->ar && t->ar->regiontype == RGN_TYPE_WINDOW) {
 			View3D *v3d = t->view;
 			Scene *scene = t->scene;
 			RegionView3D *rv3d = t->ar->regiondata;
 			
-			if(v3d->camera == OBACT && rv3d->persp==RV3D_CAMOB)
-			{
+			if (v3d->camera == OBACT && rv3d->persp==RV3D_CAMOB) {
 				float axis[3];
 				/* persinv is nasty, use viewinv instead, always right */
 				copy_v3_v3(axis, t->viewinv[2]);
@@ -1606,7 +1583,7 @@ void calculateCenter(TransInfo *t)
 				projectIntView(t, axis, t->center2d);
 				
 				/* rotate only needs correct 2d center, grab needs initgrabz() value */
-				if(t->mode==TFM_TRANSLATION)
+				if (t->mode==TFM_TRANSLATION)
 				{
 					copy_v3_v3(t->center, axis);
 					copy_v3_v3(t->con.center, t->center);
@@ -1615,10 +1592,9 @@ void calculateCenter(TransInfo *t)
 		}
 	}
 	
-	if(t->spacetype==SPACE_VIEW3D)
-	{
+	if (t->spacetype==SPACE_VIEW3D) {
 		/* initgrabz() defines a factor for perspective depth correction, used in window_to_3d_delta() */
-		if(t->flag & (T_EDIT|T_POSE)) {
+		if (t->flag & (T_EDIT|T_POSE)) {
 			Object *ob= t->obedit?t->obedit:t->poseobj;
 			float vec[3];
 			
@@ -1640,12 +1616,11 @@ void calculatePropRatio(TransInfo *t)
 	short connected = t->flag & T_PROP_CONNECTED;
 
 	if (t->flag & T_PROP_EDIT) {
-		for(i = 0 ; i < t->total; i++, td++) {
+		for (i = 0 ; i < t->total; i++, td++) {
 			if (td->flag & TD_SELECTED) {
 				td->factor = 1.0f;
 			}
-			else if (t->flag & T_MIRROR && td->loc[0] * t->mirror < -0.00001f)
-			{
+			else if (t->flag & T_MIRROR && td->loc[0] * t->mirror < -0.00001f) {
 				td->flag |= TD_SKIP;
 				td->factor = 0.0f;
 				restoreElement(td);
@@ -1654,11 +1629,12 @@ void calculatePropRatio(TransInfo *t)
 						(td->flag & TD_NOTCONNECTED || td->dist > t->prop_size))
 				||
 					(connected == 0 &&
-						td->rdist > t->prop_size)) {
+						td->rdist > t->prop_size))
+			{
 				/*
-				   The elements are sorted according to their dist member in the array,
-				   that means we can stop when it finds one element outside of the propsize.
-				*/
+				 * The elements are sorted according to their dist member in the array,
+				 * that means we can stop when it finds one element outside of the propsize.
+				 */
 				td->flag |= TD_NOACTION;
 				td->factor = 0.0f;
 				restoreElement(td);
@@ -1735,7 +1711,7 @@ void calculatePropRatio(TransInfo *t)
 		}
 	}
 	else {
-		for(i = 0 ; i < t->total; i++, td++) {
+		for (i = 0 ; i < t->total; i++, td++) {
 			td->factor = 1.0;
 		}
 		t->proptext[0]= '\0';
