@@ -90,8 +90,6 @@ typedef float Vector3[3];
 typedef float Vector4[4];
 struct IK_Target;
 typedef void (*ErrorCallback)(const iTaSC::ConstraintValues* values, unsigned int nvalues, IK_Target* iktarget);
-// For some reason, gcc doesn't find the declaration of this function in linux
-void KDL::SetToZero(JntArray& array);
 
 // one structure for each target in the scene
 struct IK_Target
@@ -200,7 +198,7 @@ struct IK_Scene
 		// delete scene first
 		if (scene)
 			delete scene;
-		for(std::vector<IK_Target*>::iterator it = targets.begin();	it != targets.end(); ++it)
+		for (std::vector<IK_Target*>::iterator it = targets.begin();	it != targets.end(); ++it)
 			delete (*it);
 		targets.clear();
 		if (channels)
@@ -247,21 +245,21 @@ static int initialize_chain(Object *ob, bPoseChannel *pchan_tip, bConstraint *co
 	data=(bKinematicConstraint*)con->data;
 	
 	/* exclude tip from chain? */
-	if(!(data->flag & CONSTRAINT_IK_TIP))
+	if (!(data->flag & CONSTRAINT_IK_TIP))
 		pchan_tip= pchan_tip->parent;
 	
 	rootbone = data->rootbone;
 	/* Find the chain's root & count the segments needed */
-	for (curchan = pchan_tip; curchan; curchan=curchan->parent){
+	for (curchan = pchan_tip; curchan; curchan=curchan->parent) {
 		pchan_root = curchan;
 		
 		if (++segcount > 255)		// 255 is weak
 			break;
 
-		if(segcount==rootbone){
+		if (segcount==rootbone) {
 			// reached this end of the chain but if the chain is overlapping with a 
 			// previous one, we must go back up to the root of the other chain
-			if ((curchan->flag & POSE_CHAIN) && curchan->iktree.first == NULL){
+			if ((curchan->flag & POSE_CHAIN) && curchan->iktree.first == NULL) {
 				rootbone++;
 				continue;
 			}
@@ -270,7 +268,7 @@ static int initialize_chain(Object *ob, bPoseChannel *pchan_tip, bConstraint *co
 
 		if (curchan->iktree.first != NULL)
 			// Oh oh, there is already a chain starting from this channel and our chain is longer... 
-			// Should handle this by moving the previous chain up to the begining of our chain
+			// Should handle this by moving the previous chain up to the beginning of our chain
 			// For now we just stop here
 			break;
 	}
@@ -291,7 +289,7 @@ static int initialize_chain(Object *ob, bPoseChannel *pchan_tip, bConstraint *co
 	// by contruction there can be only one tree per channel and each channel can be part of at most one tree.
 	tree = (PoseTree*)pchan_root->iktree.first;
 
-	if(tree==NULL) {
+	if (tree==NULL) {
 		/* make new tree */
 		tree= (PoseTree*)MEM_callocN(sizeof(PoseTree), "posetree");
 
@@ -301,7 +299,7 @@ static int initialize_chain(Object *ob, bPoseChannel *pchan_tip, bConstraint *co
 		
 		tree->pchan= (bPoseChannel**)MEM_callocN(segcount*sizeof(void*), "ik tree pchan");
 		tree->parent= (int*)MEM_callocN(segcount*sizeof(int), "ik tree parent");
-		for(a=0; a<segcount; a++) {
+		for (a=0; a<segcount; a++) {
 			tree->pchan[a]= chanlist[segcount-a-1];
 			tree->parent[a]= a-1;
 		}
@@ -324,19 +322,19 @@ static int initialize_chain(Object *ob, bPoseChannel *pchan_tip, bConstraint *co
 			for (;t<tree->totchannel && tree->pchan[t]!=chanlist[segcount-a-1];t++);
 			if (t>=tree->totchannel)
 				break;
-			for(; a<size && t<tree->totchannel && tree->pchan[t]==chanlist[segcount-a-1]; a++, t++);
+			for (; a<size && t<tree->totchannel && tree->pchan[t]==chanlist[segcount-a-1]; a++, t++);
 		}
 
 		segcount= segcount-a;
 		target->tip= tree->totchannel + segcount - 1;
 
 		if (segcount > 0) {
-			for(parent = a - 1; parent < tree->totchannel; parent++)
-				if(tree->pchan[parent] == chanlist[segcount-1]->parent)
+			for (parent = a - 1; parent < tree->totchannel; parent++)
+				if (tree->pchan[parent] == chanlist[segcount-1]->parent)
 					break;
 			
 			/* shouldn't happen, but could with dependency cycles */
-			if(parent == tree->totchannel)
+			if (parent == tree->totchannel)
 				parent = a - 1;
 
 			/* resize array */
@@ -352,7 +350,7 @@ static int initialize_chain(Object *ob, bPoseChannel *pchan_tip, bConstraint *co
 			MEM_freeN(oldparent);
 
 			/* add new pose channels at the end, in reverse order */
-			for(a=0; a<segcount; a++) {
+			for (a=0; a<segcount; a++) {
 				tree->pchan[tree->totchannel+a]= chanlist[segcount-a-1];
 				tree->parent[tree->totchannel+a]= tree->totchannel+a-1;
 			}
@@ -403,8 +401,8 @@ int initialize_scene(Object *ob, bPoseChannel *pchan_tip)
 
 	/* find all IK constraints and validate them */
 	treecount = 0;
-	for(con= (bConstraint *)pchan_tip->constraints.first; con; con= (bConstraint *)con->next) {
-		if(con->type==CONSTRAINT_TYPE_KINEMATIC) {
+	for (con= (bConstraint *)pchan_tip->constraints.first; con; con= (bConstraint *)con->next) {
+		if (con->type==CONSTRAINT_TYPE_KINEMATIC) {
 			if (constraint_valid(con))
 				treecount += initialize_chain(ob, pchan_tip, con);
 		}
@@ -430,13 +428,14 @@ static double EulerAngleFromMatrix(const KDL::Rotation& R, int axis)
 
 	if (t > 16.0*KDL::epsilon) {
 		if (axis == 0) return -KDL::atan2(R(1,2), R(2,2));
-        else if(axis == 1) return KDL::atan2(-R(0,2), t);
-        else return -KDL::atan2(R(0,1), R(0,0));
-    } else {
+		else if (axis == 1) return KDL::atan2(-R(0,2), t);
+		else return -KDL::atan2(R(0,1), R(0,0));
+	}
+	else {
 		if (axis == 0) return -KDL::atan2(-R(2,1), R(1,1));
-        else if(axis == 1) return KDL::atan2(-R(0,2), t);
-        else return 0.0f;
-    }
+		else if (axis == 1) return KDL::atan2(-R(0,2), t);
+		else return 0.0f;
+	}
 }
 
 static double ComputeTwist(const KDL::Rotation& R)
@@ -475,27 +474,29 @@ static void RemoveEulerAngleFromMatrix(KDL::Rotation& R, double angle, int axis)
 static void GetEulerXZY(const KDL::Rotation& R, double& X,double& Z,double& Y)
 {
 	if (fabs(R(0,1)) > 1.0 - KDL::epsilon ) {
-        X = -KDL::sign(R(0,1)) * KDL::atan2(R(1,2), R(1,0));
-        Z = -KDL::sign(R(0,1)) * KDL::PI / 2;
-        Y = 0.0 ;
-    } else {
-        X = KDL::atan2(R(2,1), R(1,1));
-        Z = KDL::atan2(-R(0,1), KDL::sqrt( KDL::sqr(R(0,0)) + KDL::sqr(R(0,2))));
-        Y = KDL::atan2(R(0,2), R(0,0));
-    }
+		X = -KDL::sign(R(0,1)) * KDL::atan2(R(1,2), R(1,0));
+		Z = -KDL::sign(R(0,1)) * KDL::PI / 2;
+		Y = 0.0;
+	}
+	else {
+		X = KDL::atan2(R(2,1), R(1,1));
+		Z = KDL::atan2(-R(0,1), KDL::sqrt( KDL::sqr(R(0,0)) + KDL::sqr(R(0,2))));
+		Y = KDL::atan2(R(0,2), R(0,0));
+	}
 }
 
 static void GetEulerXYZ(const KDL::Rotation& R, double& X,double& Y,double& Z)
 {
 	if (fabs(R(0,2)) > 1.0 - KDL::epsilon ) {
-        X = KDL::sign(R(0,2)) * KDL::atan2(-R(1,0), R(1,1));
-        Y = KDL::sign(R(0,2)) * KDL::PI / 2;
-        Z = 0.0 ;
-    } else {
-        X = KDL::atan2(-R(1,2), R(2,2));
-        Y = KDL::atan2(R(0,2), KDL::sqrt( KDL::sqr(R(0,0)) + KDL::sqr(R(0,1))));
-        Z = KDL::atan2(-R(0,1), R(0,0));
-    }
+		X = KDL::sign(R(0,2)) * KDL::atan2(-R(1,0), R(1,1));
+		Y = KDL::sign(R(0,2)) * KDL::PI / 2;
+		Z = 0.0;
+	}
+	else {
+		X = KDL::atan2(-R(1,2), R(2,2));
+		Y = KDL::atan2(R(0,2), KDL::sqrt( KDL::sqr(R(0,0)) + KDL::sqr(R(0,1))));
+		Z = KDL::atan2(-R(0,1), R(0,0));
+	}
 }
 #endif
 
@@ -693,7 +694,8 @@ static bool copypose_callback(const iTaSC::Timestamp& timestamp, iTaSC::Constrai
 			values->action = iTaSC::ACT_ALPHA;
 			values++;
 		}
-	} else {
+	}
+	else {
 		if (iktarget->controlType & iTaSC::CopyPose::CTL_POSITION) {
 			// update error
 			values->alpha = condata->weight;
@@ -747,7 +749,8 @@ static bool distance_callback(const iTaSC::Timestamp& timestamp, iTaSC::Constrai
 	// update weight according to mode
 	if (iktarget->blenderConstraint->flag & CONSTRAINT_OFF) {
 		values->alpha = 0.0;
-	} else {
+	}
+	else {
 		switch (condata->mode) {
 		case LIMITDIST_INSIDE:
 			values->alpha = (values->values[0].y > condata->dist) ? condata->weight : 0.0;
@@ -870,7 +873,7 @@ static int convert_channels(IK_Scene *ikscene, PoseTree *tree)
 	int a, flag, njoint;
 
 	njoint = 0;
-	for(a=0, ikchan = ikscene->channels; a<ikscene->numchan; ++a, ++ikchan) {
+	for (a=0, ikchan = ikscene->channels; a<ikscene->numchan; ++a, ++ikchan) {
 		pchan= tree->pchan[a];
 		ikchan->pchan = pchan;
 		ikchan->parent = (a>0) ? tree->parent[a] : -1;
@@ -878,47 +881,46 @@ static int convert_channels(IK_Scene *ikscene, PoseTree *tree)
 		
 		/* set DoF flag */
 		flag = 0;
-		if(!(pchan->ikflag & BONE_IK_NO_XDOF) && !(pchan->ikflag & BONE_IK_NO_XDOF_TEMP) && 
+		if (!(pchan->ikflag & BONE_IK_NO_XDOF) && !(pchan->ikflag & BONE_IK_NO_XDOF_TEMP) && 
 			(!(pchan->ikflag & BONE_IK_XLIMIT) || pchan->limitmin[0]<0.f || pchan->limitmax[0]>0.f))
 			flag |= IK_XDOF;
-		if(!(pchan->ikflag & BONE_IK_NO_YDOF) && !(pchan->ikflag & BONE_IK_NO_YDOF_TEMP) &&
+		if (!(pchan->ikflag & BONE_IK_NO_YDOF) && !(pchan->ikflag & BONE_IK_NO_YDOF_TEMP) &&
 			(!(pchan->ikflag & BONE_IK_YLIMIT) || pchan->limitmin[1]<0.f || pchan->limitmax[1]>0.f))
 			flag |= IK_YDOF;
-		if(!(pchan->ikflag & BONE_IK_NO_ZDOF) && !(pchan->ikflag & BONE_IK_NO_ZDOF_TEMP) &&
+		if (!(pchan->ikflag & BONE_IK_NO_ZDOF) && !(pchan->ikflag & BONE_IK_NO_ZDOF_TEMP) &&
 			(!(pchan->ikflag & BONE_IK_ZLIMIT) || pchan->limitmin[2]<0.f || pchan->limitmax[2]>0.f))
 			flag |= IK_ZDOF;
 		
-		if(tree->stretch && (pchan->ikstretch > 0.0)) {
+		if (tree->stretch && (pchan->ikstretch > 0.0)) {
 			flag |= IK_TRANSY;
 		}
 		/*
-		Logic to create the segments:
-		RX,RY,RZ = rotational joints with no length
-		RY(tip) = rotational joints with a fixed length arm = (0,length,0)
-		TY = translational joint on Y axis
-		F(pos) = fixed joint with an arm at position pos 
-		Conversion rule of the above flags:
-		-   ==> F(tip)
-		X   ==> RX(tip)
-		Y   ==> RY(tip)
-		Z   ==> RZ(tip)
-		XY  ==> RX+RY(tip)
-		XZ  ==> RX+RZ(tip)
-		YZ  ==> RZ+RY(tip)
-		XYZ ==> full spherical unless there are limits, in which case RX+RZ+RY(tip)
-		In case of stretch, tip=(0,0,0) and there is an additional TY joint
-		The frame at last of these joints represents the tail of the bone. 
-		The head is computed by a reverse translation on Y axis of the bone length
-		or in case of TY joint, by the frame at previous joint.
-		In case of separation of bones, there is an additional F(head) joint
-
-		Computing rest pose and length is complicated: the solver works in world space
-		Here is the logic:
-		rest position is computed only from bone->bone_mat.
-		bone length is computed from bone->length multiplied by the scaling factor of
-		the armature. Non-uniform scaling will give bad result!
-
-		*/
+		 * Logic to create the segments:
+		 * RX,RY,RZ = rotational joints with no length
+		 * RY(tip) = rotational joints with a fixed length arm = (0,length,0)
+		 * TY = translational joint on Y axis
+		 * F(pos) = fixed joint with an arm at position pos
+		 * Conversion rule of the above flags:
+		 * -   ==> F(tip)
+		 * X   ==> RX(tip)
+		 * Y   ==> RY(tip)
+		 * Z   ==> RZ(tip)
+		 * XY  ==> RX+RY(tip)
+		 * XZ  ==> RX+RZ(tip)
+		 * YZ  ==> RZ+RY(tip)
+		 * XYZ ==> full spherical unless there are limits, in which case RX+RZ+RY(tip)
+		 * In case of stretch, tip=(0,0,0) and there is an additional TY joint
+		 * The frame at last of these joints represents the tail of the bone.
+		 * The head is computed by a reverse translation on Y axis of the bone length
+		 * or in case of TY joint, by the frame at previous joint.
+		 * In case of separation of bones, there is an additional F(head) joint
+		 *
+		 * Computing rest pose and length is complicated: the solver works in world space
+		 * Here is the logic:
+		 * rest position is computed only from bone->bone_mat.
+		 * bone length is computed from bone->length multiplied by the scaling factor of
+		 * the armature. Non-uniform scaling will give bad result!
+		 */
 		switch (flag & (IK_XDOF|IK_YDOF|IK_ZDOF))
 		{
 		default:
@@ -992,14 +994,15 @@ static void convert_pose(IK_Scene *ikscene)
 	// assume uniform scaling and take Y scale as general scale for the armature
 	scale = len_v3(ikscene->blArmature->obmat[1]);
 	rot = &ikscene->jointArray(0);
-	for(joint=a=0, ikchan = ikscene->channels; a<ikscene->numchan && joint<ikscene->numjoint; ++a, ++ikchan) {
+	for (joint=a=0, ikchan = ikscene->channels; a<ikscene->numchan && joint<ikscene->numjoint; ++a, ++ikchan) {
 		pchan= ikchan->pchan;
 		bone= pchan->bone;
 		
 		if (pchan->parent) {
 			unit_m4(bmat);
 			mul_m4_m4m3(bmat, pchan->parent->pose_mat, bone->bone_mat);
-		} else {
+		}
+		else {
 			copy_m4_m4(bmat, bone->arm_mat);
 		}
 		invert_m4_m4(rmat, bmat);
@@ -1029,10 +1032,10 @@ static void rest_pose(IK_Scene *ikscene)
 	// assume uniform scaling and take Y scale as general scale for the armature
 	scale = len_v3(ikscene->blArmature->obmat[1]);
 	// rest pose is 0 
-	KDL::SetToZero(ikscene->jointArray);
+	SetToZero(ikscene->jointArray);
 	// except for transY joints
 	rot = &ikscene->jointArray(0);
-	for(joint=a=0, ikchan = ikscene->channels; a<ikscene->numchan && joint<ikscene->numjoint; ++a, ++ikchan) {
+	for (joint=a=0, ikchan = ikscene->channels; a<ikscene->numchan && joint<ikscene->numjoint; ++a, ++ikchan) {
 		pchan= ikchan->pchan;
 		bone= pchan->bone;
 
@@ -1079,7 +1082,8 @@ static IK_Scene* convert_tree(Scene *blscene, Object *ob, bPoseChannel *pchan)
 	if (!ikparam) {
 		// you must have our own copy
 		ikparam = &DefIKParam;
-	} else if (ingame) {
+	}
+	else if (ingame) {
 		// tweak the param when in game to have efficient stepping
 		// using fixed substep is not effecient since frames in the GE are often
 		// shorter than in animation => move to auto step automatically and set
@@ -1123,12 +1127,13 @@ static IK_Scene* convert_tree(Scene *blscene, Object *ob, bPoseChannel *pchan)
 		// in the GE, set the initial joint angle to match the current pose
 		// this will update the jointArray in ikscene
 		convert_pose(ikscene);
-	} else {
+	}
+	else {
 		// in Blender, the rest pose is always 0 for joints
 		rest_pose(ikscene);
 	}
 	rot = &ikscene->jointArray(0);
-	for(a=0, ikchan = ikscene->channels; a<tree->totchannel; ++a, ++ikchan) {
+	for (a=0, ikchan = ikscene->channels; a<tree->totchannel; ++a, ++ikchan) {
 		pchan= ikchan->pchan;
 		bone= pchan->bone;
 
@@ -1396,7 +1401,8 @@ static IK_Scene* convert_tree(Scene *blscene, Object *ob, bPoseChannel *pchan)
 		// move to the tail and scale to get rest pose of armature base
 		copy_v3_v3(baseFrame[3], pchan->bone->arm_tail);
 		invert_m4_m4(invBaseFrame, baseFrame);
-	} else {
+	}
+	else {
 		unit_m4(invBaseFrame);
 	}
 	// finally add the constraint
@@ -1494,7 +1500,7 @@ static void create_scene(Scene *scene, Object *ob)
 	bPoseChannel *pchan;
 
 	// create the IK scene
-	for(pchan= (bPoseChannel *)ob->pose->chanbase.first; pchan; pchan= (bPoseChannel *)pchan->next) {
+	for (pchan= (bPoseChannel *)ob->pose->chanbase.first; pchan; pchan= (bPoseChannel *)pchan->next) {
 		// by construction there is only one tree
 		PoseTree *tree = (PoseTree*)pchan->iktree.first;
 		if (tree) {
@@ -1509,9 +1515,9 @@ static void create_scene(Scene *scene, Object *ob)
 			while(tree) {
 				BLI_remlink(&pchan->iktree, tree);
 				BLI_freelistN(&tree->targets);
-				if(tree->pchan) MEM_freeN(tree->pchan);
-				if(tree->parent) MEM_freeN(tree->parent);
-				if(tree->basis_change) MEM_freeN(tree->basis_change);
+				if (tree->pchan) MEM_freeN(tree->pchan);
+				if (tree->parent) MEM_freeN(tree->parent);
+				if (tree->basis_change) MEM_freeN(tree->basis_change);
 				MEM_freeN(tree);
 				tree = (PoseTree*)pchan->iktree.first;
 			}
@@ -1522,7 +1528,7 @@ static void create_scene(Scene *scene, Object *ob)
 static void init_scene(Object *ob)
 {
 	if (ob->pose->ikdata) {
-		for(IK_Scene* scene = ((IK_Data*)ob->pose->ikdata)->first;
+		for (IK_Scene* scene = ((IK_Data*)ob->pose->ikdata)->first;
 			scene != NULL;
 			scene = scene->next) {
 			scene->channels[0].pchan->flag |= POSE_IKTREE;
@@ -1541,9 +1547,10 @@ static void execute_scene(Scene* blscene, IK_Scene* ikscene, bItasc* ikparam, fl
 			ikchan->pchan->flag |= (POSE_DONE|POSE_CHAIN);
 			ikchan->jointValid = 0;
 		}
-	} else {
+	}
+	else {
 		// in animation mode, we must get the bone position from action and constraints
-		for(i=0, ikchan=ikscene->channels; i<ikscene->numchan; i++, ++ikchan) {
+		for (i=0, ikchan=ikscene->channels; i<ikscene->numchan; i++, ++ikchan) {
 			if (!(ikchan->pchan->flag & POSE_DONE))
 				where_is_pose_bone(blscene, ikscene->blArmature, ikchan->pchan, ctime, 1);
 			// tell blender that this channel was controlled by IK, it's cleared on each where_is_pose()
@@ -1592,7 +1599,8 @@ static void execute_scene(Scene* blscene, IK_Scene* ikscene, bItasc* ikparam, fl
 			// the cache is empty before this time, reiterate
 			if (ikparam->flag & ITASC_INITIAL_REITERATION)
 				reiterate = true;
-		} else {
+		}
+		else {
 			// can take the cache as a start point.
 			sts -= cts;
 			timestep = sts/1000.0;
@@ -1703,8 +1711,8 @@ void itasc_initialize_tree(struct Scene *scene, Object *ob, float ctime)
 	itasc_clear_data(ob->pose);
 	// we should handle all the constraint and mark them all disabled
 	// for blender but we'll start with the IK constraint alone
-	for(pchan= (bPoseChannel *)ob->pose->chanbase.first; pchan; pchan= (bPoseChannel *)pchan->next) {
-		if(pchan->constflag & PCHAN_HAS_IK)
+	for (pchan= (bPoseChannel *)ob->pose->chanbase.first; pchan; pchan= (bPoseChannel *)pchan->next) {
+		if (pchan->constflag & PCHAN_HAS_IK)
 			count += initialize_scene(ob, pchan);
 	}
 	// if at least one tree, create the scenes from the PoseTree stored in the channels 
@@ -1783,7 +1791,8 @@ void itasc_update_param(struct bPose *pose)
 				ikscene->scene->setParam(iTaSC::Scene::MAX_TIMESTEP, ikparam->maxstep);
 				ikscene->solver->setParam(iTaSC::Solver::DLS_QMAX, ikparam->maxvel);
 				ikscene->armature->setControlParameter(CONSTRAINT_ID_ALL, iTaSC::Armature::ID_JOINT, iTaSC::ACT_FEEDBACK, ikparam->feedback);
-			} else {
+			}
+			else {
 				// in animation mode timestep is 1s by convention => 
 				// qmax becomes radiant and feedback becomes fraction of error gap corrected in one iteration
 				ikscene->scene->setParam(iTaSC::Scene::MIN_TIMESTEP, 1.0);
