@@ -30,33 +30,32 @@
  */
 
 /**
- * @file IMB_imbuf.h
- * @brief IMage Buffer module.
+ * \brief IMage Buffer module.
  *
  * This module offers import/export of several graphical file formats.
- * @ingroup imbuf
+ * \ingroup imbuf
  *
- * @page IMB Imbuf module external interface
+ * \page IMB Imbuf module external interface
  *
  *
- * @section about About the IMB module
+ * \section about About the IMB module
  *
  * External interface of the IMage Buffer module. This module offers
  * import/export of several graphical file formats. It offers the
  * ImBuf type as a common structure to refer to different graphical
  * file formats, and to enable a uniform way of handling them.
  *
- * @section issues Known issues with IMB
+ * \section issues Known issues with IMB
  *
  * - imbuf is written in C.
  * - Endianness issues are dealt with internally.
  * - File I/O must be done externally. The module uses FILE*'s to
  *   direct input/output.
  * - Platform dependency is limited. Some minor patches for
- *   amiga and Irix are present. A 'posix-compliancy-patch'
+ *   amiga and Irix are present. A 'posix-compliance-patch'
  *   provides the interface to windows.
  *
- * @section dependencies Dependencies
+ * \section dependencies Dependencies
  *
  * IMB needs:
  * - \ref DNA module
@@ -64,60 +63,60 @@
  *     management.
  * - \ref blenlib module
  *     blenlib handles guarded memory management in blender-style.
- *     BLI_winstuff.h makes a few windows specific behaviours
+ *     BLI_winstuff.h makes a few windows specific behaviors
  *     posix-compliant.
  */
 
-#ifndef IMB_IMBUF_H
-#define IMB_IMBUF_H
+#ifndef __IMB_IMBUF_H__
+#define __IMB_IMBUF_H__
 
 /**
  *
- * @attention defined in ???
+ * \attention defined in ???
  */
 struct ImBuf;
 
 /**
  *
- * @attention defined in ???
+ * \attention defined in ???
  */
 struct anim;
 
 /**
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 void IMB_init(void);
 void IMB_exit(void);
 
 /**
  *
- * @attention Defined in readimage.c
+ * \attention Defined in readimage.c
  */
 struct ImBuf *IMB_ibImageFromMemory(unsigned char *mem, size_t size,
                                     int flags, const char *descr);
 
 /**
  *
- * @attention Defined in readimage.c
+ * \attention Defined in readimage.c
  */
 struct ImBuf *IMB_testiffname(const char *filepath, int flags);
 
 /**
  *
- * @attention Defined in readimage.c
+ * \attention Defined in readimage.c
  */
 struct ImBuf *IMB_loadiffname(const char *filepath, int flags);
 
 /**
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 void IMB_freeImBuf(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 struct ImBuf *IMB_allocImBuf(unsigned int x, unsigned int y,
                              unsigned char d, unsigned int flags);
@@ -128,7 +127,7 @@ struct ImBuf *IMB_allocImBuf(unsigned int x, unsigned int y,
  * (to delete an imbuf you have to call freeImBuf as many times as it
  * is referenced)
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 
 void IMB_refImBuf(struct ImBuf *ibuf);
@@ -136,20 +135,20 @@ struct ImBuf * IMB_makeSingleUser(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 struct ImBuf *IMB_dupImBuf(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 short addzbufImBuf(struct ImBuf *ibuf);
 short addzbuffloatImBuf(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in rectop.c
+ * \attention Defined in rectop.c
  */
 
 typedef enum IMB_BlendMode {
@@ -181,25 +180,24 @@ void IMB_rectblend(struct ImBuf *dbuf, struct ImBuf *sbuf, int destx,
 
 /**
  *
- * @attention Defined in indexer.c
+ * \attention Defined in indexer.c
  */
 
 typedef enum IMB_Timecode_Type {
 	IMB_TC_NONE       = 0, /* don't use timecode files at all */
-	IMB_TC_RECORD_RUN = 1, /* use images in the order as they are recorded 
-				  (currently, this is the only one implemented
-				  and is a sane default)
-			       */
+
+	IMB_TC_RECORD_RUN = 1, /* use images in the order as they are recorded
+	                        * (currently, this is the only one implemented
+	                        * and is a sane default) */
+
 	IMB_TC_FREE_RUN   = 2, /* use global timestamp written by recording
-				  device (prosumer camcorders e.g. can do
-				  that) */
-	IMB_TC_INTERPOLATED_REC_DATE_FREE_RUN = 4, 
-                               /* interpolate a global timestamp using the
-				  record date and time written by recording
-				  device (*every* consumer camcorder can do
-				  that :) )*/
+                            * device (prosumer camcorders e.g. can do that) */
+	IMB_TC_INTERPOLATED_REC_DATE_FREE_RUN = 4, /* interpolate a global timestamp using the
+	                                            * record date and time written by recording
+	                                            * device (*every* consumer camcorder can do
+	                                            * that :) )*/
 	IMB_TC_RECORD_RUN_NO_GAPS = 8,
-	IMB_TC_MAX_SLOT   = 8
+	IMB_TC_MAX_SLOT   = 4
 } IMB_Timecode_Type;
 
 typedef enum IMB_Proxy_Size {
@@ -217,15 +215,21 @@ void IMB_anim_set_index_dir(struct anim * anim, const char * dir);
 int IMB_anim_index_get_frame_index(struct anim * anim, IMB_Timecode_Type tc,
                                    int position);
 
+struct IndexBuildContext;
+
+/* prepare context for proxies/imecodes builder */
+struct IndexBuildContext *IMB_anim_index_rebuild_context(struct anim *anim, IMB_Timecode_Type tcs_in_use,
+                                                         IMB_Proxy_Size proxy_sizes_in_use, int quality);
+
 /* will rebuild all used indices and proxies at once */
-void IMB_anim_index_rebuild(struct anim * anim, 
-                            IMB_Timecode_Type build_tcs,
-                            IMB_Proxy_Size build_preview_sizes,
-                            int build_quality,
+void IMB_anim_index_rebuild(struct IndexBuildContext *context,
                             short *stop, short *do_update, float *progress);
 
+/* finish rebuilding proxises/timecodes and free temporary contexts used */
+void IMB_anim_index_rebuild_finish(struct IndexBuildContext *context, short stop);
+
 /**
- * Return the length (in frames) of the given @a anim.
+ * Return the length (in frames) of the given \a anim.
  */
 int IMB_anim_get_duration(struct anim *anim, IMB_Timecode_Type tc);
 
@@ -239,15 +243,16 @@ int IMB_anim_get_fps(struct anim * anim,
 
 /**
  *
- * @attention Defined in anim_movie.c
+ * \attention Defined in anim_movie.c
  */
 struct anim *IMB_open_anim(const char *name, int ib_flags, int streamindex);
 void IMB_close_anim(struct anim *anim);
+void IMB_close_anim_proxies(struct anim *anim);
 
 
 /**
  *
- * @attention Defined in anim_movie.c
+ * \attention Defined in anim_movie.c
  */
 
 int ismovie(const char *filepath);
@@ -256,7 +261,7 @@ int IMB_anim_get_preseek(struct anim *anim);
 
 /**
  *
- * @attention Defined in anim_movie.c
+ * \attention Defined in anim_movie.c
  */
 
 struct ImBuf *IMB_anim_absolute(
@@ -266,20 +271,20 @@ struct ImBuf *IMB_anim_absolute(
 
 /**
  *
- * @attention Defined in anim_movie.c
+ * \attention Defined in anim_movie.c
  * fetches a define previewframe, usually half way into the movie
  */
 struct ImBuf *IMB_anim_previewframe(struct anim *anim);
 
 /**
  *
- * @attention Defined in anim_movie.c
+ * \attention Defined in anim_movie.c
  */
 void IMB_free_anim(struct anim *anim);
 
 /**
  *
- * @attention Defined in filter.c
+ * \attention Defined in filter.c
  */
 
 #define FILTER_MASK_NULL		0
@@ -297,7 +302,7 @@ struct ImBuf *IMB_getmipmap(struct ImBuf *ibuf, int level);
 
 /**
  *
- * @attention Defined in cache.c
+ * \attention Defined in cache.c
  */
 
 void IMB_tile_cache_params(int totthread, int maxmem);
@@ -306,70 +311,63 @@ void IMB_tiles_to_rect(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in filter.c
+ * \attention Defined in filter.c
  */
 void IMB_filtery(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in scaling.c
+ * \attention Defined in scaling.c
  */
 struct ImBuf *IMB_onehalf(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention Defined in scaling.c
+ * \attention Defined in scaling.c
  */
 struct ImBuf *IMB_scaleImBuf(struct ImBuf *ibuf, unsigned int newx, unsigned int newy);
 
 /**
  *
- * @attention Defined in scaling.c
+ * \attention Defined in scaling.c
  */
 struct ImBuf *IMB_scalefastImBuf(struct ImBuf *ibuf, unsigned int newx, unsigned int newy);
 
 /**
  *
- * @attention Defined in writeimage.c
+ * \attention Defined in writeimage.c
  */
 short IMB_saveiff(struct ImBuf *ibuf, const char *filepath, int flags);
 
 /**
- * Encodes a png image from an ImBuf
  *
- * @attention Defined in png_encode.c
- */
-short IMB_png_encode(struct ImBuf *ibuf, int file, int flags);
-
-/**
- *
- * @attention Defined in util.c
+ * \attention Defined in util.c
  */
 int IMB_ispic(const char *name);
 
 /**
  *
- * @attention Defined in util.c
+ * \attention Defined in util.c
  */
 int IMB_isanim(const char *name);
 
 /**
  *
- * @attention Defined in util.c
+ * \attention Defined in util.c
  */
 int imb_get_anim_type(const char *name);
 
 /**
  *
- * @attention Defined in divers.c
+ * \attention Defined in divers.c
  */
 void IMB_de_interlace(struct ImBuf *ibuf);
 void IMB_interlace(struct ImBuf *ibuf);
 
 /* create char buffer, color corrected if necessary, for ImBufs that lack one */ 
 void IMB_rect_from_float(struct ImBuf *ibuf);
-/* create char buffer for part of the image, color corrected if necessary,
-   Changed part will be stored in buffer. This is expected to be used for texture painting updates */ 
+/* Create char buffer for part of the image, color corrected if necessary,
+ * Changed part will be stored in buffer. This is expected to be used for texture painting updates */
 void IMB_partial_rect_from_float(struct ImBuf *ibuf, float *buffer, int x, int y, int w, int h);
 void IMB_float_from_rect(struct ImBuf *ibuf);
 void IMB_float_from_rect_simple(struct ImBuf *ibuf); /* no profile conversion */
@@ -377,6 +375,7 @@ void IMB_float_from_rect_simple(struct ImBuf *ibuf); /* no profile conversion */
 void IMB_convert_profile(struct ImBuf *ibuf, int profile);
 float *IMB_float_profile_ensure(struct ImBuf *ibuf, int profile, int *alloc);
 void IMB_color_to_bw(struct ImBuf *ibuf);
+void IMB_saturation(struct ImBuf *ibuf, float sat);
 
 /* converting pixel buffers */
 void IMB_buffer_byte_from_float(unsigned char *rect_to, const float *rect_from,
@@ -397,21 +396,13 @@ void IMB_buffer_float_clamp(float *buf, int width, int height);
  * Change the ordering of the color bytes pointed to by rect from
  * rgba to abgr. size * 4 color bytes are reordered.
  *
- * @attention Defined in imageprocess.c
+ * \attention Defined in imageprocess.c
  */
 void IMB_convert_rgba_to_abgr(struct ImBuf *ibuf);
 
 /**
- * Change the ordering of the color bytes pointed to by rect from
- * rgba to abgr. size * 4 color bytes are reordered.
  *
- * @attention Defined in imageprocess.c
- */
-void IMB_convert_bgra_to_rgba(int size, unsigned int *rect);
-
-/**
- *
- * @attention defined in imageprocess.c
+ * \attention defined in imageprocess.c
  */
 void bicubic_interpolation(struct ImBuf *in, struct ImBuf *out, float u, float v, int xout, int yout);
 void neareast_interpolation(struct ImBuf *in, struct ImBuf *out, float u, float v, int xout, int yout);
@@ -424,51 +415,51 @@ void bilinear_interpolation_color_wrap(struct ImBuf *in, unsigned char *col, flo
 
 /**
  *
- * @attention defined in readimage.c
- * @deprecated Only here for backwards compatibility of the
- * @deprecated plugin system.
+ * \attention defined in readimage.c
+ * \deprecated Only here for backwards compatibility of the
+ * \deprecated plugin system.
  */  
 struct ImBuf *IMB_loadifffile(int file, int flags, const char *descr);
 
 /**
  *
- * @attention defined in scaling.c
+ * \attention defined in scaling.c
  */
 struct ImBuf *IMB_half_x(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention defined in scaling.c
+ * \attention defined in scaling.c
  */
 struct ImBuf *IMB_double_fast_x(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention defined in scaling.c
+ * \attention defined in scaling.c
  */
 struct ImBuf *IMB_double_x(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention defined in scaling.c
+ * \attention defined in scaling.c
  */
 struct ImBuf *IMB_half_y(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention defined in scaling.c
+ * \attention defined in scaling.c
  */
 struct ImBuf *IMB_double_fast_y(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention defined in scaling.c
+ * \attention defined in scaling.c
  */
 struct ImBuf *IMB_double_y(struct ImBuf *ibuf1);
 
 /**
  *
- * @attention Defined in rotate.c
+ * \attention Defined in rotate.c
  */
 void IMB_flipx(struct ImBuf *ibuf);
 void IMB_flipy(struct ImBuf *ibuf);
@@ -479,14 +470,14 @@ void IMB_premultiply_alpha(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in allocimbuf.c
+ * \attention Defined in allocimbuf.c
  */
 void IMB_freezbufImBuf(struct ImBuf *ibuf);
 void IMB_freezbuffloatImBuf(struct ImBuf *ibuf);
 
 /**
  *
- * @attention Defined in rectop.c
+ * \attention Defined in rectop.c
  */
 void IMB_rectfill(struct ImBuf *drect, const float col[4]);
 void IMB_rectfill_area(struct ImBuf *ibuf, float *col, int x1, int y1, int x2, int y2);
