@@ -40,11 +40,11 @@
 #include "IMB_filetype.h"
 
 /* some code copied from article on microsoft.com, copied
-  here for enhanced BMP support in the future
-  http://www.microsoft.com/msj/defaultframe.asp?page=/msj/0197/mfcp1/mfcp1.htm&nav=/msj/0197/newnav.htm
-*/
+ * here for enhanced BMP support in the future
+ * http://www.microsoft.com/msj/defaultframe.asp?page=/msj/0197/mfcp1/mfcp1.htm&nav=/msj/0197/newnav.htm
+ */
 
-typedef struct BMPINFOHEADER{
+typedef struct BMPINFOHEADER {
 	unsigned int	biSize;
 	unsigned int	biWidth;
 	unsigned int	biHeight;
@@ -78,7 +78,8 @@ static int checkbmp(unsigned char *mem)
 		if ((mem[0] == 'B') && (mem[1] == 'M')) {
 			/* skip fileheader */
 			mem += BMP_FILEHEADER_SIZE;
-		} else {
+		}
+		else {
 		}
 
 		/* for systems where an int needs to be 4 bytes aligned */
@@ -129,13 +130,17 @@ struct ImBuf *imb_bmp_decode(unsigned char *mem, size_t size, int flags)
 	y = LITTLE_LONG(bmi.biHeight);
 	depth = LITTLE_SHORT(bmi.biBitCount);
 
-	/* printf("skip: %d, x: %d y: %d, depth: %d (%x)\n", skip, x, y, 
-		depth, bmi.biBitCount); */
-	/* printf("skip: %d, x: %d y: %d, depth: %d (%x)\n", skip, x, y, 
-		depth, bmi.biBitCount); */
+#if 0
+	printf("skip: %d, x: %d y: %d, depth: %d (%x)\n", skip, x, y,
+	       depth, bmi.biBitCount);
+	printf("skip: %d, x: %d y: %d, depth: %d (%x)\n", skip, x, y,
+	       depth, bmi.biBitCount);
+#endif
+
 	if (flags & IB_test) {
 		ibuf = IMB_allocImBuf(x, y, depth, 0);
-	} else {
+	}
+	else {
 		ibuf = IMB_allocImBuf(x, y, depth, IB_rect);
 		bmp = mem + skip;
 		rect = (unsigned char *) ibuf->rect;
@@ -151,7 +156,8 @@ struct ImBuf *imb_bmp_decode(unsigned char *mem, size_t size, int flags)
 				rect += 4; bmp += 2;
 			}
 
-		} else if (depth == 24) {
+		}
+		else if (depth == 24) {
 			for (i = y; i > 0; i--) {
 				int j;
 				for (j = x ; j > 0; j--) {
@@ -165,7 +171,8 @@ struct ImBuf *imb_bmp_decode(unsigned char *mem, size_t size, int flags)
 				/* for 24-bit images, rows are padded to multiples of 4 */
 				bmp += x % 4;	
 			}
-		} else if (depth == 32) {
+		}
+		else if (depth == 32) {
 			for (i = x * y; i > 0; i--) {
 				rect[0] = bmp[2];
 				rect[1] = bmp[1];
@@ -213,7 +220,7 @@ int imb_savebmp(struct ImBuf *ibuf, const char *name, int flags)
 	bytesize = (ibuf->x * 3 + extrabytes) * ibuf->y;
 
 	data = (uchar *) ibuf->rect;
-	ofile = fopen(name,"wb");
+	ofile = BLI_fopen(name,"wb");
 		if (!ofile) return 0;
 
 	putShortLSB(19778,ofile); /* "BM" */
