@@ -38,6 +38,7 @@
 #include <string.h>			 /* memset */
 #include "cin_debug_stuff.h"
 #include "logmemfile.h"
+#include "BLI_fileops.h"
 
 static void
 fillDpxChannelInfo(DpxFile* dpx, DpxChannelInformation* chan, int des) {
@@ -141,7 +142,8 @@ fillDpxImageInfo(
 	if (dpx->depth == 1) {
 		fillDpxChannelInfo(dpx, &imageInfo->channel[0], 0);
 
-	} else if (dpx->depth == 3) {
+	}
+	else if (dpx->depth == 3) {
 		fillDpxChannelInfo(dpx, &imageInfo->channel[0], 50);
 	}
 }
@@ -269,7 +271,8 @@ dpxGetRowBytes(DpxFile* dpx, unsigned short* row, int y) {
 			dpx->pixelBuffer[pixelIndex+2] = t & 0x3ff;
 			pixelIndex += 3;
 		}
-	} else /* if (dpx->depth == 3) */ {
+	}
+	else /* if (dpx->depth == 3) */ {
 		for (longIndex = 0; longIndex < readLongs; ++longIndex) {
 			unsigned int t = ntohl(dpx->lineBuffer[longIndex]);
 			t = t >> 2;
@@ -285,7 +288,7 @@ dpxGetRowBytes(DpxFile* dpx, unsigned short* row, int y) {
 
 	/* extract required pixels */
 	for (pixelIndex = 0; pixelIndex < numPixels; ++pixelIndex) {
-		if(dpx->params.doLogarithm)
+		if (dpx->params.doLogarithm)
 			row[pixelIndex] = dpx->lut10_16[dpx->pixelBuffer[pixelIndex]];
 		else
 			row[pixelIndex] = dpx->pixelBuffer[pixelIndex] << 6;
@@ -328,7 +331,7 @@ dpxSetRowBytes(DpxFile* dpx, const unsigned short* row, int y) {
 
 	/* put new pixels into pixelBuffer */
 	for (pixelIndex = 0; pixelIndex < numPixels; ++pixelIndex) {
-		if(dpx->params.doLogarithm)
+		if (dpx->params.doLogarithm)
 			dpx->pixelBuffer[dpx->pixelBufferUsed + pixelIndex] = dpx->lut16_16[row[pixelIndex]];
 		else
 			dpx->pixelBuffer[dpx->pixelBufferUsed + pixelIndex] = row[pixelIndex] >> 6;
@@ -350,7 +353,8 @@ dpxSetRowBytes(DpxFile* dpx, const unsigned short* row, int y) {
 			dpx->lineBuffer[longIndex] = htonl(t);
 			pixelIndex += 3;
 		}
-	} else {
+	}
+	else {
 		for (longIndex = 0; longIndex < writeLongs; ++longIndex) {
 			unsigned int t = dpx->pixelBuffer[pixelIndex+2] << 2 |
 					(dpx->pixelBuffer[pixelIndex+1] << 12) |
@@ -401,7 +405,7 @@ intern_dpxOpen(int mode, const char* bytestuff, int bufsize) {
 
 	if (mode == LFREALFILE) {
 		filename = bytestuff;
-		dpx->file = fopen(filename, "rb");
+		dpx->file = BLI_fopen(filename, "rb");
 		if (dpx->file == 0) {	
 			if (verbose) d_printf("Failed to open file \"%s\".\n", filename);
 			dpxClose(dpx);
@@ -410,7 +414,8 @@ intern_dpxOpen(int mode, const char* bytestuff, int bufsize) {
 		dpx->membuffer = 0;
 		dpx->memcursor = 0;
 		dpx->membuffersize = 0;
-	} else if (mode == LFMEMFILE) {
+	}
+	else if (mode == LFMEMFILE) {
 		dpx->membuffer = (unsigned char *)bytestuff;
 		dpx->memcursor = (unsigned char *)bytestuff;
 		dpx->membuffersize = bufsize;
@@ -589,7 +594,7 @@ dpxCreate(const char* filename, int width, int height, int depth) {
 	dpx->lineBuffer = 0;
 	dpx->pixelBuffer = 0;
 
-	dpx->file = fopen(filename, "wb");
+	dpx->file = BLI_fopen(filename, "wb");
 	if (dpx->file == 0) {
 		if (verbose) d_printf("Couldn't open file %s\n", filename);
 		dpxClose(dpx);
@@ -624,7 +629,8 @@ dpxCreate(const char* filename, int width, int height, int depth) {
 	shortFilename = strrchr(filename, '/');
 	if (shortFilename == 0) {
 		shortFilename = filename;
-	} else {
+	}
+	else {
 		++shortFilename;
 	}
 	initDpxMainHeader(dpx, &header, shortFilename);
@@ -687,7 +693,7 @@ dpxDump(const char* filename) {
 	DpxMainHeader header;
 	FILE* file;
 
-	file = fopen(filename, "rb");
+	file = BLI_fopen(filename, "rb");
 	if (file == 0) {
 		d_printf("Failed to open file \"%s\".\n", filename);
 		return;
