@@ -196,7 +196,7 @@ static int writetab(FILE *outf, unsigned int *tab, int len)
 {
 	int r = 0;
 
-	while(len) {
+	while (len) {
 		r = putlong(outf,*tab++);
 		len -= 4;
 	}
@@ -205,7 +205,7 @@ static int writetab(FILE *outf, unsigned int *tab, int len)
 
 static void readtab(FILE *inf, unsigned int *tab, int len)
 {
-	while(len) {
+	while (len) {
 		*tab++ = getlong(inf);
 		len -= 4;
 	}
@@ -216,13 +216,13 @@ static void test_endian_zbuf(struct ImBuf *ibuf)
 	int len;
 	int *zval;
 	
-	if( BIG_LONG(1) == 1 ) return;
-	if(ibuf->zbuf == NULL) return;
+	if ( BIG_LONG(1) == 1 ) return;
+	if (ibuf->zbuf == NULL) return;
 	
 	len= ibuf->x*ibuf->y;
 	zval= ibuf->zbuf;
 	
-	while(len--) {
+	while (len--) {
 		zval[0]= BIG_LONG(zval[0]);
 		zval++;
 	}
@@ -262,7 +262,7 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 
 	(void)size; /* unused */
 	
-	if(!imb_is_a_iris(mem)) return NULL;
+	if (!imb_is_a_iris(mem)) return NULL;
 
 	/*printf("new iris\n");*/
 	
@@ -270,14 +270,14 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 	file_offset = 0;
 	
 	readheader(inf, &image);
-	if(image.imagic != IMAGIC) {
+	if (image.imagic != IMAGIC) {
 		fprintf(stderr,"longimagedata: bad magic number in image file\n");
 		return(NULL);
 	}
 	
 	rle = ISRLE(image.type);
 	bpp = BPP(image.type);
-	if(bpp != 1 && bpp != 2) {
+	if (bpp != 1 && bpp != 2) {
 		fprintf(stderr,"longimagedata: image must have 1 or 2 byte per pix chan\n");
 		return(NULL);
 	}
@@ -313,7 +313,7 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 				}
 				cur = starttab[y+z*ysize];
 			}
-			if(badorder)
+			if (badorder)
 				break;
 		}
 	
@@ -325,9 +325,9 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 			zbase = (unsigned int *)ibuf->zbuf;
 			
 			if (badorder) {
-				for(z=0; z<zsize; z++) {
+				for (z=0; z<zsize; z++) {
 					lptr = base;
-					for(y=0; y<ysize; y++) {
+					for (y=0; y<ysize; y++) {
 						file_offset = starttab[y+z*ysize];
 						
 						rledat = file_data + file_offset;
@@ -337,20 +337,21 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 						lptr += xsize;
 					}
 				}
-			} else {
+			}
+			else {
 				lptr = base;
 				zptr = zbase;
-				for(y=0; y<ysize; y++) {
+				for (y=0; y<ysize; y++) {
 				
-					for(z=0; z<zsize; z++) {
+					for (z=0; z<zsize; z++) {
 						
 						file_offset = starttab[y+z*ysize];
 
 						rledat = file_data + file_offset;
 						file_offset += lengthtab[y+z*ysize];
 						
-						if(z<4) expandrow((uchar *)lptr, rledat, 3-z);
-						else if(z<8) expandrow((uchar *)zptr, rledat, 7-z);
+						if (z<4) expandrow((uchar *)lptr, rledat, 3-z);
+						else if (z<8) expandrow((uchar *)zptr, rledat, 7-z);
 					}
 					lptr += xsize;
 					zptr += xsize;
@@ -358,16 +359,17 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 			}
 			
 
-		} else {	/* bpp == 2 */
+		}
+		else {	/* bpp == 2 */
 			
 			ibuf = IMB_allocImBuf(xsize, ysize, 32, (flags & IB_rect)|IB_rectfloat);
 			
 			fbase = ibuf->rect_float;
 			
 			if (badorder) {
-				for(z=0; z<zsize; z++) {
+				for (z=0; z<zsize; z++) {
 					fptr = fbase;
-					for(y=0; y<ysize; y++) {
+					for (y=0; y<ysize; y++) {
 						file_offset = starttab[y+z*ysize];
 						
 						rledat = file_data + file_offset;
@@ -377,12 +379,13 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 						fptr += xsize * 4;
 					}
 				}
-			} else {
+			}
+			else {
 				fptr = fbase;
 
-				for(y=0; y<ysize; y++) {
+				for (y=0; y<ysize; y++) {
 				
-					for(z=0; z<zsize; z++) {
+					for (z=0; z<zsize; z++) {
 						
 						file_offset = starttab[y+z*ysize];
 
@@ -400,7 +403,8 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 		MEM_freeN(starttab);
 		MEM_freeN(lengthtab);	
 
-	} else {
+	}
+	else {
 		if (bpp == 1) {
 			
 			ibuf = IMB_allocImBuf(xsize, ysize, 8 * zsize, IB_rect);
@@ -412,12 +416,12 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 			file_offset = 512;
 			rledat = file_data + file_offset;
 			
-			for(z = 0; z < zsize; z++) {
+			for (z = 0; z < zsize; z++) {
 				
-				if(z<4) lptr = base;
-				else if(z<8) lptr= zbase;
+				if (z<4) lptr = base;
+				else if (z<8) lptr= zbase;
 				
-				for(y = 0; y < ysize; y++) {
+				for (y = 0; y < ysize; y++) {
 
 					interleaverow((uchar *)lptr, rledat, 3-z, xsize);
 					rledat += xsize;
@@ -426,7 +430,8 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 				}
 			}
 			
-		} else {	/* bpp == 2 */
+		}
+		else {	/* bpp == 2 */
 			
 			ibuf = IMB_allocImBuf(xsize, ysize, 32, (flags & IB_rect)|IB_rectfloat);
 
@@ -435,11 +440,11 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 			file_offset = 512;
 			rledat = file_data + file_offset;
 			
-			for(z = 0; z < zsize; z++) {
+			for (z = 0; z < zsize; z++) {
 				
 				fptr = fbase;
 				
-				for(y = 0; y < ysize; y++) {
+				for (y = 0; y < ysize; y++) {
 
 					interleaverow2(fptr, rledat, 3-z, xsize);
 					rledat += xsize * 2;
@@ -455,14 +460,15 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 	if (bpp == 1) {
 		uchar * rect;
 		
-		if (image.zsize == 1){
+		if (image.zsize == 1) {
 			rect = (uchar *) ibuf->rect;
 			for (x = ibuf->x * ibuf->y; x > 0; x--) {
 				rect[0] = 255;
 				rect[1] = rect[2] = rect[3];
 				rect += 4;
 			}
-		} else if (image.zsize == 2){
+		}
+		else if (image.zsize == 2) {
 			/* grayscale with alpha */
 			rect = (uchar *) ibuf->rect;
 			for (x = ibuf->x * ibuf->y; x > 0; x--) {
@@ -470,7 +476,8 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 				rect[1] = rect[2] = rect[3];
 				rect += 4;
 			}
-		} else if (image.zsize == 3){
+		}
+		else if (image.zsize == 3) {
 			/* add alpha */
 			rect = (uchar *) ibuf->rect;
 			for (x = ibuf->x * ibuf->y; x > 0; x--) {
@@ -479,16 +486,18 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 			}
 		}
 		
-	} else {	/* bpp == 2 */
+	}
+	else {	/* bpp == 2 */
 		
-		if (image.zsize == 1){
+		if (image.zsize == 1) {
 			fbase = ibuf->rect_float;
 			for (x = ibuf->x * ibuf->y; x > 0; x--) {
 				fbase[0] = 1;
 				fbase[1] = fbase[2] = fbase[3];
 				fbase += 4;
 			}
-		} else if (image.zsize == 2){
+		}
+		else if (image.zsize == 2) {
 			/* grayscale with alpha */
 			fbase = ibuf->rect_float;
 			for (x = ibuf->x * ibuf->y; x > 0; x--) {
@@ -496,7 +505,8 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 				fbase[1] = fbase[2] = fbase[3];
 				fbase += 4;
 			}
-		} else if (image.zsize == 3){
+		}
+		else if (image.zsize == 3) {
 			/* add alpha */
 			fbase = ibuf->rect_float;
 			for (x = ibuf->x * ibuf->y; x > 0; x--) {
@@ -530,7 +540,7 @@ struct ImBuf *imb_loadiris(unsigned char *mem, size_t size, int flags)
 static void interleaverow(unsigned char *lptr, unsigned char *cptr, int z, int n)
 {
 	lptr += z;
-	while(n--) {
+	while (n--) {
 		*lptr = *cptr++;
 		lptr += 4;
 	}
@@ -539,7 +549,7 @@ static void interleaverow(unsigned char *lptr, unsigned char *cptr, int z, int n
 static void interleaverow2(float *lptr, unsigned char *cptr, int z, int n)
 {
 	lptr += z;
-	while(n--) {
+	while (n--) {
 		*lptr = ((cptr[0]<<8) | (cptr[1]<<0)) / (float)0xFFFF;		
 		cptr += 2;
 		lptr += 4;
@@ -552,14 +562,14 @@ static void expandrow2(float *optr, unsigned char *iptr, int z)
 	float pixel_f;
 
 	optr += z;
-	while(1) {
+	while (1) {
 		pixel = (iptr[0]<<8) | (iptr[1]<<0);
 		iptr += 2;
 		
 		if ( !(count = (pixel & 0x7f)) )
 			return;
-		if(pixel & 0x80) {
-			while(count>=8) {
+		if (pixel & 0x80) {
+			while (count>=8) {
 				optr[0*4] = ((iptr[0]<<8) | (iptr[1]<<0))/(float)0xFFFF;
 				optr[1*4] = ((iptr[2]<<8) | (iptr[3]<<0))/(float)0xFFFF;
 				optr[2*4] = ((iptr[4]<<8) | (iptr[5]<<0))/(float)0xFFFF;
@@ -572,16 +582,17 @@ static void expandrow2(float *optr, unsigned char *iptr, int z)
 				iptr += 8*2;
 				count -= 8;
 			}
-			while(count--) {
+			while (count--) {
 				*optr = ((iptr[0]<<8) | (iptr[1]<<0))/(float)0xFFFF;
 				iptr+=2;
 				optr+=4;
 			}
-		} else {
+		}
+		else {
 			pixel_f = ((iptr[0]<<8) | (iptr[1]<<0))/(float)0xFFFF;
 			iptr += 2;
 
-			while(count>=8) {
+			while (count>=8) {
 				optr[0*4] = pixel_f;
 				optr[1*4] = pixel_f;
 				optr[2*4] = pixel_f;
@@ -593,7 +604,7 @@ static void expandrow2(float *optr, unsigned char *iptr, int z)
 				optr += 8*4;
 				count -= 8;
 			}
-			while(count--) {
+			while (count--) {
 				*optr = pixel_f;
 				optr+=4;
 			}
@@ -606,12 +617,12 @@ static void expandrow(unsigned char *optr, unsigned char *iptr, int z)
 	unsigned char pixel, count;
 
 	optr += z;
-	while(1) {
+	while (1) {
 		pixel = *iptr++;
 		if ( !(count = (pixel & 0x7f)) )
 			return;
-		if(pixel & 0x80) {
-			while(count>=8) {
+		if (pixel & 0x80) {
+			while (count>=8) {
 				optr[0*4] = iptr[0];
 				optr[1*4] = iptr[1];
 				optr[2*4] = iptr[2];
@@ -624,13 +635,14 @@ static void expandrow(unsigned char *optr, unsigned char *iptr, int z)
 				iptr += 8;
 				count -= 8;
 			}
-			while(count--) {
+			while (count--) {
 				*optr = *iptr++;
 				optr+=4;
 			}
-		} else {
+		}
+		else {
 			pixel = *iptr++;
-			while(count>=8) {
+			while (count>=8) {
 				optr[0*4] = pixel;
 				optr[1*4] = pixel;
 				optr[2*4] = pixel;
@@ -642,7 +654,7 @@ static void expandrow(unsigned char *optr, unsigned char *iptr, int z)
 				optr += 8*4;
 				count -= 8;
 			}
-			while(count--) {
+			while (count--) {
 				*optr = pixel;
 				optr+=4;
 			}
@@ -674,8 +686,8 @@ static int output_iris(unsigned int *lptr, int xsize, int ysize, int zsize, cons
 	int rlebuflen, goodwrite;
 
 	goodwrite = 1;
-	outf = fopen(name, "wb");
-	if(!outf) return 0;
+	outf = BLI_fopen(name, "wb");
+	if (!outf) return 0;
 
 	tablen = ysize*zsize*sizeof(int);
 
@@ -689,7 +701,7 @@ static int output_iris(unsigned int *lptr, int xsize, int ysize, int zsize, cons
 	memset(image, 0, sizeof(IMAGE));
 	image->imagic = IMAGIC;
 	image->type = RLE(1);
-	if(zsize>1)
+	if (zsize>1)
 		image->dim = 3;
 	else
 		image->dim = 2;
@@ -710,14 +722,14 @@ static int output_iris(unsigned int *lptr, int xsize, int ysize, int zsize, cons
 				len = compressrow((uchar *)lumbuf,rlebuf,CHANOFFSET(z),xsize);
 			}
 			else {
-				if(z<4) {
+				if (z<4) {
 					len = compressrow((uchar *)lptr, rlebuf,CHANOFFSET(z),xsize);
 				}
-				else if(z<8 && zptr) {
+				else if (z<8 && zptr) {
 					len = compressrow((uchar *)zptr, rlebuf,CHANOFFSET(z-4),xsize);
 				}
 			}
-			if(len>rlebuflen) {
+			if (len>rlebuflen) {
 				fprintf(stderr,"output_iris: rlebuf is too small - bad poop\n");
 				exit(1);
 			}
@@ -727,7 +739,7 @@ static int output_iris(unsigned int *lptr, int xsize, int ysize, int zsize, cons
 			pos += len;
 		}
 		lptr += xsize;
-		if(zptr) zptr += xsize;
+		if (zptr) zptr += xsize;
 	}
 
 	fseek(outf,512,SEEK_SET);
@@ -739,7 +751,7 @@ static int output_iris(unsigned int *lptr, int xsize, int ysize, int zsize, cons
 	MEM_freeN(rlebuf);
 	MEM_freeN(lumbuf);
 	fclose(outf);
-	if(goodwrite)
+	if (goodwrite)
 		return 1;
 	else {
 		fprintf(stderr,"output_iris: not enough space for image!!\n");
@@ -752,7 +764,7 @@ static int output_iris(unsigned int *lptr, int xsize, int ysize, int zsize, cons
 static void lumrow(unsigned char *rgbptr, unsigned char *lumptr, int n)
 {
 	lumptr += CHANOFFSET(0);
-	while(n--) {
+	while (n--) {
 		*lumptr = ILUM(rgbptr[OFFSET_R],rgbptr[OFFSET_G],rgbptr[OFFSET_B]);
 		lumptr += 4;
 		rgbptr += 4;
@@ -770,18 +782,18 @@ static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, int z, int cn
 	ibufend = iptr+cnt*4;
 	optr = rlebuf;
 
-	while(iptr<ibufend) {
+	while (iptr<ibufend) {
 		sptr = iptr;
 		iptr += 8;
-		while((iptr<ibufend)&& ((iptr[-8]!=iptr[-4])||(iptr[-4]!=iptr[0])))
+		while ((iptr<ibufend)&& ((iptr[-8]!=iptr[-4])||(iptr[-4]!=iptr[0])))
 			iptr+=4;
 		iptr -= 8;
 		count = (iptr-sptr)/4;
-		while(count) {
+		while (count) {
 			todo = count>126 ? 126:count;
 			count -= todo;
 			*optr++ = 0x80|todo;
-			while(todo>8) {
+			while (todo>8) {
 				optr[0] = sptr[0*4];
 				optr[1] = sptr[1*4];
 				optr[2] = sptr[2*4];
@@ -795,7 +807,7 @@ static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, int z, int cn
 				sptr += 8*4;
 				todo -= 8;
 			}
-			while(todo--) {
+			while (todo--) {
 				*optr++ = *sptr;
 				sptr += 4;
 			}
@@ -803,10 +815,10 @@ static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, int z, int cn
 		sptr = iptr;
 		cc = *iptr;
 		iptr += 4;
-		while( (iptr<ibufend) && (*iptr == cc) )
+		while ( (iptr<ibufend) && (*iptr == cc) )
 			iptr += 4;
 		count = (iptr-sptr)/4;
-		while(count) {
+		while (count) {
 			todo = count>126 ? 126:count;
 			count -= todo;
 			*optr++ = todo;
