@@ -47,8 +47,8 @@
 static void blend_color_mix(char *cp, char *cp1, char *cp2, int fac)
 {
 	/* this and other blending modes previously used >>8 instead of /255. both
-	   are not equivalent (>>8 is /256), and the former results in rounding
-	   errors that can turn colors black fast after repeated blending */
+	 * are not equivalent (>>8 is /256), and the former results in rounding
+	 * errors that can turn colors black fast after repeated blending */
 	int mfac= 255-fac;
 
 	cp[0]= (mfac*cp1[0]+fac*cp2[0])/255;
@@ -61,11 +61,11 @@ static void blend_color_add(char *cp, char *cp1, char *cp2, int fac)
 	int temp;
 
 	temp= cp1[0] + ((fac*cp2[0])/255);
-	if(temp>254) cp[0]= 255; else cp[0]= temp;
+	if (temp>254) cp[0]= 255; else cp[0]= temp;
 	temp= cp1[1] + ((fac*cp2[1])/255);
-	if(temp>254) cp[1]= 255; else cp[1]= temp;
+	if (temp>254) cp[1]= 255; else cp[1]= temp;
 	temp= cp1[2] + ((fac*cp2[2])/255);
-	if(temp>254) cp[2]= 255; else cp[2]= temp;
+	if (temp>254) cp[2]= 255; else cp[2]= temp;
 }
 
 static void blend_color_sub(char *cp, char *cp1, char *cp2, int fac)
@@ -73,11 +73,11 @@ static void blend_color_sub(char *cp, char *cp1, char *cp2, int fac)
 	int temp;
 
 	temp= cp1[0] - ((fac*cp2[0])/255);
-	if(temp<0) cp[0]= 0; else cp[0]= temp;
+	if (temp<0) cp[0]= 0; else cp[0]= temp;
 	temp= cp1[1] - ((fac*cp2[1])/255);
-	if(temp<0) cp[1]= 0; else cp[1]= temp;
+	if (temp<0) cp[1]= 0; else cp[1]= temp;
 	temp= cp1[2] - ((fac*cp2[2])/255);
-	if(temp<0) cp[2]= 0; else cp[2]= temp;
+	if (temp<0) cp[2]= 0; else cp[2]= temp;
 }
 
 static void blend_color_mul(char *cp, char *cp1, char *cp2, int fac)
@@ -92,8 +92,8 @@ static void blend_color_mul(char *cp, char *cp1, char *cp2, int fac)
 
 static void blend_color_lighten(char *cp, char *cp1, char *cp2, int fac)
 {
-	/* See if are lighter, if so mix, else dont do anything.
-	if the paint col is darker then the original, then ignore */
+	/* See if are lighter, if so mix, else don't do anything.
+	 * if the paint col is darker then the original, then ignore */
 	if (cp1[0]+cp1[1]+cp1[2] > cp2[0]+cp2[1]+cp2[2]) {
 		cp[0]= cp1[0];
 		cp[1]= cp1[1];
@@ -105,8 +105,8 @@ static void blend_color_lighten(char *cp, char *cp1, char *cp2, int fac)
 
 static void blend_color_darken(char *cp, char *cp1, char *cp2, int fac)
 {
-	/* See if were darker, if so mix, else dont do anything.
-	if the paint col is brighter then the original, then ignore */
+	/* See if were darker, if so mix, else don't do anything.
+	 * if the paint col is brighter then the original, then ignore */
 	if (cp1[0]+cp1[1]+cp1[2] < cp2[0]+cp2[1]+cp2[2]) {
 		cp[0]= cp1[0];
 		cp[1]= cp1[1];
@@ -201,8 +201,8 @@ static void blend_color_mul_float(float *cp, float *cp1, float *cp2, float fac)
 
 static void blend_color_lighten_float(float *cp, float *cp1, float *cp2, float fac)
 {
-	/* See if are lighter, if so mix, else dont do anything.
-	if the pafloat col is darker then the original, then ignore */
+	/* See if are lighter, if so mix, else don't do anything.
+	 * if the pafloat col is darker then the original, then ignore */
 	if (cp1[0]+cp1[1]+cp1[2] > cp2[0]+cp2[1]+cp2[2]) {
 		cp[0]= cp1[0];
 		cp[1]= cp1[1];
@@ -214,8 +214,8 @@ static void blend_color_lighten_float(float *cp, float *cp1, float *cp2, float f
 
 static void blend_color_darken_float(float *cp, float *cp1, float *cp2, float fac)
 {
-	/* See if were darker, if so mix, else dont do anything.
-	if the pafloat col is brighter then the original, then ignore */
+	/* See if were darker, if so mix, else don't do anything.
+	 * if the pafloat col is brighter then the original, then ignore */
 	if (cp1[0]+cp1[1]+cp1[2] < cp2[0]+cp2[1]+cp2[2]) {
 		cp[0]= cp1[0];
 		cp[1]= cp1[1];
@@ -348,7 +348,8 @@ void IMB_rectblend(struct ImBuf *dbuf, struct ImBuf *sbuf, int destx,
 		if (do_char) srect = sbuf->rect + srcy * sbuf->x + srcx;
 		if (do_float) srectf = sbuf->rect_float + (srcy * sbuf->x + srcx)*4;
 		srcskip = sbuf->x;
-	} else {
+	}
+	else {
 		srect = drect;
 		srectf = drectf;
 		srcskip = destskip;
@@ -452,7 +453,7 @@ void IMB_rectfill(struct ImBuf *drect, const float col[4])
 {
 	int num;
 
-	if(drect->rect) {
+	if (drect->rect) {
 		unsigned int *rrect = drect->rect;
 		char ccol[4];
 		
@@ -466,7 +467,7 @@ void IMB_rectfill(struct ImBuf *drect, const float col[4])
 			*rrect++ = *((unsigned int*)ccol);
 	}
 	
-	if(drect->rect_float) {
+	if (drect->rect_float) {
 		float *rrectf = drect->rect_float;
 		
 		num = drect->x * drect->y;
@@ -514,7 +515,8 @@ void buf_rectfill_area(unsigned char *rect, float *rectf, int width, int height,
 			chr = FTOCHAR(col[0]);
 			chg = FTOCHAR(col[1]);
 			chb = FTOCHAR(col[2]);
-		} else {
+		}
+		else {
 			fr = col[0]*a;
 			fg = col[1]*a;
 			fb = col[2]*a;
@@ -528,7 +530,8 @@ void buf_rectfill_area(unsigned char *rect, float *rectf, int width, int height,
 						pixel[1] = chg;
 						pixel[2] = chb;
 						pixel[3] = 255;
-					} else {
+					}
+					else {
 						int alphatest;
 						pixel[0] = (char)((fr + ((float)pixel[0]*aich))*255.0f);
 						pixel[1] = (char)((fg + ((float)pixel[1]*aich))*255.0f);
@@ -550,7 +553,8 @@ void buf_rectfill_area(unsigned char *rect, float *rectf, int width, int height,
 					pixel[1] = col[1];
 					pixel[2] = col[2];
 					pixel[3] = 1.0f;
-				} else {
+				}
+				else {
 					float alphatest;
 					pixel[0] = (col[0]*a) + (pixel[0]*ai);
 					pixel[1] = (col[1]*a) + (pixel[1]*ai);
