@@ -40,6 +40,7 @@
 #endif
 
 #include "BLI_blenlib.h"
+#include "BLI_fileops.h"
 
 #include "DNA_userdef_types.h"
 #include "BKE_global.h"
@@ -152,17 +153,17 @@ static int IMB_ispic_name(const char *name)
 	struct stat st;
 	int fp, buf[10];
 
-	if(UTIL_DEBUG) printf("IMB_ispic_name: loading %s\n", name);
+	if (UTIL_DEBUG) printf("IMB_ispic_name: loading %s\n", name);
 	
-	if(stat(name,&st) == -1)
+	if (stat(name,&st) == -1)
 		return FALSE;
-	if(((st.st_mode) & S_IFMT) != S_IFREG)
+	if (((st.st_mode) & S_IFMT) != S_IFREG)
 		return FALSE;
 
-	if((fp = open(name,O_BINARY|O_RDONLY)) < 0)
+	if ((fp = BLI_open(name,O_BINARY|O_RDONLY, 0)) < 0)
 		return FALSE;
 
-	if(read(fp, buf, 32) != 32) {
+	if (read(fp, buf, 32) != 32) {
 		close(fp);
 		return FALSE;
 	}
@@ -170,11 +171,11 @@ static int IMB_ispic_name(const char *name)
 	close(fp);
 
 	/* XXX move this exception */
-	if((BIG_LONG(buf[0]) & 0xfffffff0) == 0xffd8ffe0)
+	if ((BIG_LONG(buf[0]) & 0xfffffff0) == 0xffd8ffe0)
 		return JPG;
 
-	for(type=IMB_FILE_TYPES; type->is_a; type++)
-		if(type->is_a((uchar*)buf))
+	for (type=IMB_FILE_TYPES; type->is_a; type++)
+		if (type->is_a((uchar*)buf))
 			return type->filetype;
 
 	return FALSE;
@@ -182,13 +183,13 @@ static int IMB_ispic_name(const char *name)
 
 int IMB_ispic(const char *filename)
 {
-	if(U.uiflag & USER_FILTERFILEEXTS) {
-		if(	(BLI_testextensie_array(filename, imb_ext_image)) ||
+	if (U.uiflag & USER_FILTERFILEEXTS) {
+		if (	(BLI_testextensie_array(filename, imb_ext_image)) ||
 			(G.have_quicktime && BLI_testextensie_array(filename, imb_ext_image_qt))
 		) {
 			return IMB_ispic_name(filename);
 		}
-		else  {
+		else {
 			return FALSE;
 		}
 	}
@@ -215,12 +216,10 @@ static int isqtime (const char *name)
 
 void silence_log_ffmpeg(int quiet)
 {
-	if (quiet)
-	{
+	if (quiet) {
 		av_log_set_level(AV_LOG_QUIET);
 	}
-	else
-	{
+	else {
 		av_log_set_level(AV_LOG_DEBUG);
 	}
 }
@@ -233,10 +232,10 @@ void do_init_ffmpeg(void)
 		ffmpeg_init = 1;
 		av_register_all();
 		avdevice_register_all();
-		
-		if ((G.f & G_DEBUG) == 0) {
+		if ((G.debug & G_DEBUG_FFMPEG) == 0) {
 			silence_log_ffmpeg(1);
-		} else {
+		}
+		else {
 			silence_log_ffmpeg(0);
 		}
 	}
@@ -252,7 +251,7 @@ static int isffmpeg (const char *filename)
 
 	do_init_ffmpeg();
 
-	if( BLI_testextensie(filename, ".swf") ||
+	if ( BLI_testextensie(filename, ".swf") ||
 		BLI_testextensie(filename, ".jpg") ||
 		BLI_testextensie(filename, ".png") ||
 		BLI_testextensie(filename, ".dds") ||
@@ -262,24 +261,24 @@ static int isffmpeg (const char *filename)
 		BLI_testextensie(filename, ".cin") ||
 		BLI_testextensie(filename, ".wav")) return 0;
 
-	if(av_open_input_file(&pFormatCtx, filename, NULL, 0, NULL)!=0) {
-		if(UTIL_DEBUG) fprintf(stderr, "isffmpeg: av_open_input_file failed\n");
+	if (av_open_input_file(&pFormatCtx, filename, NULL, 0, NULL)!=0) {
+		if (UTIL_DEBUG) fprintf(stderr, "isffmpeg: av_open_input_file failed\n");
 		return 0;
 	}
 
-	if(av_find_stream_info(pFormatCtx)<0) {
-		if(UTIL_DEBUG) fprintf(stderr, "isffmpeg: av_find_stream_info failed\n");
+	if (av_find_stream_info(pFormatCtx)<0) {
+		if (UTIL_DEBUG) fprintf(stderr, "isffmpeg: av_find_stream_info failed\n");
 		av_close_input_file(pFormatCtx);
 		return 0;
 	}
 
-	if(UTIL_DEBUG) av_dump_format(pFormatCtx, 0, filename, 0);
+	if (UTIL_DEBUG) av_dump_format(pFormatCtx, 0, filename, 0);
 
 
 		/* Find the first video stream */
 	videoStream=-1;
-	for(i=0; i<pFormatCtx->nb_streams; i++)
-		if(pFormatCtx->streams[i] &&
+	for (i=0; i<pFormatCtx->nb_streams; i++)
+		if (pFormatCtx->streams[i] &&
 		   pFormatCtx->streams[i]->codec && 
 		  (pFormatCtx->streams[i]->codec->codec_type==AVMEDIA_TYPE_VIDEO))
 		{
@@ -287,7 +286,7 @@ static int isffmpeg (const char *filename)
 			break;
 		}
 
-	if(videoStream==-1) {
+	if (videoStream==-1) {
 		av_close_input_file(pFormatCtx);
 		return 0;
 	}
@@ -296,12 +295,12 @@ static int isffmpeg (const char *filename)
 
 		/* Find the decoder for the video stream */
 	pCodec=avcodec_find_decoder(pCodecCtx->codec_id);
-	if(pCodec==NULL) {
+	if (pCodec==NULL) {
 		av_close_input_file(pFormatCtx);
 		return 0;
 	}
 
-	if(avcodec_open(pCodecCtx, pCodec)<0) {
+	if (avcodec_open(pCodecCtx, pCodec)<0) {
 		av_close_input_file(pFormatCtx);
 		return 0;
 	}
@@ -331,7 +330,7 @@ int imb_get_anim_type(const char * name)
 	int type;
 	struct stat st;
 
-	if(UTIL_DEBUG) printf("in getanimtype: %s\n", name);
+	if (UTIL_DEBUG) printf("in getanimtype: %s\n", name);
 
 #ifndef _WIN32
 #	ifdef WITH_QUICKTIME
@@ -341,14 +340,14 @@ int imb_get_anim_type(const char * name)
 	/* stat test below fails on large files > 4GB */
 	if (isffmpeg(name)) return (ANIM_FFMPEG);
 #	endif
-	if (stat(name,&st) == -1) return(0);
+	if (BLI_stat(name, &st) == -1) return(0);
 	if (((st.st_mode) & S_IFMT) != S_IFREG) return(0);
 
 	if (isavi(name)) return (ANIM_AVI);
 
 	if (ismovie(name)) return (ANIM_MOVIE);
 #else
-	if (stat(name,&st) == -1) return(0);
+	if (BLI_stat(name, &st) == -1) return(0);
 	if (((st.st_mode) & S_IFMT) != S_IFREG) return(0);
 
 	if (ismovie(name)) return (ANIM_MOVIE);
@@ -358,45 +357,55 @@ int imb_get_anim_type(const char * name)
 #	ifdef WITH_FFMPEG
 	if (isffmpeg(name)) return (ANIM_FFMPEG);
 #	endif
+
+
 	if (isavi(name)) return (ANIM_AVI);
 #endif
 #ifdef WITH_REDCODE
 	if (isredcode(name)) return (ANIM_REDCODE);
 #endif
 	type = IMB_ispic(name);
-	if (type) return(ANIM_SEQUENCE);
-	return(0);
+	if (type) {
+		return ANIM_SEQUENCE;
+	}
+
+	return ANIM_NONE;
 }
  
 int IMB_isanim(const char *filename)
 {
 	int type;
 	
-	if(U.uiflag & USER_FILTERFILEEXTS) {
-		if (G.have_quicktime){
-			if(		BLI_testextensie(filename, ".avi")
-				||	BLI_testextensie(filename, ".flc")
-				||	BLI_testextensie(filename, ".dv")
-				||	BLI_testextensie(filename, ".r3d")
-				||	BLI_testextensie(filename, ".mov")
-				||	BLI_testextensie(filename, ".movie")
-				||	BLI_testextensie(filename, ".mv")) {
+	if (U.uiflag & USER_FILTERFILEEXTS) {
+		if (G.have_quicktime) {
+			if (BLI_testextensie(filename, ".avi")   ||
+			    BLI_testextensie(filename, ".flc")   ||
+			    BLI_testextensie(filename, ".dv")    ||
+			    BLI_testextensie(filename, ".r3d")   ||
+			    BLI_testextensie(filename, ".mov")   ||
+			    BLI_testextensie(filename, ".movie") ||
+			    BLI_testextensie(filename, ".mv"))
+			{
 				type = imb_get_anim_type(filename);
-			} else {
+			}
+			else {
 				return(FALSE);			
 			}
-		} else { // no quicktime
-			if(		BLI_testextensie(filename, ".avi")
-				||	BLI_testextensie(filename, ".dv")
-				||	BLI_testextensie(filename, ".r3d")
-				||	BLI_testextensie(filename, ".mv")) {
+		}
+		else { /* no quicktime */
+			if (BLI_testextensie(filename, ".avi") ||
+			    BLI_testextensie(filename, ".dv")  ||
+			    BLI_testextensie(filename, ".r3d") ||
+			    BLI_testextensie(filename, ".mv"))
+			{
 				type = imb_get_anim_type(filename);
 			}
-			else  {
+			else {
 				return(FALSE);
 			}
 		}
-	} else { // no FILTERFILEEXTS
+	}
+	else { /* no FILTERFILEEXTS */
 		type = imb_get_anim_type(filename);
 	}
 	
