@@ -29,8 +29,8 @@
  *  \ingroup DNA
  */
 
-#ifndef DNA_ACTION_TYPES_H
-#define DNA_ACTION_TYPES_H
+#ifndef __DNA_ACTION_TYPES_H__
+#define __DNA_ACTION_TYPES_H__
 
 #include "DNA_listBase.h"
 #include "DNA_ID.h"
@@ -219,14 +219,15 @@ typedef struct bPoseChannel {
 	short 		pad;
 	
 	float		chan_mat[4][4];		/* matrix result of loc/quat/size , and where we put deform in, see next line */
-	float		pose_mat[4][4];		/* constraints accumulate here. in the end, pose_mat = bone->arm_mat * chan_mat */
+	float		pose_mat[4][4];		/* constraints accumulate here. in the end, pose_mat = bone->arm_mat * chan_mat
+	                                 * this matrix is object space */
 	float		constinv[4][4];		/* inverse result of constraints.
 	                                 * doesn't include effect of restposition, parent, and local transform*/
 	
 	float		pose_head[3];		/* actually pose_mat[3] */
 	float		pose_tail[3];		/* also used for drawing help lines... */
 	
-	float		limitmin[3], limitmax[3];	/* DOF constraint */
+	float		limitmin[3], limitmax[3];	/* DOF constraint, note! - these are stored in degrees, not radians */
 	float		stiffness[3];				/* DOF stiffness */
 	float		ikstretch;
 	float		ikrotweight;		/* weight of joint rotation constraint */
@@ -416,7 +417,7 @@ typedef enum eItasc_Solver {
 /* Groups -------------------------------------- */
 
 /* Action-Channel Group (agrp)
-
+ *
  * These are stored as a list per-Action, and are only used to 
  * group that Action's channels in an Animation Editor. 
  *
@@ -511,7 +512,7 @@ typedef enum eAction_Flags {
 /* Storage for Dopesheet/Grease-Pencil Editor data */
 typedef struct bDopeSheet {
 	ID 		*source;			/* currently ID_SCE (for Dopesheet), and ID_SC (for Grease Pencil) */
-	ListBase chanbase;			/* cache for channels (only initialised when pinned) */  // XXX not used!
+	ListBase chanbase;			/* cache for channels (only initialized when pinned) */  // XXX not used!
 	
 	struct Group *filter_grp;	/* object group for ADS_FILTER_ONLYOBGROUP filtering option */
 	char searchstr[64];			/* string to search for in displayed names of F-Curves for ADS_FILTER_BY_FCU_NAME filtering option */
