@@ -30,8 +30,8 @@
  *  \ingroup DNA
  */
 
-#ifndef DNA_CONSTRAINT_TYPES_H
-#define DNA_CONSTRAINT_TYPES_H
+#ifndef __DNA_CONSTRAINT_TYPES_H__
+#define __DNA_CONSTRAINT_TYPES_H__
 
 #include "DNA_defs.h"
 #include "DNA_ID.h"
