@@ -29,8 +29,8 @@
  *  \ingroup DNA
  */
 
-#ifndef DNA_CUSTOMDATA_TYPES_H
-#define DNA_CUSTOMDATA_TYPES_H
+#ifndef __DNA_CUSTOMDATA_TYPES_H__
+#define __DNA_CUSTOMDATA_TYPES_H__
 
 #ifdef __cplusplus
 extern "C" {
@@ -47,7 +47,7 @@ typedef struct CustomDataLayer {
 	int active_rnd; /* number of the layer to render*/
 	int active_clone; /* number of the layer to render*/
 	int active_mask; /* number of the layer to render*/
-	char pad[4];
+	int uid;        /* shape keyblock unique id reference*/
 	char name[64];  /* layer name, MAX_CUSTOMDATA_LAYER_AAME */
 	void *data;     /* layer data */
 } CustomDataLayer;
@@ -59,15 +59,16 @@ typedef struct CustomDataExternal {
 } CustomDataExternal;
 
 /** structure which stores custom element data associated with mesh elements
- * (vertices, edges or faces). The custom data is organised into a series of
+ * (vertices, edges or faces). The custom data is organized into a series of
  * layers, each with a data type (e.g. MTFace, MDeformVert, etc.). */
 typedef struct CustomData {
 	CustomDataLayer *layers;      /* CustomDataLayers, ordered by type */
-	int typemap[32];              /* runtime only! - maps types to indices of first layer of that type,
+	int typemap[34];              /* runtime only! - maps types to indices of first layer of that type,
 	                               * MUST be >= CD_NUMTYPES, but we cant use a define here.
 	                               * Correct size is ensured in CustomData_update_typemap assert() */
+
 	int totlayer, maxlayer;       /* number of layers, size of layers array */
-	int totsize, pad;             /* in editmode, total size of all data layers */
+	int totsize, pad2;             /* in editmode, total size of all data layers */
 	void *pool;                   /* Bmesh: Memory pool for allocation of blocks */
 	CustomDataExternal *external; /* external file storing customdata layers */
 } CustomData;
@@ -93,14 +94,12 @@ typedef struct CustomData {
 #define CD_MLOOPCOL		17
 #define CD_TANGENT		18
 #define CD_MDISPS		19
-#define CD_WEIGHT_MCOL	20 /* for displaying weightpaint colors */
+#define CD_PREVIEW_MCOL	20 /* for displaying weightpaint colors */
 #define CD_ID_MCOL		21
 #define CD_TEXTURE_MCOL	22
 #define CD_CLOTH_ORCO	23
 #define CD_RECAST		24
 
-#ifdef USE_BMESH_FORWARD_COMPAT
-
 /* BMESH ONLY START */
 #define CD_MPOLY		25
 #define CD_MLOOP		26
@@ -108,16 +107,12 @@ typedef struct CustomData {
 #define CD_SHAPEKEY		28
 #define CD_BWEIGHT		29
 #define CD_CREASE		30
-#define CD_WEIGHT_MLOOPCOL	31
+#define CD_ORIGSPACE_MLOOP	31
+#define CD_PREVIEW_MLOOPCOL	32
+#define CD_BM_ELEM_PYPTR	33
 /* BMESH ONLY END */
 
-#define CD_NUMTYPES		32
-
-#else
-
-#define CD_NUMTYPES		25
-
-#endif
+#define CD_NUMTYPES		34
 
 /* Bits for CustomDataMask */
 #define CD_MASK_MVERT		(1 << CD_MVERT)
@@ -140,12 +135,10 @@ typedef struct CustomData {
 #define CD_MASK_MLOOPCOL	(1 << CD_MLOOPCOL)
 #define CD_MASK_TANGENT		(1 << CD_TANGENT)
 #define CD_MASK_MDISPS		(1 << CD_MDISPS)
-#define CD_MASK_WEIGHT_MCOL	(1 << CD_WEIGHT_MCOL)
+#define CD_MASK_PREVIEW_MCOL	(1 << CD_PREVIEW_MCOL)
 #define CD_MASK_CLOTH_ORCO	(1 << CD_CLOTH_ORCO)
 #define CD_MASK_RECAST		(1 << CD_RECAST)
 
-#ifdef USE_BMESH_FORWARD_COMPAT
-
 /* BMESH ONLY START */
 #define CD_MASK_MPOLY		(1 << CD_MPOLY)
 #define CD_MASK_MLOOP		(1 << CD_MLOOP)
@@ -153,11 +146,11 @@ typedef struct CustomData {
 #define CD_MASK_SHAPEKEY	(1 << CD_SHAPEKEY)
 #define CD_MASK_BWEIGHT		(1 << CD_BWEIGHT)
 #define CD_MASK_CREASE		(1 << CD_CREASE)
-#define CD_MASK_WEIGHT_MLOOPCOL (1 << CD_WEIGHT_MLOOPCOL)
+#define CD_MASK_ORIGSPACE_MLOOP	(1 << CD_ORIGSPACE_MLOOP)
+#define CD_MASK_PREVIEW_MLOOPCOL (1LL << CD_PREVIEW_MLOOPCOL)
+#define CD_MASK_BM_ELEM_PYPTR (1LL << CD_BM_ELEM_PYPTR)
 /* BMESH ONLY END */
 
-#endif
-
 /* CustomData.flag */
 
 /* indicates layer should not be copied by CustomData_from_template or
