@@ -33,8 +33,8 @@
  *   etc. are only still maintained to provide backwards compatibility for old files.
  */
  
-#ifndef DNA_IPO_TYPES_H
-#define DNA_IPO_TYPES_H
+#ifndef __DNA_IPO_TYPES_H__
+#define __DNA_IPO_TYPES_H__
 
 #include "DNA_listBase.h"
 #include "DNA_curve_types.h"
