@@ -22,8 +22,8 @@
  *  \ingroup DNA
  */
 
-#ifndef DNA_MODIFIER_TYPES_H
-#define DNA_MODIFIER_TYPES_H
+#ifndef __DNA_MODIFIER_TYPES_H__
+#define __DNA_MODIFIER_TYPES_H__
 
 #include "DNA_defs.h"
 #include "DNA_listBase.h"
@@ -135,6 +135,8 @@ typedef struct LatticeModifierData {
 
 	struct Object *object;
 	char name[64];			/* optional vertexgroup name, MAX_VGROUP_NAME */
+	float strength;
+	char pad[4];
 } LatticeModifierData;
 
 typedef struct CurveModifierData {
@@ -191,33 +193,33 @@ typedef struct ArrayModifierData {
 	/* the object to use for object offset */
 	struct Object *offset_ob;
 	/* a constant duplicate offset;
-	   1 means the duplicates are 1 unit apart
-	*/
+	 * 1 means the duplicates are 1 unit apart
+	 */
 	float offset[3];
 	/* a scaled factor for duplicate offsets;
-	   1 means the duplicates are 1 object-width apart
-	*/
+	 * 1 means the duplicates are 1 object-width apart
+	 */
 	float scale[3];
 	/* the length over which to distribute the duplicates */
 	float length;
 	/* the limit below which to merge vertices in adjacent duplicates */
 	float merge_dist;
 	/* determines how duplicate count is calculated; one of:
-		  MOD_ARR_FIXEDCOUNT -> fixed
-		  MOD_ARR_FITLENGTH  -> calculated to fit a set length
-		  MOD_ARR_FITCURVE   -> calculated to fit the length of a Curve object
-	*/
+	 * - MOD_ARR_FIXEDCOUNT -> fixed
+	 * - MOD_ARR_FITLENGTH  -> calculated to fit a set length
+	 * - MOD_ARR_FITCURVE   -> calculated to fit the length of a Curve object
+	 */
 	int fit_type;
 	/* flags specifying how total offset is calculated; binary OR of:
-		 MOD_ARR_OFF_CONST    -> total offset += offset
-		 MOD_ARR_OFF_RELATIVE -> total offset += relative * object width
-		 MOD_ARR_OFF_OBJ      -> total offset += offset_ob's matrix
-	   total offset is the sum of the individual enabled offsets
-	*/
+	 * - MOD_ARR_OFF_CONST    -> total offset += offset
+	 * - MOD_ARR_OFF_RELATIVE -> total offset += relative * object width
+	 * - MOD_ARR_OFF_OBJ      -> total offset += offset_ob's matrix
+	 * total offset is the sum of the individual enabled offsets
+	 */
 	int offset_type;
 	/* general flags:
-		  MOD_ARR_MERGE -> merge vertices in adjacent duplicates
-	*/
+	 * MOD_ARR_MERGE -> merge vertices in adjacent duplicates
+	 */
 	int flags;
 	/* the number of duplicates to generate for MOD_ARR_FIXEDCOUNT */
 	int count;
@@ -676,6 +678,7 @@ typedef struct ShrinkwrapModifierData {
 #define MOD_SHRINKWRAP_PROJECT_OVER_Z_AXIS		(1<<2)
 #define MOD_SHRINKWRAP_PROJECT_OVER_NORMAL			0	/* projection over normal is used if no axis is selected */
 
+
 typedef struct SimpleDeformModifierData {
 	ModifierData modifier;
 
@@ -810,7 +813,6 @@ typedef struct OceanModifierData {
 
 typedef struct WarpModifierData {
 	ModifierData modifier;
-
 	/* keep in sync with MappingInfoModifierData */
 	struct Tex *texture;
 	struct Object *map_object;
@@ -896,7 +898,7 @@ typedef struct WeightVGEditModifierData {
 typedef struct WeightVGMixModifierData {
 	ModifierData modifier;
 
-	/* XXX Note: I tried to keep everything logically ordered – provided the
+	/* XXX Note: I tried to keep everything logically ordered - provided the
 	 *           alignment constraints... */
 
 	char	defgrp_name_a[64];      /* Name of vertex group to modify/weight. MAX_VGROUP_NAME. */
@@ -1045,7 +1047,7 @@ typedef struct RemeshModifierData {
 	ModifierData modifier;
 
 	/* floodfill option, controls how small components can be
-	   before they are removed */
+	 * before they are removed */
 	float threshold;
 
 	/* ratio between size of model and grid */
