@@ -29,8 +29,8 @@
  *  \ingroup DNA
  */
 
-#ifndef DNA_NODE_TYPES_H
-#define DNA_NODE_TYPES_H
+#ifndef __DNA_NODE_TYPES_H__
+#define __DNA_NODE_TYPES_H__
 
 #include "DNA_ID.h"
 #include "DNA_vec_types.h"
@@ -77,7 +77,7 @@ typedef struct bNodeSocket {
 	
 	short type, flag;
 	short limit;				/* max. number of links */
-	short pad1;
+	short struct_type;			/* optional identifier for RNA struct subtype */
 	
 	float locx, locy;
 	
@@ -112,6 +112,10 @@ typedef struct bNodeSocket {
 #define SOCK_INT			6
 #define NUM_SOCKET_TYPES	7	/* must be last! */
 
+/* sock->struct_type */
+#define SOCK_STRUCT_NONE				0	/* default, type is defined by sock->type only */
+#define SOCK_STRUCT_OUTPUT_FILE			1	/* file output node socket */
+
 /* socket side (input/output) */
 #define SOCK_IN		1
 #define SOCK_OUT	2
@@ -132,7 +136,8 @@ typedef struct bNodeSocket {
 	/* hide socket value, if it gets auto default */
 #define SOCK_HIDE_VALUE			128
 	/* socket hidden automatically, to distinguish from manually hidden */
-#define SOCK_AUTO_HIDDEN		256
+	/* DEPRECATED, only kept here to avoid reusing the flag */
+#define SOCK_AUTO_HIDDEN__DEPRECATED	256
 
 typedef struct bNodePreview {
 	unsigned char *rect;
@@ -189,7 +194,7 @@ typedef struct bNode {
 #define NODE_GROUP_EDIT		128
 	/* free test flag, undefined */
 #define NODE_TEST			256
-	/* composite: don't do node but pass on buffer(s) */
+	/* node is disabled */
 #define NODE_MUTED			512
 #define NODE_CUSTOM_NAME	1024	/* deprecated! */
 	/* group node types: use const outputs by default */
@@ -234,7 +239,7 @@ typedef struct bNodeTree {
 	
 	int type, init;					/* set init on fileread */
 	int cur_index;					/* sockets in groups have unique identifiers, adding new sockets always 
-									   will increase this counter */
+									 * will increase this counter */
 	int flag;
 	int update;						/* update flags */
 	
@@ -354,6 +359,21 @@ typedef struct NodeImageFile {
 	int sfra, efra;
 } NodeImageFile;
 
+/* XXX first struct fields should match NodeImageFile to ensure forward compatibility */
+typedef struct NodeImageMultiFile {
+	char base_path[1024];	/* 1024 = FILE_MAX */
+	ImageFormatData format;
+	int sfra DNA_DEPRECATED, efra DNA_DEPRECATED;	/* XXX old frame rand values from NodeImageFile for forward compatibility */
+	int active_input;		/* selected input in details view list */
+	int pad;
+} NodeImageMultiFile;
+typedef struct NodeImageMultiFileSocket {
+	short use_render_format  DNA_DEPRECATED;
+	short use_node_format;	/* use overall node image format */
+	int pad2;
+	ImageFormatData format;
+} NodeImageMultiFileSocket;
+
 typedef struct NodeChroma {
 	float t1,t2,t3;
 	float fsize,fstrength,falpha;
@@ -456,7 +476,7 @@ typedef struct NodeTexChecker {
 
 typedef struct NodeTexEnvironment {
 	NodeTexBase base;
-	int color_space, pad;
+	int color_space, projection;
 } NodeTexEnvironment;
 
 typedef struct NodeTexGradient {
@@ -563,8 +583,12 @@ typedef struct TexNodeOutput {
 #define SHD_WAVE_TRI	2
 
 /* image/environment texture */
-#define SHD_COLORSPACE_LINEAR	0
-#define SHD_COLORSPACE_SRGB		1
+#define SHD_COLORSPACE_NONE		0
+#define SHD_COLORSPACE_COLOR	1
+
+/* environment texture */
+#define SHD_PROJ_EQUIRECTANGULAR	0
+#define SHD_PROJ_MIRROR_BALL		1
 
 /* blur node */
 #define CMP_NODE_BLUR_ASPECT_NONE		0
