@@ -33,6 +33,7 @@
 #include "rna_internal.h"
 
 #include "DNA_ID.h"
+#include "DNA_scene_types.h"
 #include "DNA_curve_types.h"
 #include "DNA_key_types.h"
 #include "DNA_lattice_types.h"
@@ -55,7 +56,7 @@
 
 static Key *rna_ShapeKey_find_key(ID *id)
 {
-	switch(GS(id->name)) {
+	switch (GS(id->name)) {
 		case ID_CU: return ((Curve*)id)->key;
 		case ID_KE: return (Key*)id;
 		case ID_LT: return ((Lattice*)id)->key;
@@ -67,7 +68,7 @@ static Key *rna_ShapeKey_find_key(ID *id)
 
 void rna_ShapeKey_name_set(PointerRNA *ptr, const char *value)
 {
-	KeyBlock *kb= ptr->data;
+	KeyBlock *kb = ptr->data;
 	char oldname[sizeof(kb->name)];
 	
 	/* make a copy of the old name first */
@@ -78,64 +79,64 @@ void rna_ShapeKey_name_set(PointerRNA *ptr, const char *value)
 	
 	/* make sure the name is truly unique */
 	if (ptr->id.data) {
-		Key *key= rna_ShapeKey_find_key(ptr->id.data);
+		Key *key = rna_ShapeKey_find_key(ptr->id.data);
 		BLI_uniquename(&key->block, kb, "Key", '.', offsetof(KeyBlock, name), sizeof(kb->name));
 	}
 	
 	/* fix all the animation data which may link to this */
-	BKE_all_animdata_fix_paths_rename("key_blocks", oldname, kb->name);
+	BKE_all_animdata_fix_paths_rename(NULL, "key_blocks", oldname, kb->name);
 }
 
 static void rna_ShapeKey_value_set(PointerRNA *ptr, float value)
 {
-	KeyBlock *data= (KeyBlock*)ptr->data;
+	KeyBlock *data = (KeyBlock*)ptr->data;
 	CLAMP(value, data->slidermin, data->slidermax);
-	data->curval= value;
+	data->curval = value;
 }
 
-static void rna_ShapeKey_value_range(PointerRNA *ptr, float *min, float *max)
+static void rna_ShapeKey_value_range(PointerRNA *ptr, float *min, float *max, float *softmin, float *softmax)
 {
-	KeyBlock *data= (KeyBlock*)ptr->data;
+	KeyBlock *data = (KeyBlock*)ptr->data;
 
-	*min= data->slidermin;
-	*max= data->slidermax;
+	*min = data->slidermin;
+	*max = data->slidermax;
 }
 
 /* epsilon for how close one end of shapekey range can get to the other */
 #define SHAPEKEY_SLIDER_TOL 0.001f
 
-static void rna_ShapeKey_slider_min_range(PointerRNA *ptr, float *min, float *max)
+static void rna_ShapeKey_slider_min_range(PointerRNA *ptr, float *min, float *max, float *softmin, float *softmax)
 {
-	KeyBlock *data= (KeyBlock*)ptr->data;
+	KeyBlock *data = (KeyBlock*)ptr->data;
 
-	*min= -10.0f;
-	*max= data->slidermax - SHAPEKEY_SLIDER_TOL;
+	*min = -10.0f;
+	*max = data->slidermax - SHAPEKEY_SLIDER_TOL;
 }
 
 static void rna_ShapeKey_slider_min_set(PointerRNA *ptr, float value)
 {
-	KeyBlock *data= (KeyBlock*)ptr->data;
-	float min, max;
+	KeyBlock *data = (KeyBlock*)ptr->data;
+	float min, max, softmin, softmax;
 	
-	rna_ShapeKey_slider_min_range(ptr, &min, &max);
+	rna_ShapeKey_slider_min_range(ptr, &min, &max, &softmin, &softmax);
 	CLAMP(value, min, max);
 	data->slidermin = value;
 }
 
-static void rna_ShapeKey_slider_max_range(PointerRNA *ptr, float *min, float *max)
+static void rna_ShapeKey_slider_max_range(PointerRNA *ptr, float *min, float *max, float *softmin, float *softmax)
 {
-	KeyBlock *data= (KeyBlock*)ptr->data;
+	KeyBlock *data = (KeyBlock*)ptr->data;
 
-	*min= data->slidermin + SHAPEKEY_SLIDER_TOL;
-	*max= 10.0f;
+	*min = data->slidermin + SHAPEKEY_SLIDER_TOL;
+	*max = 10.0f;
 }
 
 static void rna_ShapeKey_slider_max_set(PointerRNA *ptr, float value)
 {
-	KeyBlock *data= (KeyBlock*)ptr->data;
-	float min, max;
+	KeyBlock *data = (KeyBlock*)ptr->data;
+	float min, max, softmin, softmax;
 	
-	rna_ShapeKey_slider_max_range(ptr, &min, &max);
+	rna_ShapeKey_slider_max_range(ptr, &min, &max, &softmin, &softmax);
 	CLAMP(value, min, max);
 	data->slidermax = value;
 }
@@ -144,8 +145,8 @@ static void rna_ShapeKey_slider_max_set(PointerRNA *ptr, float value)
 
 PointerRNA rna_object_shapekey_index_get(ID *id, int value)
 {
-	Key *key= rna_ShapeKey_find_key(id);
-	KeyBlock *kb= NULL;
+	Key *key = rna_ShapeKey_find_key(id);
+	KeyBlock *kb = NULL;
 	PointerRNA ptr;
 
 	if (key && value < key->totkey)
@@ -158,7 +159,7 @@ PointerRNA rna_object_shapekey_index_get(ID *id, int value)
 
 int rna_object_shapekey_index_set(ID *id, PointerRNA value, int current)
 {
-	Key *key= rna_ShapeKey_find_key(id);
+	Key *key = rna_ShapeKey_find_key(id);
 
 	if (key) {
 		int a = BLI_findindex(&key->block, value.data);
@@ -170,103 +171,104 @@ int rna_object_shapekey_index_set(ID *id, PointerRNA value, int current)
 
 static PointerRNA rna_ShapeKey_relative_key_get(PointerRNA *ptr)
 {
-	KeyBlock *kb= (KeyBlock*)ptr->data;
+	KeyBlock *kb = (KeyBlock*)ptr->data;
 
 	return rna_object_shapekey_index_get(ptr->id.data, kb->relative);
 }
 
 static void rna_ShapeKey_relative_key_set(PointerRNA *ptr, PointerRNA value)
 {
-	KeyBlock *kb= (KeyBlock*)ptr->data;
+	KeyBlock *kb = (KeyBlock*)ptr->data;
 
-	kb->relative= rna_object_shapekey_index_set(ptr->id.data, value, kb->relative);
+	kb->relative = rna_object_shapekey_index_set(ptr->id.data, value, kb->relative);
 }
 
 static void rna_ShapeKeyPoint_co_get(PointerRNA *ptr, float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	values[0]= vec[0];
-	values[1]= vec[1];
-	values[2]= vec[2];
+	values[0] = vec[0];
+	values[1] = vec[1];
+	values[2] = vec[2];
 }
 
 static void rna_ShapeKeyPoint_co_set(PointerRNA *ptr, const float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	vec[0]= values[0];
-	vec[1]= values[1];
-	vec[2]= values[2];
+	vec[0] = values[0];
+	vec[1] = values[1];
+	vec[2] = values[2];
 }
 
 static float rna_ShapeKeyCurvePoint_tilt_get(PointerRNA *ptr)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 	return vec[3];
 }
 
 static void rna_ShapeKeyCurvePoint_tilt_set(PointerRNA *ptr, float value)
 {
-	float *vec= (float*)ptr->data;
-	vec[3]= value;
+	float *vec = (float*)ptr->data;
+	vec[3] = value;
 }
 
 static void rna_ShapeKeyBezierPoint_co_get(PointerRNA *ptr, float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	values[0]= vec[0+3];
-	values[1]= vec[1+3];
-	values[2]= vec[2+3];
+	values[0] = vec[0+3];
+	values[1] = vec[1+3];
+	values[2] = vec[2+3];
 }
 
 static void rna_ShapeKeyBezierPoint_co_set(PointerRNA *ptr, const float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	vec[0+3]= values[0];
-	vec[1+3]= values[1];
-	vec[2+3]= values[2];
+	vec[0+3] = values[0];
+	vec[1+3] = values[1];
+	vec[2+3] = values[2];
 }
 
 static void rna_ShapeKeyBezierPoint_handle_1_co_get(PointerRNA *ptr, float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	values[0]= vec[0];
-	values[1]= vec[1];
-	values[2]= vec[2];
+	values[0] = vec[0];
+	values[1] = vec[1];
+	values[2] = vec[2];
 }
 
 static void rna_ShapeKeyBezierPoint_handle_1_co_set(PointerRNA *ptr, const float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	vec[0]= values[0];
-	vec[1]= values[1];
-	vec[2]= values[2];
+	vec[0] = values[0];
+	vec[1] = values[1];
+	vec[2] = values[2];
 }
 
 static void rna_ShapeKeyBezierPoint_handle_2_co_get(PointerRNA *ptr, float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	values[0]= vec[6+0];
-	values[1]= vec[6+1];
-	values[2]= vec[6+2];
+	values[0] = vec[6+0];
+	values[1] = vec[6+1];
+	values[2] = vec[6+2];
 }
 
 static void rna_ShapeKeyBezierPoint_handle_2_co_set(PointerRNA *ptr, const float *values)
 {
-	float *vec= (float*)ptr->data;
+	float *vec = (float*)ptr->data;
 
-	vec[6+0]= values[0];
-	vec[6+1]= values[1];
-	vec[6+2]= values[2];
+	vec[6+0] = values[0];
+	vec[6+1] = values[1];
+	vec[6+2] = values[2];
 }
 
-/*static float rna_ShapeKeyBezierPoint_tilt_get(PointerRNA *ptr)
+#if 0
+static float rna_ShapeKeyBezierPoint_tilt_get(PointerRNA *ptr)
 {
 	float *vec= (float*)ptr->data;
 	return vec[10];
@@ -276,21 +278,22 @@ static void rna_ShapeKeyBezierPoint_tilt_set(PointerRNA *ptr, float value)
 {
 	float *vec= (float*)ptr->data;
 	vec[10]= value;
-}*/
+}
+#endif
 
 static void rna_ShapeKey_data_begin(CollectionPropertyIterator *iter, PointerRNA *ptr)
 {
-	Key *key= rna_ShapeKey_find_key(ptr->id.data);
-	KeyBlock *kb= (KeyBlock*)ptr->data;
+	Key *key = rna_ShapeKey_find_key(ptr->id.data);
+	KeyBlock *kb = (KeyBlock*)ptr->data;
 	Curve *cu;
 	Nurb *nu;
-	int tot= kb->totelem, size= key->elemsize;
+	int tot = kb->totelem, size = key->elemsize;
 	
-	if(GS(key->from->name) == ID_CU) {
-		cu= (Curve*)key->from;
-		nu= cu->nurb.first;
+	if (GS(key->from->name) == ID_CU) {
+		cu = (Curve*)key->from;
+		nu = cu->nurb.first;
 		
-		if(nu->bezt) {
+		if (nu->bezt) {
 			tot /= 3;
 			size *= 3;
 		}
@@ -301,17 +304,17 @@ static void rna_ShapeKey_data_begin(CollectionPropertyIterator *iter, PointerRNA
 
 static int rna_ShapeKey_data_length(PointerRNA *ptr)
 {
-	Key *key= rna_ShapeKey_find_key(ptr->id.data);
-	KeyBlock *kb= (KeyBlock*)ptr->data;
+	Key *key = rna_ShapeKey_find_key(ptr->id.data);
+	KeyBlock *kb = (KeyBlock*)ptr->data;
 	Curve *cu;
 	Nurb *nu;
-	int tot= kb->totelem;
+	int tot = kb->totelem;
 	
-	if(GS(key->from->name) == ID_CU) {
-		cu= (Curve*)key->from;
-		nu= cu->nurb.first;
+	if (GS(key->from->name) == ID_CU) {
+		cu = (Curve*)key->from;
+		nu = cu->nurb.first;
 		
-		if(nu->bezt)
+		if (nu->bezt)
 			tot /= 3;
 	}
 	
@@ -320,30 +323,30 @@ static int rna_ShapeKey_data_length(PointerRNA *ptr)
 
 static PointerRNA rna_ShapeKey_data_get(CollectionPropertyIterator *iter)
 {
-	Key *key= rna_ShapeKey_find_key(iter->parent.id.data);
+	Key *key = rna_ShapeKey_find_key(iter->parent.id.data);
 	StructRNA *type;
 	Curve *cu;
 	Nurb *nu;
 	
-	if(GS(key->from->name) == ID_CU) {
-		cu= (Curve*)key->from;
-		nu= cu->nurb.first;
+	if (GS(key->from->name) == ID_CU) {
+		cu = (Curve*)key->from;
+		nu = cu->nurb.first;
 		
-		if(nu->bezt)
-			type= &RNA_ShapeKeyBezierPoint;
+		if (nu->bezt)
+			type = &RNA_ShapeKeyBezierPoint;
 		else
-			type= &RNA_ShapeKeyCurvePoint;
+			type = &RNA_ShapeKeyCurvePoint;
 	}
 	else
-		type= &RNA_ShapeKeyPoint;
+		type = &RNA_ShapeKeyPoint;
 	
 	return rna_pointer_inherit_refine(&iter->parent, type, rna_iterator_array_get(iter));
 }
 
 static char *rna_ShapeKey_path(PointerRNA *ptr)
 {
-	KeyBlock *kb= (KeyBlock *)ptr->data;
-	ID *id= ptr->id.data;
+	KeyBlock *kb = (KeyBlock *)ptr->data;
+	ID *id = ptr->id.data;
 	
 	if ((id) && (GS(id->name) != ID_KE))
 		return BLI_sprintfN("shape_keys.key_blocks[\"%s\"]", kb->name);
@@ -353,11 +356,11 @@ static char *rna_ShapeKey_path(PointerRNA *ptr)
 
 static void rna_Key_update_data(Main *bmain, Scene *UNUSED(scene), PointerRNA *ptr)
 {
-	Key *key= ptr->id.data;
+	Key *key = ptr->id.data;
 	Object *ob;
 
-	for(ob=bmain->object.first; ob; ob= ob->id.next) {
-		if(ob_get_key(ob) == key) {
+	for (ob = bmain->object.first; ob; ob = ob->id.next) {
+		if (ob_get_key(ob) == key) {
 			DAG_id_tag_update(&ob->id, OB_RECALC_DATA);
 			WM_main_add_notifier(NC_OBJECT|ND_MODIFIER, ob);
 		}
@@ -372,7 +375,7 @@ static KeyBlock *rna_ShapeKeyData_find_keyblock(Key *key, float *point)
 	if (ELEM(NULL, key, point))
 		return NULL;
 	
-	/* we'll need to manually search through the keyblocks and check 
+	/* we'll need to manually search through the keyblocks and check
 	 * if the point is somewhere in the middle of each block's data
 	 */
 	for (kb = key->block.first; kb; kb = kb->next) {
@@ -390,7 +393,7 @@ static KeyBlock *rna_ShapeKeyData_find_keyblock(Key *key, float *point)
 				return kb;
 			}
 			
-			/* determine where end of array is 
+			/* determine where end of array is
 			 *	- elemsize is in bytes, so use char* cast to get array in terms of bytes
 			 */
 			end = (float *)((char *)start + (key->elemsize * kb->totelem));
@@ -408,7 +411,7 @@ static KeyBlock *rna_ShapeKeyData_find_keyblock(Key *key, float *point)
 
 static int rna_ShapeKeyPoint_get_index(Key *key, KeyBlock *kb, float *point)
 {
-	/* if we frame the data array and point pointers as char*, then the difference between 
+	/* if we frame the data array and point pointers as char*, then the difference between
 	 * them will be in bytes. Thus, dividing through by key->elemsize (number of bytes per point)
 	 * gives us the offset of point from start of array.
 	 */
@@ -426,7 +429,7 @@ static char *rna_ShapeKeyPoint_path(PointerRNA *ptr)
 	float *point = (float *)ptr->data;
 	
 	/* if we can get a key block, we can construct a path */
-	kb = rna_ShapeKeyData_find_keyblock(key, point); 
+	kb = rna_ShapeKeyData_find_keyblock(key, point);
 	
 	if (kb) {
 		int index = rna_ShapeKeyPoint_get_index(key, kb, point);
@@ -437,7 +440,7 @@ static char *rna_ShapeKeyPoint_path(PointerRNA *ptr)
 			return BLI_sprintfN("shape_keys.key_blocks[\"%s\"].data[%d]", kb->name, index);
 	}
 	else
-		return NULL; // XXX: there's really no way to resolve this...
+		return NULL; /* XXX: there's really no way to resolve this... */
 }
 
 #else
@@ -447,58 +450,64 @@ static void rna_def_keydata(BlenderRNA *brna)
 	StructRNA *srna;
 	PropertyRNA *prop;
 
-	srna= RNA_def_struct(brna, "ShapeKeyPoint", NULL);
+	srna = RNA_def_struct(brna, "ShapeKeyPoint", NULL);
 	RNA_def_struct_ui_text(srna, "Shape Key Point", "Point in a shape key");
 	RNA_def_struct_path_func(srna, "rna_ShapeKeyPoint_path");
 
-	prop= RNA_def_property(srna, "co", PROP_FLOAT, PROP_TRANSLATION);
+	prop = RNA_def_property(srna, "co", PROP_FLOAT, PROP_TRANSLATION);
 	RNA_def_property_array(prop, 3);
 	RNA_def_property_float_funcs(prop, "rna_ShapeKeyPoint_co_get", "rna_ShapeKeyPoint_co_set", NULL);
 	RNA_def_property_ui_text(prop, "Location", "");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	srna= RNA_def_struct(brna, "ShapeKeyCurvePoint", NULL);
+	srna = RNA_def_struct(brna, "ShapeKeyCurvePoint", NULL);
 	RNA_def_struct_ui_text(srna, "Shape Key Curve Point", "Point in a shape key for curves");
-	RNA_def_struct_path_func(srna, "rna_ShapeKeyPoint_path"); /* there's nothing type specific here, so this is fine for now */
+		/* there's nothing type specific here, so this is fine for now */
+	RNA_def_struct_path_func(srna, "rna_ShapeKeyPoint_path");
 
-	prop= RNA_def_property(srna, "co", PROP_FLOAT, PROP_TRANSLATION);
+	prop = RNA_def_property(srna, "co", PROP_FLOAT, PROP_TRANSLATION);
 	RNA_def_property_array(prop, 3);
 	RNA_def_property_float_funcs(prop, "rna_ShapeKeyPoint_co_get", "rna_ShapeKeyPoint_co_set", NULL);
 	RNA_def_property_ui_text(prop, "Location", "");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "tilt", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "tilt", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_funcs(prop, "rna_ShapeKeyCurvePoint_tilt_get", "rna_ShapeKeyCurvePoint_tilt_set", NULL);
 	RNA_def_property_ui_text(prop, "Tilt", "");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	srna= RNA_def_struct(brna, "ShapeKeyBezierPoint", NULL);
+	srna = RNA_def_struct(brna, "ShapeKeyBezierPoint", NULL);
 	RNA_def_struct_ui_text(srna, "Shape Key Bezier Point", "Point in a shape key for Bezier curves");
-	RNA_def_struct_path_func(srna, "rna_ShapeKeyPoint_path"); /* there's nothing type specific here, so this is fine for now */
+		/* there's nothing type specific here, so this is fine for now */
+	RNA_def_struct_path_func(srna, "rna_ShapeKeyPoint_path");
 
-	prop= RNA_def_property(srna, "co", PROP_FLOAT, PROP_TRANSLATION);
+	prop = RNA_def_property(srna, "co", PROP_FLOAT, PROP_TRANSLATION);
 	RNA_def_property_array(prop, 3);
 	RNA_def_property_float_funcs(prop, "rna_ShapeKeyBezierPoint_co_get", "rna_ShapeKeyBezierPoint_co_set", NULL);
 	RNA_def_property_ui_text(prop, "Location", "");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "handle_left", PROP_FLOAT, PROP_TRANSLATION);
+	prop = RNA_def_property(srna, "handle_left", PROP_FLOAT, PROP_TRANSLATION);
 	RNA_def_property_array(prop, 3);
-	RNA_def_property_float_funcs(prop, "rna_ShapeKeyBezierPoint_handle_1_co_get", "rna_ShapeKeyBezierPoint_handle_1_co_set", NULL);
+	RNA_def_property_float_funcs(prop, "rna_ShapeKeyBezierPoint_handle_1_co_get",
+	                             "rna_ShapeKeyBezierPoint_handle_1_co_set", NULL);
 	RNA_def_property_ui_text(prop, "Handle 1 Location", "");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "handle_right", PROP_FLOAT, PROP_TRANSLATION);
+	prop = RNA_def_property(srna, "handle_right", PROP_FLOAT, PROP_TRANSLATION);
 	RNA_def_property_array(prop, 3);
-	RNA_def_property_float_funcs(prop, "rna_ShapeKeyBezierPoint_handle_2_co_get", "rna_ShapeKeyBezierPoint_handle_2_co_set", NULL);
+	RNA_def_property_float_funcs(prop, "rna_ShapeKeyBezierPoint_handle_2_co_get",
+	                             "rna_ShapeKeyBezierPoint_handle_2_co_set", NULL);
 	RNA_def_property_ui_text(prop, "Handle 2 Location", "");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	/* appears to be unused currently
-	prop= RNA_def_property(srna, "tilt", PROP_FLOAT, PROP_NONE);
+	/* appears to be unused currently */
+#if 0
+	prop = RNA_def_property(srna, "tilt", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_funcs(prop, "rna_ShapeKeyBezierPoint_tilt_get", "rna_ShapeKeyBezierPoint_tilt_set", NULL);
 	RNA_def_property_ui_text(prop, "Tilt", "");
-	RNA_def_property_update(prop, 0, "rna_Key_update_data"); */
+	RNA_def_property_update(prop, 0, "rna_Key_update_data");
+#endif
 }
 
 static void rna_def_keyblock(BlenderRNA *brna)
@@ -512,74 +521,77 @@ static void rna_def_keyblock(BlenderRNA *brna)
 		{KEY_BSPLINE, "KEY_BSPLINE", 0, "BSpline", ""},
 		{0, NULL, 0, NULL, NULL}};
 
-	srna= RNA_def_struct(brna, "ShapeKey", NULL);
+	srna = RNA_def_struct(brna, "ShapeKey", NULL);
 	RNA_def_struct_ui_text(srna, "Shape Key", "Shape key in a shape keys datablock");
 	RNA_def_struct_sdna(srna, "KeyBlock");
 	RNA_def_struct_path_func(srna, "rna_ShapeKey_path");
 	RNA_def_struct_ui_icon(srna, ICON_SHAPEKEY_DATA);
 
-	prop= RNA_def_property(srna, "name", PROP_STRING, PROP_NONE);
+	prop = RNA_def_property(srna, "name", PROP_STRING, PROP_NONE);
 	RNA_def_property_ui_text(prop, "Name", "Name of Shape Key");
 	RNA_def_property_string_funcs(prop, NULL, NULL, "rna_ShapeKey_name_set");
 	RNA_def_struct_name_property(srna, prop);
 
 	/* keys need to be sorted to edit this */
-	prop= RNA_def_property(srna, "frame", PROP_FLOAT, PROP_TIME);
+	prop = RNA_def_property(srna, "frame", PROP_FLOAT, PROP_TIME);
 	RNA_def_property_clear_flag(prop, PROP_EDITABLE);
 	RNA_def_property_float_sdna(prop, NULL, "pos");
 	RNA_def_property_ui_text(prop, "Frame", "Frame for absolute keys");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 	
-	/* for now, this is editable directly, as users can set this even if they're not animating them (to test results) */
-	prop= RNA_def_property(srna, "value", PROP_FLOAT, PROP_FACTOR);
+	/* for now, this is editable directly, as users can set this even if they're not animating them
+	 * (to test results) */
+	prop = RNA_def_property(srna, "value", PROP_FLOAT, PROP_FACTOR);
 	RNA_def_property_float_sdna(prop, NULL, "curval");
 	RNA_def_property_float_funcs(prop, NULL, "rna_ShapeKey_value_set", "rna_ShapeKey_value_range");
 	RNA_def_property_ui_range(prop, -10.0f, 10.0f, 10, 3);
 	RNA_def_property_ui_text(prop, "Value", "Value of shape key at the current frame");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "interpolation", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "interpolation", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "type");
 	RNA_def_property_enum_items(prop, prop_keyblock_type_items);
 	RNA_def_property_ui_text(prop, "Interpolation", "Interpolation type");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "vertex_group", PROP_STRING, PROP_NONE);
+	prop = RNA_def_property(srna, "vertex_group", PROP_STRING, PROP_NONE);
 	RNA_def_property_string_sdna(prop, NULL, "vgroup");
 	RNA_def_property_ui_text(prop, "Vertex Group", "Vertex weight group, to blend with basis shape");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "relative_key", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "relative_key", PROP_POINTER, PROP_NONE);
 	RNA_def_property_struct_type(prop, "ShapeKey");
 	RNA_def_property_flag(prop, PROP_EDITABLE);
-	RNA_def_property_pointer_funcs(prop, "rna_ShapeKey_relative_key_get", "rna_ShapeKey_relative_key_set", NULL, NULL);
+	RNA_def_property_pointer_funcs(prop, "rna_ShapeKey_relative_key_get",
+	                               "rna_ShapeKey_relative_key_set", NULL, NULL);
 	RNA_def_property_ui_text(prop, "Relative Key", "Shape used as a relative key");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "mute", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "mute", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "flag", KEYBLOCK_MUTE);
 	RNA_def_property_ui_text(prop, "Mute", "Mute this shape key");
 	RNA_def_property_ui_icon(prop, ICON_RESTRICT_VIEW_OFF, 1);
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "slider_min", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "slider_min", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "slidermin");
 	RNA_def_property_range(prop, -10.0f, 10.0f);
 	RNA_def_property_float_funcs(prop, NULL, "rna_ShapeKey_slider_min_set", "rna_ShapeKey_slider_min_range");
 	RNA_def_property_ui_text(prop, "Slider Min", "Minimum for slider");
 
-	prop= RNA_def_property(srna, "slider_max", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "slider_max", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "slidermax");
 	RNA_def_property_range(prop, -10.0f, 10.0f);
 	RNA_def_property_float_default(prop, 1.0f);
 	RNA_def_property_float_funcs(prop, NULL, "rna_ShapeKey_slider_max_set", "rna_ShapeKey_slider_max_range");
 	RNA_def_property_ui_text(prop, "Slider Max", "Maximum for slider");
 
-	prop= RNA_def_property(srna, "data", PROP_COLLECTION, PROP_NONE);
+	prop = RNA_def_property(srna, "data", PROP_COLLECTION, PROP_NONE);
 	RNA_def_property_collection_sdna(prop, NULL, "data", "totelem");
 	RNA_def_property_struct_type(prop, "UnknownType");
 	RNA_def_property_ui_text(prop, "Data", "");
-	RNA_def_property_collection_funcs(prop, "rna_ShapeKey_data_begin", NULL, NULL, "rna_ShapeKey_data_get", "rna_ShapeKey_data_length", NULL, NULL, NULL);
+	RNA_def_property_collection_funcs(prop, "rna_ShapeKey_data_begin", NULL, NULL, "rna_ShapeKey_data_get",
+	                                  "rna_ShapeKey_data_length", NULL, NULL, NULL);
 }
 
 static void rna_def_key(BlenderRNA *brna)
@@ -587,37 +599,46 @@ static void rna_def_key(BlenderRNA *brna)
 	StructRNA *srna;
 	PropertyRNA *prop;
 
-	srna= RNA_def_struct(brna, "Key", "ID");
+	srna = RNA_def_struct(brna, "Key", "ID");
 	RNA_def_struct_ui_text(srna, "Key", "Shape keys datablock containing different shapes of geometric datablocks");
 	RNA_def_struct_ui_icon(srna, ICON_SHAPEKEY_DATA);
 
-	prop= RNA_def_property(srna, "reference_key", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "reference_key", PROP_POINTER, PROP_NONE);
 	RNA_def_property_flag(prop, PROP_NEVER_NULL);
 	RNA_def_property_clear_flag(prop, PROP_EDITABLE);
 	RNA_def_property_pointer_sdna(prop, NULL, "refkey");
 	RNA_def_property_ui_text(prop, "Reference Key", "");
 
-	prop= RNA_def_property(srna, "key_blocks", PROP_COLLECTION, PROP_NONE);
+	prop = RNA_def_property(srna, "key_blocks", PROP_COLLECTION, PROP_NONE);
 	RNA_def_property_collection_sdna(prop, NULL, "block", NULL);
 	RNA_def_property_struct_type(prop, "ShapeKey");
 	RNA_def_property_ui_text(prop, "Key Blocks", "Shape keys");
 
 	rna_def_animdata_common(srna);
 
-	prop= RNA_def_property(srna, "user", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "user", PROP_POINTER, PROP_NONE);
 	RNA_def_property_flag(prop, PROP_NEVER_NULL);
 	RNA_def_property_pointer_sdna(prop, NULL, "from");
 	RNA_def_property_ui_text(prop, "User", "Datablock using these shape keys");
 
-	prop= RNA_def_property(srna, "use_relative", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_relative", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "type", KEY_RELATIVE);
-	RNA_def_property_ui_text(prop, "Relative", "Make shape keys relative");
+	RNA_def_property_ui_text(prop, "Relative",
+	                         "Make shape keys relative, "
+	                         "otherwise play through shapes as a sequence using the evaluation time");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 
-	prop= RNA_def_property(srna, "slurph", PROP_INT, PROP_UNSIGNED);
+	prop = RNA_def_property(srna, "eval_time", PROP_FLOAT, PROP_NONE);
+	RNA_def_property_float_sdna(prop, NULL, "ctime");
+	RNA_def_property_range(prop, MINFRAME, MAXFRAME);
+	RNA_def_property_ui_text(prop, "Evaluation Time", "Evaluation time for absolute shape keys");
+	RNA_def_property_update(prop, 0, "rna_Key_update_data");
+
+	prop = RNA_def_property(srna, "slurph", PROP_INT, PROP_UNSIGNED);
 	RNA_def_property_int_sdna(prop, NULL, "slurph");
 	RNA_def_property_range(prop, -500, 500);
-	RNA_def_property_ui_text(prop, "Slurph", "Create a delay (in frames) in applying keypositions, first vertex goes first");
+	RNA_def_property_ui_text(prop, "Slurph",
+	                         "Create a delay (in frames) in applying keypositions, first vertex goes first");
 	RNA_def_property_update(prop, 0, "rna_Key_update_data");
 }
 
@@ -629,4 +650,3 @@ void RNA_def_key(BlenderRNA *brna)
 }
 
 #endif
-
