@@ -67,29 +67,29 @@ static PointerRNA rna_World_mist_get(PointerRNA *ptr)
 
 static void rna_World_mtex_begin(CollectionPropertyIterator *iter, PointerRNA *ptr)
 {
-	World *wo= (World*)ptr->data;
+	World *wo = (World*)ptr->data;
 	rna_iterator_array_begin(iter, (void*)wo->mtex, sizeof(MTex*), MAX_MTEX, 0, NULL);
 }
 
 static PointerRNA rna_World_active_texture_get(PointerRNA *ptr)
 {
-	World *wo= (World*)ptr->data;
+	World *wo = (World*)ptr->data;
 	Tex *tex;
 
-	tex= give_current_world_texture(wo);
+	tex = give_current_world_texture(wo);
 	return rna_pointer_inherit_refine(ptr, &RNA_Texture, tex);
 }
 
 static void rna_World_active_texture_set(PointerRNA *ptr, PointerRNA value)
 {
-	World *wo= (World*)ptr->data;
+	World *wo = (World*)ptr->data;
 
 	set_current_world_texture(wo, value.data);
 }
 
 static void rna_World_update(Main *UNUSED(bmain), Scene *UNUSED(scene), PointerRNA *ptr)
 {
-	World *wo= ptr->id.data;
+	World *wo = ptr->id.data;
 
 	DAG_id_tag_update(&wo->id, 0);
 	WM_main_add_notifier(NC_WORLD, wo);
@@ -97,7 +97,7 @@ static void rna_World_update(Main *UNUSED(bmain), Scene *UNUSED(scene), PointerR
 
 static void rna_World_draw_update(Main *UNUSED(bmain), Scene *UNUSED(scene), PointerRNA *ptr)
 {
-	World *wo= ptr->id.data;
+	World *wo = ptr->id.data;
 
 	DAG_id_tag_update(&wo->id, 0);
 	WM_main_add_notifier(NC_WORLD|ND_WORLD_DRAW, wo);
@@ -106,7 +106,7 @@ static void rna_World_draw_update(Main *UNUSED(bmain), Scene *UNUSED(scene), Poi
 /* so camera mist limits redraw */
 static void rna_World_draw_mist_update(Main *UNUSED(bmain), Scene *UNUSED(scene), PointerRNA *ptr)
 {
-	World *wo= ptr->id.data;
+	World *wo = ptr->id.data;
 
 	DAG_id_tag_update(&wo->id, 0);
 	WM_main_add_notifier(NC_WORLD|ND_WORLD_DRAW, wo);
@@ -115,7 +115,7 @@ static void rna_World_draw_mist_update(Main *UNUSED(bmain), Scene *UNUSED(scene)
 
 static void rna_World_stars_update(Main *UNUSED(bmain), Scene *UNUSED(scene), PointerRNA *ptr)
 {
-	World *wo= ptr->id.data;
+	World *wo = ptr->id.data;
 
 	DAG_id_tag_update(&wo->id, 0);
 	WM_main_add_notifier(NC_WORLD|ND_WORLD_STARS, wo);
@@ -123,9 +123,9 @@ static void rna_World_stars_update(Main *UNUSED(bmain), Scene *UNUSED(scene), Po
 
 static void rna_World_use_nodes_update(Main *bmain, Scene *scene, PointerRNA *ptr)
 {
-	World *wrld= (World*)ptr->data;
+	World *wrld = (World*)ptr->data;
 
-	if(wrld->use_nodes && wrld->nodetree==NULL)
+	if (wrld->use_nodes && wrld->nodetree == NULL)
 		ED_node_shader_default(scene, &wrld->id);
 	
 	rna_World_update(bmain, scene, ptr);
@@ -148,63 +148,64 @@ static void rna_def_world_mtex(BlenderRNA *brna)
 		{TEXCO_OBJECT, "OBJECT", 0, "Object", "Use linked object's coordinates for texture coordinates"},
 		{0, NULL, 0, NULL, NULL}};
 
-	srna= RNA_def_struct(brna, "WorldTextureSlot", "TextureSlot");
+	srna = RNA_def_struct(brna, "WorldTextureSlot", "TextureSlot");
 	RNA_def_struct_sdna(srna, "MTex");
 	RNA_def_struct_ui_text(srna, "World Texture Slot", "Texture slot for textures in a World datablock");
 
 	/* map to */
-	prop= RNA_def_property(srna, "use_map_blend", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_map_blend", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mapto", WOMAP_BLEND);
 	RNA_def_property_ui_text(prop, "Blend", "Affect the color progression of the background");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_map_horizon", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_map_horizon", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mapto", WOMAP_HORIZ);
 	RNA_def_property_ui_text(prop, "Horizon", "Affect the color of the horizon");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_map_zenith_up", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_map_zenith_up", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mapto", WOMAP_ZENUP);
 	RNA_def_property_ui_text(prop, "Zenith Up", "Affect the color of the zenith above");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_map_zenith_down", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_map_zenith_down", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mapto", WOMAP_ZENDOWN);
 	RNA_def_property_ui_text(prop, "Zenith Down", "Affect the color of the zenith below");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "texture_coords", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "texture_coords", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "texco");
 	RNA_def_property_enum_items(prop, texco_items);
-	RNA_def_property_ui_text(prop, "Texture Coordinates", "Texture coordinates used to map the texture onto the background");
+	RNA_def_property_ui_text(prop, "Texture Coordinates",
+	                         "Texture coordinates used to map the texture onto the background");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "object", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "object", PROP_POINTER, PROP_NONE);
 	RNA_def_property_pointer_sdna(prop, NULL, "object");
 	RNA_def_property_struct_type(prop, "Object");
 	RNA_def_property_flag(prop, PROP_EDITABLE);
 	RNA_def_property_ui_text(prop, "Object", "Object to use for mapping with Object texture coordinates");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "blend_factor", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "blend_factor", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "blendfac");
 	RNA_def_property_ui_range(prop, 0, 1, 10, 3);
 	RNA_def_property_ui_text(prop, "Blend Factor", "Amount texture affects color progression of the background");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "horizon_factor", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "horizon_factor", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "colfac");
 	RNA_def_property_ui_range(prop, 0, 1, 10, 3);
 	RNA_def_property_ui_text(prop, "Horizon Factor", "Amount texture affects color of the horizon");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "zenith_up_factor", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "zenith_up_factor", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "zenupfac");
 	RNA_def_property_ui_range(prop, 0, 1, 10, 3);
 	RNA_def_property_ui_text(prop, "Zenith Up Factor", "Amount texture affects color of the zenith above");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "zenith_down_factor", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "zenith_down_factor", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "zendownfac");
 	RNA_def_property_ui_range(prop, 0, 1, 10, 3);
 	RNA_def_property_ui_text(prop, "Zenith Down Factor", "Amount texture affects color of the zenith below");
@@ -238,138 +239,150 @@ static void rna_def_lighting(BlenderRNA *brna)
 		{WO_AOGATHER_APPROX, "APPROXIMATE", 0, "Approximate", "Inaccurate, but faster and without noise"},
 		{0, NULL, 0, NULL, NULL}};
 
-	srna= RNA_def_struct(brna, "WorldLighting", NULL);
+	srna = RNA_def_struct(brna, "WorldLighting", NULL);
 	RNA_def_struct_sdna(srna, "World");
 	RNA_def_struct_nested(brna, srna, "World");
 	RNA_def_struct_ui_text(srna, "Lighting", "Lighting for a World datablock");
 
 	/* ambient occlusion */
-	prop= RNA_def_property(srna, "use_ambient_occlusion", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_ambient_occlusion", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mode", WO_AMB_OCC);
-	RNA_def_property_ui_text(prop, "Use Ambient Occlusion", "Use Ambient Occlusion to add shadowing based on distance between objects");
+	RNA_def_property_ui_text(prop, "Use Ambient Occlusion",
+	                         "Use Ambient Occlusion to add shadowing based on distance between objects");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "ao_factor", PROP_FLOAT, PROP_FACTOR);
+	prop = RNA_def_property(srna, "ao_factor", PROP_FLOAT, PROP_FACTOR);
 	RNA_def_property_float_sdna(prop, NULL, "aoenergy");
 	RNA_def_property_range(prop, 0, INT_MAX);
 	RNA_def_property_ui_range(prop, 0, 1, 0.1, 2);
 	RNA_def_property_ui_text(prop, "Factor", "Factor for ambient occlusion blending");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "ao_blend_type", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "ao_blend_type", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "aomix");
 	RNA_def_property_enum_items(prop, blend_mode_items);
 	RNA_def_property_ui_text(prop, "Blend Mode", "Defines how AO mixes with material shading");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
 	/* environment lighting */
-	prop= RNA_def_property(srna, "use_environment_light", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_environment_light", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mode", WO_ENV_LIGHT);
 	RNA_def_property_ui_text(prop, "Use Environment Lighting", "Add light coming from the environment");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "environment_energy", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "environment_energy", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "ao_env_energy");
 	RNA_def_property_ui_range(prop, 0, FLT_MAX, 1, 3);
 	RNA_def_property_ui_text(prop, "Environment Color", "Defines the strength of environment light");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "environment_color", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "environment_color", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "aocolor");
 	RNA_def_property_enum_items(prop, prop_color_items);
 	RNA_def_property_ui_text(prop, "Environment Color", "Defines where the color of the environment light comes from");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
 	/* indirect lighting */
-	prop= RNA_def_property(srna, "use_indirect_light", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_indirect_light", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mode", WO_INDIRECT_LIGHT);
 	RNA_def_property_ui_text(prop, "Use Indirect Lighting", "Add indirect light bouncing of surrounding objects");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "indirect_factor", PROP_FLOAT, PROP_FACTOR);
+	prop = RNA_def_property(srna, "indirect_factor", PROP_FLOAT, PROP_FACTOR);
 	RNA_def_property_float_sdna(prop, NULL, "ao_indirect_energy");
 	RNA_def_property_range(prop, 0, INT_MAX);
 	RNA_def_property_ui_range(prop, 0, 1, 0.1, 2);
 	RNA_def_property_ui_text(prop, "Indirect Factor", "Factor for how much surrounding objects contribute to light");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "indirect_bounces", PROP_INT, PROP_UNSIGNED);
+	prop = RNA_def_property(srna, "indirect_bounces", PROP_INT, PROP_UNSIGNED);
 	RNA_def_property_int_sdna(prop, NULL, "ao_indirect_bounces");
 	RNA_def_property_range(prop, 1, SHRT_MAX);
 	RNA_def_property_ui_text(prop, "Bounces", "Number of indirect diffuse light bounces");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
 	/* gathering parameters */
-	prop= RNA_def_property(srna, "gather_method", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "gather_method", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "ao_gather_method");
 	RNA_def_property_enum_items(prop, prop_gather_method_items);
 	RNA_def_property_ui_text(prop, "Gather Method", "");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "passes", PROP_INT, PROP_NONE);
+	prop = RNA_def_property(srna, "passes", PROP_INT, PROP_NONE);
 	RNA_def_property_int_sdna(prop, NULL, "ao_approx_passes");
 	RNA_def_property_range(prop, 0, 10);
 	RNA_def_property_ui_text(prop, "Passes", "Number of preprocessing passes to reduce overocclusion");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "distance", PROP_FLOAT, PROP_DISTANCE);
+	prop = RNA_def_property(srna, "distance", PROP_FLOAT, PROP_DISTANCE);
 	RNA_def_property_float_sdna(prop, NULL, "aodist");
-	RNA_def_property_ui_text(prop, "Distance", "Length of rays, defines how far away other faces give occlusion effect");
+	RNA_def_property_ui_text(prop, "Distance",
+	                         "Length of rays, defines how far away other faces give occlusion effect");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "falloff_strength", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "falloff_strength", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "aodistfac");
-	RNA_def_property_ui_text(prop, "Strength", "Attenuation falloff strength, the higher, the less influence distant objects have");
+	RNA_def_property_ui_text(prop, "Strength",
+	                         "Attenuation falloff strength, the higher, the less influence distant objects have");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "bias", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "bias", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "aobias");
 	RNA_def_property_range(prop, 0, 0.5);
-	RNA_def_property_ui_text(prop, "Bias", "Bias (in radians) to prevent smoothed faces from showing banding (for Raytrace Constant Jittered)");
+	RNA_def_property_ui_text(prop, "Bias",
+	                         "Bias (in radians) to prevent smoothed faces from showing banding "
+	                         "(for Raytrace Constant Jittered)");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "threshold", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "threshold", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "ao_adapt_thresh");
 	RNA_def_property_range(prop, 0, 1);
-	RNA_def_property_ui_text(prop, "Threshold", "Samples below this threshold will be considered fully shadowed/unshadowed and skipped (for Raytrace Adaptive QMC)");
+	RNA_def_property_ui_text(prop, "Threshold",
+	                         "Samples below this threshold will be considered fully shadowed/unshadowed and skipped "
+	                         "(for Raytrace Adaptive QMC)");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "adapt_to_speed", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "adapt_to_speed", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "ao_adapt_speed_fac");
 	RNA_def_property_range(prop, 0, 1);
-	RNA_def_property_ui_text(prop, "Adapt To Speed", "Use the speed vector pass to reduce AO samples in fast moving pixels. Higher values result in more aggressive sample reduction. Requires Vec pass enabled (for Raytrace Adaptive QMC)");
+	RNA_def_property_ui_text(prop, "Adapt To Speed",
+	                         "Use the speed vector pass to reduce AO samples in fast moving pixels - "
+	                         "higher values result in more aggressive sample reduction "
+	                         "(requires Vec pass enabled, for Raytrace Adaptive QMC)");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "error_threshold", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "error_threshold", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "ao_approx_error");
 	RNA_def_property_range(prop, 0.0001, 10);
 	RNA_def_property_ui_text(prop, "Error Tolerance", "Low values are slower and higher quality");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "correction", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "correction", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "ao_approx_correction");
 	RNA_def_property_range(prop, 0, 1);
 	RNA_def_property_ui_range(prop, 0, 1, 0.1, 2);
 	RNA_def_property_ui_text(prop, "Correction", "Ad-hoc correction for over-occlusion due to the approximation");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_falloff", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_falloff", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "aomode", WO_AODIST);
 	RNA_def_property_ui_text(prop, "Falloff", "Distance will be used to attenuate shadows");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_cache", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_cache", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "aomode", WO_AOCACHE);
-	RNA_def_property_ui_text(prop, "Pixel Cache", "Cache AO results in pixels and interpolate over neighbouring pixels for speedup");
+	RNA_def_property_ui_text(prop, "Pixel Cache",
+	                         "Cache AO results in pixels and interpolate over neighboring pixels for speedup");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "samples", PROP_INT, PROP_NONE);
+	prop = RNA_def_property(srna, "samples", PROP_INT, PROP_NONE);
 	RNA_def_property_int_sdna(prop, NULL, "aosamp");
 	RNA_def_property_range(prop, 1, 128);
-	RNA_def_property_ui_text(prop, "Samples", "Amount of ray samples. Higher values give smoother results and longer rendering times");
+	RNA_def_property_ui_text(prop, "Samples",
+	                         "Amount of ray samples. Higher values give smoother results and longer rendering times");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "sample_method", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "sample_method", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "ao_samp_method");
 	RNA_def_property_enum_items(prop, prop_sample_method_items);
 	RNA_def_property_ui_text(prop, "Sample Method", "Method for generating shadow samples (for Raytrace)");
@@ -387,43 +400,43 @@ static void rna_def_world_mist(BlenderRNA *brna)
 		{2, "INVERSE_QUADRATIC", 0, "Inverse Quadratic", "Use inverse quadratic progression"},
 		{0, NULL, 0, NULL, NULL}};
 
-	srna= RNA_def_struct(brna, "WorldMistSettings", NULL);
+	srna = RNA_def_struct(brna, "WorldMistSettings", NULL);
 	RNA_def_struct_sdna(srna, "World");
 	RNA_def_struct_nested(brna, srna, "World");
 	RNA_def_struct_ui_text(srna, "World Mist", "Mist settings for a World data-block");
 
-	prop= RNA_def_property(srna, "use_mist", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_mist", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mode", WO_MIST);
 	RNA_def_property_ui_text(prop, "Use Mist", "Occlude objects with the environment color as they are further away");
 	RNA_def_property_update(prop, 0, "rna_World_draw_update");
 
-	prop= RNA_def_property(srna, "intensity", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "intensity", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "misi");
 	RNA_def_property_range(prop, 0, 1);
 	RNA_def_property_ui_text(prop, "Minimum", "Overall minimum intensity of the mist effect");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "start", PROP_FLOAT, PROP_DISTANCE);
+	prop = RNA_def_property(srna, "start", PROP_FLOAT, PROP_DISTANCE);
 	RNA_def_property_float_sdna(prop, NULL, "miststa");
 	RNA_def_property_range(prop, 0, FLT_MAX);
 	RNA_def_property_ui_range(prop, 0, 10000, 10, 2);
 	RNA_def_property_ui_text(prop, "Start", "Starting distance of the mist, measured from the camera");
 	RNA_def_property_update(prop, 0, "rna_World_draw_mist_update");
 
-	prop= RNA_def_property(srna, "depth", PROP_FLOAT, PROP_DISTANCE);
+	prop = RNA_def_property(srna, "depth", PROP_FLOAT, PROP_DISTANCE);
 	RNA_def_property_float_sdna(prop, NULL, "mistdist");
 	RNA_def_property_range(prop, 0, FLT_MAX);
 	RNA_def_property_ui_range(prop, 0, 10000, 10, 2);
 	RNA_def_property_ui_text(prop, "Depth", "Distance over which the mist effect fades in");
 	RNA_def_property_update(prop, 0, "rna_World_draw_mist_update");
 
-	prop= RNA_def_property(srna, "height", PROP_FLOAT, PROP_DISTANCE);
+	prop = RNA_def_property(srna, "height", PROP_FLOAT, PROP_DISTANCE);
 	RNA_def_property_float_sdna(prop, NULL, "misthi");
 	RNA_def_property_range(prop, 0, 100);
 	RNA_def_property_ui_text(prop, "Height", "Control how much mist density decreases with height");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 	
-	prop= RNA_def_property(srna, "falloff", PROP_ENUM, PROP_NONE);
+	prop = RNA_def_property(srna, "falloff", PROP_ENUM, PROP_NONE);
 	RNA_def_property_enum_sdna(prop, NULL, "mistype");
 	RNA_def_property_enum_items(prop, falloff_items);
 	RNA_def_property_ui_text(prop, "Falloff", "Type of transition used to fade mist");
@@ -435,35 +448,35 @@ static void rna_def_world_stars(BlenderRNA *brna)
 	StructRNA *srna;
 	PropertyRNA *prop;
 
-	srna= RNA_def_struct(brna, "WorldStarsSettings", NULL);
+	srna = RNA_def_struct(brna, "WorldStarsSettings", NULL);
 	RNA_def_struct_sdna(srna, "World");
 	RNA_def_struct_nested(brna, srna, "World");
 	RNA_def_struct_ui_text(srna, "World Stars", "Stars settings for a World data-block");
 
-	prop= RNA_def_property(srna, "use_stars", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_stars", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "mode", WO_STARS);
 	RNA_def_property_ui_text(prop, "Use Stars", "Enable starfield generation");
 	RNA_def_property_update(prop, 0, "rna_World_stars_update");
 
-	prop= RNA_def_property(srna, "size", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "size", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "starsize");
 	RNA_def_property_range(prop, 0, 10);
 	RNA_def_property_ui_text(prop, "Size", "Average screen dimension of stars");
-	RNA_def_property_update(prop, 0, "rna_World_draw_update"); /* use normal update since this isnt visualized */
+	RNA_def_property_update(prop, 0, "rna_World_draw_update"); /* use normal update since this isn't visualized */
 
-	prop= RNA_def_property(srna, "distance_min", PROP_FLOAT, PROP_DISTANCE);
+	prop = RNA_def_property(srna, "distance_min", PROP_FLOAT, PROP_DISTANCE);
 	RNA_def_property_float_sdna(prop, NULL, "starmindist");
 	RNA_def_property_range(prop, 0, 1000);
 	RNA_def_property_ui_text(prop, "Minimum Distance", "Minimum distance to the camera for stars");
 	RNA_def_property_update(prop, 0, "rna_World_stars_update");
 
-	prop= RNA_def_property(srna, "average_separation", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "average_separation", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "stardist");
 	RNA_def_property_range(prop, 2, 1000);
 	RNA_def_property_ui_text(prop, "Average Separation", "Average distance between any two stars");
 	RNA_def_property_update(prop, 0, "rna_World_stars_update");
 
-	prop= RNA_def_property(srna, "color_random", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "color_random", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "starcolnoise");
 	RNA_def_property_range(prop, 0, 1);
 	RNA_def_property_ui_text(prop, "Color Randomization", "Randomize star colors");
@@ -475,19 +488,20 @@ void RNA_def_world(BlenderRNA *brna)
 	StructRNA *srna;
 	PropertyRNA *prop;
 
-/*
+#if 0
 	static EnumPropertyItem physics_engine_items[] = {
 		{WOPHY_NONE, "NONE", 0, "None", ""},
-		//{WOPHY_ENJI, "ENJI", 0, "Enji", ""},
-		//{WOPHY_SUMO, "SUMO", 0, "Sumo (Deprecated)", ""},
-		//{WOPHY_DYNAMO, "DYNAMO", 0, "Dynamo", ""},
-		//{WOPHY_ODE, "ODE", 0, "ODE", ""},
+		/*{WOPHY_ENJI, "ENJI", 0, "Enji", ""}, */
+		/*{WOPHY_SUMO, "SUMO", 0, "Sumo (Deprecated)", ""}, */
+		/*{WOPHY_DYNAMO, "DYNAMO", 0, "Dynamo", ""}, */
+		/*{WOPHY_ODE, "ODE", 0, "ODE", ""}, */
 		{WOPHY_BULLET, "BULLET", 0, "Bullet", ""},
 		{0, NULL, 0, NULL, NULL}};
-*/
+#endif
 
-	srna= RNA_def_struct(brna, "World", "ID");
-	RNA_def_struct_ui_text(srna, "World", "World datablock describing the environment and ambient lighting of a scene");
+	srna = RNA_def_struct(brna, "World", "ID");
+	RNA_def_struct_ui_text(srna, "World",
+	                       "World datablock describing the environment and ambient lighting of a scene");
 	RNA_def_struct_ui_icon(srna, ICON_WORLD_DATA);
 
 	rna_def_animdata_common(srna);
@@ -495,7 +509,7 @@ void RNA_def_world(BlenderRNA *brna)
 		"rna_World_active_texture_set", NULL, "WorldTextureSlot", "WorldTextureSlots", "rna_World_update");
 
 	/* colors */
-	prop= RNA_def_property(srna, "horizon_color", PROP_FLOAT, PROP_COLOR);
+	prop = RNA_def_property(srna, "horizon_color", PROP_FLOAT, PROP_COLOR);
 	RNA_def_property_float_sdna(prop, NULL, "horr");
 	RNA_def_property_array(prop, 3);
 	RNA_def_property_ui_text(prop, "Horizon Color", "Color at the horizon");
@@ -504,72 +518,72 @@ void RNA_def_world(BlenderRNA *brna)
 	RNA_def_property_update(prop, NC_WORLD|ND_WORLD_DRAW, "rna_World_update");
 
 	
-	prop= RNA_def_property(srna, "zenith_color", PROP_FLOAT, PROP_COLOR);
+	prop = RNA_def_property(srna, "zenith_color", PROP_FLOAT, PROP_COLOR);
 	RNA_def_property_float_sdna(prop, NULL, "zenr");
 	RNA_def_property_array(prop, 3);
 	RNA_def_property_ui_text(prop, "Zenith Color", "Color at the zenith");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "ambient_color", PROP_FLOAT, PROP_COLOR);
+	prop = RNA_def_property(srna, "ambient_color", PROP_FLOAT, PROP_COLOR);
 	RNA_def_property_float_sdna(prop, NULL, "ambr");
 	RNA_def_property_array(prop, 3);
 	RNA_def_property_ui_text(prop, "Ambient Color", "Ambient color of the world");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
 	/* exp, range */
-	prop= RNA_def_property(srna, "exposure", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "exposure", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "exp");
 	RNA_def_property_range(prop, 0.0, 1.0);
 	RNA_def_property_ui_text(prop, "Exposure", "Amount of exponential color correction for light");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "color_range", PROP_FLOAT, PROP_NONE);
+	prop = RNA_def_property(srna, "color_range", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_float_sdna(prop, NULL, "range");
 	RNA_def_property_range(prop, 0.2, 5.0);
 	RNA_def_property_ui_text(prop, "Range", "The color range that will be mapped to 0-1");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
 	/* sky type */
-	prop= RNA_def_property(srna, "use_sky_blend", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_sky_blend", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "skytype", WO_SKYBLEND);
 	RNA_def_property_ui_text(prop, "Blend Sky", "Render background with natural progression from horizon to zenith");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_sky_paper", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_sky_paper", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "skytype", WO_SKYPAPER);
 	RNA_def_property_ui_text(prop, "Paper Sky", "Flatten blend or texture coordinates");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
-	prop= RNA_def_property(srna, "use_sky_real", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_sky_real", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "skytype", WO_SKYREAL);
 	RNA_def_property_ui_text(prop, "Real Sky", "Render background with a real horizon, relative to the camera angle");
 	RNA_def_property_update(prop, 0, "rna_World_update");
 
 	/* nested structs */
-	prop= RNA_def_property(srna, "light_settings", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "light_settings", PROP_POINTER, PROP_NONE);
 	RNA_def_property_flag(prop, PROP_NEVER_NULL);
 	RNA_def_property_struct_type(prop, "WorldLighting");
 	RNA_def_property_pointer_funcs(prop, "rna_World_lighting_get", NULL, NULL, NULL);
 	RNA_def_property_ui_text(prop, "Lighting", "World lighting settings");
 
-	prop= RNA_def_property(srna, "mist_settings", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "mist_settings", PROP_POINTER, PROP_NONE);
 	RNA_def_property_flag(prop, PROP_NEVER_NULL);
 	RNA_def_property_struct_type(prop, "WorldMistSettings");
 	RNA_def_property_pointer_funcs(prop, "rna_World_mist_get", NULL, NULL, NULL);
 	RNA_def_property_ui_text(prop, "Mist", "World mist settings");
 
-	prop= RNA_def_property(srna, "star_settings", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "star_settings", PROP_POINTER, PROP_NONE);
 	RNA_def_property_flag(prop, PROP_NEVER_NULL);
 	RNA_def_property_struct_type(prop, "WorldStarsSettings");
 	RNA_def_property_pointer_funcs(prop, "rna_World_stars_get", NULL, NULL, NULL);
 	RNA_def_property_ui_text(prop, "Stars", "World stars settings");
 
 	/* nodes */
-	prop= RNA_def_property(srna, "node_tree", PROP_POINTER, PROP_NONE);
+	prop = RNA_def_property(srna, "node_tree", PROP_POINTER, PROP_NONE);
 	RNA_def_property_pointer_sdna(prop, NULL, "nodetree");
 	RNA_def_property_ui_text(prop, "Node Tree", "Node tree for node based worlds");
 
-	prop= RNA_def_property(srna, "use_nodes", PROP_BOOLEAN, PROP_NONE);
+	prop = RNA_def_property(srna, "use_nodes", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_sdna(prop, NULL, "use_nodes", 1);
 	RNA_def_property_clear_flag(prop, PROP_ANIMATABLE);
 	RNA_def_property_ui_text(prop, "Use Nodes", "Use shader nodes to render the world");
