@@ -32,17 +32,20 @@
  *  \ingroup modifiers
  */
 
-#include "MEM_guardedalloc.h"
-
 #include "BLI_utildefines.h"
+#include "BLI_math.h"
 #include "BLI_string.h"
 
-#include "BKE_bmesh.h"
 #include "BKE_cdderivedmesh.h"
 #include "BKE_modifier.h"
-#include "BKE_particle.h"
+#include "BKE_tessmesh.h"
+#include "BKE_mesh.h"
 
-#include "MOD_util.h"
+#include "BKE_bmesh.h" /* only for defines */
+
+#include "DNA_object_types.h"
+
+#include "MEM_guardedalloc.h"
 
 
 static void initData(ModifierData *md)
@@ -80,44 +83,123 @@ static CustomDataMask requiredDataMask(Object *UNUSED(ob), ModifierData *md)
 	CustomDataMask dataMask = 0;
 
 	/* ask for vertexgroups if we need them */
-	if(bmd->defgrp_name[0]) dataMask |= CD_MASK_MDEFORMVERT;
+	if (bmd->defgrp_name[0]) dataMask |= CD_MASK_MDEFORMVERT;
 
 	return dataMask;
 }
 
+#define EDGE_MARK	1
+
+#ifdef USE_BM_BEVEL_OP_AS_MOD
+
+/* BMESH_TODO
+ *
+ * this bevel calls the operator which is missing many of the options
+ * which the bevel modifier in trunk has.
+ * - no vertex bevel
+ * - no weight bevel
+ *
+ * These will need to be added to the bmesh operator.
+ *       - campbell
+ *
+ * note: this code is very close to MOD_edgesplit.c.
+ * note: if 0'd code from trunk included below.
+ */
+static DerivedMesh *applyModifier(ModifierData *md, struct Object *UNUSED(ob),
+                                  DerivedMesh *dm,
+                                  int UNUSED(useRenderParams),
+                                  int UNUSED(isFinalCalc))
+{
+	DerivedMesh *result;
+	BMesh *bm;
+	BMEditMesh *em;
+	BMIter iter;
+	BMEdge *e;
+	BevelModifierData *bmd = (BevelModifierData*) md;
+	float threshold = cos((bmd->bevel_angle + 0.00001) * M_PI / 180.0);
+
+	em = DM_to_editbmesh(dm, NULL, FALSE);
+	bm = em->bm;
+
+	BM_mesh_normals_update(bm, FALSE);
+	BMO_push(bm, NULL);
+
+	if (bmd->lim_flags & BME_BEVEL_ANGLE) {
+		BM_ITER_MESH (e, &iter, bm, BM_EDGES_OF_MESH) {
+			/* check for 1 edge having 2 face users */
+			BMLoop *l1, *l2;
+			if ( (l1= e->l) &&
+			     (l2= e->l->radial_next) != l1)
+			{
+				if (dot_v3v3(l1->f->no, l2->f->no) < threshold) {
+					BMO_elem_flag_enable(bm, e, EDGE_MARK);
+				}
+			}
+		}
+	}
+	else {
+		/* crummy, is there a way just to operator on all? - campbell */
+		BM_ITER_MESH (e, &iter, bm, BM_EDGES_OF_MESH) {
+			BMO_elem_flag_enable(bm, e, EDGE_MARK);
+		}
+	}
+
+	BMO_op_callf(bm, "bevel geom=%fe percent=%f use_even=%b use_dist=%b",
+	             EDGE_MARK, bmd->value, (bmd->flags & BME_BEVEL_EVEN) != 0, (bmd->flags & BME_BEVEL_DIST) != 0);
+	BMO_pop(bm);
+
+	BLI_assert(em->looptris == NULL);
+	result = CDDM_from_BMEditMesh(em, NULL, TRUE, FALSE);
+	BMEdit_Free(em);
+	MEM_freeN(em);
+
+	return result;
+}
+
+
+#else /* from trunk, see note above */
+
 static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 						DerivedMesh *derivedData,
 						int UNUSED(useRenderParams),
 						int UNUSED(isFinalCalc))
 {
 	DerivedMesh *result;
-	BME_Mesh *bm;
+	BMEditMesh *em;
 
 	/*bDeformGroup *def;*/
 	int /*i,*/ options, defgrp_index = -1;
 	BevelModifierData *bmd = (BevelModifierData*) md;
 
-	options = bmd->flags|bmd->val_flags|bmd->lim_flags|bmd->e_flags;
+	options = bmd->flags | bmd->val_flags | bmd->lim_flags | bmd->e_flags;
 
-	/*if ((options & BME_BEVEL_VWEIGHT) && bmd->defgrp_name[0]) {
+#if 0
+	if ((options & BME_BEVEL_VWEIGHT) && bmd->defgrp_name[0]) {
 		defgrp_index = defgroup_name_index(ob, bmd->defgrp_name);
 		if (defgrp_index < 0) {
 			options &= ~BME_BEVEL_VWEIGHT;
 		}
-	}*/
+	}
+#endif
 
-	bm = BME_derivedmesh_to_bmesh(derivedData);
-	BME_bevel(bm,bmd->value,bmd->res,options,defgrp_index,bmd->bevel_angle,NULL);
-	result = BME_bmesh_to_derivedmesh(bm,derivedData);
-	BME_free_mesh(bm);
+	em = DM_to_editbmesh(derivedData, NULL, FALSE);
+	BME_bevel(em, bmd->value, bmd->res, options, defgrp_index, DEG2RADF(bmd->bevel_angle), NULL, FALSE);
+	BLI_assert(em->looptris == NULL);
+	result = CDDM_from_BMEditMesh(em, NULL, TRUE, FALSE);
+	BMEdit_Free(em);
+	MEM_freeN(em);
 
+	/* until we allow for dirty normal flag, always calc,
+	 * note: calculating on the CDDM is faster then the BMesh equivalent */
 	CDDM_calc_normals(result);
 
 	return result;
 }
 
+#endif
+
 static DerivedMesh *applyModifierEM(ModifierData *md, Object *ob,
-						EditMesh *UNUSED(editData),
+						struct BMEditMesh *UNUSED(editData),
 						DerivedMesh *derivedData)
 {
 	return applyModifier(md, ob, derivedData, 0, 1);
