@@ -173,29 +173,31 @@ static int FaceIt_Done(CSG_IteratorPtr it)
 {
 	// assume CSG_IteratorPtr is of the correct type.
 	FaceIt * iterator = (FaceIt *)it;
-	return(iterator->pos >= iterator->dm->getNumFaces(iterator->dm));
+	return(iterator->pos >= iterator->dm->getNumTessFaces(iterator->dm));
 }
 
 static void FaceIt_Fill(CSG_IteratorPtr it, CSG_IFace *face)
 {
 	// assume CSG_IteratorPtr is of the correct type.
 	FaceIt *face_it = (FaceIt *)it;
-	MFace *mfaces = face_it->dm->getFaceArray(face_it->dm);
+	MFace *mfaces = face_it->dm->getTessFaceArray(face_it->dm);
 	MFace *mface = &mfaces[face_it->pos];
 
 	/* reverse face vertices if necessary */
 	face->vertex_index[1] = mface->v2;
-	if( face_it->flip == 0 ) {
+	if ( face_it->flip == 0 ) {
 	face->vertex_index[0] = mface->v1;
 	face->vertex_index[2] = mface->v3;
-	} else {
+	}
+	else {
 		face->vertex_index[2] = mface->v1;
 		face->vertex_index[0] = mface->v3;
 	}
 	if (mface->v4) {
 		face->vertex_index[3] = mface->v4;
 		face->vertex_number = 4;
-	} else {
+	}
+	else {
 		face->vertex_number = 3;
 	}
 
@@ -223,7 +225,7 @@ static void FaceIt_Construct(
 	// allocate some memory for blender iterator
 	it = (FaceIt *)(MEM_mallocN(sizeof(FaceIt),"Boolean_FIt"));
 	if (it == 0) {
-		return ;
+		return;
 	}
 	// assign blender specific variables
 	it->dm = dm;
@@ -234,17 +236,22 @@ static void FaceIt_Construct(
 	if (ob->size[0] < 0.0f) {
 		if (ob->size[1] < 0.0f && ob->size[2] < 0.0f) {
 			it->flip = 1;
-		} else if (ob->size[1] >= 0.0f && ob->size[2] >= 0.0f) {
+		}
+		else if (ob->size[1] >= 0.0f && ob->size[2] >= 0.0f) {
 			it->flip = 1;
-		} else {
+		}
+		else {
 			it->flip = 0;
 		}
-	} else {
+	}
+	else {
 		if (ob->size[1] < 0.0f && ob->size[2] < 0.0f) {
 			it->flip = 0;
-		} else if (ob->size[1] >= 0.0f && ob->size[2] >= 0.0f) {
+		}
+		else if (ob->size[1] >= 0.0f && ob->size[2] >= 0.0f) {
 			it->flip = 0;
-		} else {
+		}
+		else {
 			it->flip = 1;
 		}
 	}
@@ -254,7 +261,7 @@ static void FaceIt_Construct(
 	output->Fill = FaceIt_Fill;
 	output->Done = FaceIt_Done;
 	output->Reset = FaceIt_Reset;
-	output->num_elements = it->dm->getNumFaces(it->dm);
+	output->num_elements = it->dm->getNumTessFaces(it->dm);
 	output->it = it;
 }
 
@@ -304,8 +311,8 @@ static void InterpCSGFace(
 	MFace *mface, *orig_mface;
 	int j;
 
-	mface = CDDM_get_face(dm, index);
-	orig_mface = orig_dm->getFaceArray(orig_dm) + orig_index;
+	mface = CDDM_get_tessface(dm, index);
+	orig_mface = orig_dm->getTessFaceArray(orig_dm) + orig_index;
 
 	// get the vertex coordinates from the original mesh
 	orig_co[0] = (orig_dm->getVertArray(orig_dm) + orig_mface->v1)->co;
@@ -333,7 +340,7 @@ static void InterpCSGFace(
 }
 
 /* Iterate over the CSG Output Descriptors and create a new DerivedMesh
-   from them */
+ * from them */
 static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 	CSG_FaceIteratorDescriptor *face_it,
 	CSG_VertexIteratorDescriptor *vertex_it,
@@ -353,10 +360,10 @@ static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 	int i, *origindex_layer;
 
 	// create a new DerivedMesh
-	result = CDDM_new(vertex_it->num_elements, 0, face_it->num_elements);
-	CustomData_merge(&dm1->faceData, &result->faceData, CD_MASK_DERIVEDMESH,
+	result = CDDM_new(vertex_it->num_elements, 0, face_it->num_elements, 0, 0);
+	CustomData_merge(&dm1->faceData, &result->faceData, CD_MASK_DERIVEDMESH & ~(CD_MASK_NORMAL | CD_MASK_POLYINDEX | CD_MASK_ORIGINDEX),
 					  CD_DEFAULT, face_it->num_elements); 
-	CustomData_merge(&dm2->faceData, &result->faceData, CD_MASK_DERIVEDMESH,
+	CustomData_merge(&dm2->faceData, &result->faceData, CD_MASK_DERIVEDMESH & ~(CD_MASK_NORMAL | CD_MASK_POLYINDEX | CD_MASK_ORIGINDEX),
 					  CD_DEFAULT, face_it->num_elements); 
 
 	// step through the vertex iterators:
@@ -379,10 +386,10 @@ static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 	if (mat)
 		*totmat = 0;
 
-	origindex_layer = result->getFaceDataArray(result, CD_ORIGINDEX);
+	origindex_layer = result->getTessFaceDataArray(result, CD_ORIGINDEX);
 
 	// step through the face iterators
-	for(i = 0; !face_it->Done(face_it->it); i++) {
+	for (i = 0; !face_it->Done(face_it->it); i++) {
 		Mesh *orig_me;
 		Object *orig_ob;
 		Material *orig_mat;
@@ -395,23 +402,23 @@ static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 		face_it->Step(face_it->it);
 
 		// find the original mesh and data
-		orig_ob = (csgface.orig_face < dm1->getNumFaces(dm1))? ob1: ob2;
-		orig_dm = (csgface.orig_face < dm1->getNumFaces(dm1))? dm1: dm2;
+		orig_ob = (csgface.orig_face < dm1->getNumTessFaces(dm1))? ob1: ob2;
+		orig_dm = (csgface.orig_face < dm1->getNumTessFaces(dm1))? dm1: dm2;
 		orig_me = (orig_ob == ob1)? me1: me2;
-		orig_index = (orig_ob == ob1)? csgface.orig_face: csgface.orig_face - dm1->getNumFaces(dm1);
+		orig_index = (orig_ob == ob1)? csgface.orig_face: csgface.orig_face - dm1->getNumTessFaces(dm1);
 
 		// copy all face layers, including mface
 		CustomData_copy_data(&orig_dm->faceData, &result->faceData, orig_index, i, 1);
 
 		// set mface
-		mface = CDDM_get_face(result, i);
+		mface = CDDM_get_tessface(result, i);
 		mface->v1 = csgface.vertex_index[0];
 		mface->v2 = csgface.vertex_index[1];
 		mface->v3 = csgface.vertex_index[2];
 		mface->v4 = (csgface.vertex_number == 4)? csgface.vertex_index[3]: 0;
 
 		// set material, based on lookup in hash table
-		orig_mat= give_current_material(orig_ob, mface->mat_nr+1);
+		orig_mat = give_current_material(orig_ob, mface->mat_nr + 1);
 
 		if (mat && orig_mat) {
 			if (!BLI_ghash_haskey(material_hash, orig_mat)) {
@@ -422,8 +429,8 @@ static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 			else
 				mface->mat_nr = GET_INT_FROM_POINTER(BLI_ghash_lookup(material_hash, orig_mat));
 		}
-		else if(orig_mat) {
-			if(orig_ob == ob1) {
+		else if (orig_mat) {
+			if (orig_ob == ob1) {
 				// No need to change materian index for faces from left operand
 			}
 			else {
@@ -433,8 +440,8 @@ static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 					int a;
 
 					mat_nr = 0;
-					for(a = 0; a < ob1->totcol; a++) {
-						if(give_current_material(ob1, a+1) == orig_mat) {
+					for (a = 0; a < ob1->totcol; a++) {
+						if (give_current_material(ob1, a+1) == orig_mat) {
 							mat_nr = a;
 							break;
 						}
@@ -456,14 +463,27 @@ static DerivedMesh *ConvertCSGDescriptorsToDerivedMesh(
 
 		test_index_face(mface, &result->faceData, i, csgface.vertex_number);
 
-		if(origindex_layer && orig_ob == ob2)
+		if (origindex_layer && orig_ob == ob2)
 			origindex_layer[i] = ORIGINDEX_NONE;
 	}
 
 	if (material_hash)
 		BLI_ghash_free(material_hash, NULL, NULL);
 
-	CDDM_calc_edges(result);
+	CDDM_calc_edges_tessface(result);
+
+	CDDM_tessfaces_to_faces(result); /*builds ngon faces from tess (mface) faces*/
+
+	/* this fixes shading issues but SHOULD NOT.
+	 * TODO, find out why face normals are wrong & flicker - campbell */
+#if 0
+	DM_debug_print(result);
+
+	CustomData_free(&result->faceData, result->numTessFaceData);
+	result->numTessFaceData = 0;
+	DM_ensure_tessface(result);
+#endif
+
 	CDDM_calc_normals(result);
 
 	return result;
@@ -499,7 +519,7 @@ static DerivedMesh *NewBooleanDerivedMesh_intern(
 	DerivedMesh *result = NULL;
 
 	if (dm == NULL || dm_select == NULL) return 0;
-	if (!dm->getNumFaces(dm) || !dm_select->getNumFaces(dm_select)) return 0;
+	if (!dm->getNumTessFaces(dm) || !dm_select->getNumTessFaces(dm_select)) return 0;
 
 	// we map the final object back into ob's local coordinate space. For this
 	// we need to compute the inverse transform from global to ob (inv_mat),
@@ -531,7 +551,7 @@ static DerivedMesh *NewBooleanDerivedMesh_intern(
 		}
 		
 		BuildMeshDescriptors(dm_select, ob_select, 0, &fd_1, &vd_1);
-		BuildMeshDescriptors(dm, ob, dm_select->getNumFaces(dm_select) , &fd_2, &vd_2);
+		BuildMeshDescriptors(dm, ob, dm_select->getNumTessFaces(dm_select) , &fd_2, &vd_2);
 
 		bool_op = CSG_NewBooleanFunction();
 
@@ -584,9 +604,11 @@ int NewBooleanMesh(Scene *scene, Base *base, Base *base_select, int int_op_type)
 	mat= (Material**)MEM_mallocN(sizeof(Material*)*maxmat, "NewBooleanMeshMat");
 	
 	/* put some checks in for nice user feedback */
-	if (dm == NULL || dm_select == NULL) return 0;
-	if (!dm->getNumFaces(dm) || !dm_select->getNumFaces(dm_select))
-	{
+	if (dm == NULL || dm_select == NULL) {
+		return 0;
+	}
+
+	if (!dm->getNumTessFaces(dm) || !dm_select->getNumTessFaces(dm_select)) {
 		MEM_freeN(mat);
 		return -1;
 	}
@@ -602,7 +624,7 @@ int NewBooleanMesh(Scene *scene, Base *base, Base *base_select, int int_op_type)
 	ob_new= AddNewBlenderMesh(scene, base_select);
 	me_new= ob_new->data;
 
-	DM_to_mesh(result, me_new);
+	DM_to_mesh(result, me_new, ob_new);
 	result->release(result);
 
 	dm->release(dm);
