@@ -61,7 +61,7 @@ static void initData(ModifierData *md)
 	clmd->point_cache = BKE_ptcache_add(&clmd->ptcaches);
 	
 	/* check for alloc failing */
-	if(!clmd->sim_parms || !clmd->coll_parms || !clmd->point_cache)
+	if (!clmd->sim_parms || !clmd->coll_parms || !clmd->point_cache)
 		return;
 	
 	cloth_init (clmd);
@@ -75,23 +75,24 @@ static void deformVerts(ModifierData *md, Object *ob, DerivedMesh *derivedData,
 	DerivedMesh *result=NULL;
 	
 	/* check for alloc failing */
-	if(!clmd->sim_parms || !clmd->coll_parms)
-	{
+	if (!clmd->sim_parms || !clmd->coll_parms) {
 		initData(md);
 
-		if(!clmd->sim_parms || !clmd->coll_parms)
+		if (!clmd->sim_parms || !clmd->coll_parms)
 			return;
 	}
 
 	dm = get_dm(ob, NULL, derivedData, NULL, 0);
-	if(dm == derivedData)
+	if (dm == derivedData)
 		dm = CDDM_copy(dm);
 
 	CDDM_apply_vert_coords(dm, vertexCos);
 
+	DM_ensure_tessface(dm); /* BMESH - UNTIL MODIFIER IS UPDATED FOR MPoly */
+
 	clothModifier_do(clmd, md->scene, ob, dm, vertexCos);
 
-	if(result) {
+	if (result) {
 		result->getVertCos(result, vertexCos);
 		result->release(result);
 	}
@@ -99,24 +100,18 @@ static void deformVerts(ModifierData *md, Object *ob, DerivedMesh *derivedData,
 	dm->release(dm);
 }
 
-static void updateDepgraph(
-					 ModifierData *md, DagForest *forest, Scene *scene, Object *ob,
-	  DagNode *obNode)
+static void updateDepgraph(ModifierData *md, DagForest *forest, Scene *scene, Object *ob, DagNode *obNode)
 {
 	ClothModifierData *clmd = (ClothModifierData*) md;
 	
 	Base *base;
 	
-	if(clmd)
-	{
-		for(base = scene->base.first; base; base= base->next) 
-		{
+	if (clmd) {
+		for (base = scene->base.first; base; base= base->next) {
 			Object *ob1= base->object;
-			if(ob1 != ob)
-			{
+			if (ob1 != ob) {
 				CollisionModifierData *coll_clmd = (CollisionModifierData *)modifiers_findByType(ob1, eModifierType_Collision);
-				if(coll_clmd)
-				{
+				if (coll_clmd) {
 					DagNode *curNode = dag_get_node(forest, ob1);
 					dag_add_relation(forest, curNode, obNode, DAG_RL_DATA_DATA|DAG_RL_OB_DATA, "Cloth Collision");
 				}
@@ -130,10 +125,10 @@ static CustomDataMask requiredDataMask(Object *UNUSED(ob), ModifierData *md)
 	CustomDataMask dataMask = 0;
 	ClothModifierData *clmd = (ClothModifierData*)md;
 
-	if(cloth_uses_vgroup(clmd))
+	if (cloth_uses_vgroup(clmd))
 		dataMask |= CD_MASK_MDEFORMVERT;
 
-	if(clmd->sim_parms->shapekey_rest != 0)
+	if (clmd->sim_parms->shapekey_rest != 0)
 		dataMask |= CD_MASK_CLOTH_ORCO;
 
 	return dataMask;
@@ -144,20 +139,20 @@ static void copyData(ModifierData *md, ModifierData *target)
 	ClothModifierData *clmd = (ClothModifierData*) md;
 	ClothModifierData *tclmd = (ClothModifierData*) target;
 
-	if(tclmd->sim_parms) {
-		if(tclmd->sim_parms->effector_weights)
+	if (tclmd->sim_parms) {
+		if (tclmd->sim_parms->effector_weights)
 			MEM_freeN(tclmd->sim_parms->effector_weights);
 		MEM_freeN(tclmd->sim_parms);
 	}
 
-	if(tclmd->coll_parms)
+	if (tclmd->coll_parms)
 		MEM_freeN(tclmd->coll_parms);
 	
 	BKE_ptcache_free_list(&tclmd->ptcaches);
 	tclmd->point_cache = NULL;
 
 	tclmd->sim_parms = MEM_dupallocN(clmd->sim_parms);
-	if(clmd->sim_parms->effector_weights)
+	if (clmd->sim_parms->effector_weights)
 		tclmd->sim_parms->effector_weights = MEM_dupallocN(clmd->sim_parms->effector_weights);
 	tclmd->coll_parms = MEM_dupallocN(clmd->coll_parms);
 	tclmd->point_cache = BKE_ptcache_copy_list(&tclmd->ptcaches, &clmd->ptcaches);
@@ -173,19 +168,18 @@ static void freeData(ModifierData *md)
 {
 	ClothModifierData *clmd = (ClothModifierData*) md;
 	
-	if (clmd) 
-	{
-		if(G.rt > 0)
+	if (clmd) {
+		if (G.rt > 0)
 			printf("clothModifier_freeData\n");
 		
 		cloth_free_modifier_extern (clmd);
 		
-		if(clmd->sim_parms) {
-			if(clmd->sim_parms->effector_weights)
+		if (clmd->sim_parms) {
+			if (clmd->sim_parms->effector_weights)
 				MEM_freeN(clmd->sim_parms->effector_weights);
 			MEM_freeN(clmd->sim_parms);
 		}
-		if(clmd->coll_parms)
+		if (clmd->coll_parms)
 			MEM_freeN(clmd->coll_parms);	
 		
 		BKE_ptcache_free_list(&clmd->ptcaches);
@@ -198,11 +192,11 @@ static void foreachIDLink(ModifierData *md, Object *ob,
 {
 	ClothModifierData *clmd = (ClothModifierData*) md;
 
-	if(clmd->coll_parms) {
+	if (clmd->coll_parms) {
 		walk(userData, ob, (ID **)&clmd->coll_parms->group);
 	}
 
-	if(clmd->sim_parms && clmd->sim_parms->effector_weights) {
+	if (clmd->sim_parms && clmd->sim_parms->effector_weights) {
 		walk(userData, ob, (ID **)&clmd->sim_parms->effector_weights->group);
 	}
 }
