@@ -38,6 +38,8 @@
 #include "BLI_math.h"
 #include "BLI_utildefines.h"
 
+#include "BLF_translation.h"
+
 #include "MEM_guardedalloc.h"
 
 #include "BKE_mesh.h"
@@ -81,10 +83,12 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 	int totvert, totface;
 	int a, numTris;
 
+	DM_ensure_tessface(dm); /* BMESH - UNTIL MODIFIER IS UPDATED FOR MPoly */
+
 	mvert = dm->getVertArray(dm);
-	mface = dm->getFaceArray(dm);
+	mface = dm->getTessFaceArray(dm);
 	totvert = dm->getNumVerts(dm);
-	totface = dm->getNumFaces(dm);
+	totface = dm->getNumTessFaces(dm);
 
 	numTris = 0;
 	for (a=0; a<totface; a++) {
@@ -93,10 +97,10 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 		if (mf->v4) numTris++;
 	}
 
-	if(numTris<3) {
-		modifier_setError(md,
-			"Modifier requires more than 3 input faces (triangles).");
-		goto exit;
+	if (numTris<3) {
+		modifier_setError(md, "%s", TIP_("Modifier requires more than 3 input faces (triangles)."));
+		dm = CDDM_copy(dm);
+		return dm;
 	}
 
 	lod.vertex_buffer= MEM_mallocN(3*sizeof(float)*totvert, "vertices");
@@ -105,7 +109,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 	lod.vertex_num= totvert;
 	lod.face_num= numTris;
 
-	for(a=0; a<totvert; a++) {
+	for (a=0; a<totvert; a++) {
 		MVert *mv = &mvert[a];
 		float *vbCo = &lod.vertex_buffer[a*3];
 		float *vbNo = &lod.vertex_normal_buffer[a*3];
@@ -115,14 +119,14 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 	}
 
 	numTris = 0;
-	for(a=0; a<totface; a++) {
+	for (a=0; a<totface; a++) {
 		MFace *mf = &mface[a];
 		int *tri = &lod.triangle_index_buffer[3*numTris++];
 		tri[0]= mf->v1;
 		tri[1]= mf->v2;
 		tri[2]= mf->v3;
 
-		if(mf->v4) {
+		if (mf->v4) {
 			tri = &lod.triangle_index_buffer[3*numTris++];
 			tri[0]= mf->v1;
 			tri[1]= mf->v3;
@@ -131,32 +135,32 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 	}
 
 	dmd->faceCount = 0;
-	if(LOD_LoadMesh(&lod) ) {
-		if( LOD_PreprocessMesh(&lod) ) {
+	if (LOD_LoadMesh(&lod) ) {
+		if ( LOD_PreprocessMesh(&lod) ) {
 			/* we assume the decim_faces tells how much to reduce */
 
-			while(lod.face_num > numTris*dmd->percent) {
-				if( LOD_CollapseEdge(&lod)==0) break;
+			while (lod.face_num > numTris*dmd->percent) {
+				if ( LOD_CollapseEdge(&lod)==0) break;
 			}
 
-			if(lod.vertex_num>2) {
-				result = CDDM_new(lod.vertex_num, 0, lod.face_num);
+			if (lod.vertex_num>2) {
+				result = CDDM_new(lod.vertex_num, 0, lod.face_num, 0, 0);
 				dmd->faceCount = lod.face_num;
 			}
 			else
-				result = CDDM_new(lod.vertex_num, 0, 0);
+				result = CDDM_new(lod.vertex_num, 0, 0, 0, 0);
 
 			mvert = CDDM_get_verts(result);
-			for(a=0; a<lod.vertex_num; a++) {
+			for (a=0; a<lod.vertex_num; a++) {
 				MVert *mv = &mvert[a];
 				float *vbCo = &lod.vertex_buffer[a*3];
 				
 				copy_v3_v3(mv->co, vbCo);
 			}
 
-			if(lod.vertex_num>2) {
-				mface = CDDM_get_faces(result);
-				for(a=0; a<lod.face_num; a++) {
+			if (lod.vertex_num>2) {
+				mface = CDDM_get_tessfaces(result);
+				for (a=0; a<lod.face_num; a++) {
 					MFace *mf = &mface[a];
 					int *tri = &lod.triangle_index_buffer[a*3];
 					mf->v1 = tri[0];
@@ -166,23 +170,28 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *UNUSED(ob),
 				}
 			}
 
-			CDDM_calc_edges(result);
-			CDDM_calc_normals(result);
+			CDDM_calc_edges_tessface(result);
 		}
 		else
-			modifier_setError(md, "Out of memory.");
+			modifier_setError(md, "%s", TIP_("Out of memory."));
 
 		LOD_FreeDecimationData(&lod);
 	}
 	else
-		modifier_setError(md, "Non-manifold mesh as input.");
+		modifier_setError(md, "%s", TIP_("Non-manifold mesh as input."));
 
 	MEM_freeN(lod.vertex_buffer);
 	MEM_freeN(lod.vertex_normal_buffer);
 	MEM_freeN(lod.triangle_index_buffer);
 
-exit:
+	if (result) {
+		CDDM_tessfaces_to_faces(result); /*builds ngon faces from tess (mface) faces*/
+
 		return result;
+	}
+	else {
+		return dm;
+	}
 }
 #else // WITH_MOD_DECIMATE
 static DerivedMesh *applyModifier(ModifierData *UNUSED(md), Object *UNUSED(ob),
