@@ -87,10 +87,10 @@ static CustomDataMask requiredDataMask(Object *UNUSED(ob), ModifierData *md)
 	CustomDataMask dataMask = 0;
 
 	/* ask for vertexgroups if we need them */
-	if(dmd->defgrp_name[0]) dataMask |= CD_MASK_MDEFORMVERT;
+	if (dmd->defgrp_name[0]) dataMask |= CD_MASK_MDEFORMVERT;
 
 	/* ask for UV coordinates if we need them */
-	if(dmd->texmapping == MOD_DISP_MAP_UV) dataMask |= CD_MASK_MTFACE;
+	if (dmd->texmapping == MOD_DISP_MAP_UV) dataMask |= CD_MASK_MTFACE;
 
 	return dataMask;
 }
@@ -99,12 +99,10 @@ static int dependsOnTime(ModifierData *md)
 {
 	DisplaceModifierData *dmd = (DisplaceModifierData *)md;
 
-	if(dmd->texture)
-	{
+	if (dmd->texture) {
 		return BKE_texture_dependsOnTime(dmd->texture);
 	}
-	else
-	{
+	else {
 		return 0;
 	}
 }
@@ -153,7 +151,7 @@ static void updateDepgraph(ModifierData *md, DagForest *forest,
 {
 	DisplaceModifierData *dmd = (DisplaceModifierData*) md;
 
-	if(dmd->map_object && dmd->texmapping == MOD_DISP_MAP_OBJECT) {
+	if (dmd->map_object && dmd->texmapping == MOD_DISP_MAP_OBJECT) {
 		DagNode *curNode = dag_get_node(forest, dmd->map_object);
 
 		dag_add_relation(forest, curNode, obNode,
@@ -161,7 +159,7 @@ static void updateDepgraph(ModifierData *md, DagForest *forest,
 	}
 	
 
-	if(dmd->texmapping == MOD_DISP_MAP_GLOBAL)
+	if (dmd->texmapping == MOD_DISP_MAP_GLOBAL)
 		dag_add_relation(forest, obNode, obNode,
 		                 DAG_RL_DATA_DATA | DAG_RL_OB_DATA, "Displace Modifier");
 	
@@ -179,8 +177,8 @@ static void displaceModifier_do(
 	float (*tex_co)[3];
 	float weight= 1.0f; /* init value unused but some compilers may complain */
 
-	if(!dmd->texture) return;
-	if(dmd->strength == 0.0f) return;
+	if (!dmd->texture) return;
+	if (dmd->strength == 0.0f) return;
 
 	mvert = CDDM_get_verts(dm);
 	modifier_get_vgroup(ob, dm, dmd->defgrp_name, &dvert, &defgrp_index);
@@ -189,13 +187,15 @@ static void displaceModifier_do(
 				 "displaceModifier_do tex_co");
 	get_texture_coords((MappingInfoModifierData *)dmd, ob, dm, vertexCos, tex_co, numVerts);
 
-	for(i = 0; i < numVerts; ++i) {
+	modifier_init_texture(dmd->modifier.scene, dmd->texture);
+
+	for (i = 0; i < numVerts; ++i) {
 		TexResult texres;
 		float delta = 0, strength = dmd->strength;
 
-		if(dvert) {
+		if (dvert) {
 			weight= defvert_find_weight(dvert + i, defgrp_index);
-			if(weight == 0.0f) continue;
+			if (weight == 0.0f) continue;
 		}
 
 		texres.nor = NULL;
@@ -203,7 +203,7 @@ static void displaceModifier_do(
 
 		delta = texres.tin - dmd->midlevel;
 
-		if(dvert) strength *= weight;
+		if (dvert) strength *= weight;
 
 		delta *= strength;
 		CLAMP(delta, -10000, 10000);
@@ -246,12 +246,12 @@ static void deformVerts(ModifierData *md, Object *ob,
 	displaceModifier_do((DisplaceModifierData *)md, ob, dm,
 	                    vertexCos, numVerts);
 
-	if(dm != derivedData)
+	if (dm != derivedData)
 		dm->release(dm);
 }
 
 static void deformVertsEM(
-					   ModifierData *md, Object *ob, struct EditMesh *editData,
+					   ModifierData *md, Object *ob, struct BMEditMesh *editData,
 	DerivedMesh *derivedData, float (*vertexCos)[3], int numVerts)
 {
 	DerivedMesh *dm= get_cddm(ob, editData, derivedData, vertexCos);
@@ -259,7 +259,7 @@ static void deformVertsEM(
 	displaceModifier_do((DisplaceModifierData *)md, ob, dm,
 	                    vertexCos, numVerts);
 
-	if(dm != derivedData)
+	if (dm != derivedData)
 		dm->release(dm);
 }
 
