@@ -75,7 +75,7 @@ static CustomDataMask requiredDataMask(Object *UNUSED(ob), ModifierData *md)
 
 	if (pmd->canvas) {
 		DynamicPaintSurface *surface = pmd->canvas->surfaces.first;
-		for(; surface; surface=surface->next) {
+		for (; surface; surface=surface->next) {
 			/* tface */
 			if (surface->format == MOD_DPAINT_SURFACE_F_IMAGESEQ || 
 				surface->init_color_type == MOD_DPAINT_INITIAL_TEXTURE) {
@@ -119,15 +119,13 @@ static void updateDepgraph(ModifierData *md, DagForest *forest,
 	DynamicPaintModifierData *pmd = (DynamicPaintModifierData*) md;
 
 	/* add relation from canvases to all brush objects */
-	if(pmd && pmd->canvas)
-	{
+	if (pmd && pmd->canvas) {
 		Base *base = scene->base.first;
 
-		for(; base; base = base->next) {
+		for (; base; base = base->next) {
 			DynamicPaintModifierData *pmd2 = (DynamicPaintModifierData *)modifiers_findByType(base->object, eModifierType_DynamicPaint);
 
-			if(pmd2 && pmd2->brush && ob!=base->object)
-			{
+			if (pmd2 && pmd2->brush && ob!=base->object) {
 				DagNode *brushNode = dag_get_node(forest, base->object);
 				dag_add_relation(forest, brushNode, obNode, DAG_RL_DATA_DATA|DAG_RL_OB_DATA, "Dynamic Paint Brush");
 			}
@@ -145,10 +143,10 @@ static void foreachIDLink(ModifierData *md, Object *ob,
 {
 	DynamicPaintModifierData *pmd = (DynamicPaintModifierData*) md;
 
-	if(pmd->canvas) {
+	if (pmd->canvas) {
 		DynamicPaintSurface *surface = pmd->canvas->surfaces.first;
 
-		for(; surface; surface=surface->next) {
+		for (; surface; surface=surface->next) {
 			walk(userData, ob, (ID **)&surface->brush_group);
 			walk(userData, ob, (ID **)&surface->init_texture);
 		}
