@@ -66,13 +66,13 @@
 void fluidsim_init(FluidsimModifierData *fluidmd)
 {
 #ifdef WITH_MOD_FLUID
-	if(fluidmd)
+	if (fluidmd)
 	{
 		FluidsimSettings *fss = MEM_callocN(sizeof(FluidsimSettings), "fluidsimsettings");
 
 		fluidmd->fss = fss;
 		
-		if(!fss)
+		if (!fss)
 			return;
 		
 		fss->fmd = fluidmd;
@@ -85,7 +85,6 @@ void fluidsim_init(FluidsimModifierData *fluidmd)
 		fss->guiDisplayMode = 2; // preview
 		fss->renderDisplayMode = 3; // render
 
-		fss->viscosityMode = 2; // default to water
 		fss->viscosityValue = 1.0;
 		fss->viscosityExponent = 6;
 		
@@ -131,11 +130,11 @@ void fluidsim_init(FluidsimModifierData *fluidmd)
 		fss->cpsQuality = 10.0; // 1.0 / 10.0 => means 0.1 width
 		
 		/*
-		BAD TODO: this is done in buttons_object.c in the moment 
-		Mesh *mesh = ob->data;
-		// calculate bounding box
-		fluid_get_bb(mesh->mvert, mesh->totvert, ob->obmat, fss->bbStart, fss->bbSize);	
-		*/
+		 * BAD TODO: this is done in buttons_object.c in the moment
+		 * Mesh *mesh = ob->data;
+		 * // calculate bounding box
+		 * fluid_get_bb(mesh->mvert, mesh->totvert, ob->obmat, fss->bbStart, fss->bbSize);
+		 */
 		
 		fss->meshVelocities = NULL;
 		
@@ -152,9 +151,8 @@ void fluidsim_init(FluidsimModifierData *fluidmd)
 
 void fluidsim_free(FluidsimModifierData *fluidmd)
 {
-	if(fluidmd) {
-		if(fluidmd->fss->meshVelocities)
-		{
+	if (fluidmd && fluidmd->fss) {
+		if (fluidmd->fss->meshVelocities) {
 			MEM_freeN(fluidmd->fss->meshVelocities);
 			fluidmd->fss->meshVelocities = NULL;
 		}
@@ -166,25 +164,26 @@ void fluidsim_free(FluidsimModifierData *fluidmd)
 
 #ifdef WITH_MOD_FLUID
 /* read .bobj.gz file into a fluidsimDerivedMesh struct */
-static DerivedMesh *fluidsim_read_obj(const char *filename, const MFace *mf_example)
+static DerivedMesh *fluidsim_read_obj(const char *filename, const MPoly *mp_example)
 {
 	int wri = 0,i;
 	int gotBytes;
 	gzFile gzf;
 	int numverts = 0, numfaces = 0;
 	DerivedMesh *dm = NULL;
-	MFace *mf;
+	MPoly *mp;
+	MLoop *ml;
 	MVert *mv;
 	short *normals, *no_s;
 	float no[3];
 
-	const short mf_mat_nr = mf_example->mat_nr;
-	const char  mf_flag =   mf_example->flag;
+	const short mp_mat_nr = mp_example->mat_nr;
+	const char  mp_flag =   mp_example->flag;
 
 	// ------------------------------------------------
 	// get numverts + numfaces first
 	// ------------------------------------------------
-	gzf = gzopen(filename, "rb");
+	gzf = BLI_gzopen(filename, "rb");
 	if (!gzf)
 	{
 		return NULL;
@@ -199,34 +198,34 @@ static DerivedMesh *fluidsim_read_obj(const char *filename, const MFace *mf_exam
 
 
 	// read number of normals
-	if(gotBytes)
+	if (gotBytes)
 		gotBytes = gzread(gzf, &wri, sizeof(wri));
 
 	// skip normals
 	gotBytes = gzseek(gzf, numverts * 3 * sizeof(float), SEEK_CUR) != -1;
 
 	/* get no. of triangles */
-	if(gotBytes)
+	if (gotBytes)
 		gotBytes = gzread(gzf, &wri, sizeof(wri));
 	numfaces = wri;
 
-	gzclose( gzf );
+	gzclose(gzf);
 	// ------------------------------------------------
 
-	if(!numfaces || !numverts || !gotBytes)
+	if (!numfaces || !numverts || !gotBytes)
 		return NULL;
 
-	gzf = gzopen(filename, "rb");
+	gzf = BLI_gzopen(filename, "rb");
 	if (!gzf)
 	{
 		return NULL;
 	}
 
-	dm = CDDM_new(numverts, 0, numfaces);
+	dm = CDDM_new(numverts, 0, 0, numfaces * 3, numfaces);
 
-	if(!dm)
+	if (!dm)
 	{
-		gzclose( gzf );
+		gzclose(gzf);
 		return NULL;
 	}
 
@@ -236,30 +235,30 @@ static DerivedMesh *fluidsim_read_obj(const char *filename, const MFace *mf_exam
 	// read vertex position from file
 	mv = CDDM_get_verts(dm);
 
-	for(i=0; i<numverts; i++, mv++)
+	for (i=0; i<numverts; i++, mv++)
 		gotBytes = gzread(gzf, mv->co, sizeof(float) * 3);
 
 	// should be the same as numverts
 	gotBytes = gzread(gzf, &wri, sizeof(wri));
-	if(wri != numverts)
+	if (wri != numverts)
 	{
-		if(dm)
+		if (dm)
 			dm->release(dm);
-		gzclose( gzf );
+		gzclose(gzf);
 		return NULL;
 	}
 
 	normals = MEM_callocN(sizeof(short) * numverts * 3, "fluid_tmp_normals" );
-	if(!normals)
+	if (!normals)
 	{
-		if(dm)
+		if (dm)
 			dm->release(dm);
-		gzclose( gzf );
+		gzclose(gzf);
 		return NULL;
 	}
 
 	// read normals from file (but don't save them yet)
-	for(i=numverts, no_s= normals; i>0; i--, no_s += 3)
+	for (i=numverts, no_s= normals; i>0; i--, no_s += 3)
 	{
 		gotBytes = gzread(gzf, no, sizeof(float) * 3);
 		normal_float_to_short_v3(no_s, no);
@@ -268,46 +267,38 @@ static DerivedMesh *fluidsim_read_obj(const char *filename, const MFace *mf_exam
 	/* read no. of triangles */
 	gotBytes = gzread(gzf, &wri, sizeof(wri));
 
-	if(wri!=numfaces) {
+	if (wri!=numfaces) {
 		printf("Fluidsim: error in reading data from file.\n");
-		if(dm)
+		if (dm)
 			dm->release(dm);
-		gzclose( gzf );
+		gzclose(gzf);
 		MEM_freeN(normals);
 		return NULL;
 	}
 
 	// read triangles from file
-	mf = CDDM_get_faces(dm);
-	for(i=numfaces; i>0; i--, mf++)
+	mp = CDDM_get_polys(dm);
+	ml = CDDM_get_loops(dm);
+	for (i=0; i < numfaces; i++, mp++, ml += 3)
 	{
 		int face[3];
 
 		gotBytes = gzread(gzf, face, sizeof(int) * 3);
 
 		/* initialize from existing face */
-		mf->mat_nr = mf_mat_nr;
-		mf->flag =   mf_flag;
+		mp->mat_nr = mp_mat_nr;
+		mp->flag =   mp_flag;
 
-		// check if 3rd vertex has index 0 (not allowed in blender)
-		if(face[2])
-		{
-			mf->v1 = face[0];
-			mf->v2 = face[1];
-			mf->v3 = face[2];
-		}
-		else
-		{
-			mf->v1 = face[1];
-			mf->v2 = face[2];
-			mf->v3 = face[0];
-		}
-		mf->v4 = 0;
+		mp->loopstart = i * 3;
+		mp->totloop = 3;
+
+		ml[0].v = face[0];
+		ml[1].v = face[1];
+		ml[2].v = face[2];
 
-		test_index_face(mf, NULL, 0, 3);
 	}
 
-	gzclose( gzf );
+	gzclose(gzf);
 
 	CDDM_calc_edges(dm);
 
@@ -315,7 +306,6 @@ static DerivedMesh *fluidsim_read_obj(const char *filename, const MFace *mf_exam
 	MEM_freeN(normals);
 
 	// CDDM_calc_normals(result);
-
 	return dm;
 }
 
@@ -328,7 +318,7 @@ void fluid_get_bb(MVert *mvert, int totvert, float obmat[][4],
 	int i;
 	float vec[3];
 
-	if(totvert == 0) {
+	if (totvert == 0) {
 		zero_v3(start);
 		zero_v3(size);
 		return;
@@ -339,25 +329,25 @@ void fluid_get_bb(MVert *mvert, int totvert, float obmat[][4],
 	bbsx = vec[0]; bbsy = vec[1]; bbsz = vec[2];
 	bbex = vec[0]; bbey = vec[1]; bbez = vec[2];
 
-	for(i = 1; i < totvert; i++) {
+	for (i = 1; i < totvert; i++) {
 		copy_v3_v3(vec, mvert[i].co);
 		mul_m4_v3(obmat, vec);
 
-		if(vec[0] < bbsx){ bbsx= vec[0]; }
-		if(vec[1] < bbsy){ bbsy= vec[1]; }
-		if(vec[2] < bbsz){ bbsz= vec[2]; }
-		if(vec[0] > bbex){ bbex= vec[0]; }
-		if(vec[1] > bbey){ bbey= vec[1]; }
-		if(vec[2] > bbez){ bbez= vec[2]; }
+		if (vec[0] < bbsx) { bbsx= vec[0]; }
+		if (vec[1] < bbsy) { bbsy= vec[1]; }
+		if (vec[2] < bbsz) { bbsz= vec[2]; }
+		if (vec[0] > bbex) { bbex= vec[0]; }
+		if (vec[1] > bbey) { bbey= vec[1]; }
+		if (vec[2] > bbez) { bbez= vec[2]; }
 	}
 
 	// return values...
-	if(start) {
+	if (start) {
 		start[0] = bbsx;
 		start[1] = bbsy;
 		start[2] = bbsz;
 	}
-	if(size) {
+	if (size) {
 		size[0] = bbex-bbsx;
 		size[1] = bbey-bbsy;
 		size[2] = bbez-bbsz;
@@ -374,7 +364,7 @@ void fluid_estimate_memory(Object *ob, FluidsimSettings *fss, char *value)
 
 	value[0]= '\0';
 
-	if(ob->type == OB_MESH) {
+	if (ob->type == OB_MESH) {
 		/* use mesh bounding box and object scaling */
 		mesh= ob->data;
 
@@ -397,15 +387,15 @@ static void fluidsim_read_vel_cache(FluidsimModifierData *fluidmd, DerivedMesh *
 
 	// mesh and vverts have to be valid from loading...
 
-	if(fss->meshVelocities)
+	if (fss->meshVelocities)
 		MEM_freeN(fss->meshVelocities);
 
-	if(len<7)
+	if (len<7)
 	{
 		return;
 	}
 
-	if(fss->domainNovecgen>0) return;
+	if (fss->domainNovecgen>0) return;
 
 	fss->meshVelocities = MEM_callocN(sizeof(FluidVertexVelocity)*dm->getNumVerts(dm), "Fluidsim_velocities");
 	fss->totvert = totvert;
@@ -418,7 +408,7 @@ static void fluidsim_read_vel_cache(FluidsimModifierData *fluidmd, DerivedMesh *
 	filename[len-5] = 'e';
 	filename[len-4] = 'l';
 
-	gzf = gzopen(filename, "rb");
+	gzf = BLI_gzopen(filename, "rb");
 	if (!gzf)
 	{
 		MEM_freeN(fss->meshVelocities);
@@ -427,16 +417,16 @@ static void fluidsim_read_vel_cache(FluidsimModifierData *fluidmd, DerivedMesh *
 	}
 
 	gzread(gzf, &wri, sizeof( wri ));
-	if(wri != totvert)
+	if (wri != totvert)
 	{
 		MEM_freeN(fss->meshVelocities);
 		fss->meshVelocities = NULL;
 		return;
 	}
 
-	for(i=0; i<totvert;i++)
+	for (i=0; i<totvert;i++)
 	{
-		for(j=0; j<3; j++)
+		for (j=0; j<3; j++)
 		{
 			gzread(gzf, &wrf, sizeof( wrf ));
 			velarray[i].vel[j] = wrf;
@@ -453,13 +443,13 @@ static DerivedMesh *fluidsim_read_cache(Object *ob, DerivedMesh *orgdm, Fluidsim
 	char targetFile[FILE_MAX];
 	FluidsimSettings *fss = fluidmd->fss;
 	DerivedMesh *dm = NULL;
-	MFace *mface;
-	MFace mf_example = {0};
+	MPoly *mpoly;
+	MPoly mp_example = {0};
 
-
-	if(!useRenderParams) {
+	if (!useRenderParams) {
 		displaymode = fss->guiDisplayMode;
-	} else {
+	}
+	else {
 		displaymode = fss->renderDisplayMode;
 	}
 
@@ -485,23 +475,23 @@ static DerivedMesh *fluidsim_read_cache(Object *ob, DerivedMesh *orgdm, Fluidsim
 
 	// assign material + flags to new dm
 	// if there's no faces in original dm, keep materials and flags unchanged
-	mface = orgdm->getFaceArray(orgdm);
-	if (mface) {
-		mf_example = *mface;
+	mpoly = orgdm->getPolyArray(orgdm);
+	if (mpoly) {
+		mp_example = *mpoly;
 	}
 	/* else leave NULL'd */
 
-	dm = fluidsim_read_obj(targetFile, &mf_example);
+	dm = fluidsim_read_obj(targetFile, &mp_example);
 
-	if(!dm)
+	if (!dm)
 	{
 		// switch, abort background rendering when fluidsim mesh is missing
 		const char *strEnvName2 = "BLENDER_ELBEEMBOBJABORT"; // from blendercall.cpp
 
-		if(G.background==1) {
-			if(getenv(strEnvName2)) {
+		if (G.background==1) {
+			if (getenv(strEnvName2)) {
 				int elevel = atoi(getenv(strEnvName2));
-				if(elevel>0) {
+				if (elevel>0) {
 					printf("Env. var %s set, fluid sim mesh '%s' not found, aborting render...\n",strEnvName2, targetFile);
 					exit(1);
 				}
@@ -515,13 +505,11 @@ static DerivedMesh *fluidsim_read_cache(Object *ob, DerivedMesh *orgdm, Fluidsim
 	// load vertex velocities, if they exist...
 	// TODO? use generate flag as loading flag as well?
 	// warning, needs original .bobj.gz mesh loading filename
-	if(displaymode==3)
-	{
+	if (displaymode==3) {
 		fluidsim_read_vel_cache(fluidmd, dm, targetFile);
 	}
-	else
-	{
-		if(fss->meshVelocities)
+	else {
+		if (fss->meshVelocities)
 			MEM_freeN(fss->meshVelocities);
 
 		fss->meshVelocities = NULL;
@@ -544,11 +532,11 @@ DerivedMesh *fluidsimModifier_do(FluidsimModifierData *fluidmd, Scene *scene,
 	framenr= (int)scene->r.cfra;
 	
 	// only handle fluidsim domains
-	if(fluidmd && fluidmd->fss && (fluidmd->fss->type != OB_FLUIDSIM_DOMAIN))
+	if (fluidmd && fluidmd->fss && (fluidmd->fss->type != OB_FLUIDSIM_DOMAIN))
 		return dm;
 	
 	// sanity check
-	if(!fluidmd || (fluidmd && !fluidmd->fss))
+	if (!fluidmd || (fluidmd && !fluidmd->fss))
 		return dm;
 	
 	fss = fluidmd->fss;
@@ -557,15 +545,14 @@ DerivedMesh *fluidsimModifier_do(FluidsimModifierData *fluidmd, Scene *scene,
 	// clmd->sim_parms->timescale= timescale;
 
 	// support reversing of baked fluid frames here
-	if((fss->flag & OB_FLUIDSIM_REVERSE) && (fss->lastgoodframe >= 0))
-	{
+	if ((fss->flag & OB_FLUIDSIM_REVERSE) && (fss->lastgoodframe >= 0)) {
 		framenr = fss->lastgoodframe - framenr + 1;
 		CLAMP(framenr, 1, fss->lastgoodframe);
 	}
 	
 	/* try to read from cache */
 	/* if the frame is there, fine, otherwise don't do anything */
-	if((result = fluidsim_read_cache(ob, dm, fluidmd, framenr, useRenderParams)))
+	if ((result = fluidsim_read_cache(ob, dm, fluidmd, framenr, useRenderParams)))
 		return result;
 	
 	return dm;
