@@ -142,13 +142,13 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 	ScrewModifierData *ltmd= (ScrewModifierData*) md;
 	
 	int *origindex;
-	int mface_index=0;
+	int mpoly_index=0;
 	int step;
 	int i, j;
 	unsigned int i1, i2;
 	int step_tot= useRenderParams ? ltmd->render_steps : ltmd->steps;
 	const int do_flip = ltmd->flag & MOD_SCREW_NORMAL_FLIP ? 1 : 0;
-	int maxVerts=0, maxEdges=0, maxFaces=0;
+	int maxVerts=0, maxEdges=0, maxPolys=0;
 	const unsigned int totvert= dm->getNumVerts(dm);
 	const unsigned int totedge= dm->getNumEdges(dm);
 
@@ -165,16 +165,19 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 	int vc_tot_linked= 0;
 	short other_axis_1, other_axis_2;
 	float *tmpf1, *tmpf2;
+
+	int edge_offset;
 	
-	MFace *mface_new, *mf_new;
+	MPoly *mpoly_new, *mp_new;
+	MLoop *mloop_new, *ml_new;
 	MEdge *medge_orig, *med_orig, *med_new, *med_new_firstloop, *medge_new;
 	MVert *mvert_new, *mvert_orig, *mv_orig, *mv_new, *mv_new_base;
 
 	ScrewVertConnect *vc, *vc_tmp, *vert_connect= NULL;
 
-	/* dont do anything? */
+	/* don't do anything? */
 	if (!totvert)
-		return CDDM_from_template(dm, 0, 0, 0);
+		return CDDM_from_template(dm, 0, 0, 0, 0, 0);
 
 	switch(ltmd->axis) {
 	case 0:
@@ -204,11 +207,11 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		normalize_v3(axis_vec);
 
 		/* screw */
-		if(ltmd->flag & MOD_SCREW_OBJECT_OFFSET) {
+		if (ltmd->flag & MOD_SCREW_OBJECT_OFFSET) {
 			/* find the offset along this axis relative to this objects matrix */
 			float totlen = len_v3(mtx_tx[3]);
 
-			if(totlen != 0.0f) {
+			if (totlen != 0.0f) {
 				float zero[3]={0.0f, 0.0f, 0.0f};
 				float cp[3];				
 				screw_ofs= closest_to_line_v3(cp, mtx_tx[3], zero, axis_vec);
@@ -221,7 +224,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		/* angle */
 
 #if 0	// cant incluide this, not predictable enough, though quite fun,.
-		if(ltmd->flag & MOD_SCREW_OBJECT_ANGLE) {
+		if (ltmd->flag & MOD_SCREW_OBJECT_ANGLE) {
 			float mtx3_tx[3][3];
 			copy_m3_m4(mtx3_tx, mtx_tx);
 
@@ -245,7 +248,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 				cross_v3_v3v3(axis_tmp, cross1, c2);
 				normalize_v3(axis_tmp);
 
-				if(len_v3v3(axis_tmp, axis_vec) > 1.0f)
+				if (len_v3v3(axis_tmp, axis_vec) > 1.0f)
 					angle= -angle;
 
 			}
@@ -273,36 +276,45 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 	if (fabsf(screw_ofs) <= (FLT_EPSILON*100.0f) && fabsf(fabsf(angle) - ((float)M_PI * 2.0f)) <= (FLT_EPSILON*100.0f)) {
 		close= 1;
 		step_tot--;
-		if(step_tot < 3) step_tot= 3;
+		if (step_tot < 3) step_tot= 3;
 	
 		maxVerts =	totvert  * step_tot; /* -1 because we're joining back up */
 		maxEdges =	(totvert * step_tot) + /* these are the edges between new verts */
 					(totedge * step_tot); /* -1 because vert edges join */
-		maxFaces =	totedge * step_tot;
+		maxPolys =	totedge * step_tot;
 
 		screw_ofs= 0.0f;
 	}
 	else {
 		close= 0;
-		if(step_tot < 3) step_tot= 3;
+		if (step_tot < 3) step_tot= 3;
 
 		maxVerts =	totvert  * step_tot; /* -1 because we're joining back up */
 		maxEdges =	(totvert * (step_tot-1)) + /* these are the edges between new verts */
 					(totedge * step_tot); /* -1 because vert edges join */
-		maxFaces =	totedge * (step_tot-1);
+		maxPolys =	totedge * (step_tot-1);
 	}
 	
-	result= CDDM_from_template(dm, maxVerts, maxEdges, maxFaces);
+	result= CDDM_from_template(dm, maxVerts, maxEdges, 0, maxPolys * 4, maxPolys);
 	
 	/* copy verts from mesh */
 	mvert_orig =	dm->getVertArray(dm);
 	medge_orig =	dm->getEdgeArray(dm);
 	
 	mvert_new =		result->getVertArray(result);
-	mface_new =		result->getFaceArray(result);
+	mpoly_new =		result->getPolyArray(result);
+	mloop_new =		result->getLoopArray(result);
 	medge_new =		result->getEdgeArray(result);
-	
-	origindex= result->getFaceDataArray(result, CD_ORIGINDEX);
+
+	if (!CustomData_has_layer(&result->polyData, CD_ORIGINDEX)) {
+		CustomData_add_layer(&result->polyData, CD_ORIGINDEX, CD_CALLOC, NULL, maxPolys);
+	}
+
+#if 0 // trunk
+	origindex = result->getPolyDataArray(result, CD_ORIGINDEX);
+#else // bmesh
+	origindex = CustomData_get_layer(&result->polyData, CD_ORIGINDEX);
+#endif
 
 	DM_copy_vert_data(dm, result, 0, 0, totvert); /* copy first otherwise this overwrites our own vertex normals */
 	
@@ -321,7 +333,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		med_new->flag= med_orig->flag &  ~ME_LOOSEEDGE;
 	}
 	
-	if(ltmd->flag & MOD_SCREW_NORMAL_CALC) {
+	if (ltmd->flag & MOD_SCREW_NORMAL_CALC) {
 		/*
 		 * Normal Calculation (for face flipping)
 		 * Sort edge verts for correct face flipping
@@ -333,7 +345,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		/* Notice!
 		 *
 		 * Since we are only ordering the edges here it can avoid mallocing the
-		 * extra space by abusing the vert array berfore its filled with new verts.
+		 * extra space by abusing the vert array before its filled with new verts.
 		 * The new array for vert_connect must be at least sizeof(ScrewVertConnect) * totvert
 		 * and the size of our resulting meshes array is sizeof(MVert) * totvert * 3
 		 * so its safe to use the second 2 thrids of MVert the array for vert_connect,
@@ -376,7 +388,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 					vc->v[0]= vc->v[1]= -1;
 
 					mul_m4_v3(mtx_tx, vc->co);
-					/* length in 2d, dont sqrt because this is only for comparison */
+					/* length in 2d, don't sqrt because this is only for comparison */
 					vc->dist =	vc->co[other_axis_1]*vc->co[other_axis_1] +
 								vc->co[other_axis_2]*vc->co[other_axis_2];
 
@@ -393,7 +405,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 					vc->e[0]= vc->e[1]= NULL;
 					vc->v[0]= vc->v[1]= -1;
 
-					/* length in 2d, dont sqrt because this is only for comparison */
+					/* length in 2d, don't sqrt because this is only for comparison */
 					vc->dist =	vc->co[other_axis_1]*vc->co[other_axis_1] +
 								vc->co[other_axis_2]*vc->co[other_axis_2];
 
@@ -414,7 +426,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 					vc->e[1]= med_new;
 				}
 				else {
-					vc->v[0]= vc->v[1]= -2; /* erro value  - dont use, 3 edges on vert */
+					vc->v[0]= vc->v[1]= -2; /* erro value  - don't use, 3 edges on vert */
 				}
 
 				vc= &vert_connect[med_new->v2];
@@ -429,7 +441,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 					vc->e[1]= med_new;
 				}
 				else {
-					vc->v[0]= vc->v[1]= -2; /* erro value  - dont use, 3 edges on vert */
+					vc->v[0]= vc->v[1]= -2; /* erro value  - don't use, 3 edges on vert */
 				}
 			}
 
@@ -447,7 +459,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 
 					/*printf("Loop on connected vert: %i\n", i);*/
 
-					for(j=0; j<2; j++) {
+					for (j=0; j<2; j++) {
 						/*printf("\tSide: %i\n", j);*/
 						screwvert_iter_init(&lt_iter, vert_connect, i, j);
 						if (j == 1) {
@@ -531,25 +543,28 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 								ed_loop_flip= 0;
 							}
 
-						}/* else {
+						}
+#if 0
+						else {
 							printf("No Connected ___\n");
-						}*/
+						}
+#endif
 
 						/*printf("flip direction %i\n", ed_loop_flip);*/
 
 
 						/* switch the flip option if set
 						 * note: flip is now done at face level so copying vgroup slizes is easier */
-						/*						
+#if 0
 						if (do_flip)
 							ed_loop_flip= !ed_loop_flip;
-						*/
+#endif
 
 						if (angle < 0.0f)
 							ed_loop_flip= !ed_loop_flip;
 
 						/* if its closed, we only need 1 loop */
-						for(j=ed_loop_closed; j<2; j++) {
+						for (j=ed_loop_closed; j<2; j++) {
 							/*printf("Ordering Side J %i\n", j);*/
 
 							screwvert_iter_init(&lt_iter, vert_connect, v_best, j);
@@ -572,7 +587,8 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 										if (ed_loop_flip == 0) {
 											/*printf("\t\t\tFlipping 0\n");*/
 											SWAP(unsigned int, lt_iter.e->v1, lt_iter.e->v2);
-										}/* else {
+										}
+										/* else {
 											printf("\t\t\tFlipping Not 0\n");
 										}*/
 									}
@@ -580,13 +596,16 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 										if (ed_loop_flip == 1) {
 											/*printf("\t\t\tFlipping 1\n");*/
 											SWAP(unsigned int, lt_iter.e->v1, lt_iter.e->v2);
-										}/* else {
+										}
+										/* else {
 											printf("\t\t\tFlipping Not 1\n");
 										}*/
-									}/* else {
+									}
+									/* else {
 										printf("\t\tIncorrect edge topology");
 									}*/
-								}/* else {
+								}
+								/* else {
 									printf("\t\tNo Edge at this point\n");
 								}*/
 								screwvert_iter_step(&lt_iter);
@@ -599,7 +618,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 				 * we know the surrounding edges are ordered correctly now
 				 * so its safe to create vertex normals.
 				 *
-				 * calculate vertex normals that can be propodated on lathing
+				 * calculate vertex normals that can be propagated on lathing
 				 * use edge connectivity work this out */
 				if (vc->v[0] >= 0) {
 					if (vc->v[1] >= 0) {
@@ -624,7 +643,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 					}
 					else {
 						/* only 1 edge connected - same as above except
-						 * dont need to average edge direction */
+						 * don't need to average edge direction */
 						if (vc->e && vc->e[0]->v2 == i) {
 							sub_v3_v3v3(tmp_vec1, mvert_new[i].co, mvert_new[vc->v[0]].co);
 						}
@@ -685,7 +704,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 			copy_m3_m4(mat3, mat);
 		}
 
-		if(screw_ofs)
+		if (screw_ofs)
 			madd_v3_v3fl(mat[3], axis_vec, screw_ofs * ((float)step / (float)(step_tot-1)));
 
 		/* copy a slice */
@@ -696,7 +715,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		
 		for (j=0; j<totvert; j++, mv_new_base++, mv_new++) {
 			/* set normal */
-			if(vert_connect) {
+			if (vert_connect) {
 				mul_v3_m3v3(nor_tx, mat3, vert_connect[j].no);
 
 				/* set the normal now its transformed */
@@ -729,7 +748,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 	}
 
 	/* we can avoid if using vert alloc trick */
-	if(vert_connect) {
+	if (vert_connect) {
 		MEM_freeN(vert_connect);
 		vert_connect= NULL;
 	}
@@ -746,9 +765,13 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		}
 	}
 	
-	mf_new= mface_new;
+	mp_new= mpoly_new;
+	ml_new= mloop_new;
 	med_new_firstloop= medge_new;
 	
+	/* more of an offset in this case */
+	edge_offset = totedge + (totvert * (step_tot - (close ? 0 : 1)));
+
 	for (i=0; i < totedge; i++, med_new_firstloop++) {
 		/* for each edge, make a cylinder of quads */
 		i1= med_new_firstloop->v1;
@@ -757,27 +780,37 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		for (step=0; step < step_tot-1; step++) {
 			
 			/* new face */
-			if(do_flip) {
-				mf_new->v4= i1;
-				mf_new->v3= i2;
-				mf_new->v2= i2 + totvert;
-				mf_new->v1= i1 + totvert;
+			if (do_flip) {
+				ml_new[3].v = i1;
+				ml_new[2].v = i2;
+				ml_new[1].v = i2 + totvert;
+				ml_new[0].v = i1 + totvert;
+
+				ml_new[2].e = step == 0 ? i : (edge_offset + step + (i * (step_tot - 1))) - 1;
+				ml_new[1].e = totedge + i2;
+				ml_new[0].e = edge_offset + step + (i * (step_tot - 1));
+				ml_new[3].e = totedge + i1;
 			}
 			else {
-				mf_new->v1= i1;
-				mf_new->v2= i2;
-				mf_new->v3= i2 + totvert;
-				mf_new->v4= i1 + totvert;
+				ml_new[0].v = i1;
+				ml_new[1].v = i2;
+				ml_new[2].v = i2 + totvert;
+				ml_new[3].v = i1 + totvert;
+
+				ml_new[0].e = step == 0 ? i : (edge_offset + step + (i * (step_tot - 1))) - 1;
+				ml_new[1].e = totedge + i2;
+				ml_new[2].e = edge_offset + step + (i * (step_tot - 1));
+				ml_new[3].e = totedge + i1;
 			}
-			
-			if( !mf_new->v3 || !mf_new->v4 ) {
-				SWAP(unsigned int, mf_new->v1, mf_new->v3);
-				SWAP(unsigned int, mf_new->v2, mf_new->v4);
-			}
-			mf_new->flag= ME_SMOOTH;
-			origindex[mface_index]= ORIGINDEX_NONE;
-			mf_new++;
-			mface_index++;
+
+
+			mp_new->loopstart = mpoly_index * 4;
+			mp_new->totloop = 4;
+			mp_new->flag= ME_SMOOTH;
+			origindex[mpoly_index]= ORIGINDEX_NONE;
+			mp_new++;
+			ml_new += 4;
+			mpoly_index++;
 			
 			/* new vertical edge */
 			if (step) { /* The first set is already dome */
@@ -793,27 +826,36 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		
 		/* close the loop*/
 		if (close) { 
-			if(do_flip) {
-				mf_new->v4= i1;
-				mf_new->v3= i2;
-				mf_new->v2= med_new_firstloop->v2;
-				mf_new->v1= med_new_firstloop->v1;
+			if (do_flip) {
+				ml_new[3].v = i1;
+				ml_new[2].v = i2;
+				ml_new[1].v = med_new_firstloop->v2;
+				ml_new[0].v = med_new_firstloop->v1;
+
+				ml_new[2].e = (edge_offset + step + (i * (step_tot - 1))) - 1;
+				ml_new[1].e = totedge + i2;
+				ml_new[0].e = i;
+				ml_new[3].e = totedge + i1;
 			}
 			else {
-				mf_new->v1= i1;
-				mf_new->v2= i2;
-				mf_new->v3= med_new_firstloop->v2;
-				mf_new->v4= med_new_firstloop->v1;
+				ml_new[0].v = i1;
+				ml_new[1].v = i2;
+				ml_new[2].v = med_new_firstloop->v2;
+				ml_new[3].v = med_new_firstloop->v1;
+
+				ml_new[0].e = (edge_offset + step + (i * (step_tot - 1))) - 1;
+				ml_new[1].e = totedge + i2;
+				ml_new[2].e = i;
+				ml_new[3].e = totedge + i1;
 			}
 
-			if( !mf_new->v3 || !mf_new->v4 ) {
-				SWAP(unsigned int, mf_new->v1, mf_new->v3);
-				SWAP(unsigned int, mf_new->v2, mf_new->v4);
-			}
-			mf_new->flag= ME_SMOOTH;
-			origindex[mface_index]= ORIGINDEX_NONE;
-			mf_new++;
-			mface_index++;
+			mp_new->loopstart = mpoly_index * 4;
+			mp_new->totloop = 4;
+			mp_new->flag= ME_SMOOTH;
+			origindex[mpoly_index]= ORIGINDEX_NONE;
+			mp_new++;
+			ml_new += 4;
+			mpoly_index++;
 		}
 		
 		/* new vertical edge */
@@ -823,8 +865,37 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob,
 		med_new->crease= med_new_firstloop->crease;
 		med_new++;
 	}
-	
-	if((ltmd->flag & MOD_SCREW_NORMAL_CALC) == 0) {
+
+	/* validate loop edges */
+#if 0
+	{
+		i = 0;
+		printf("\n");
+		for ( ; i < maxPolys * 4; i += 4) {
+			int ii;
+			ml_new = mloop_new + i;
+			ii = findEd(medge_new, maxEdges, ml_new[0].v, ml_new[1].v);
+			printf("%d %d -- ", ii, ml_new[0].e);
+			ml_new[0].e = ii;
+
+			ii = findEd(medge_new, maxEdges, ml_new[1].v, ml_new[2].v);
+			printf("%d %d -- ", ii, ml_new[1].e);
+			ml_new[1].e = ii;
+
+			ii = findEd(medge_new, maxEdges, ml_new[2].v, ml_new[3].v);
+			printf("%d %d -- ", ii, ml_new[2].e);
+			ml_new[2].e = ii;
+
+			ii = findEd(medge_new, maxEdges, ml_new[3].v, ml_new[0].v);
+			printf("%d %d\n", ii, ml_new[3].e);
+			ml_new[3].e = ii;
+
+		}
+	}
+#endif
+
+	if ((ltmd->flag & MOD_SCREW_NORMAL_CALC) == 0) {
+		/* BMESH_TODO, we only need to get vertex normals here, this is way overkill */
 		CDDM_calc_normals(result);
 	}
 
@@ -839,7 +910,7 @@ static void updateDepgraph(ModifierData *md, DagForest *forest,
 {
 	ScrewModifierData *ltmd= (ScrewModifierData*) md;
 
-	if(ltmd->ob_axis) {
+	if (ltmd->ob_axis) {
 		DagNode *curNode= dag_get_node(forest, ltmd->ob_axis);
 
 		dag_add_relation(forest, curNode, obNode,
@@ -862,7 +933,7 @@ static void foreachObjectLink(
 static DerivedMesh *applyModifierEM(
 						ModifierData *md,
 						Object *ob,
-						struct EditMesh *UNUSED(editData),
+						struct BMEditMesh *UNUSED(editData),
 						DerivedMesh *derivedData)
 {
 	return applyModifier(md, ob, derivedData, 0, 1);
