@@ -32,11 +32,13 @@
 
 #include <string.h>
 
+#include "DNA_curve_types.h"
+#include "DNA_image_types.h"
 #include "DNA_lattice_types.h"
+#include "DNA_meshdata_types.h"
 #include "DNA_modifier_types.h"
 #include "DNA_object_types.h"
-#include "DNA_curve_types.h"
-#include "DNA_meshdata_types.h"
+#include "DNA_scene_types.h"
 
 #include "BLI_utildefines.h"
 #include "BLI_math_vector.h"
@@ -44,6 +46,7 @@
 
 #include "BKE_cdderivedmesh.h"
 #include "BKE_deform.h"
+#include "BKE_image.h"
 #include "BKE_lattice.h"
 #include "BKE_mesh.h"
 #include "BKE_displist.h"
@@ -57,6 +60,15 @@
 
 #include "RE_shader_ext.h"
 
+void modifier_init_texture(Scene *scene, Tex *tex)
+{
+	if (!tex)
+		return;
+
+	if (tex->ima && ELEM(tex->ima->source, IMA_SRC_MOVIE, IMA_SRC_SEQUENCE))
+		BKE_image_user_calc_frame(&tex->iuser, scene->r.cfra, 0);
+}
+
 void get_texture_value(Tex *texture, float *tex_co, TexResult *texres)
 {
 	int result_type;
@@ -65,10 +77,10 @@ void get_texture_value(Tex *texture, float *tex_co, TexResult *texres)
 	result_type = multitex_ext_safe(texture, tex_co, texres);
 
 	/* if the texture gave an RGB value, we assume it didn't give a valid
-	* intensity, so calculate one (formula from do_material_tex).
-	* if the texture didn't give an RGB value, copy the intensity across
-	*/
-	if(result_type & TEX_RGB)
+	 * intensity, so calculate one (formula from do_material_tex).
+	 * if the texture didn't give an RGB value, copy the intensity across
+	 */
+	if (result_type & TEX_RGB)
 		texres->tin = (0.35f * texres->tr + 0.45f * texres->tg
 				+ 0.2f * texres->tb);
 	else
@@ -84,38 +96,40 @@ void get_texture_coords(MappingInfoModifierData *dmd, Object *ob,
 	int texmapping = dmd->texmapping;
 	float mapob_imat[4][4];
 
-	if(texmapping == MOD_DISP_MAP_OBJECT) {
-		if(dmd->map_object)
+	if (texmapping == MOD_DISP_MAP_OBJECT) {
+		if (dmd->map_object)
 			invert_m4_m4(mapob_imat, dmd->map_object->obmat);
 		else /* if there is no map object, default to local */
 			texmapping = MOD_DISP_MAP_LOCAL;
 	}
 
 	/* UVs need special handling, since they come from faces */
-	if(texmapping == MOD_DISP_MAP_UV) {
-		if(CustomData_has_layer(&dm->faceData, CD_MTFACE)) {
-			MFace *mface = dm->getFaceArray(dm);
-			MFace *mf;
+	if (texmapping == MOD_DISP_MAP_UV) {
+		if (CustomData_has_layer(&dm->loopData, CD_MLOOPUV)) {
+			MPoly *mpoly = dm->getPolyArray(dm);
+			MPoly *mp;
+			MLoop *mloop = dm->getLoopArray(dm);
 			char *done = MEM_callocN(sizeof(*done) * numVerts,
 			                         "get_texture_coords done");
-			int numFaces = dm->getNumFaces(dm);
+			int numPolys = dm->getNumPolys(dm);
 			char uvname[MAX_CUSTOMDATA_LAYER_NAME];
-			MTFace *tf;
+			MLoopUV *mloop_uv;
 
-			CustomData_validate_layer_name(&dm->faceData, CD_MTFACE, dmd->uvlayer_name, uvname);
-			tf = CustomData_get_layer_named(&dm->faceData, CD_MTFACE, uvname);
+			CustomData_validate_layer_name(&dm->loopData, CD_MLOOPUV, dmd->uvlayer_name, uvname);
+			mloop_uv = CustomData_get_layer_named(&dm->loopData, CD_MLOOPUV, uvname);
 
 			/* verts are given the UV from the first face that uses them */
-			for(i = 0, mf = mface; i < numFaces; ++i, ++mf, ++tf) {
-				unsigned int fidx= mf->v4 ? 3:2;
+			for (i = 0, mp = mpoly; i < numPolys; ++i, ++mp) {
+				unsigned int fidx= mp->totloop - 1;
 
 				do {
-					unsigned int vidx = *(&mf->v1 + fidx);
+					unsigned int lidx= mp->loopstart + fidx;
+					unsigned int vidx= mloop[lidx].v;
 
 					if (done[vidx] == 0) {
 						/* remap UVs from [0, 1] to [-1, 1] */
-						texco[vidx][0] = (tf->uv[fidx][0] * 2.0f) - 1.0f;
-						texco[vidx][1] = (tf->uv[fidx][1] * 2.0f) - 1.0f;
+						texco[vidx][0] = (mloop_uv[lidx].uv[0] * 2.0f) - 1.0f;
+						texco[vidx][1] = (mloop_uv[lidx].uv[1] * 2.0f) - 1.0f;
 						done[vidx] = 1;
 					}
 
@@ -124,11 +138,12 @@ void get_texture_coords(MappingInfoModifierData *dmd, Object *ob,
 
 			MEM_freeN(done);
 			return;
-		} else /* if there are no UVs, default to local */
+		}
+		else /* if there are no UVs, default to local */
 			texmapping = MOD_DISP_MAP_LOCAL;
 	}
 
-	for(i = 0; i < numVerts; ++i, ++co, ++texco) {
+	for (i = 0; i < numVerts; ++i, ++co, ++texco) {
 		switch(texmapping) {
 		case MOD_DISP_MAP_LOCAL:
 			copy_v3_v3(*texco, *co);
@@ -146,9 +161,9 @@ void get_texture_coords(MappingInfoModifierData *dmd, Object *ob,
 
 void modifier_vgroup_cache(ModifierData *md, float (*vertexCos)[3])
 {
-	while((md=md->next) && md->type==eModifierType_Armature) {
+	while ((md=md->next) && md->type==eModifierType_Armature) {
 		ArmatureModifierData *amd = (ArmatureModifierData*) md;
-		if(amd->multi && amd->prevCos==NULL)
+		if (amd->multi && amd->prevCos==NULL)
 			amd->prevCos= MEM_dupallocN(vertexCos);
 		else
 			break;
@@ -157,12 +172,12 @@ void modifier_vgroup_cache(ModifierData *md, float (*vertexCos)[3])
 }
 
 /* returns a cdderivedmesh if dm == NULL or is another type of derivedmesh */
-DerivedMesh *get_cddm(Object *ob, struct EditMesh *em, DerivedMesh *dm, float (*vertexCos)[3])
+DerivedMesh *get_cddm(Object *ob, struct BMEditMesh *em, DerivedMesh *dm, float (*vertexCos)[3])
 {
-	if(dm && dm->type == DM_TYPE_CDDM)
+	if (dm && dm->type == DM_TYPE_CDDM)
 		return dm;
 
-	if(!dm) {
+	if (!dm) {
 		dm= get_dm(ob, em, dm, vertexCos, 0);
 	}
 	else {
@@ -170,31 +185,31 @@ DerivedMesh *get_cddm(Object *ob, struct EditMesh *em, DerivedMesh *dm, float (*
 		CDDM_apply_vert_coords(dm, vertexCos);
 	}
 
-	if(dm)
+	if (dm)
 		CDDM_calc_normals(dm);
 	
 	return dm;
 }
 
 /* returns a derived mesh if dm == NULL, for deforming modifiers that need it */
-DerivedMesh *get_dm(Object *ob, struct EditMesh *em, DerivedMesh *dm, float (*vertexCos)[3], int orco)
+DerivedMesh *get_dm(Object *ob, struct BMEditMesh *em, DerivedMesh *dm, float (*vertexCos)[3], int orco)
 {
-	if(dm)
+	if (dm)
 		return dm;
 
-	if(ob->type==OB_MESH) {
-		if(em) dm= CDDM_from_editmesh(em, ob->data);
+	if (ob->type==OB_MESH) {
+		if (em) dm= CDDM_from_BMEditMesh(em, ob->data, FALSE, FALSE);
 		else dm = CDDM_from_mesh((struct Mesh *)(ob->data), ob);
 
-		if(vertexCos) {
+		if (vertexCos) {
 			CDDM_apply_vert_coords(dm, vertexCos);
 			//CDDM_calc_normals(dm);
 		}
 		
-		if(orco)
+		if (orco)
 			DM_add_vert_layer(dm, CD_ORCO, CD_ASSIGN, get_mesh_orco_verts(ob));
 	}
-	else if(ELEM3(ob->type,OB_FONT,OB_CURVE,OB_SURF)) {
+	else if (ELEM3(ob->type,OB_FONT,OB_CURVE,OB_SURF)) {
 		dm= CDDM_from_curve(ob);
 	}
 
@@ -206,10 +221,10 @@ void modifier_get_vgroup(Object *ob, DerivedMesh *dm, const char *name, MDeformV
 	*defgrp_index = defgroup_name_index(ob, name);
 	*dvert = NULL;
 
-	if(*defgrp_index >= 0) {
-		if(ob->type == OB_LATTICE)
+	if (*defgrp_index >= 0) {
+		if (ob->type == OB_LATTICE)
 			*dvert = lattice_get_deform_verts(ob);
-		else if(dm)
+		else if (dm)
 			*dvert = dm->getVertDataArray(dm, CD_MDEFORMVERT);
 	}
 }
