@@ -38,6 +38,7 @@
 #include "DNA_meshdata_types.h"
 #include "DNA_modifier_types.h"
 #include "DNA_object_types.h"
+#include "DNA_scene_types.h"
 
 #include "BKE_cdderivedmesh.h"
 #include "BKE_colortools.h"       /* CurveMapping. */
@@ -52,7 +53,7 @@
 #include "MOD_weightvg_util.h"
 #include "RE_shader_ext.h"        /* Texture masking. */
 
-/* Maps new_w weights in place, using either one of the predifined functions, or a custom curve.
+/* Maps new_w weights in place, using either one of the predefined functions, or a custom curve.
  * Return values are in new_w.
  * If indices is not NULL, it must be a table of same length as org_w and new_w, mapping to the real
  * vertex index (in case the weight tables do not cover the whole vertices...).
@@ -64,14 +65,14 @@ void weightvg_do_map(int num, float *new_w, short falloff_type, CurveMapping *cm
 
 	/* Return immediately, if we have nothing to do! */
 	/* Also security checks... */
-	if(((falloff_type == MOD_WVG_MAPPING_CURVE) && (cmap == NULL))
-	        || !ELEM7(falloff_type, MOD_WVG_MAPPING_CURVE, MOD_WVG_MAPPING_SHARP, MOD_WVG_MAPPING_SMOOTH,
-	                  MOD_WVG_MAPPING_ROOT, MOD_WVG_MAPPING_SPHERE, MOD_WVG_MAPPING_RANDOM,
-	                  MOD_WVG_MAPPING_STEP))
+	if (((falloff_type == MOD_WVG_MAPPING_CURVE) && (cmap == NULL)) ||
+	    !ELEM7(falloff_type, MOD_WVG_MAPPING_CURVE, MOD_WVG_MAPPING_SHARP, MOD_WVG_MAPPING_SMOOTH,
+	           MOD_WVG_MAPPING_ROOT, MOD_WVG_MAPPING_SPHERE, MOD_WVG_MAPPING_RANDOM,
+	           MOD_WVG_MAPPING_STEP))
 		return;
 
 	/* Map each weight (vertex) to its new value, accordingly to the chosen mode. */
-	for(i = 0; i < num; ++i) {
+	for (i = 0; i < num; ++i) {
 		float fac = new_w[i];
 
 		/* Code borrowed from the warp modifier. */
@@ -109,11 +110,11 @@ void weightvg_do_map(int num, float *new_w, short falloff_type, CurveMapping *cm
  * Return values are in org_w.
  * If indices is not NULL, it must be a table of same length as org_w and new_w, mapping to the real
  * vertex index (in case the weight tables do not cover the whole vertices...).
- * XXX The standard “factor” value is assumed in [0.0, 1.0] range. Else, weird results might appear.
+ * XXX The standard "factor" value is assumed in [0.0, 1.0] range. Else, weird results might appear.
  */
 void weightvg_do_mask(int num, const int *indices, float *org_w, const float *new_w,
                       Object *ob, DerivedMesh *dm, float fact, const char defgrp_name[MAX_VGROUP_NAME],
-                      Tex *texture, int tex_use_channel, int tex_mapping,
+                      Scene *scene, Tex *texture, int tex_use_channel, int tex_mapping,
                       Object *tex_map_object, const char *tex_uvlayer_name)
 {
 	int ref_didx;
@@ -145,8 +146,10 @@ void weightvg_do_mask(int num, const int *indices, float *org_w, const float *ne
 		get_texture_coords(&t_map, ob, dm, v_co, tex_co, num);
 		MEM_freeN(v_co);
 
+		modifier_init_texture(scene, texture);
+
 		/* For each weight (vertex), make the mix between org and new weights. */
-		for(i = 0; i < num; ++i) {
+		for (i = 0; i < num; ++i) {
 			int idx = indices ? indices[i] : i;
 			TexResult texres;
 			float h, s, v; /* For HSV color space. */
@@ -225,7 +228,7 @@ void weightvg_do_mask(int num, const int *indices, float *org_w, const float *ne
 
 
 
-/* Applies weights to given vgroup (defgroup), and optionnaly add/remove vertices from the group.
+/* Applies weights to given vgroup (defgroup), and optionally add/remove vertices from the group.
  * If dws is not NULL, it must be an array of MDeformWeight pointers of same length as weights (and
  * defgrp_idx can then have any value).
  * If indices is not NULL, it must be an array of same length as weights, mapping to the real
@@ -237,7 +240,7 @@ void weightvg_update_vg(MDeformVert *dvert, int defgrp_idx, MDeformWeight **dws,
 {
 	int i;
 
-	for(i = 0; i < num; i++) {
+	for (i = 0; i < num; i++) {
 		float w = weights[i];
 		MDeformVert *dv = &dvert[indices ? indices[i] : i];
 		MDeformWeight *dw = dws ? dws[i] : defvert_find_index(dv, defgrp_idx);
@@ -246,8 +249,8 @@ void weightvg_update_vg(MDeformVert *dvert, int defgrp_idx, MDeformWeight **dws,
 		CLAMP(w, 0.0f, 1.0f);
 
 		/* If the vertex is in this vgroup, remove it if needed, or just update it. */
-		if(dw != NULL) {
-			if(do_rem && w < rem_thresh) {
+		if (dw != NULL) {
+			if (do_rem && w < rem_thresh) {
 				defvert_remove_group(dv, dw);
 			}
 			else {
@@ -255,7 +258,7 @@ void weightvg_update_vg(MDeformVert *dvert, int defgrp_idx, MDeformWeight **dws,
 			}
 		}
 		/* Else, add it if needed! */
-		else if(do_add && w > add_thresh) {
+		else if (do_add && w > add_thresh) {
 			defvert_add_index_notest(dv, defgrp_idx, w);
 		}
 	}
