@@ -29,8 +29,8 @@
  */
 
 
-#ifndef MOD_WEIGHTVG_UTIL_H
-#define MOD_WEIGHTVG_UTIL_H
+#ifndef __MOD_WEIGHTVG_UTIL_H__
+#define __MOD_WEIGHTVG_UTIL_H__
 
 /* so modifier types match their defines */
 #include "MOD_modifiertypes.h"
@@ -39,6 +39,7 @@ struct CurveMapping;
 struct DerivedMesh;
 struct Object;
 struct Tex;
+struct Scene;
 
 /*
  * XXX I'd like to make modified weights visible in WeightPaint mode,
@@ -58,7 +59,7 @@ struct Tex;
  */
 #define MOD_WVG_ZEROFLOOR		1.0e-32f
 
-/* Maps new_w weights in place, using either one of the predifined functions, or a custom curve.
+/* Maps new_w weights in place, using either one of the predefined functions, or a custom curve.
  * Return values are in new_w.
  * If indices is not NULL, it must be a table of same length as org_w and new_w, mapping to the real
  * vertex index (in case the weight tables do not cover the whole vertices...).
@@ -70,14 +71,14 @@ void weightvg_do_map(int num, float *new_w, short mode, struct CurveMapping *cma
  * Return values are in org_w.
  * If indices is not NULL, it must be a table of same length as org_w and new_w, mapping to the real
  * vertex index (in case the weight tables do not cover the whole vertices...).
- * XXX The standard “factor” value is assumed in [0.0, 1.0] range. Else, weird results might appear.
+ * XXX The standard "factor" value is assumed in [0.0, 1.0] range. Else, weird results might appear.
  */
 void weightvg_do_mask(int num, const int *indices, float *org_w, const float *new_w, Object *ob,
-                      DerivedMesh *dm, float fact, const char defgrp_name[MAX_VGROUP_NAME], Tex *texture,
-                      int tex_use_channel, int tex_mapping, Object *tex_map_object,
-                      const char *tex_uvlayer_name);
+                      DerivedMesh *dm, float fact, const char defgrp_name[MAX_VGROUP_NAME],
+                      struct Scene *scene, Tex *texture, int tex_use_channel, int tex_mapping,
+                      Object *tex_map_object, const char *tex_uvlayer_name);
 
-/* Applies weights to given vgroup (defgroup), and optionnaly add/remove vertices from the group.
+/* Applies weights to given vgroup (defgroup), and optionally add/remove vertices from the group.
  * If indices is not NULL, it must be a table of same length as weights, mapping to the real
  * vertex index (in case the weight table does not cover the whole vertices...).
  */
@@ -85,4 +86,4 @@ void weightvg_update_vg(MDeformVert *dvert, int defgrp_idx, MDeformWeight **dws,
                         const int *indices, const float *weights, int do_add,
                         float add_thresh, int do_rem, float rem_thresh);
 
-#endif /* MOD_WEIGHTVG_UTIL_H */
+#endif /* __MOD_WEIGHTVG_UTIL_H__ */
