@@ -153,10 +153,10 @@ static CustomDataMask requiredDataMask(Object *UNUSED(ob), ModifierData *md)
 	dataMask |= CD_MASK_MDEFORMVERT;
 
 	/* Ask for UV coordinates if we need them. */
-	if(wmd->mask_tex_mapping == MOD_DISP_MAP_UV)
+	if (wmd->mask_tex_mapping == MOD_DISP_MAP_UV)
 		dataMask |= CD_MASK_MTFACE;
 
-	/* No need to ask for CD_WEIGHT_MCOL... */
+	/* No need to ask for CD_PREVIEW_MLOOPCOL... */
 
 	return dataMask;
 }
@@ -165,7 +165,7 @@ static int dependsOnTime(ModifierData *md)
 {
 	WeightVGMixModifierData *wmd = (WeightVGMixModifierData*) md;
 
-	if(wmd->mask_texture)
+	if (wmd->mask_texture)
 		return BKE_texture_dependsOnTime(wmd->mask_texture);
 	return 0;
 }
@@ -198,14 +198,14 @@ static void updateDepgraph(ModifierData *md, DagForest *forest, struct Scene *UN
 	WeightVGMixModifierData *wmd = (WeightVGMixModifierData*) md;
 	DagNode *curNode;
 
-	if(wmd->mask_tex_map_obj && wmd->mask_tex_mapping == MOD_DISP_MAP_OBJECT) {
+	if (wmd->mask_tex_map_obj && wmd->mask_tex_mapping == MOD_DISP_MAP_OBJECT) {
 		curNode = dag_get_node(forest, wmd->mask_tex_map_obj);
 
 		dag_add_relation(forest, curNode, obNode, DAG_RL_DATA_DATA|DAG_RL_OB_DATA,
 		                 "WeightVGMix Modifier");
 	}
 
-	if(wmd->mask_tex_mapping == MOD_DISP_MAP_GLOBAL)
+	if (wmd->mask_tex_mapping == MOD_DISP_MAP_GLOBAL)
 		dag_add_relation(forest, obNode, obNode, DAG_RL_DATA_DATA|DAG_RL_OB_DATA,
 		                 "WeightVGMix Modifier");
 }
@@ -258,17 +258,17 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 
 	dvert = CustomData_duplicate_referenced_layer(&dm->vertData, CD_MDEFORMVERT, numVerts);
 	/* If no vertices were ever added to an object's vgroup, dvert might be NULL. */
-	if(!dvert)
+	if (!dvert) {
 		/* If not affecting all vertices, just return. */
-		if(wmd->mix_set != MOD_WVG_SET_ALL)
+		if (wmd->mix_set != MOD_WVG_SET_ALL)
 			return dm;
 		/* Else, add a valid data layer! */
 		dvert = CustomData_add_layer_named(&dm->vertData, CD_MDEFORMVERT, CD_CALLOC,
 		                                   NULL, numVerts, wmd->defgrp_name_a);
 		/* Ultimate security check. */
-		if(!dvert)
+		if (!dvert)
 			return dm;
-
+	}
 	/* Find out which vertices to work on. */
 	tidx = MEM_mallocN(sizeof(int) * numVerts, "WeightVGMix Modifier, tidx");
 	tdw1 = MEM_mallocN(sizeof(MDeformWeight*) * numVerts, "WeightVGMix Modifier, tdw1");
@@ -278,7 +278,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 		/* All vertices in first vgroup. */
 		for (i = 0; i < numVerts; i++) {
 			MDeformWeight *dw = defvert_find_index(&dvert[i], defgrp_idx);
-			if(dw) {
+			if (dw) {
 				tdw1[numIdx] = dw;
 				tdw2[numIdx] = defvert_find_index(&dvert[i], defgrp_idx2);
 				tidx[numIdx++] = i;
@@ -289,7 +289,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 		/* All vertices in second vgroup. */
 		for (i = 0; i < numVerts; i++) {
 			MDeformWeight *dw = defvert_find_index(&dvert[i], defgrp_idx2);
-			if(dw) {
+			if (dw) {
 				tdw1[numIdx] = defvert_find_index(&dvert[i], defgrp_idx);
 				tdw2[numIdx] = dw;
 				tidx[numIdx++] = i;
@@ -301,7 +301,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 		for (i = 0; i < numVerts; i++) {
 			MDeformWeight *adw = defvert_find_index(&dvert[i], defgrp_idx);
 			MDeformWeight *bdw = defvert_find_index(&dvert[i], defgrp_idx2);
-			if(adw || bdw) {
+			if (adw || bdw) {
 				tdw1[numIdx] = adw;
 				tdw2[numIdx] = bdw;
 				tidx[numIdx++] = i;
@@ -313,7 +313,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 		for (i = 0; i < numVerts; i++) {
 			MDeformWeight *adw = defvert_find_index(&dvert[i], defgrp_idx);
 			MDeformWeight *bdw = defvert_find_index(&dvert[i], defgrp_idx2);
-			if(adw && bdw) {
+			if (adw && bdw) {
 				tdw1[numIdx] = adw;
 				tdw2[numIdx] = bdw;
 				tidx[numIdx++] = i;
@@ -330,7 +330,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 		numIdx = -1;
 		break;
 	}
-	if(numIdx == 0) {
+	if (numIdx == 0) {
 		/* Use no vertices! Hence, return org data. */
 		MEM_freeN(tdw1);
 		MEM_freeN(tdw2);
@@ -370,8 +370,9 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 
 	/* Do masking. */
 	weightvg_do_mask(numIdx, indices, org_w, new_w, ob, dm, wmd->mask_constant,
-	                 wmd->mask_defgrp_name, wmd->mask_texture, wmd->mask_tex_use_channel,
-	                 wmd->mask_tex_mapping, wmd->mask_tex_map_obj, wmd->mask_tex_uvlayer_name);
+	                 wmd->mask_defgrp_name, wmd->modifier.scene, wmd->mask_texture,
+	                 wmd->mask_tex_use_channel, wmd->mask_tex_mapping,
+	                 wmd->mask_tex_map_obj, wmd->mask_tex_uvlayer_name);
 
 	/* Update (add to) vgroup.
 	 * XXX Depending on the MOD_WVG_SET_xxx option chosen, we might have to add vertices to vgroup.
@@ -380,7 +381,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 
 	/* If weight preview enabled... */
 #if 0 /* XXX Currently done in mod stack :/ */
-	if(do_prev)
+	if (do_prev)
 		DM_update_weight_mcol(ob, dm, 0, org_w, numIdx, indices);
 #endif
 
@@ -398,7 +399,7 @@ static DerivedMesh *applyModifier(ModifierData *md, Object *ob, DerivedMesh *der
 }
 
 static DerivedMesh *applyModifierEM(ModifierData *md, Object *ob,
-                                    struct EditMesh *UNUSED(editData),
+                                    struct BMEditMesh *UNUSED(editData),
                                     DerivedMesh *derivedData)
 {
 	return applyModifier(md, ob, derivedData, 0, 1);
