@@ -40,6 +40,8 @@
 #include "BLI_string.h"
 #include "BLI_utildefines.h"
 
+#include "BLF_translation.h"
+
 #include "BKE_action.h"
 #include "BKE_animsys.h"
 #include "BKE_global.h"
@@ -103,7 +105,7 @@ bNodeSocket *node_group_add_extern_socket(bNodeTree *UNUSED(ntree), ListBase *lb
 	sock->default_value = node_socket_make_default_value(sock->type);
 	node_socket_copy_default_value(sock->type, sock->default_value, gsock->default_value);
 	
-	if(lb)
+	if (lb)
 		BLI_addtail(lb, sock);
 	
 	return sock;
@@ -123,42 +125,42 @@ bNode *node_group_make_from_selected(bNodeTree *ntree)
 	INIT_MINMAX2(min, max);
 	
 	/* is there something to group? also do some clearing */
-	for(node= ntree->nodes.first; node; node= node->next) {
-		if(node->flag & NODE_SELECT) {
+	for (node= ntree->nodes.first; node; node= node->next) {
+		if (node->flag & NODE_SELECT) {
 			/* no groups in groups */
-			if(node->type==NODE_GROUP)
+			if (node->type==NODE_GROUP)
 				return NULL;
 			DO_MINMAX2( (&node->locx), min, max);
 			totnode++;
 		}
 		node->done= 0;
 	}
-	if(totnode==0) return NULL;
+	if (totnode==0) return NULL;
 	
 	/* check if all connections are OK, no unselected node has both
-		inputs and outputs to a selection */
-	for(link= ntree->links.first; link; link= link->next) {
-		if(link->fromnode && link->tonode && link->fromnode->flag & NODE_SELECT)
+	 * inputs and outputs to a selection */
+	for (link= ntree->links.first; link; link= link->next) {
+		if (link->fromnode && link->tonode && link->fromnode->flag & NODE_SELECT)
 			link->tonode->done |= 1;
-		if(link->fromnode && link->tonode && link->tonode->flag & NODE_SELECT)
+		if (link->fromnode && link->tonode && link->tonode->flag & NODE_SELECT)
 			link->fromnode->done |= 2;
 	}	
 	
-	for(node= ntree->nodes.first; node; node= node->next) {
-		if((node->flag & NODE_SELECT)==0)
-			if(node->done==3)
+	for (node= ntree->nodes.first; node; node= node->next) {
+		if ((node->flag & NODE_SELECT)==0)
+			if (node->done==3)
 				break;
 	}
-	if(node) 
+	if (node) 
 		return NULL;
 	
 	/* OK! new nodetree */
 	ngroup= ntreeAddTree("NodeGroup", ntree->type, NODE_GROUP);
 	
 	/* move nodes over */
-	for(node= ntree->nodes.first; node; node= nextn) {
+	for (node= ntree->nodes.first; node; node= nextn) {
 		nextn= node->next;
-		if(node->flag & NODE_SELECT) {
+		if (node->flag & NODE_SELECT) {
 			/* keep track of this node's RNA "base" path (the part of the pat identifying the node) 
 			 * if the old nodetree has animation data which potentially covers this node
 			 */
@@ -208,20 +210,20 @@ bNode *node_group_make_from_selected(bNodeTree *ntree)
 	gnode->locy= 0.5f*(min[1]+max[1]);
 	
 	/* relink external sockets */
-	for(link= ntree->links.first; link; link= linkn) {
+	for (link= ntree->links.first; link; link= linkn) {
 		linkn= link->next;
 		
-		if(link->fromnode && link->tonode && (link->fromnode->flag & link->tonode->flag & NODE_SELECT)) {
+		if (link->fromnode && link->tonode && (link->fromnode->flag & link->tonode->flag & NODE_SELECT)) {
 			BLI_remlink(&ntree->links, link);
 			BLI_addtail(&ngroup->links, link);
 		}
-		else if(link->tonode && (link->tonode->flag & NODE_SELECT)) {
+		else if (link->tonode && (link->tonode->flag & NODE_SELECT)) {
 			gsock = node_group_expose_socket(ngroup, link->tosock, SOCK_IN);
 			link->tosock->link = nodeAddLink(ngroup, NULL, gsock, link->tonode, link->tosock);
 			link->tosock = node_group_add_extern_socket(ntree, &gnode->inputs, SOCK_IN, gsock);
 			link->tonode = gnode;
 		}
-		else if(link->fromnode && (link->fromnode->flag & NODE_SELECT)) {
+		else if (link->fromnode && (link->fromnode->flag & NODE_SELECT)) {
 			/* search for existing group node socket */
 			for (gsock=ngroup->outputs.first; gsock; gsock=gsock->next)
 				if (gsock->link && gsock->link->fromsock==link->fromsock)
@@ -256,10 +258,10 @@ int node_group_ungroup(bNodeTree *ntree, bNode *gnode)
 	ListBase anim_basepaths = {NULL, NULL};
 	
 	ngroup= (bNodeTree *)gnode->id;
-	if(ngroup==NULL) return 0;
+	if (ngroup==NULL) return 0;
 	
 	/* clear new pointers, set in copytree */
-	for(node= ntree->nodes.first; node; node= node->next)
+	for (node= ntree->nodes.first; node; node= node->next)
 		node->new_node= NULL;
 	
 	/* wgroup is a temporary copy of the NodeTree we're merging in
@@ -269,7 +271,7 @@ int node_group_ungroup(bNodeTree *ntree, bNode *gnode)
 	wgroup= ntreeCopyTree(ngroup);
 	
 	/* add the nodes into the ntree */
-	for(node= wgroup->nodes.first; node; node= nextn) {
+	for (node= wgroup->nodes.first; node; node= nextn) {
 		nextn= node->next;
 		
 		/* keep track of this node's RNA "base" path (the part of the pat identifying the node) 
@@ -297,7 +299,7 @@ int node_group_ungroup(bNodeTree *ntree, bNode *gnode)
 	}
 	
 	/* restore external links to and from the gnode */
-	for(link= ntree->links.first; link; link= link->next) {
+	for (link= ntree->links.first; link; link= link->next) {
 		if (link->fromnode==gnode) {
 			if (link->fromsock->groupsock) {
 				bNodeSocket *gsock= link->fromsock->groupsock;
@@ -324,13 +326,13 @@ int node_group_ungroup(bNodeTree *ntree, bNode *gnode)
 		}
 	}
 	/* remove internal output links, these are not used anymore */
-	for(link=wgroup->links.first; link; link= linkn) {
+	for (link=wgroup->links.first; link; link= linkn) {
 		linkn = link->next;
 		if (!link->tonode)
 			nodeRemLink(wgroup, link);
 	}
 	/* restore links from internal nodes */
-	for(link= wgroup->links.first; link; link= link->next) {
+	for (link= wgroup->links.first; link; link= link->next) {
 		/* indicates link to group input */
 		if (!link->fromnode) {
 			/* NB: can't use find_group_node_input here,
@@ -353,7 +355,7 @@ int node_group_ungroup(bNodeTree *ntree, bNode *gnode)
 	}
 	
 	/* add internal links to the ntree */
-	for(link= wgroup->links.first; link; link= linkn) {
+	for (link= wgroup->links.first; link; link= linkn) {
 		linkn= link->next;
 		BLI_remlink(&wgroup->links, link);
 		BLI_addtail(&ntree->links, link);
@@ -487,7 +489,7 @@ void node_group_remove_socket(bNodeTree *ngroup, bNodeSocket *gsock, int in_out)
 /* groups display their internal tree name as label */
 const char *node_group_label(bNode *node)
 {
-	return (node->id)? node->id->name+2: "Missing Datablock";
+	return (node->id)? node->id->name+2: IFACE_("Missing Datablock");
 }
 
 int node_group_valid(bNodeTree *ntree, bNodeTemplate *ntemp)
@@ -541,15 +543,16 @@ static bNodeSocket *group_verify_socket(bNodeTree *ntree, ListBase *lb, int in_o
 	if (gsock->flag & SOCK_INTERNAL)
 		return NULL;
 	
-	for(sock= lb->first; sock; sock= sock->next) {
-		if(sock->own_index==gsock->own_index)
+	for (sock= lb->first; sock; sock= sock->next) {
+		if (sock->own_index==gsock->own_index)
 				break;
 	}
-	if(sock) {
+	if (sock) {
 		sock->groupsock = gsock;
 		
 		BLI_strncpy(sock->name, gsock->name, sizeof(sock->name));
-		sock->type= gsock->type;
+		if(gsock->type != sock->type)
+			nodeSocketSetType(sock, gsock->type);
 		
 		/* XXX hack: group socket input/output roles are inverted internally,
 		 * need to change the limit value when making actual node sockets from them.
@@ -613,7 +616,7 @@ struct bNodeTree *node_group_edit_set(bNode *node, int edit)
 	if (edit) {
 		bNodeTree *ngroup= (bNodeTree*)node->id;
 		if (ngroup) {
-			if(ngroup->id.lib)
+			if (ngroup->id.lib)
 				ntreeMakeLocal(ngroup);
 			
 			node->flag |= NODE_GROUP_EDIT;
