@@ -47,6 +47,8 @@ static PyStructSequence_Field app_cb_info_fields[] = {
 	{(char *)"render_pre",        (char *)"Callback list - on render (before)"},
 	{(char *)"render_post",       (char *)"Callback list - on render (after)"},
 	{(char *)"render_stats",      (char *)"Callback list - on printing render statistics"},
+	{(char *)"render_complete",   (char *)"Callback list - on completion of render job"},
+	{(char *)"render_cancel",     (char *)"Callback list - on cancelling a render job"},
 	{(char *)"load_pre",          (char *)"Callback list - on loading a new blend file (before)"},
 	{(char *)"load_post",         (char *)"Callback list - on loading a new blend file (after)"},
 	{(char *)"save_pre",          (char *)"Callback list - on saving a blend file (before)"},
@@ -68,11 +70,11 @@ static PyStructSequence_Desc app_cb_info_desc = {
 	(sizeof(app_cb_info_fields) / sizeof(PyStructSequence_Field)) - 1
 };
 
-/*
-#if (BLI_CB_EVT_TOT != ((sizeof(app_cb_info_fields)/sizeof(PyStructSequence_Field))))
-#  error "Callbacks are out of sync"
+#if 0
+#  if (BLI_CB_EVT_TOT != ((sizeof(app_cb_info_fields) / sizeof(PyStructSequence_Field))))
+#    error "Callbacks are out of sync"
+#  endif
 #endif
-*/
 
 /* --------------------------------------------------------------------------*/
 /* permanent tagging code */
@@ -116,51 +118,51 @@ static PyObject *bpy_app_handlers_persistent_new(PyTypeObject *UNUSED(type), PyO
 static PyTypeObject BPyPersistent_Type = {
 
 #if defined(_MSC_VER) || defined(FREE_WINDOWS)
-    PyVarObject_HEAD_INIT(NULL, 0)
+	PyVarObject_HEAD_INIT(NULL, 0)
 #else
-    PyVarObject_HEAD_INIT(&PyType_Type, 0)
+	PyVarObject_HEAD_INIT(&PyType_Type, 0)
 #endif
 
-    "persistent",                               /* tp_name */
-    0,                                          /* tp_basicsize */
-    0,                                          /* tp_itemsize */
-    /* methods */
-    0,                                          /* tp_dealloc */
-    0,                                          /* tp_print */
-    0,                                          /* tp_getattr */
-    0,                                          /* tp_setattr */
-    0,                                          /* tp_reserved */
-    0,                                          /* tp_repr */
-    0,                                          /* tp_as_number */
-    0,                                          /* tp_as_sequence */
-    0,                                          /* tp_as_mapping */
-    0,                                          /* tp_hash */
-    0,                                          /* tp_call */
-    0,                                          /* tp_str */
-    0,                                          /* tp_getattro */
-    0,                                          /* tp_setattro */
-    0,                                          /* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC |
-        Py_TPFLAGS_BASETYPE,                    /* tp_flags */
-    0,                                          /* tp_doc */
-    0,                                          /* tp_traverse */
-    0,                                          /* tp_clear */
-    0,                                          /* tp_richcompare */
-    0,                                          /* tp_weaklistoffset */
-    0,                                          /* tp_iter */
-    0,                                          /* tp_iternext */
-    0,                                          /* tp_methods */
-    0,                                          /* tp_members */
-    0,                                          /* tp_getset */
-    0,                                          /* tp_base */
-    0,                                          /* tp_dict */
-    0,                                          /* tp_descr_get */
-    0,                                          /* tp_descr_set */
-    0,                                          /* tp_dictoffset */
-    0,                                          /* tp_init */
-    0,                                          /* tp_alloc */
-    bpy_app_handlers_persistent_new,            /* tp_new */
-    0,                                          /* tp_free */
+	"persistent",                               /* tp_name */
+	0,                                          /* tp_basicsize */
+	0,                                          /* tp_itemsize */
+	/* methods */
+	0,                                          /* tp_dealloc */
+	0,                                          /* tp_print */
+	0,                                          /* tp_getattr */
+	0,                                          /* tp_setattr */
+	0,                                          /* tp_reserved */
+	0,                                          /* tp_repr */
+	0,                                          /* tp_as_number */
+	0,                                          /* tp_as_sequence */
+	0,                                          /* tp_as_mapping */
+	0,                                          /* tp_hash */
+	0,                                          /* tp_call */
+	0,                                          /* tp_str */
+	0,                                          /* tp_getattro */
+	0,                                          /* tp_setattro */
+	0,                                          /* tp_as_buffer */
+	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC |
+	Py_TPFLAGS_BASETYPE,                        /* tp_flags */
+	0,                                          /* tp_doc */
+	0,                                          /* tp_traverse */
+	0,                                          /* tp_clear */
+	0,                                          /* tp_richcompare */
+	0,                                          /* tp_weaklistoffset */
+	0,                                          /* tp_iter */
+	0,                                          /* tp_iternext */
+	0,                                          /* tp_methods */
+	0,                                          /* tp_members */
+	0,                                          /* tp_getset */
+	0,                                          /* tp_base */
+	0,                                          /* tp_dict */
+	0,                                          /* tp_descr_get */
+	0,                                          /* tp_descr_set */
+	0,                                          /* tp_dictoffset */
+	0,                                          /* tp_init */
+	0,                                          /* tp_alloc */
+	bpy_app_handlers_persistent_new,            /* tp_new */
+	0,                                          /* tp_free */
 };
 
 static PyObject *py_cb_array[BLI_CB_EVT_TOT] = {NULL};
@@ -235,7 +237,7 @@ void BPY_app_handlers_reset(const short do_all)
 	int pos = 0;
 
 	if (do_all) {
-	for (pos = 0; pos < BLI_CB_EVT_TOT; pos++) {
+		for (pos = 0; pos < BLI_CB_EVT_TOT; pos++) {
 			/* clear list */
 			PyList_SetSlice(py_cb_array[pos], 0, PY_SSIZE_T_MAX, NULL);
 		}
@@ -254,10 +256,10 @@ void BPY_app_handlers_reset(const short do_all)
 
 			for (i = PyList_GET_SIZE(ls) - 1; i >= 0; i--) {
 
-				if ( (PyFunction_Check((item = PyList_GET_ITEM(ls, i)))) &&
-				     (dict_ptr = _PyObject_GetDictPtr(item)) &&
-				     (*dict_ptr) &&
-				     (PyDict_GetItem(*dict_ptr, perm_id_str) != NULL))
+				if ((PyFunction_Check((item = PyList_GET_ITEM(ls, i)))) &&
+				    (dict_ptr = _PyObject_GetDictPtr(item)) &&
+				    (*dict_ptr) &&
+				    (PyDict_GetItem(*dict_ptr, perm_id_str) != NULL))
 				{
 					/* keep */
 				}
@@ -277,13 +279,12 @@ void BPY_app_handlers_reset(const short do_all)
 void bpy_app_generic_callback(struct Main *UNUSED(main), struct ID *id, void *arg)
 {
 	PyObject *cb_list = py_cb_array[GET_INT_FROM_POINTER(arg)];
-	Py_ssize_t cb_list_len;
-	if ((cb_list_len = PyList_GET_SIZE(cb_list)) > 0) {
+	if (PyList_GET_SIZE(cb_list) > 0) {
 		PyGILState_STATE gilstate = PyGILState_Ensure();
 
-		PyObject* args = PyTuple_New(1); // save python creating each call
-		PyObject* func;
-		PyObject* ret;
+		PyObject *args = PyTuple_New(1); // save python creating each call
+		PyObject *func;
+		PyObject *ret;
 		Py_ssize_t pos;
 
 		/* setup arguments */
@@ -297,8 +298,9 @@ void bpy_app_generic_callback(struct Main *UNUSED(main), struct ID *id, void *ar
 			Py_INCREF(Py_None);
 		}
 
-		// Iterate the list and run the callbacks
-		for (pos = 0; pos < cb_list_len; pos++) {
+		/* Iterate the list and run the callbacks
+		 * note: don't store the list size since the scripts may remove themselves */
+		for (pos = 0; pos < PyList_GET_SIZE(cb_list); pos++) {
 			func = PyList_GET_ITEM(cb_list, pos);
 			ret = PyObject_Call(func, args, NULL);
 			if (ret == NULL) {
