@@ -62,7 +62,7 @@
 #endif
 
 typedef struct {
-	PyObject_HEAD /* required python macro   */
+	PyObject_HEAD /* required python macro */
 	/* collection iterator specific parts */
 	char relpath[FILE_MAX];
 	char abspath[FILE_MAX]; /* absolute path */
@@ -92,75 +92,75 @@ static void bpy_lib_dealloc(BPy_Library *self)
 
 static PyTypeObject bpy_lib_Type = {
 	PyVarObject_HEAD_INIT(NULL, 0)
-	"bpy_lib",		/* tp_name */
-	sizeof(BPy_Library),			/* tp_basicsize */
-	0,							/* tp_itemsize */
+	"bpy_lib",      /* tp_name */
+	sizeof(BPy_Library),            /* tp_basicsize */
+	0,                          /* tp_itemsize */
 	/* methods */
-	(destructor)bpy_lib_dealloc,/* tp_dealloc */
+	(destructor)bpy_lib_dealloc, /* tp_dealloc */
 	NULL,                       /* printfunc tp_print; */
-	NULL,						/* getattrfunc tp_getattr; */
+	NULL,                       /* getattrfunc tp_getattr; */
 	NULL,                       /* setattrfunc tp_setattr; */
-	NULL,						/* tp_compare */ /* DEPRECATED in python 3.0! */
-	NULL,						/* tp_repr */
+	NULL,                       /* tp_compare */ /* DEPRECATED in python 3.0! */
+	NULL,                       /* tp_repr */
 
 	/* Method suites for standard classes */
 
-	NULL,						/* PyNumberMethods *tp_as_number; */
-	NULL,						/* PySequenceMethods *tp_as_sequence; */
-	NULL,						/* PyMappingMethods *tp_as_mapping; */
+	NULL,                       /* PyNumberMethods *tp_as_number; */
+	NULL,                       /* PySequenceMethods *tp_as_sequence; */
+	NULL,                       /* PyMappingMethods *tp_as_mapping; */
 
 	/* More standard operations (here for binary compatibility) */
 
-	NULL,						/* hashfunc tp_hash; */
+	NULL,                       /* hashfunc tp_hash; */
 	NULL,                       /* ternaryfunc tp_call; */
 	NULL,                       /* reprfunc tp_str; */
 
 	/* will only use these if this is a subtype of a py class */
-	NULL /*PyObject_GenericGetAttr is assigned later */,	/* getattrofunc tp_getattro; */
-	NULL,						/* setattrofunc tp_setattro; */
+	NULL /*PyObject_GenericGetAttr is assigned later */,    /* getattrofunc tp_getattro; */
+	NULL,                       /* setattrofunc tp_setattro; */
 
 	/* Functions to access object as input/output buffer */
 	NULL,                       /* PyBufferProcs *tp_as_buffer; */
 
-  /*** Flags to define presence of optional/expanded features ***/
+	/*** Flags to define presence of optional/expanded features ***/
 	Py_TPFLAGS_DEFAULT,         /* long tp_flags; */
 
-	NULL,						/*  char *tp_doc;  Documentation string */
-  /*** Assigned meaning in release 2.0 ***/
+	NULL,                       /*  char *tp_doc;  Documentation string */
+	/*** Assigned meaning in release 2.0 ***/
 	/* call function for all accessible objects */
 	NULL,                       /* traverseproc tp_traverse; */
 
 	/* delete references to contained objects */
 	NULL,                       /* inquiry tp_clear; */
 
-  /***  Assigned meaning in release 2.1 ***/
-  /*** rich comparisons ***/
+	/***  Assigned meaning in release 2.1 ***/
+	/*** rich comparisons ***/
 	NULL, /* subclassed */		/* richcmpfunc tp_richcompare; */
 
-  /***  weak reference enabler ***/
+	/***  weak reference enabler ***/
 	0,
-  /*** Added in release 2.2 ***/
+	/*** Added in release 2.2 ***/
 	/*   Iterators */
-	NULL,						/* getiterfunc tp_iter; */
+	NULL,                       /* getiterfunc tp_iter; */
 	NULL,                       /* iternextfunc tp_iternext; */
 
-  /*** Attribute descriptor and subclassing stuff ***/
-	bpy_lib_methods,			/* struct PyMethodDef *tp_methods; */
+	/*** Attribute descriptor and subclassing stuff ***/
+	bpy_lib_methods,            /* struct PyMethodDef *tp_methods; */
 	NULL,                       /* struct PyMemberDef *tp_members; */
-	NULL,				      	/* struct PyGetSetDef *tp_getset; */
+	NULL,                       /* struct PyGetSetDef *tp_getset; */
 	NULL,                       /* struct _typeobject *tp_base; */
 	NULL,                       /* PyObject *tp_dict; */
 	NULL,                       /* descrgetfunc tp_descr_get; */
 	NULL,                       /* descrsetfunc tp_descr_set; */
-	offsetof(BPy_Library, dict),/* long tp_dictoffset; */
+	offsetof(BPy_Library, dict), /* long tp_dictoffset; */
 	NULL,                       /* initproc tp_init; */
 	NULL,                       /* allocfunc tp_alloc; */
-	NULL,						/* newfunc tp_new; */
+	NULL,                       /* newfunc tp_new; */
 	/*  Low-level free-memory routine */
 	NULL,                       /* freefunc tp_free;  */
 	/* For PyObject_IS_GC */
 	NULL,                       /* inquiry tp_is_gc;  */
-	NULL,						/* PyObject *tp_bases; */
+	NULL,                       /* PyObject *tp_bases; */
 	/* method resolution order */
 	NULL,                       /* PyObject *tp_mro;  */
 	NULL,                       /* PyObject *tp_cache; */
@@ -170,23 +170,23 @@ static PyTypeObject bpy_lib_Type = {
 };
 
 PyDoc_STRVAR(bpy_lib_load_doc,
-".. method:: load(filepath, link=False, relative=False)\n"
-"\n"
-"   Returns a context manager which exposes 2 library objects on entering.\n"
-"   Each object has attributes matching bpy.data which are lists of strings to be linked.\n"
-"\n"
-"   :arg filepath: The path to a blend file.\n"
-"   :type filepath: string\n"
-"   :arg link: When False reference to the original file is lost.\n"
-"   :type link: bool\n"
-"   :arg relative: When True the path is stored relative to the open blend file.\n"
-"   :type relative: bool\n"
-);
+             ".. method:: load(filepath, link=False, relative=False)\n"
+             "\n"
+             "   Returns a context manager which exposes 2 library objects on entering.\n"
+             "   Each object has attributes matching bpy.data which are lists of strings to be linked.\n"
+             "\n"
+             "   :arg filepath: The path to a blend file.\n"
+             "   :type filepath: string\n"
+             "   :arg link: When False reference to the original file is lost.\n"
+             "   :type link: bool\n"
+             "   :arg relative: When True the path is stored relative to the open blend file.\n"
+             "   :type relative: bool\n"
+             );
 static PyObject *bpy_lib_load(PyObject *UNUSED(self), PyObject *args, PyObject *kwds)
 {
 	static const char *kwlist[] = {"filepath", "link", "relative", NULL};
 	BPy_Library *ret;
-	const char* filename = NULL;
+	const char *filename = NULL;
 	int is_rel = 0, is_link = 0;
 
 	if (!PyArg_ParseTupleAndKeywords(args, kwds, "s|ii:load", (char **)kwlist, &filename, &is_link, &is_rel))
@@ -199,8 +199,8 @@ static PyObject *bpy_lib_load(PyObject *UNUSED(self), PyObject *args, PyObject *
 	BLI_path_abs(ret->abspath, G.main->name);
 
 	ret->blo_handle = NULL;
-	ret->flag=	(is_link ? FILE_LINK : 0) |
-				(is_rel ? FILE_RELPATH : 0);
+	ret->flag = ((is_link ? FILE_LINK : 0) |
+	             (is_rel ? FILE_RELPATH : 0));
 
 	ret->dict = PyDict_New();
 
@@ -222,7 +222,7 @@ static PyObject *_bpy_names(BPy_Library *self, int blocktype)
 			PyList_SET_ITEM(list, counter, PyUnicode_FromString((char *)l->link));
 			counter++;
 		}
-		BLI_linklist_free(names, free);	/* free linklist *and* each node's data */
+		BLI_linklist_free(names, free); /* free linklist *and* each node's data */
 	}
 	else {
 		list = PyList_New(0);
@@ -401,7 +401,8 @@ static PyObject *bpy_lib_exit(BPy_Library *self, PyObject *UNUSED(args))
 		BLO_blendhandle_close(self->blo_handle);
 		self->blo_handle = NULL;
 
-		{	/* copied from wm_operator.c */
+		/* copied from wm_operator.c */
+		{
 			/* mark all library linked objects to be updated */
 			recalc_all_library_objects(G.main);
 
@@ -426,12 +427,12 @@ static PyObject *bpy_lib_dir(BPy_Library *self)
 int bpy_lib_init(PyObject *mod_par)
 {
 	static PyMethodDef load_meth = {"load", (PyCFunction)bpy_lib_load,
-	                               METH_STATIC|METH_VARARGS|METH_KEYWORDS,
-	                               bpy_lib_load_doc};
+	                                METH_STATIC | METH_VARARGS | METH_KEYWORDS,
+	                                bpy_lib_load_doc};
 
 	PyModule_AddObject(mod_par, "_library_load", PyCFunction_New(&load_meth, NULL));
 
-	/* some compilers dont like accessing this directly, delay assignment */
+	/* some compilers don't like accessing this directly, delay assignment */
 	bpy_lib_Type.tp_getattro = PyObject_GenericGetAttr;
 
 	if (PyType_Ready(&bpy_lib_Type) < 0)
