@@ -24,8 +24,8 @@
  *  \ingroup pythonintern
  */
 
-#ifndef BPY_OPERATOR_H
-#define BPY_OPERATOR_H
+#ifndef __BPY_OPERATOR_H__
+#define __BPY_OPERATOR_H__
 
 extern PyTypeObject pyop_base_Type;
 
