@@ -52,8 +52,8 @@ static int mathutils_array_parse_fast(float *array,
 	i = size;
 	do {
 		i--;
-		if ( ((array[i] = PyFloat_AsDouble((item = PySequence_Fast_GET_ITEM(value_fast, i)))) == -1.0f) &&
-		     PyErr_Occurred())
+		if (((array[i] = PyFloat_AsDouble((item = PySequence_Fast_GET_ITEM(value_fast, i)))) == -1.0f) &&
+		    PyErr_Occurred())
 		{
 			PyErr_Format(PyExc_TypeError,
 			             "%.200s: sequence index %d expected a number, "
@@ -75,17 +75,17 @@ int mathutils_array_parse(float *array, int array_min, int array_max, PyObject *
 
 #if 1 /* approx 6x speedup for mathutils types */
 
-	if ( (size = VectorObject_Check(value)     ? ((VectorObject *)value)->size : 0) ||
-	     (size = EulerObject_Check(value)      ? 3 : 0) ||
-	     (size = QuaternionObject_Check(value) ? 4 : 0) ||
-	     (size = ColorObject_Check(value)      ? 3 : 0))
+	if ((size = VectorObject_Check(value)     ? ((VectorObject *)value)->size : 0) ||
+	    (size = EulerObject_Check(value)      ? 3 : 0) ||
+	    (size = QuaternionObject_Check(value) ? 4 : 0) ||
+	    (size = ColorObject_Check(value)      ? 3 : 0))
 	{
 		if (BaseMath_ReadCallback((BaseMathObject *)value) == -1) {
 			return -1;
 		}
 
 		if (size > array_max || size < array_min) {
-			if (array_max == array_min)	{
+			if (array_max == array_min) {
 				PyErr_Format(PyExc_ValueError,
 				             "%.200s: sequence size is %d, expected %d",
 				             error_prefix, size, array_max);
@@ -115,15 +115,15 @@ int mathutils_array_parse(float *array, int array_min, int array_max, PyObject *
 		size = PySequence_Fast_GET_SIZE(value_fast);
 
 		if (size > array_max || size < array_min) {
-			if (array_max == array_min)	{
+			if (array_max == array_min) {
 				PyErr_Format(PyExc_ValueError,
-							 "%.200s: sequence size is %d, expected %d",
-							 error_prefix, size, array_max);
+				             "%.200s: sequence size is %d, expected %d",
+				             error_prefix, size, array_max);
 			}
 			else {
 				PyErr_Format(PyExc_ValueError,
-							 "%.200s: sequence size is %d, expected [%d - %d]",
-							 error_prefix, size, array_min, array_max);
+				             "%.200s: sequence size is %d, expected [%d - %d]",
+				             error_prefix, size, array_min, array_max);
 			}
 			Py_DECREF(value_fast);
 			return -1;
@@ -139,10 +139,10 @@ int mathutils_array_parse_alloc(float **array, int array_min, PyObject *value, c
 
 #if 1 /* approx 6x speedup for mathutils types */
 
-	if ( (size = VectorObject_Check(value)     ? ((VectorObject *)value)->size : 0) ||
-	     (size = EulerObject_Check(value)      ? 3 : 0) ||
-	     (size = QuaternionObject_Check(value) ? 4 : 0) ||
-	     (size = ColorObject_Check(value)      ? 3 : 0))
+	if ((size = VectorObject_Check(value)     ? ((VectorObject *)value)->size : 0) ||
+	    (size = EulerObject_Check(value)      ? 3 : 0) ||
+	    (size = QuaternionObject_Check(value) ? 4 : 0) ||
+	    (size = ColorObject_Check(value)      ? 3 : 0))
 	{
 		if (BaseMath_ReadCallback((BaseMathObject *)value) == -1) {
 			return -1;
@@ -163,7 +163,7 @@ int mathutils_array_parse_alloc(float **array, int array_min, PyObject *value, c
 #endif
 	{
 		PyObject *value_fast = NULL;
-		//*array = NULL;
+		// *array = NULL;
 
 		/* non list/tuple cases */
 		if (!(value_fast = PySequence_Fast(value, error_prefix))) {
@@ -186,6 +186,41 @@ int mathutils_array_parse_alloc(float **array, int array_min, PyObject *value, c
 	}
 }
 
+/* parse an array of vectors */
+int mathutils_array_parse_alloc_v(float **array, int array_dim, PyObject *value, const char *error_prefix)
+{
+	PyObject *value_fast = NULL;
+	int i, size;
+
+	/* non list/tuple cases */
+	if (!(value_fast = PySequence_Fast(value, error_prefix))) {
+		/* PySequence_Fast sets the error */
+		return -1;
+	}
+
+	size = PySequence_Fast_GET_SIZE(value_fast);
+
+	if (size != 0) {
+		float *fp;
+
+		fp = *array = PyMem_Malloc(size * array_dim * sizeof(float));
+
+		for (i = 0; i < size; i++, fp += array_dim) {
+			PyObject *item = PySequence_Fast_GET_ITEM(value, i);
+
+			if (mathutils_array_parse(fp, array_dim, array_dim, item, error_prefix) == -1) {
+				PyMem_Free(*array);
+				*array = NULL;
+				size = -1;
+				break;
+			}
+		}
+	}
+
+	Py_DECREF(value_fast);
+	return size;
+}
+
 int mathutils_any_to_rotmat(float rmat[3][3], PyObject *value, const char *error_prefix)
 {
 	if (EulerObject_Check(value)) {
@@ -239,25 +274,26 @@ int mathutils_any_to_rotmat(float rmat[3][3], PyObject *value, const char *error
 /* Utility functions */
 
 // LomontRRDCompare4, Ever Faster Float Comparisons by Randy Dillon
-#define SIGNMASK(i) (-(int)(((unsigned int)(i))>>31))
+#define SIGNMASK(i) (-(int)(((unsigned int)(i)) >> 31))
 
 int EXPP_FloatsAreEqual(float af, float bf, int maxDiff)
-{	// solid, fast routine across all platforms
-	// with constant time behavior
+{
+	/* solid, fast routine across all platforms
+	 * with constant time behavior */
 	int ai = *(int *)(&af);
 	int bi = *(int *)(&bf);
-	int test = SIGNMASK(ai^bi);
+	int test = SIGNMASK(ai ^ bi);
 	int diff, v1, v2;
 
 	assert((0 == test) || (0xFFFFFFFF == test));
 	diff = (ai ^ (test & 0x7fffffff)) - bi;
 	v1 = maxDiff + diff;
 	v2 = maxDiff - diff;
-	return (v1|v2) >= 0;
+	return (v1 | v2) >= 0;
 }
 
 /*---------------------- EXPP_VectorsAreEqual -------------------------
-  Builds on EXPP_FloatsAreEqual to test vectors */
+ * Builds on EXPP_FloatsAreEqual to test vectors */
 int EXPP_VectorsAreEqual(float *vecA, float *vecB, int size, int floatSteps)
 {
 	int x;
@@ -281,21 +317,31 @@ PyObject *mathutils_dynstr_to_py(struct DynStr *ds)
 	return ret;
 }
 
+/* silly function, we dont use arg. just check its compatible with __deepcopy__ */
+int mathutils_deepcopy_args_check(PyObject *args)
+{
+	PyObject *dummy_pydict;
+	return PyArg_ParseTuple(args, "|O!:__deepcopy__", &PyDict_Type, &dummy_pydict) != 0;
+}
+
 /* Mathutils Callbacks */
 
 /* for mathutils internal use only, eventually should re-alloc but to start with we only have a few users */
-static Mathutils_Callback *mathutils_callbacks[8] = {NULL};
+#define MATHUTILS_TOT_CB 10
+static Mathutils_Callback *mathutils_callbacks[MATHUTILS_TOT_CB] = {NULL};
 
-int Mathutils_RegisterCallback(Mathutils_Callback *cb)
+unsigned char Mathutils_RegisterCallback(Mathutils_Callback *cb)
 {
-	int i;
+	unsigned char i;
 	
 	/* find the first free slot */
 	for (i = 0; mathutils_callbacks[i]; i++) {
 		if (mathutils_callbacks[i] == cb) /* already registered? */
 			return i;
 	}
-	
+
+	BLI_assert(i + 1 < MATHUTILS_TOT_CB);
+
 	mathutils_callbacks[i] = cb;
 	return i;
 }
@@ -304,8 +350,9 @@ int Mathutils_RegisterCallback(Mathutils_Callback *cb)
 int _BaseMathObject_ReadCallback(BaseMathObject *self)
 {
 	Mathutils_Callback *cb = mathutils_callbacks[self->cb_type];
-	if (cb->get(self, self->cb_subtype) != -1)
+	if (LIKELY(cb->get(self, self->cb_subtype) != -1)) {
 		return 0;
+	}
 
 	if (!PyErr_Occurred()) {
 		PyErr_Format(PyExc_RuntimeError,
@@ -318,8 +365,9 @@ int _BaseMathObject_ReadCallback(BaseMathObject *self)
 int _BaseMathObject_WriteCallback(BaseMathObject *self)
 {
 	Mathutils_Callback *cb = mathutils_callbacks[self->cb_type];
-	if (cb->set(self, self->cb_subtype) != -1)
+	if (LIKELY(cb->set(self, self->cb_subtype) != -1)) {
 		return 0;
+	}
 
 	if (!PyErr_Occurred()) {
 		PyErr_Format(PyExc_RuntimeError,
@@ -332,8 +380,9 @@ int _BaseMathObject_WriteCallback(BaseMathObject *self)
 int _BaseMathObject_ReadIndexCallback(BaseMathObject *self, int index)
 {
 	Mathutils_Callback *cb = mathutils_callbacks[self->cb_type];
-	if (cb->get_index(self, self->cb_subtype, index) != -1)
+	if (LIKELY(cb->get_index(self, self->cb_subtype, index) != -1)) {
 		return 0;
+	}
 
 	if (!PyErr_Occurred()) {
 		PyErr_Format(PyExc_RuntimeError,
@@ -346,8 +395,9 @@ int _BaseMathObject_ReadIndexCallback(BaseMathObject *self, int index)
 int _BaseMathObject_WriteIndexCallback(BaseMathObject *self, int index)
 {
 	Mathutils_Callback *cb = mathutils_callbacks[self->cb_type];
-	if (cb->set_index(self, self->cb_subtype, index) != -1)
+	if (LIKELY(cb->set_index(self, self->cb_subtype, index) != -1)) {
 		return 0;
+	}
 
 	if (!PyErr_Occurred()) {
 		PyErr_Format(PyExc_RuntimeError,
@@ -358,7 +408,7 @@ int _BaseMathObject_WriteIndexCallback(BaseMathObject *self, int index)
 }
 
 /* BaseMathObject generic functions for all mathutils types */
-char BaseMathObject_owner_doc[] = "The item this is wrapping or None  (readonly).";
+char BaseMathObject_owner_doc[] = "The item this is wrapping or None  (read-only).";
 PyObject *BaseMathObject_owner_get(BaseMathObject *self, void *UNUSED(closure))
 {
 	PyObject *ret = self->cb_user ? self->cb_user : Py_None;
@@ -366,10 +416,10 @@ PyObject *BaseMathObject_owner_get(BaseMathObject *self, void *UNUSED(closure))
 	return ret;
 }
 
-char BaseMathObject_is_wrapped_doc[] = "True when this object wraps external data (readonly).\n\n:type: boolean";
+char BaseMathObject_is_wrapped_doc[] = "True when this object wraps external data (read-only).\n\n:type: boolean";
 PyObject *BaseMathObject_is_wrapped_get(BaseMathObject *self, void *UNUSED(closure))
 {
-	return PyBool_FromLong((self->wrapped == Py_WRAP) ? 1:0);
+	return PyBool_FromLong((self->wrapped == Py_WRAP) ? 1 : 0);
 }
 
 int BaseMathObject_traverse(BaseMathObject *self, visitproc visit, void *arg)
@@ -418,8 +468,8 @@ static struct PyModuleDef M_Mathutils_module_def = {
 
 PyMODINIT_FUNC PyInit_mathutils(void)
 {
+	PyObject *mod;
 	PyObject *submodule;
-	PyObject *item;
 	PyObject *sys_modules = PyThreadState_GET()->interp->modules;
 
 	if (PyType_Ready(&vector_Type) < 0)
@@ -435,31 +485,31 @@ PyMODINIT_FUNC PyInit_mathutils(void)
 	if (PyType_Ready(&color_Type) < 0)
 		return NULL;
 
-	submodule = PyModule_Create(&M_Mathutils_module_def);
+	mod = PyModule_Create(&M_Mathutils_module_def);
 	
 	/* each type has its own new() function */
-	PyModule_AddObject(submodule, "Vector",		(PyObject *)&vector_Type);
-	PyModule_AddObject(submodule, "Matrix",		(PyObject *)&matrix_Type);
-	PyModule_AddObject(submodule, "Euler",		(PyObject *)&euler_Type);
-	PyModule_AddObject(submodule, "Quaternion",	(PyObject *)&quaternion_Type);
-	PyModule_AddObject(submodule, "Color",		(PyObject *)&color_Type);
+	PyModule_AddObject(mod, vector_Type.tp_name,     (PyObject *)&vector_Type);
+	PyModule_AddObject(mod, matrix_Type.tp_name,     (PyObject *)&matrix_Type);
+	PyModule_AddObject(mod, euler_Type.tp_name,      (PyObject *)&euler_Type);
+	PyModule_AddObject(mod, quaternion_Type.tp_name, (PyObject *)&quaternion_Type);
+	PyModule_AddObject(mod, color_Type.tp_name,      (PyObject *)&color_Type);
 	
 	/* submodule */
-	PyModule_AddObject(submodule, "geometry",		(item = PyInit_mathutils_geometry()));
+	PyModule_AddObject(mod, "geometry",       (submodule = PyInit_mathutils_geometry()));
 	/* XXX, python doesnt do imports with this usefully yet
 	 * 'from mathutils.geometry import PolyFill'
 	 * ...fails without this. */
-	PyDict_SetItemString(sys_modules, "mathutils.geometry", item);
-	Py_INCREF(item);
+	PyDict_SetItemString(sys_modules, PyModule_GetName(submodule), submodule);
+	Py_INCREF(submodule);
 
 	/* Noise submodule */
-	PyModule_AddObject(submodule, "noise",		(item = PyInit_mathutils_noise()));
-	PyDict_SetItemString(sys_modules, "mathutils.noise", item);
-	Py_INCREF(item);
+	PyModule_AddObject(mod, "noise", (submodule = PyInit_mathutils_noise()));
+	PyDict_SetItemString(sys_modules, PyModule_GetName(submodule), submodule);
+	Py_INCREF(submodule);
 
 	mathutils_matrix_row_cb_index = Mathutils_RegisterCallback(&mathutils_matrix_row_cb);
 	mathutils_matrix_col_cb_index = Mathutils_RegisterCallback(&mathutils_matrix_col_cb);
 	mathutils_matrix_translation_cb_index = Mathutils_RegisterCallback(&mathutils_matrix_translation_cb);
 
-	return submodule;
+	return mod;
 }
