@@ -99,11 +99,11 @@ static PyObject *M_Geometry_intersect_ray_tri(PyObject *UNUSED(self), PyObject *
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(vec1) == -1 ||
-	     BaseMath_ReadCallback(vec2) == -1 ||
-	     BaseMath_ReadCallback(vec3) == -1 ||
-	     BaseMath_ReadCallback(ray)  == -1 ||
-	     BaseMath_ReadCallback(ray_off) == -1)
+	if (BaseMath_ReadCallback(vec1) == -1 ||
+	    BaseMath_ReadCallback(vec2) == -1 ||
+	    BaseMath_ReadCallback(vec3) == -1 ||
+	    BaseMath_ReadCallback(ray)  == -1 ||
+	    BaseMath_ReadCallback(ray_off) == -1)
 	{
 		return NULL;
 	}
@@ -199,10 +199,10 @@ static PyObject *M_Geometry_intersect_line_line(PyObject *UNUSED(self), PyObject
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(vec1) == -1 ||
-	     BaseMath_ReadCallback(vec2) == -1 ||
-	     BaseMath_ReadCallback(vec3) == -1 ||
-	     BaseMath_ReadCallback(vec4) == -1)
+	if (BaseMath_ReadCallback(vec1) == -1 ||
+	    BaseMath_ReadCallback(vec2) == -1 ||
+	    BaseMath_ReadCallback(vec3) == -1 ||
+	    BaseMath_ReadCallback(vec4) == -1)
 	{
 		return NULL;
 	}
@@ -298,9 +298,9 @@ static PyObject *M_Geometry_normal(PyObject *UNUSED(self), PyObject *args)
 			return NULL;
 		}
 
-		if ( BaseMath_ReadCallback(vec1) == -1 ||
-		     BaseMath_ReadCallback(vec2) == -1 ||
-		     BaseMath_ReadCallback(vec3) == -1)
+		if (BaseMath_ReadCallback(vec1) == -1 ||
+		    BaseMath_ReadCallback(vec2) == -1 ||
+		    BaseMath_ReadCallback(vec3) == -1)
 		{
 			return NULL;
 		}
@@ -327,10 +327,10 @@ static PyObject *M_Geometry_normal(PyObject *UNUSED(self), PyObject *args)
 			return NULL;
 		}
 
-		if ( BaseMath_ReadCallback(vec1) == -1 ||
-		     BaseMath_ReadCallback(vec2) == -1 ||
-		     BaseMath_ReadCallback(vec3) == -1 ||
-		     BaseMath_ReadCallback(vec4) == -1)
+		if (BaseMath_ReadCallback(vec1) == -1 ||
+		    BaseMath_ReadCallback(vec2) == -1 ||
+		    BaseMath_ReadCallback(vec3) == -1 ||
+		    BaseMath_ReadCallback(vec4) == -1)
 		{
 			return NULL;
 		}
@@ -374,9 +374,9 @@ static PyObject *M_Geometry_area_tri(PyObject *UNUSED(self), PyObject *args)
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(vec1) == -1 ||
-	     BaseMath_ReadCallback(vec2) == -1 ||
-	     BaseMath_ReadCallback(vec3) == -1)
+	if (BaseMath_ReadCallback(vec1) == -1 ||
+	    BaseMath_ReadCallback(vec2) == -1 ||
+	    BaseMath_ReadCallback(vec3) == -1)
 	{
 		return NULL;
 	}
@@ -424,10 +424,10 @@ static PyObject *M_Geometry_intersect_line_line_2d(PyObject *UNUSED(self), PyObj
 		return NULL;
 	}
 	
-	if ( BaseMath_ReadCallback(line_a1) == -1 ||
-	     BaseMath_ReadCallback(line_a2) == -1 ||
-	     BaseMath_ReadCallback(line_b1) == -1 ||
-	     BaseMath_ReadCallback(line_b2) == -1)
+	if (BaseMath_ReadCallback(line_a1) == -1 ||
+	    BaseMath_ReadCallback(line_a2) == -1 ||
+	    BaseMath_ReadCallback(line_b1) == -1 ||
+	    BaseMath_ReadCallback(line_b2) == -1)
 	{
 		return NULL;
 	}
@@ -444,7 +444,8 @@ static PyObject *M_Geometry_intersect_line_line_2d(PyObject *UNUSED(self), PyObj
 PyDoc_STRVAR(M_Geometry_intersect_line_plane_doc,
 ".. function:: intersect_line_plane(line_a, line_b, plane_co, plane_no, no_flip=False)\n"
 "\n"
-"   Takes 2 lines (as 4 vectors) and returns a vector for their point of intersection or None.\n"
+"   Calculate the intersection between a line (as 2 vectors) and a plane.\n"
+"   Returns a vector for the intersection or None.\n"
 "\n"
 "   :arg line_a: First point of the first line\n"
 "   :type line_a: :class:`mathutils.Vector`\n"
@@ -474,10 +475,10 @@ static PyObject *M_Geometry_intersect_line_plane(PyObject *UNUSED(self), PyObjec
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(line_a) == -1 ||
-	     BaseMath_ReadCallback(line_b) == -1 ||
-	     BaseMath_ReadCallback(plane_co) == -1 ||
-	     BaseMath_ReadCallback(plane_no) == -1)
+	if (BaseMath_ReadCallback(line_a) == -1 ||
+	    BaseMath_ReadCallback(line_b) == -1 ||
+	    BaseMath_ReadCallback(plane_co) == -1 ||
+	    BaseMath_ReadCallback(plane_no) == -1)
 	{
 		return NULL;
 	}
@@ -530,10 +531,10 @@ static PyObject *M_Geometry_intersect_plane_plane(PyObject *UNUSED(self), PyObje
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(plane_a_co) == -1 ||
-	     BaseMath_ReadCallback(plane_a_no) == -1 ||
-	     BaseMath_ReadCallback(plane_b_co) == -1 ||
-	     BaseMath_ReadCallback(plane_b_no) == -1)
+	if (BaseMath_ReadCallback(plane_a_co) == -1 ||
+	    BaseMath_ReadCallback(plane_a_no) == -1 ||
+	    BaseMath_ReadCallback(plane_b_co) == -1 ||
+	    BaseMath_ReadCallback(plane_b_no) == -1)
 	{
 		return NULL;
 	}
@@ -592,9 +593,9 @@ static PyObject *M_Geometry_intersect_line_sphere(PyObject *UNUSED(self), PyObje
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(line_a) == -1 ||
-	     BaseMath_ReadCallback(line_b) == -1 ||
-	     BaseMath_ReadCallback(sphere_co) == -1)
+	if (BaseMath_ReadCallback(line_a) == -1 ||
+	    BaseMath_ReadCallback(line_b) == -1 ||
+	    BaseMath_ReadCallback(sphere_co) == -1)
 	{
 		return NULL;
 	}
@@ -613,24 +614,24 @@ static PyObject *M_Geometry_intersect_line_sphere(PyObject *UNUSED(self), PyObje
 		PyObject *ret = PyTuple_New(2);
 
 		switch (isect_line_sphere_v3(line_a->vec, line_b->vec, sphere_co->vec, sphere_radius, isect_a, isect_b)) {
-		case 1:
-			if (!(!clip || (((lambda = line_point_factor_v3(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
-			use_b = FALSE;
-			break;
-		case 2:
-			if (!(!clip || (((lambda = line_point_factor_v3(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
-			if (!(!clip || (((lambda = line_point_factor_v3(isect_b, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_b = FALSE;
-			break;
-		default:
-			use_a = FALSE;
-			use_b = FALSE;
+			case 1:
+				if (!(!clip || (((lambda = line_point_factor_v3(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
+				use_b = FALSE;
+				break;
+			case 2:
+				if (!(!clip || (((lambda = line_point_factor_v3(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
+				if (!(!clip || (((lambda = line_point_factor_v3(isect_b, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_b = FALSE;
+				break;
+			default:
+				use_a = FALSE;
+				use_b = FALSE;
 		}
 
 		if (use_a) { PyTuple_SET_ITEM(ret, 0,  Vector_CreatePyObject(isect_a, 3, Py_NEW, NULL)); }
-		else      { PyTuple_SET_ITEM(ret, 0,  Py_None); Py_INCREF(Py_None); }
+		else       { PyTuple_SET_ITEM(ret, 0,  Py_None); Py_INCREF(Py_None); }
 
 		if (use_b) { PyTuple_SET_ITEM(ret, 1,  Vector_CreatePyObject(isect_b, 3, Py_NEW, NULL)); }
-		else      { PyTuple_SET_ITEM(ret, 1,  Py_None); Py_INCREF(Py_None); }
+		else       { PyTuple_SET_ITEM(ret, 1,  Py_None); Py_INCREF(Py_None); }
 
 		return ret;
 	}
@@ -672,9 +673,9 @@ static PyObject *M_Geometry_intersect_line_sphere_2d(PyObject *UNUSED(self), PyO
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(line_a) == -1 ||
-	     BaseMath_ReadCallback(line_b) == -1 ||
-	     BaseMath_ReadCallback(sphere_co) == -1)
+	if (BaseMath_ReadCallback(line_a) == -1 ||
+	    BaseMath_ReadCallback(line_b) == -1 ||
+	    BaseMath_ReadCallback(sphere_co) == -1)
 	{
 		return NULL;
 	}
@@ -686,24 +687,24 @@ static PyObject *M_Geometry_intersect_line_sphere_2d(PyObject *UNUSED(self), PyO
 		PyObject *ret = PyTuple_New(2);
 
 		switch (isect_line_sphere_v2(line_a->vec, line_b->vec, sphere_co->vec, sphere_radius, isect_a, isect_b)) {
-		case 1:
-			if (!(!clip || (((lambda = line_point_factor_v2(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
-			use_b = FALSE;
-			break;
-		case 2:
-			if (!(!clip || (((lambda = line_point_factor_v2(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
-			if (!(!clip || (((lambda = line_point_factor_v2(isect_b, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_b = FALSE;
-			break;
-		default:
-			use_a = FALSE;
-			use_b = FALSE;
+			case 1:
+				if (!(!clip || (((lambda = line_point_factor_v2(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
+				use_b = FALSE;
+				break;
+			case 2:
+				if (!(!clip || (((lambda = line_point_factor_v2(isect_a, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_a = FALSE;
+				if (!(!clip || (((lambda = line_point_factor_v2(isect_b, line_a->vec, line_b->vec)) >= 0.0f) && (lambda <= 1.0f)))) use_b = FALSE;
+				break;
+			default:
+				use_a = FALSE;
+				use_b = FALSE;
 		}
 
 		if (use_a) { PyTuple_SET_ITEM(ret, 0,  Vector_CreatePyObject(isect_a, 2, Py_NEW, NULL)); }
-		else      { PyTuple_SET_ITEM(ret, 0,  Py_None); Py_INCREF(Py_None); }
+		else       { PyTuple_SET_ITEM(ret, 0,  Py_None); Py_INCREF(Py_None); }
 
 		if (use_b) { PyTuple_SET_ITEM(ret, 1,  Vector_CreatePyObject(isect_b, 2, Py_NEW, NULL)); }
-		else      { PyTuple_SET_ITEM(ret, 1,  Py_None); Py_INCREF(Py_None); }
+		else       { PyTuple_SET_ITEM(ret, 1,  Py_None); Py_INCREF(Py_None); }
 
 		return ret;
 	}
@@ -737,21 +738,21 @@ static PyObject *M_Geometry_intersect_point_line(PyObject *UNUSED(self), PyObjec
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(pt) == -1 ||
-	     BaseMath_ReadCallback(line_1) == -1 ||
-	     BaseMath_ReadCallback(line_2) == -1)
+	if (BaseMath_ReadCallback(pt) == -1 ||
+	    BaseMath_ReadCallback(line_1) == -1 ||
+	    BaseMath_ReadCallback(line_2) == -1)
 	{
 		return NULL;
 	}
 
 	/* accept 2d verts */
-	if (pt->size == 3) {     copy_v3_v3(pt_in, pt->vec);}
+	if (pt->size == 3) {     copy_v3_v3(pt_in, pt->vec); }
 	else { pt_in[2] = 0.0f;  copy_v2_v2(pt_in, pt->vec); }
 	
-	if (line_1->size == 3) { copy_v3_v3(l1, line_1->vec);}
+	if (line_1->size == 3) { copy_v3_v3(l1, line_1->vec); }
 	else { l1[2] = 0.0f;     copy_v2_v2(l1, line_1->vec); }
 	
-	if (line_2->size == 3) { copy_v3_v3(l2, line_2->vec);}
+	if (line_2->size == 3) { copy_v3_v3(l2, line_2->vec); }
 	else { l2[2] = 0.0f;     copy_v2_v2(l2, line_2->vec); }
 	
 	/* do the calculation */
@@ -791,10 +792,10 @@ static PyObject *M_Geometry_intersect_point_tri_2d(PyObject *UNUSED(self), PyObj
 		return NULL;
 	}
 	
-	if ( BaseMath_ReadCallback(pt_vec) == -1 ||
-	     BaseMath_ReadCallback(tri_p1) == -1 ||
-	     BaseMath_ReadCallback(tri_p2) == -1 ||
-	     BaseMath_ReadCallback(tri_p3) == -1)
+	if (BaseMath_ReadCallback(pt_vec) == -1 ||
+	    BaseMath_ReadCallback(tri_p1) == -1 ||
+	    BaseMath_ReadCallback(tri_p2) == -1 ||
+	    BaseMath_ReadCallback(tri_p3) == -1)
 	{
 		return NULL;
 	}
@@ -834,11 +835,11 @@ static PyObject *M_Geometry_intersect_point_quad_2d(PyObject *UNUSED(self), PyOb
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(pt_vec)  == -1 ||
-	     BaseMath_ReadCallback(quad_p1) == -1 ||
-	     BaseMath_ReadCallback(quad_p2) == -1 ||
-	     BaseMath_ReadCallback(quad_p3) == -1 ||
-	     BaseMath_ReadCallback(quad_p4) == -1)
+	if (BaseMath_ReadCallback(pt_vec)  == -1 ||
+	    BaseMath_ReadCallback(quad_p1) == -1 ||
+	    BaseMath_ReadCallback(quad_p2) == -1 ||
+	    BaseMath_ReadCallback(quad_p3) == -1 ||
+	    BaseMath_ReadCallback(quad_p4) == -1)
 	{
 		return NULL;
 	}
@@ -872,9 +873,9 @@ static PyObject *M_Geometry_distance_point_to_plane(PyObject *UNUSED(self), PyOb
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(pt) == -1 ||
-	     BaseMath_ReadCallback(plene_co) == -1 ||
-	     BaseMath_ReadCallback(plane_no) == -1)
+	if (BaseMath_ReadCallback(pt) == -1 ||
+	    BaseMath_ReadCallback(plene_co) == -1 ||
+	    BaseMath_ReadCallback(plane_no) == -1)
 	{
 		return NULL;
 	}
@@ -923,13 +924,13 @@ static PyObject *M_Geometry_barycentric_transform(PyObject *UNUSED(self), PyObje
 		return NULL;
 	}
 
-	if (	vec_pt->size != 3 ||
-		vec_t1_src->size != 3 ||
-		vec_t2_src->size != 3 ||
-		vec_t3_src->size != 3 ||
-		vec_t1_tar->size != 3 ||
-		vec_t2_tar->size != 3 ||
-		vec_t3_tar->size != 3)
+	if (vec_pt->size != 3 ||
+	    vec_t1_src->size != 3 ||
+	    vec_t2_src->size != 3 ||
+	    vec_t3_src->size != 3 ||
+	    vec_t1_tar->size != 3 ||
+	    vec_t2_tar->size != 3 ||
+	    vec_t3_tar->size != 3)
 	{
 		PyErr_SetString(PyExc_ValueError,
 		                "One of more of the vector arguments wasn't a 3D vector");
@@ -937,8 +938,8 @@ static PyObject *M_Geometry_barycentric_transform(PyObject *UNUSED(self), PyObje
 	}
 
 	barycentric_transform(vec, vec_pt->vec,
-			vec_t1_tar->vec, vec_t2_tar->vec, vec_t3_tar->vec,
-			vec_t1_src->vec, vec_t2_src->vec, vec_t3_src->vec);
+	                      vec_t1_tar->vec, vec_t2_tar->vec, vec_t3_tar->vec,
+	                      vec_t1_src->vec, vec_t2_src->vec, vec_t3_src->vec);
 
 	return Vector_CreatePyObject(vec, 3, Py_NEW, NULL);
 }
@@ -993,10 +994,10 @@ static PyObject *M_Geometry_interpolate_bezier(PyObject *UNUSED(self), PyObject
 		return NULL;
 	}
 
-	if ( BaseMath_ReadCallback(vec_k1) == -1 ||
-	     BaseMath_ReadCallback(vec_h1) == -1 ||
-	     BaseMath_ReadCallback(vec_k2) == -1 ||
-	     BaseMath_ReadCallback(vec_h2) == -1)
+	if (BaseMath_ReadCallback(vec_k1) == -1 ||
+	    BaseMath_ReadCallback(vec_h1) == -1 ||
+	    BaseMath_ReadCallback(vec_k2) == -1 ||
+	    BaseMath_ReadCallback(vec_h2) == -1)
 	{
 		return NULL;
 	}
@@ -1010,7 +1011,7 @@ static PyObject *M_Geometry_interpolate_bezier(PyObject *UNUSED(self), PyObject
 
 	coord_array = MEM_callocN(dims * (resolu) * sizeof(float), "interpolate_bezier");
 	for (i = 0; i < dims; i++) {
-		forward_diff_bezier(k1[i], h1[i], h2[i], k2[i], coord_array + i, resolu - 1, sizeof(float)*dims);
+		forward_diff_bezier(k1[i], h1[i], h2[i], k2[i], coord_array + i, resolu - 1, sizeof(float) * dims);
 	}
 
 	list = PyList_New(resolu);
@@ -1023,8 +1024,8 @@ static PyObject *M_Geometry_interpolate_bezier(PyObject *UNUSED(self), PyObject
 }
 
 
-PyDoc_STRVAR(M_Geometry_tesselate_polygon_doc,
-".. function:: tesselate_polygon(veclist_list)\n"
+PyDoc_STRVAR(M_Geometry_tessellate_polygon_doc,
+".. function:: tessellate_polygon(veclist_list)\n"
 "\n"
 "   Takes a list of polylines (each point a vector) and returns the point indices for a polyline filled with triangles.\n"
 "\n"
@@ -1032,7 +1033,7 @@ PyDoc_STRVAR(M_Geometry_tesselate_polygon_doc,
 "   :rtype: list\n"
 );
 /* PolyFill function, uses Blenders scanfill to fill multiple poly lines */
-static PyObject *M_Geometry_tesselate_polygon(PyObject *UNUSED(self), PyObject *polyLineSeq)
+static PyObject *M_Geometry_tessellate_polygon(PyObject *UNUSED(self), PyObject *polyLineSeq)
 {
 	PyObject *tri_list; /*return this list of tri's */
 	PyObject *polyLine, *polyVec;
@@ -1063,7 +1064,7 @@ static PyObject *M_Geometry_tesselate_polygon(PyObject *UNUSED(self), PyObject *
 		}
 
 		len_polypoints = PySequence_Size(polyLine);
-		if (len_polypoints > 0) { /* dont bother adding edges as polylines */
+		if (len_polypoints > 0) { /* don't bother adding edges as polylines */
 #if 0
 			if (EXPP_check_sequence_consistency(polyLine, &vector_Type) != 1) {
 				freedisplist(&dispbase);
@@ -1095,7 +1096,7 @@ static PyObject *M_Geometry_tesselate_polygon(PyObject *UNUSED(self), PyObject *
 					if (((VectorObject *)polyVec)->size > 2)
 						fp[2] = ((VectorObject *)polyVec)->vec[2];
 					else
-						fp[2] = 0.0f; /* if its a 2d vector then set the z to be zero */
+						fp[2] = 0.0f;  /* if its a 2d vector then set the z to be zero */
 				}
 				else {
 					ls_error = 1;
@@ -1120,7 +1121,7 @@ static PyObject *M_Geometry_tesselate_polygon(PyObject *UNUSED(self), PyObject *
 		filldisplist(&dispbase, &dispbase, 0);
 
 		/* The faces are stored in a new DisplayList
-		thats added to the head of the listbase */
+		 * thats added to the head of the listbase */
 		dl = dispbase.first;
 
 		tri_list = PyList_New(dl->parts);
@@ -1141,7 +1142,7 @@ static PyObject *M_Geometry_tesselate_polygon(PyObject *UNUSED(self), PyObject *
 		freedisplist(&dispbase);
 	}
 	else {
-		/* no points, do this so scripts dont barf */
+		/* no points, do this so scripts don't barf */
 		freedisplist(&dispbase); /* possible some dl was allocated */
 		tri_list = PyList_New(0);
 	}
@@ -1280,7 +1281,7 @@ static PyMethodDef M_Geometry_methods[] = {
 	{"barycentric_transform", (PyCFunction) M_Geometry_barycentric_transform, METH_VARARGS, M_Geometry_barycentric_transform_doc},
 #ifndef MATH_STANDALONE
 	{"interpolate_bezier", (PyCFunction) M_Geometry_interpolate_bezier, METH_VARARGS, M_Geometry_interpolate_bezier_doc},
-	{"tesselate_polygon", (PyCFunction) M_Geometry_tesselate_polygon, METH_O, M_Geometry_tesselate_polygon_doc},
+	{"tessellate_polygon", (PyCFunction) M_Geometry_tessellate_polygon, METH_O, M_Geometry_tessellate_polygon_doc},
 	{"box_pack_2d", (PyCFunction) M_Geometry_box_pack_2d, METH_O, M_Geometry_box_pack_2d_doc},
 #endif
 	{NULL, NULL, 0, NULL}
