@@ -32,11 +32,11 @@
 
 /*Include this file for access to vector, quat, matrix, euler, etc...*/
 
-#ifndef MATHUTILS_GEOMETRY_H
-#define MATHUTILS_GEOMETRY_H
+#ifndef __MATHUTILS_GEOMETRY_H__
+#define __MATHUTILS_GEOMETRY_H__
 
 #include "mathutils.h"
 
 PyMODINIT_FUNC PyInit_mathutils_geometry(void);
 
-#endif /* MATHUTILS_GEOMETRY_H */
+#endif /* __MATHUTILS_GEOMETRY_H__ */
