@@ -33,8 +33,8 @@
  */
 
 
-#ifndef ENVMAP_EXT_H
-#define ENVMAP_EXT_H 
+#ifndef __ENVMAP_H__
+#define __ENVMAP_H__ 
 
 /**
  * Make environment maps for all objects in the scene that have an
@@ -48,5 +48,5 @@ struct TexResult;
 void make_envmaps(struct Render *re);
 int envmaptex(struct Tex *tex, float *texvec, float *dxt, float *dyt, int osatex, struct TexResult *texres);
 
-#endif /* ENVMAP_EXT_H */
+#endif /* __ENVMAP_H__ */
 
