@@ -33,11 +33,11 @@
  */
 
 
-#ifndef GAMMACORRECTIONTABLES_H
-#define GAMMACORRECTIONTABLES_H
+#ifndef __GAMMACORRECTIONTABLES_H__
+#define __GAMMACORRECTIONTABLES_H__
 
 /**
- * Initialise the gamma lookup tables
+ * Initialize the gamma lookup tables
  */
 void makeGammaTables(float gamma);
 
