@@ -28,8 +28,8 @@
  */
 
 
-#ifndef RENDER_TYPES_H
-#define RENDER_TYPES_H
+#ifndef __RENDER_TYPES_H__
+#define __RENDER_TYPES_H__
 
 /* ------------------------------------------------------------------------- */
 /* exposed internal in render module only! */
@@ -131,8 +131,8 @@ struct Render
 	/* a list of RenderResults, for fullsample */
 	ListBase fullresult;	
 	/* read/write mutex, all internal code that writes to re->result must use a
-	   write lock, all external code must use a read lock. internal code is assumed
-	   to not conflict with writes, so no lock used for that */
+	 * write lock, all external code must use a read lock. internal code is assumed
+	 * to not conflict with writes, so no lock used for that */
 	ThreadRWMutex resultmutex;
 	
 	/* window size, display rect, viewplane */
@@ -149,7 +149,7 @@ struct Render
 	/* real maximum amount of xparts/yparts after correction for minimum */
 	int xparts, yparts;
 	/* real maximum size of parts after correction for minimum 
-	   partx*xparts can be larger than rectx, in that case last part is smaller */
+	 * partx*xparts can be larger than rectx, in that case last part is smaller */
 	int partx, party;
 	
 	/* values for viewing */
@@ -190,7 +190,7 @@ struct Render
 	struct RayObject *raytree;
 	struct RayFace *rayfaces;
 	struct VlakPrimitive *rayprimitives;
-	float maxdist; /* needed for keeping an incorrect behaviour of SUN and HEMI lights (avoid breaking old scenes) */
+	float maxdist; /* needed for keeping an incorrect behavior of SUN and HEMI lights (avoid breaking old scenes) */
 
 	/* occlusion tree */
 	void *occlusiontree;
@@ -229,8 +229,8 @@ struct Render
 	ListBase volume_precache_parts;
 
 	/* arena for allocating data for use during render, for
-		* example dynamic TFaces to go in the VlakRen structure.
-		*/
+	 * example dynamic TFaces to go in the VlakRen structure.
+	 */
 	struct MemArena *memArena;
 	
 	/* callbacks */
@@ -628,5 +628,5 @@ typedef struct LampRen {
 #define R_ENV_TRANSFORMED	2
 #define R_TRANSFORMED		(1|2)
 
-#endif /* RENDER_TYPES_H */
+#endif /* __RENDER_TYPES_H__ */
 
