@@ -66,32 +66,33 @@
 extern struct Render R;
 /* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ */
 
-
-#define VECADDISFAC(v1,v3,fac) {*(v1)+= *(v3)*(fac); *(v1+1)+= *(v3+1)*(fac); *(v1+2)+= *(v3+2)*(fac);}
-
-
-
 /* Shade Sample order:
+ *
+ * - shade_samples_fill_with_ps()
+ *     - for each sample
+ *         - shade_input_set_triangle()  <- if prev sample-face is same, use shade_input_copy_triangle()
+ *         - if vlr
+ *             - shade_input_set_viewco()    <- not for ray or bake
+ *             - shade_input_set_uv()        <- not for ray or bake
+ *             - shade_input_set_normals()
+ * - shade_samples()
+ *     - if AO
+ *         - shade_samples_do_AO()
+ *     - if shading happens
+ *         - for each sample
+ *             - shade_input_set_shade_texco()
+ *             - shade_samples_do_shade()
+ * - OSA: distribute sample result with filter masking
+ *
+ */
 
-- shade_samples_fill_with_ps()
-	- for each sample
-		- shade_input_set_triangle()  <- if prev sample-face is same, use shade_input_copy_triangle()
-		- if vlr
-			- shade_input_set_viewco()    <- not for ray or bake
-			- shade_input_set_uv()        <- not for ray or bake
-			- shade_input_set_normals()
-- shade_samples()
-	- if AO
-		- shade_samples_do_AO()
-	- if shading happens
-		- for each sample
-			- shade_input_set_shade_texco()
-			- shade_samples_do_shade()
-- OSA: distribute sample result with filter masking
+#define VECADDISFAC(v1,v3,fac)  {   \
+	*(v1 + 0) += *(v3 + 0) * (fac); \
+	*(v1 + 1) += *(v3 + 1) * (fac); \
+	*(v1 + 2) += *(v3 + 2) * (fac); \
+}
 
-	*/
-
-/* initialise material variables in shadeinput, 
+/* initialize material variables in shadeinput, 
  * doing inverse gamma correction where applicable */
 void shade_input_init_material(ShadeInput *shi)
 {
@@ -107,7 +108,7 @@ void shade_material_loop(ShadeInput *shi, ShadeResult *shr)
 
 	shade_lamp_loop(shi, shr);	/* clears shr */
 	
-	if(shi->translucency!=0.0f) {
+	if (shi->translucency!=0.0f) {
 		ShadeResult shr_t;
 		float fac= shi->translucency;
 		
@@ -120,11 +121,11 @@ void shade_material_loop(ShadeInput *shi, ShadeResult *shr)
 
 		/* a couple of passes */
 		VECADDISFAC(shr->combined, shr_t.combined, fac);
-		if(shi->passflag & SCE_PASS_SPEC)
+		if (shi->passflag & SCE_PASS_SPEC)
 			VECADDISFAC(shr->spec, shr_t.spec, fac);
-		if(shi->passflag & SCE_PASS_DIFFUSE)
+		if (shi->passflag & SCE_PASS_DIFFUSE)
 			VECADDISFAC(shr->diff, shr_t.diff, fac);
-		if(shi->passflag & SCE_PASS_SHADOW)
+		if (shi->passflag & SCE_PASS_SHADOW)
 			VECADDISFAC(shr->shad, shr_t.shad, fac);
 
 		negate_v3(shi->vn);
@@ -132,20 +133,20 @@ void shade_material_loop(ShadeInput *shi, ShadeResult *shr)
 	}
 	
 	/* depth >= 1 when ray-shading */
-	if(shi->depth==0 || shi->volume_depth > 0) {
-		if(R.r.mode & R_RAYTRACE) {
-			if(shi->ray_mirror!=0.0f || ((shi->mode & MA_TRANSP) && (shi->mode & MA_RAYTRANSP) && shr->alpha!=1.0f)) {
+	if (shi->depth==0 || shi->volume_depth > 0) {
+		if (R.r.mode & R_RAYTRACE) {
+			if (shi->ray_mirror!=0.0f || ((shi->mode & MA_TRANSP) && (shi->mode & MA_RAYTRANSP) && shr->alpha!=1.0f)) {
 				/* ray trace works on combined, but gives pass info */
 				ray_trace(shi, shr);
 			}
 		}
 		/* disable adding of sky for raytransp */
-		if((shi->mode & MA_TRANSP) && (shi->mode & MA_RAYTRANSP))
-			if((shi->layflag & SCE_LAY_SKY) && (R.r.alphamode==R_ADDSKY))
+		if ((shi->mode & MA_TRANSP) && (shi->mode & MA_RAYTRANSP))
+			if ((shi->layflag & SCE_LAY_SKY) && (R.r.alphamode==R_ADDSKY))
 				shr->alpha= 1.0f;
 	}
 	
-	if(R.r.mode & R_RAYTRACE) {
+	if (R.r.mode & R_RAYTRACE) {
 		if (R.render_volumes_inside.first)
 			shade_volume_inside(shi, shr);
 	}
@@ -162,7 +163,7 @@ void shade_input_do_shade(ShadeInput *shi, ShadeResult *shr)
 	memset(&shi->raycounter, 0, sizeof(shi->raycounter));
 #endif
 	
-	if(shi->mat->nodetree && shi->mat->use_nodes) {
+	if (shi->mat->nodetree && shi->mat->use_nodes) {
 		ntreeShaderExecTree(shi->mat->nodetree, shi, shr);
 	}
 	else {
@@ -170,36 +171,37 @@ void shade_input_do_shade(ShadeInput *shi, ShadeResult *shr)
 		shade_input_init_material(shi);
 		
 		if (shi->mat->material_type == MA_TYPE_VOLUME) {
-			if(R.r.mode & R_RAYTRACE) {
+			if (R.r.mode & R_RAYTRACE) {
 				shade_volume_outside(shi, shr);
 			}
-		} else { /* MA_TYPE_SURFACE, MA_TYPE_WIRE */
+		}
+		else { /* MA_TYPE_SURFACE, MA_TYPE_WIRE */
 			shade_material_loop(shi, shr);
 		}
 	}
 	
 	/* copy additional passes */
-	if(shi->passflag & (SCE_PASS_VECTOR|SCE_PASS_NORMAL)) {
+	if (shi->passflag & (SCE_PASS_VECTOR|SCE_PASS_NORMAL)) {
 		copy_v4_v4(shr->winspeed, shi->winspeed);
 		copy_v3_v3(shr->nor, shi->vn);
 	}
 	
 	/* MIST */
-	if((shi->passflag & SCE_PASS_MIST) || ((R.wrld.mode & WO_MIST) && (shi->mat->mode & MA_NOMIST)==0))  {
-		if(R.r.mode & R_ORTHO)
+	if ((shi->passflag & SCE_PASS_MIST) || ((R.wrld.mode & WO_MIST) && (shi->mat->mode & MA_NOMIST)==0)) {
+		if (R.r.mode & R_ORTHO)
 			shr->mist= mistfactor(-shi->co[2], shi->co);
 		else
 			shr->mist= mistfactor(len_v3(shi->co), shi->co);
 	}
 	else shr->mist= 0.0f;
 	
-	if((R.wrld.mode & WO_MIST) && (shi->mat->mode & MA_NOMIST)==0 ) {
+	if ((R.wrld.mode & WO_MIST) && (shi->mat->mode & MA_NOMIST)==0 ) {
 		alpha= shr->mist;
 	}
 	else alpha= 1.0f;
 	
 	/* add mist and premul color */
-	if(shr->alpha!=1.0f || alpha!=1.0f) {
+	if (shr->alpha!=1.0f || alpha!=1.0f) {
 		float fac= alpha*(shr->alpha);
 		shr->combined[3]= fac;
 		
@@ -213,15 +215,15 @@ void shade_input_do_shade(ShadeInput *shi, ShadeResult *shr)
 	shr->z= -shi->co[2];
 	
 	/* RAYHITS */
-/*
-	if(1 || shi->passflag & SCE_PASS_RAYHITS)
-	{
+#if 0
+	if (1 || shi->passflag & SCE_PASS_RAYHITS) {
 		shr->rayhits[0] = (float)shi->raycounter.faces.test;
 		shr->rayhits[1] = (float)shi->raycounter.bb.hit;
 		shr->rayhits[2] = 0.0;
 		shr->rayhits[3] = 1.0;
 	}
- */
+#endif
+
 	RE_RC_MERGE(&re_rc_counter[shi->thread], &shi->raycounter);
 }
 
@@ -239,15 +241,15 @@ void vlr_set_uv_indices(VlakRen *vlr, int *i1, int *i2, int *i3)
 	/*		1---2		1---2 	0 = orig face, 1 = new face */
 	
 	/* Update vert nums to point to correct verts of original face */
-	if(vlr->flag & R_DIVIDE_24) {  
-		if(vlr->flag & R_FACE_SPLIT) {
+	if (vlr->flag & R_DIVIDE_24) {  
+		if (vlr->flag & R_FACE_SPLIT) {
 			(*i1)++; (*i2)++; (*i3)++;
 		}
 		else {
 			(*i3)++;
 		}
 	}
-	else if(vlr->flag & R_FACE_SPLIT) {
+	else if (vlr->flag & R_FACE_SPLIT) {
 		(*i2)++; (*i3)++; 
 	}
 }
@@ -281,12 +283,12 @@ void shade_input_set_triangle_i(ShadeInput *shi, ObjectInstanceRen *obi, VlakRen
 	RE_vlakren_get_normal(&R, obi, vlr, shi->facenor);
 	
 	/* calculate vertexnormals */
-	if(vlr->flag & R_SMOOTH) {
+	if (vlr->flag & R_SMOOTH) {
 		copy_v3_v3(shi->n1, shi->v1->n);
 		copy_v3_v3(shi->n2, shi->v2->n);
 		copy_v3_v3(shi->n3, shi->v3->n);
 
-		if(obi->flag & R_TRANSFORMED) {
+		if (obi->flag & R_TRANSFORMED) {
 			mul_m3_v3(obi->nmat, shi->n1); normalize_v3(shi->n1);
 			mul_m3_v3(obi->nmat, shi->n2); normalize_v3(shi->n2);
 			mul_m3_v3(obi->nmat, shi->n3); normalize_v3(shi->n3);
@@ -294,21 +296,21 @@ void shade_input_set_triangle_i(ShadeInput *shi, ObjectInstanceRen *obi, VlakRen
 	}
 }
 
-/* note, facenr declared volatile due to over-eager -O2 optimizations
+/* note, facenr declared volatile due to over-eager -O2 optimization's
  * on cygwin (particularly -frerun-cse-after-loop)
  */
 
 /* copy data from face to ShadeInput, scanline case */
 void shade_input_set_triangle(ShadeInput *shi, volatile int obi, volatile int facenr, int UNUSED(normal_flip))
 {
-	if(facenr>0) {
+	if (facenr>0) {
 		shi->obi= &R.objectinstance[obi];
 		shi->obr= shi->obi->obr;
 		shi->facenr= (facenr-1) & RE_QUAD_MASK;
-		if( shi->facenr < shi->obr->totvlak ) {
+		if ( shi->facenr < shi->obr->totvlak ) {
 			VlakRen *vlr= RE_findOrAddVlak(shi->obr, shi->facenr);
 			
-			if(facenr & RE_QUAD_OFFS)
+			if (facenr & RE_QUAD_OFFS)
 				shade_input_set_triangle_i(shi, shi->obi, vlr, 0, 2, 3);
 			else
 				shade_input_set_triangle_i(shi, shi->obi, vlr, 0, 1, 2);
@@ -344,7 +346,7 @@ void shade_input_set_strand(ShadeInput *shi, StrandRen *strand, StrandPoint *spo
 	shi->xs= (int)spoint->x;
 	shi->ys= (int)spoint->y;
 
-	if(shi->osatex || (R.r.mode & R_SHADOW)) {
+	if (shi->osatex || (R.r.mode & R_SHADOW)) {
 		copy_v3_v3(shi->dxco, spoint->dtco);
 		copy_v3_v3(shi->dyco, spoint->dsco);
 	}
@@ -355,7 +357,7 @@ void shade_input_set_strand(ShadeInput *shi, StrandRen *strand, StrandPoint *spo
 	copy_v3_v3(shi->facenor, spoint->nor);
 
 	/* shade_input_set_normals equivalent */
-	if(shi->mat->mode & MA_TANGENT_STR) {
+	if (shi->mat->mode & MA_TANGENT_STR) {
 		copy_v3_v3(shi->vn, spoint->tan);
 	}
 	else {
@@ -365,7 +367,7 @@ void shade_input_set_strand(ShadeInput *shi, StrandRen *strand, StrandPoint *spo
 		cross_v3_v3v3(shi->vn, cross, spoint->tan);
 		normalize_v3(shi->vn);
 
-		if(dot_v3v3(shi->vn, shi->view) < 0.0f)
+		if (dot_v3v3(shi->vn, shi->view) < 0.0f)
 			negate_v3(shi->vn);
 	}
 
@@ -380,57 +382,57 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 	int mode= shi->mode;		/* or-ed result for all nodes */
 	short texco= shi->mat->texco;
 
-	if((shi->mat->texco & TEXCO_REFL)) {
+	if ((shi->mat->texco & TEXCO_REFL)) {
 		/* shi->dxview, shi->dyview, not supported */
 	}
 
-	if(shi->osatex && (texco & (TEXCO_NORM|TEXCO_REFL))) {
+	if (shi->osatex && (texco & (TEXCO_NORM|TEXCO_REFL))) {
 		/* not supported */
 	}
 
-	if(mode & (MA_TANGENT_V|MA_NORMAP_TANG)) {
+	if (mode & (MA_TANGENT_V|MA_NORMAP_TANG)) {
 		copy_v3_v3(shi->tang, spoint->tan);
 		copy_v3_v3(shi->nmaptang, spoint->tan);
 	}
 
-	if(mode & MA_STR_SURFDIFF) {
+	if (mode & MA_STR_SURFDIFF) {
 		float *surfnor= RE_strandren_get_surfnor(obr, strand, 0);
 
-		if(surfnor)
+		if (surfnor)
 			copy_v3_v3(shi->surfnor, surfnor);
 		else
 			copy_v3_v3(shi->surfnor, shi->vn);
 
-		if(shi->mat->strand_surfnor > 0.0f) {
+		if (shi->mat->strand_surfnor > 0.0f) {
 			shi->surfdist= 0.0f;
-			for(sv=strand->vert; sv!=svert; sv++)
+			for (sv=strand->vert; sv!=svert; sv++)
 				shi->surfdist+=len_v3v3(sv->co, (sv+1)->co);
 			shi->surfdist += spoint->t*len_v3v3(sv->co, (sv+1)->co);
 		}
 	}
 
-	if(R.r.mode & R_SPEED) {
+	if (R.r.mode & R_SPEED) {
 		float *speed;
 		
 		speed= RE_strandren_get_winspeed(shi->obi, strand, 0);
-		if(speed)
+		if (speed)
 			copy_v4_v4(shi->winspeed, speed);
 		else
 			shi->winspeed[0]= shi->winspeed[1]= shi->winspeed[2]= shi->winspeed[3]= 0.0f;
 	}
 
 	/* shade_input_set_shade_texco equivalent */
-	if(texco & NEED_UV) {
-		if(texco & TEXCO_ORCO) {
+	if (texco & NEED_UV) {
+		if (texco & TEXCO_ORCO) {
 			copy_v3_v3(shi->lo, strand->orco);
 			/* no shi->osatex, orco derivatives are zero */
 		}
 
-		if(texco & TEXCO_GLOB) {
+		if (texco & TEXCO_GLOB) {
 			copy_v3_v3(shi->gl, shi->co);
 			mul_m4_v3(R.viewinv, shi->gl);
 			
-			if(shi->osatex) {
+			if (shi->osatex) {
 				copy_v3_v3(shi->dxgl, shi->dxco);
 				mul_mat3_m4_v3(R.viewinv, shi->dxgl); 
 				copy_v3_v3(shi->dygl, shi->dyco);
@@ -438,16 +440,16 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 			}
 		}
 
-		if(texco & TEXCO_STRAND) {
+		if (texco & TEXCO_STRAND) {
 			shi->strandco= spoint->strandco;
 
-			if(shi->osatex) {
+			if (shi->osatex) {
 				shi->dxstrand= spoint->dtstrandco;
 				shi->dystrand= 0.0f;
 			}
 		}
 
-		if((texco & TEXCO_UV) || (mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE)))  {
+		if ((texco & TEXCO_UV) || (mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE))) {
 			MCol *mcol;
 			float *uv;
 			char *name;
@@ -458,7 +460,7 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 			shi->actuv= obr->actmtface;
 			shi->actcol= obr->actmcol;
 
-			if(mode & (MA_VERTEXCOL|MA_VERTEXCOLP)) {
+			if (mode & (MA_VERTEXCOL|MA_VERTEXCOLP)) {
 				for (i=0; (mcol=RE_strandren_get_mcol(obr, strand, i, &name, 0)); i++) {
 					ShadeInputCol *scol= &shi->col[i];
 					char *cp= (char*)mcol;
@@ -472,7 +474,7 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 					scol->col[3]= cp[0]/255.0f;
 				}
 
-				if(shi->totcol) {
+				if (shi->totcol) {
 					shi->vcol[0]= shi->col[shi->actcol].col[0];
 					shi->vcol[1]= shi->col[shi->actcol].col[1];
 					shi->vcol[2]= shi->col[shi->actcol].col[2];
@@ -492,7 +494,7 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 				shi->totuv++;
 				suv->name= name;
 
-				if(strandbuf->overrideuv == i) {
+				if (strandbuf->overrideuv == i) {
 					suv->uv[0]= -1.0f;
 					suv->uv[1]= spoint->strandco;
 					suv->uv[2]= 0.0f;
@@ -503,15 +505,15 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 					suv->uv[2]= 0.0f;	/* texture.c assumes there are 3 coords */
 				}
 
-				if(shi->osatex) {
+				if (shi->osatex) {
 					suv->dxuv[0]= 0.0f;
 					suv->dxuv[1]= 0.0f;
 					suv->dyuv[0]= 0.0f;
 					suv->dyuv[1]= 0.0f;
 				}
 
-				if((mode & MA_FACETEXTURE) && i==obr->actmtface) {
-					if((mode & (MA_VERTEXCOL|MA_VERTEXCOLP))==0) {
+				if ((mode & MA_FACETEXTURE) && i==obr->actmtface) {
+					if ((mode & (MA_VERTEXCOL|MA_VERTEXCOLP))==0) {
 						shi->vcol[0]= 1.0f;
 						shi->vcol[1]= 1.0f;
 						shi->vcol[2]= 1.0f;
@@ -520,14 +522,14 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 				}
 			}
 
-			if(shi->totuv == 0) {
+			if (shi->totuv == 0) {
 				ShadeInputUV *suv= &shi->uv[0];
 
 				suv->uv[0]= 0.0f;
 				suv->uv[1]= spoint->strandco;
 				suv->uv[2]= 0.0f;	/* texture.c assumes there are 3 coords */
 				
-				if(mode & MA_FACETEXTURE) {
+				if (mode & MA_FACETEXTURE) {
 					/* no tface? set at 1.0f */
 					shi->vcol[0]= 1.0f;
 					shi->vcol[1]= 1.0f;
@@ -538,18 +540,18 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 
 		}
 
-		if(texco & TEXCO_NORM) {
+		if (texco & TEXCO_NORM) {
 			shi->orn[0]= -shi->vn[0];
 			shi->orn[1]= -shi->vn[1];
 			shi->orn[2]= -shi->vn[2];
 		}
 
-		if(texco & TEXCO_STRESS) {
+		if (texco & TEXCO_STRESS) {
 			/* not supported */
 		}
 
-		if(texco & TEXCO_TANGENT) {
-			if((mode & MA_TANGENT_V)==0) {
+		if (texco & TEXCO_TANGENT) {
+			if ((mode & MA_TANGENT_V)==0) {
 				/* just prevent surprises */
 				shi->tang[0]= shi->tang[1]= shi->tang[2]= 0.0f;
 				shi->nmaptang[0]= shi->nmaptang[1]= shi->nmaptang[2]= 0.0f;
@@ -558,14 +560,14 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 	}
 
 	/* this only avalailable for scanline renders */
-	if(shi->depth==0) {
-		if(texco & TEXCO_WINDOW) {
+	if (shi->depth==0) {
+		if (texco & TEXCO_WINDOW) {
 			shi->winco[0]= -1.0f + 2.0f*spoint->x/(float)R.winx;
 			shi->winco[1]= -1.0f + 2.0f*spoint->y/(float)R.winy;
 			shi->winco[2]= 0.0f;
 
 			/* not supported */
-			if(shi->osatex) {
+			if (shi->osatex) {
 				shi->dxwin[0]= 0.0f;
 				shi->dywin[1]= 0.0f;
 				shi->dxwin[0]= 0.0f;
@@ -573,13 +575,13 @@ void shade_input_set_strand_texco(ShadeInput *shi, StrandRen *strand, StrandVert
 			}
 		}
 
-		if(texco & TEXCO_STICKY) {
+		if (texco & TEXCO_STICKY) {
 			/* not supported */
 		}
 	}
 	
 	if (shi->do_manage) {
-		if(mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE)) {
+		if (mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE)) {
 			srgb_to_linearrgb_v3_v3(shi->vcol, shi->vcol);
 		}
 	}
@@ -592,10 +594,10 @@ void shade_input_calc_viewco(ShadeInput *shi, float x, float y, float z, float v
 	/* returns not normalized, so is in viewplane coords */
 	calc_view_vector(view, x, y);
 	
-	if(shi->mat->material_type == MA_TYPE_WIRE) {
+	if (shi->mat->material_type == MA_TYPE_WIRE) {
 		/* wire cannot use normal for calculating shi->co, so
 		 * we reconstruct the coordinate less accurate */
-		if(R.r.mode & R_ORTHO)
+		if (R.r.mode & R_ORTHO)
 			calc_renderco_ortho(co, x, y, z);
 		else
 			calc_renderco_zbuf(co, view, z);
@@ -605,13 +607,13 @@ void shade_input_calc_viewco(ShadeInput *shi, float x, float y, float z, float v
 		float fac, dface, v1[3];
 		
 		copy_v3_v3(v1, shi->v1->co);
-		if(shi->obi->flag & R_TRANSFORMED)
+		if (shi->obi->flag & R_TRANSFORMED)
 			mul_m4_v3(shi->obi->mat, v1);
 		
 		dface = dot_v3v3(v1, shi->facenor);
 		
 		/* ortho viewplane cannot intersect using view vector originating in (0,0,0) */
-		if(R.r.mode & R_ORTHO) {
+		if (R.r.mode & R_ORTHO) {
 			/* x and y 3d coordinate can be derived from pixel coord and winmat */
 			float fx= 2.0f/(R.winx*R.winmat[0][0]);
 			float fy= 2.0f/(R.winy*R.winmat[1][1]);
@@ -620,28 +622,28 @@ void shade_input_calc_viewco(ShadeInput *shi, float x, float y, float z, float v
 			co[1]= (y - 0.5f*R.winy)*fy - R.winmat[3][1]/R.winmat[1][1];
 			
 			/* using a*x + b*y + c*z = d equation, (a b c) is normal */
-			if(shi->facenor[2]!=0.0f)
+			if (shi->facenor[2]!=0.0f)
 				co[2]= (dface - shi->facenor[0]*co[0] - shi->facenor[1]*co[1])/shi->facenor[2];
 			else
 				co[2]= 0.0f;
 			
-			if(dxco && dyco) {
+			if (dxco && dyco) {
 				dxco[0]= fx;
 				dxco[1]= 0.0f;
-				if(shi->facenor[2]!=0.0f)
+				if (shi->facenor[2]!=0.0f)
 					dxco[2]= -(shi->facenor[0]*fx)/shi->facenor[2];
 				else 
 					dxco[2]= 0.0f;
 				
 				dyco[0]= 0.0f;
 				dyco[1]= fy;
-				if(shi->facenor[2]!=0.0f)
+				if (shi->facenor[2]!=0.0f)
 					dyco[2]= -(shi->facenor[1]*fy)/shi->facenor[2];
 				else 
 					dyco[2]= 0.0f;
 				
-				if(dxyview) {
-					if(co[2]!=0.0f) fac= 1.0f/co[2]; else fac= 0.0f;
+				if (dxyview) {
+					if (co[2]!=0.0f) fac= 1.0f/co[2]; else fac= 0.0f;
 					dxyview[0]= -R.viewdx*fac;
 					dxyview[1]= -R.viewdy*fac;
 				}
@@ -659,7 +661,7 @@ void shade_input_calc_viewco(ShadeInput *shi, float x, float y, float z, float v
 			co[2]= fac*view[2];
 			
 			/* pixel dx/dy for render coord */
-			if(dxco && dyco) {
+			if (dxco && dyco) {
 				float u= dface/(div - R.viewdx*shi->facenor[0]);
 				float v= dface/(div - R.viewdy*shi->facenor[1]);
 				
@@ -671,8 +673,8 @@ void shade_input_calc_viewco(ShadeInput *shi, float x, float y, float z, float v
 				dyco[1]= co[1]- (view[1]-R.viewdy)*v;
 				dyco[2]= co[2]- (view[2])*v;
 				
-				if(dxyview) {
-					if(fac!=0.0f) fac= 1.0f/fac;
+				if (dxyview) {
+					if (fac!=0.0f) fac= 1.0f/fac;
 					dxyview[0]= -R.viewdx*fac;
 					dxyview[1]= -R.viewdy*fac;
 				}
@@ -703,11 +705,11 @@ void shade_input_set_viewco(ShadeInput *shi, float x, float y, float xs, float y
 	shi->scanco[2]= z;
 
 	/* check if we need derivatives */
-	if(shi->osatex || (R.r.mode & R_SHADOW)) {
+	if (shi->osatex || (R.r.mode & R_SHADOW)) {
 		dxco= shi->dxco;
 		dyco= shi->dyco;
 
-		if((shi->mat->texco & TEXCO_REFL))
+		if ((shi->mat->texco & TEXCO_REFL))
 			dxyview= &shi->dxview;
 	}
 
@@ -719,27 +721,27 @@ void shade_input_set_uv(ShadeInput *shi)
 {
 	VlakRen *vlr= shi->vlr;
 	
-	if((vlr->flag & R_SMOOTH) || (shi->mat->texco & NEED_UV) || (shi->passflag & SCE_PASS_UV)) {
+	if ((vlr->flag & R_SMOOTH) || (shi->mat->texco & NEED_UV) || (shi->passflag & SCE_PASS_UV)) {
 		float v1[3], v2[3], v3[3];
 
 		copy_v3_v3(v1, shi->v1->co);
 		copy_v3_v3(v2, shi->v2->co);
 		copy_v3_v3(v3, shi->v3->co);
 
-		if(shi->obi->flag & R_TRANSFORMED) {
+		if (shi->obi->flag & R_TRANSFORMED) {
 			mul_m4_v3(shi->obi->mat, v1);
 			mul_m4_v3(shi->obi->mat, v2);
 			mul_m4_v3(shi->obi->mat, v3);
 		}
 
 		/* exception case for wire render of edge */
-		if(vlr->v2==vlr->v3) {
+		if (vlr->v2==vlr->v3) {
 			float lend, lenc;
 			
 			lend= len_v3v3(v2, v1);
 			lenc= len_v3v3(shi->co, v1);
 			
-			if(lend==0.0f) {
+			if (lend==0.0f) {
 				shi->u=shi->v= 0.0f;
 			}
 			else {
@@ -747,7 +749,7 @@ void shade_input_set_uv(ShadeInput *shi)
 				shi->v= 0.0f;
 			}
 			
-			if(shi->osatex) {
+			if (shi->osatex) {
 				shi->dx_u=  0.0f;
 				shi->dx_v=  0.0f;
 				shi->dy_u=  0.0f;
@@ -773,7 +775,7 @@ void shade_input_set_uv(ShadeInput *shi)
 
 			shi->u= (shi->co[axis1]-v3[axis1])*t11-(shi->co[axis2]-v3[axis2])*t10;
 			shi->v= (shi->co[axis2]-v3[axis2])*t00-(shi->co[axis1]-v3[axis1])*t01;
-			if(shi->osatex) {
+			if (shi->osatex) {
 				shi->dx_u=  shi->dxco[axis1]*t11- shi->dxco[axis2]*t10;
 				shi->dx_v=  shi->dxco[axis2]*t00- shi->dxco[axis1]*t01;
 				shi->dy_u=  shi->dyco[axis1]*t11- shi->dyco[axis2]*t10;
@@ -795,18 +797,18 @@ void shade_input_set_normals(ShadeInput *shi)
 	shi->flippednor = 0;
 
 	/* test flip normals to viewing direction */
-	if(!(shi->vlr->flag & R_TANGENT)) {
-		if(dot_v3v3(shi->facenor, shi->view) < 0.0f) {
+	if (!(shi->vlr->flag & R_TANGENT)) {
+		if (dot_v3v3(shi->facenor, shi->view) < 0.0f) {
 			negate_v3(shi->facenor);
 			shi->flippednor= 1;
 		}
 	}
 	
 	/* calculate vertexnormals */
-	if(shi->vlr->flag & R_SMOOTH) {
+	if (shi->vlr->flag & R_SMOOTH) {
 		float *n1= shi->n1, *n2= shi->n2, *n3= shi->n3;
 
-		if(shi->flippednor) {
+		if (shi->flippednor) {
 			negate_v3(n1);
 			negate_v3(n2);
 			negate_v3(n3);
@@ -821,8 +823,7 @@ void shade_input_set_normals(ShadeInput *shi)
 		
 		normalize_v3(shi->vn);
 	}
-	else
-	{
+	else {
 		copy_v3_v3(shi->vn, shi->facenor);
 		copy_v3_v3(shi->nmapnorm, shi->vn);
 	}
@@ -831,8 +832,8 @@ void shade_input_set_normals(ShadeInput *shi)
 	copy_v3_v3(shi->vno, shi->vn);
 
 	/* flip normals to viewing direction */
-	if(!(shi->vlr->flag & R_TANGENT))
-		if(dot_v3v3(shi->facenor, shi->view) < 0.0f)
+	if (!(shi->vlr->flag & R_TANGENT))
+		if (dot_v3v3(shi->facenor, shi->view) < 0.0f)
 			shade_input_flip_normals(shi);
 }
 
@@ -843,7 +844,7 @@ void shade_input_set_vertex_normals(ShadeInput *shi)
 	float l= 1.0f+u+v;
 	
 	/* calculate vertexnormals */
-	if(shi->vlr->flag & R_SMOOTH) {
+	if (shi->vlr->flag & R_SMOOTH) {
 		float *n1= shi->n1, *n2= shi->n2, *n3= shi->n3;
 		
 		shi->vn[0]= l*n3[0]-u*n1[0]-v*n2[0];
@@ -855,8 +856,7 @@ void shade_input_set_vertex_normals(ShadeInput *shi)
 		
 		normalize_v3(shi->vn);
 	}
-	else
-	{
+	else {
 		copy_v3_v3(shi->vn, shi->facenor);
 		copy_v3_v3(shi->nmapnorm, shi->vn);
 	}
@@ -899,9 +899,9 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 	short texco= shi->mat->texco;
 
 	/* calculate dxno */
-	if(shi->vlr->flag & R_SMOOTH) {
+	if (shi->vlr->flag & R_SMOOTH) {
 		
-		if(shi->osatex && (texco & (TEXCO_NORM|TEXCO_REFL)) ) {
+		if (shi->osatex && (texco & (TEXCO_NORM|TEXCO_REFL)) ) {
 			float *n1= shi->n1, *n2= shi->n2, *n3= shi->n3;
 			
 			dl= shi->dx_u+shi->dx_v;
@@ -921,14 +921,14 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 		float *tangent, *s1, *s2, *s3;
 		float tl, tu, tv;
 
-		if(shi->vlr->flag & R_SMOOTH) {
+		if (shi->vlr->flag & R_SMOOTH) {
 			tl= l;
 			tu= u;
 			tv= v;
 		}
 		else {
 			/* qdn: flat faces have tangents too,
-			   could pick either one, using average here */
+			 * could pick either one, using average here */
 			tl= 1.0f/3.0f;
 			tu= -1.0f/3.0f;
 			tv= -1.0f/3.0f;
@@ -937,17 +937,17 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 		shi->tang[0]= shi->tang[1]= shi->tang[2]= 0.0f;
 		shi->nmaptang[0]= shi->nmaptang[1]= shi->nmaptang[2]= 0.0f;
 
-		if(mode & MA_TANGENT_V) {
+		if (mode & MA_TANGENT_V) {
 			s1 = RE_vertren_get_tangent(obr, v1, 0);
 			s2 = RE_vertren_get_tangent(obr, v2, 0);
 			s3 = RE_vertren_get_tangent(obr, v3, 0);
 
-			if(s1 && s2 && s3) {
+			if (s1 && s2 && s3) {
 				shi->tang[0]= (tl*s3[0] - tu*s1[0] - tv*s2[0]);
 				shi->tang[1]= (tl*s3[1] - tu*s1[1] - tv*s2[1]);
 				shi->tang[2]= (tl*s3[2] - tu*s1[2] - tv*s2[2]);
 
-				if(obi->flag & R_TRANSFORMED)
+				if (obi->flag & R_TRANSFORMED)
 					mul_m3_v3(obi->nmat, shi->tang);
 
 				normalize_v3(shi->tang);
@@ -955,10 +955,10 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			}
 		}
 
-		if(mode & MA_NORMAP_TANG || R.flag & R_NEED_TANGENT) {
+		if (mode & MA_NORMAP_TANG || R.flag & R_NEED_TANGENT) {
 			tangent= RE_vlakren_get_nmap_tangent(obr, shi->vlr, 0);
 
-			if(tangent) {
+			if (tangent) {
 				int j1= shi->i1, j2= shi->i2, j3= shi->i3;
 				float c0[3], c1[3], c2[3];
 
@@ -970,8 +970,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 
 				// keeping tangents normalized at vertex level
 				// corresponds better to how it's done in game engines
-				if(obi->flag & R_TRANSFORMED)
-				{
+				if (obi->flag & R_TRANSFORMED) {
 					mul_mat3_m4_v3(obi->mat, c0); normalize_v3(c0);
 					mul_mat3_m4_v3(obi->mat, c1); normalize_v3(c1);
 					mul_mat3_m4_v3(obi->mat, c2); normalize_v3(c2);
@@ -990,12 +989,12 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 		}
 	}
 
-	if(mode & MA_STR_SURFDIFF) {
+	if (mode & MA_STR_SURFDIFF) {
 		float *surfnor= RE_vlakren_get_surfnor(obr, shi->vlr, 0);
 
-		if(surfnor) {
+		if (surfnor) {
 			copy_v3_v3(shi->surfnor, surfnor);
-			if(obi->flag & R_TRANSFORMED)
+			if (obi->flag & R_TRANSFORMED)
 				mul_m3_v3(obi->nmat, shi->surfnor);
 		}
 		else
@@ -1004,13 +1003,13 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 		shi->surfdist= 0.0f;
 	}
 	
-	if(R.r.mode & R_SPEED) {
+	if (R.r.mode & R_SPEED) {
 		float *s1, *s2, *s3;
 		
 		s1= RE_vertren_get_winspeed(obi, v1, 0);
 		s2= RE_vertren_get_winspeed(obi, v2, 0);
 		s3= RE_vertren_get_winspeed(obi, v3, 0);
-		if(s1 && s2 && s3) {
+		if (s1 && s2 && s3) {
 			shi->winspeed[0]= (l*s3[0] - u*s1[0] - v*s2[0]);
 			shi->winspeed[1]= (l*s3[1] - u*s1[1] - v*s2[1]);
 			shi->winspeed[2]= (l*s3[2] - u*s1[2] - v*s2[2]);
@@ -1022,14 +1021,14 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 	}
 
 	/* pass option forces UV calc */
-	if(shi->passflag & SCE_PASS_UV)
+	if (shi->passflag & SCE_PASS_UV)
 		texco |= (NEED_UV|TEXCO_UV);
 	
 	/* texture coordinates. shi->dxuv shi->dyuv have been set */
-	if(texco & NEED_UV) {
+	if (texco & NEED_UV) {
 		
-		if(texco & TEXCO_ORCO) {
-			if(v1->orco) {
+		if (texco & TEXCO_ORCO) {
+			if (v1->orco) {
 				float *o1, *o2, *o3;
 				
 				o1= v1->orco;
@@ -1040,7 +1039,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 				shi->lo[1]= l*o3[1]-u*o1[1]-v*o2[1];
 				shi->lo[2]= l*o3[2]-u*o1[2]-v*o2[2];
 				
-				if(shi->osatex) {
+				if (shi->osatex) {
 					dl= shi->dx_u+shi->dx_v;
 					shi->dxlo[0]= dl*o3[0]-shi->dx_u*o1[0]-shi->dx_v*o2[0];
 					shi->dxlo[1]= dl*o3[1]-shi->dx_u*o1[1]-shi->dx_v*o2[1];
@@ -1055,10 +1054,10 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			copy_v3_v3(shi->duplilo, obi->dupliorco);
 		}
 		
-		if(texco & TEXCO_GLOB) {
+		if (texco & TEXCO_GLOB) {
 			copy_v3_v3(shi->gl, shi->co);
 			mul_m4_v3(R.viewinv, shi->gl);
-			if(shi->osatex) {
+			if (shi->osatex) {
 				copy_v3_v3(shi->dxgl, shi->dxco);
 				mul_mat3_m4_v3(R.viewinv, shi->dxgl); 
 				copy_v3_v3(shi->dygl, shi->dyco);
@@ -1066,9 +1065,9 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			}
 		}
 		
-		if(texco & TEXCO_STRAND) {
+		if (texco & TEXCO_STRAND) {
 			shi->strandco= (l*v3->accum - u*v1->accum - v*v2->accum);
-			if(shi->osatex) {
+			if (shi->osatex) {
 				dl= shi->dx_u+shi->dx_v;
 				shi->dxstrand= dl*v3->accum-shi->dx_u*v1->accum-shi->dx_v*v2->accum;
 				dl= shi->dy_u+shi->dy_v;
@@ -1076,7 +1075,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			}
 		}
 				
-		if((texco & TEXCO_UV) || (mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE)))  {
+		if ((texco & TEXCO_UV) || (mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE))) {
 			VlakRen *vlr= shi->vlr;
 			MTFace *tface;
 			MCol *mcol;
@@ -1091,7 +1090,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			shi->actuv= obr->actmtface;
 			shi->actcol= obr->actmcol;
 
-			if(mode & (MA_VERTEXCOL|MA_VERTEXCOLP)) {
+			if (mode & (MA_VERTEXCOL|MA_VERTEXCOLP)) {
 				for (i=0; (mcol=RE_vlakren_get_mcol(obr, vlr, i, &name, 0)); i++) {
 					ShadeInputCol *scol= &shi->col[i];
 					char *cp1, *cp2, *cp3;
@@ -1121,7 +1120,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 					}
 				}
 
-				if(shi->totcol) {
+				if (shi->totcol) {
 					shi->vcol[0]= shi->col[shi->actcol].col[0];
 					shi->vcol[1]= shi->col[shi->actcol].col[1];
 					shi->vcol[2]= shi->col[shi->actcol].col[2];
@@ -1150,7 +1149,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 				suv->uv[1]= -1.0f + 2.0f*(l*uv3[1]-u*uv1[1]-v*uv2[1]);
 				suv->uv[2]= 0.0f;	/* texture.c assumes there are 3 coords */
 
-				if(shi->osatex) {
+				if (shi->osatex) {
 					float duv[2];
 					
 					dl= shi->dx_u+shi->dx_v;
@@ -1168,14 +1167,14 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 					suv->dyuv[1]= 2.0f*(dl*uv3[1]-duv[0]*uv1[1]-duv[1]*uv2[1]);
 				}
 
-				if((mode & MA_FACETEXTURE) && i==obr->actmtface) {
-					if((mode & (MA_VERTEXCOL|MA_VERTEXCOLP))==0) {
+				if ((mode & MA_FACETEXTURE) && i==obr->actmtface) {
+					if ((mode & (MA_VERTEXCOL|MA_VERTEXCOLP))==0) {
 						shi->vcol[0]= 1.0f;
 						shi->vcol[1]= 1.0f;
 						shi->vcol[2]= 1.0f;
 						shi->vcol[3]= 1.0f;
 					}
-					if(tface->tpage) {
+					if (tface->tpage) {
 						render_realtime_texture(shi, tface->tpage);
 					}
 				}
@@ -1187,14 +1186,14 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			shi->dupliuv[1]= -1.0f + 2.0f*obi->dupliuv[1];
 			shi->dupliuv[2]= 0.0f;
 
-			if(shi->totuv == 0) {
+			if (shi->totuv == 0) {
 				ShadeInputUV *suv= &shi->uv[0];
 
 				suv->uv[0]= 2.0f*(u+.5f);
 				suv->uv[1]= 2.0f*(v+.5f);
 				suv->uv[2]= 0.0f;	/* texture.c assumes there are 3 coords */
 				
-				if(mode & MA_FACETEXTURE) {
+				if (mode & MA_FACETEXTURE) {
 					/* no tface? set at 1.0f */
 					shi->vcol[0]= 1.0f;
 					shi->vcol[1]= 1.0f;
@@ -1204,28 +1203,28 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			}
 		}
 		
-		if(texco & TEXCO_NORM) {
+		if (texco & TEXCO_NORM) {
 			shi->orn[0]= -shi->vn[0];
 			shi->orn[1]= -shi->vn[1];
 			shi->orn[2]= -shi->vn[2];
 		}
 		
-		if(texco & TEXCO_STRESS) {
+		if (texco & TEXCO_STRESS) {
 			float *s1, *s2, *s3;
 			
 			s1= RE_vertren_get_stress(obr, v1, 0);
 			s2= RE_vertren_get_stress(obr, v2, 0);
 			s3= RE_vertren_get_stress(obr, v3, 0);
-			if(s1 && s2 && s3) {
+			if (s1 && s2 && s3) {
 				shi->stress= l*s3[0] - u*s1[0] - v*s2[0];
-				if(shi->stress<1.0f) shi->stress-= 1.0f;
+				if (shi->stress<1.0f) shi->stress-= 1.0f;
 				else shi->stress= (shi->stress-1.0f)/shi->stress;
 			}
 			else shi->stress= 0.0f;
 		}
 		
-		if(texco & TEXCO_TANGENT) {
-			if((mode & MA_TANGENT_V)==0) {
+		if (texco & TEXCO_TANGENT) {
+			if ((mode & MA_TANGENT_V)==0) {
 				/* just prevent surprises */
 				shi->tang[0]= shi->tang[1]= shi->tang[2]= 0.0f;
 				shi->nmaptang[0]= shi->nmaptang[1]= shi->nmaptang[2]= 0.0f;
@@ -1234,15 +1233,15 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 	}
 	
 	/* this only avalailable for scanline renders */
-	if(shi->depth==0) {
+	if (shi->depth==0) {
 		float x= shi->xs;
 		float y= shi->ys;
 		
-		if(texco & TEXCO_WINDOW) {
+		if (texco & TEXCO_WINDOW) {
 			shi->winco[0]= -1.0f + 2.0f*x/(float)R.winx;
 			shi->winco[1]= -1.0f + 2.0f*y/(float)R.winy;
 			shi->winco[2]= 0.0f;
-			if(shi->osatex) {
+			if (shi->osatex) {
 				shi->dxwin[0]= 2.0f/(float)R.winx;
 				shi->dywin[1]= 2.0f/(float)R.winy;
 				shi->dxwin[1]= shi->dxwin[2]= 0.0f;
@@ -1250,14 +1249,14 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 			}
 		}
 
-		if(texco & TEXCO_STICKY) {
+		if (texco & TEXCO_STICKY) {
 			float *s1, *s2, *s3;
 			
 			s1= RE_vertren_get_sticky(obr, v1, 0);
 			s2= RE_vertren_get_sticky(obr, v2, 0);
 			s3= RE_vertren_get_sticky(obr, v3, 0);
 			
-			if(s1 && s2 && s3) {
+			if (s1 && s2 && s3) {
 				float obwinmat[4][4], winmat[4][4], ho1[4], ho2[4], ho3[4];
 				float Zmulx, Zmuly;
 				float hox, hoy, l, dl, u, v;
@@ -1267,7 +1266,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 				Zmulx=  ((float)R.winx)/2.0f; Zmuly=  ((float)R.winy)/2.0f;
 
 				zbuf_make_winmat(&R, winmat);
-				if(shi->obi->flag & R_TRANSFORMED)
+				if (shi->obi->flag & R_TRANSFORMED)
 					mult_m4_m4m4(obwinmat, winmat, obi->mat);
 				else
 					copy_m4_m4(obwinmat, winmat);
@@ -1297,7 +1296,7 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 				shi->sticky[1]= l*s3[1]-u*s1[1]-v*s2[1];
 				shi->sticky[2]= 0.0f;
 				
-				if(shi->osatex) {
+				if (shi->osatex) {
 					float dxuv[2], dyuv[2];
 					dxuv[0]=  s11/Zmulx;
 					dxuv[1]=  - s01/Zmulx;
@@ -1313,11 +1312,14 @@ void shade_input_set_shade_texco(ShadeInput *shi)
 				}
 			}
 		}
-	} /* else {
-	 Note! For raytracing winco is not set, important because thus means all shader input's need to have their variables set to zero else in-initialized values are used
-	*/
+	}
+	/* else {
+	 * Note! For raytracing winco is not set,
+	 * important because thus means all shader input's need to have their variables set to zero
+	 * else un-initialized values are used
+	 */
 	if (shi->do_manage) {
-		if(mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE)) {
+		if (mode & (MA_VERTEXCOL|MA_VERTEXCOLP|MA_FACETEXTURE)) {
 			srgb_to_linearrgb_v3_v3(shi->vcol, shi->vcol);
 		}
 	}
@@ -1354,7 +1356,7 @@ void shade_sample_initialize(ShadeSample *ssamp, RenderPart *pa, RenderLayer *rl
 	
 	tot= R.osa==0?1:R.osa;
 	
-	for(a=0; a<tot; a++) {
+	for (a=0; a<tot; a++) {
 		shade_input_initialize(&ssamp->shi[a], pa, rl, a);
 		memset(&ssamp->shr[a], 0, sizeof(ShadeResult));
 	}
@@ -1365,20 +1367,22 @@ void shade_sample_initialize(ShadeSample *ssamp, RenderPart *pa, RenderLayer *rl
 /* Do AO or (future) GI */
 void shade_samples_do_AO(ShadeSample *ssamp)
 {
-	if(!(R.r.mode & R_SHADOW))
+	if (!(R.r.mode & R_SHADOW))
 		return;
-	if(!(R.r.mode & R_RAYTRACE) && !(R.wrld.ao_gather_method == WO_AOGATHER_APPROX))
+	if (!(R.r.mode & R_RAYTRACE) && !(R.wrld.ao_gather_method == WO_AOGATHER_APPROX))
 		return;
 	
-	if(R.wrld.mode & (WO_AMB_OCC|WO_ENV_LIGHT|WO_INDIRECT_LIGHT)) {
+	if (R.wrld.mode & (WO_AMB_OCC|WO_ENV_LIGHT|WO_INDIRECT_LIGHT)) {
 		ShadeInput *shi= &ssamp->shi[0];
 		int sample;
 
-		if(((shi->passflag & SCE_PASS_COMBINED) && (shi->combinedflag & (SCE_PASS_AO|SCE_PASS_ENVIRONMENT|SCE_PASS_INDIRECT)))
-			|| (shi->passflag & (SCE_PASS_AO|SCE_PASS_ENVIRONMENT|SCE_PASS_INDIRECT)))
-			for(sample=0; sample<ssamp->tot; shi++, sample++)
-				if(!(shi->mode & MA_SHLESS))
+		if (((shi->passflag & SCE_PASS_COMBINED) && (shi->combinedflag & (SCE_PASS_AO|SCE_PASS_ENVIRONMENT|SCE_PASS_INDIRECT))) ||
+		    (shi->passflag & (SCE_PASS_AO|SCE_PASS_ENVIRONMENT|SCE_PASS_INDIRECT)))
+		{
+			for (sample=0; sample<ssamp->tot; shi++, sample++)
+				if (!(shi->mode & MA_SHLESS))
 					ambient_occlusion(shi);		/* stores in shi->ao[] */
+		}
 	}
 }
 
@@ -1390,23 +1394,23 @@ void shade_samples_fill_with_ps(ShadeSample *ssamp, PixStr *ps, int x, int y)
 	
 	ssamp->tot= 0;
 	
-	for(shi= ssamp->shi; ps; ps= ps->next) {
+	for (shi= ssamp->shi; ps; ps= ps->next) {
 		shade_input_set_triangle(shi, ps->obi, ps->facenr, 1);
 		
-		if(shi->vlr) {	/* NULL happens for env material or for 'all z' */
+		if (shi->vlr) {	/* NULL happens for env material or for 'all z' */
 			unsigned short curmask= ps->mask;
 			
 			/* full osa is only set for OSA renders */
-			if(shi->vlr->flag & R_FULL_OSA) {
+			if (shi->vlr->flag & R_FULL_OSA) {
 				short shi_cp= 0, samp;
 				
-				for(samp=0; samp<R.osa; samp++) {
-					if(curmask & (1<<samp)) {
+				for (samp=0; samp<R.osa; samp++) {
+					if (curmask & (1<<samp)) {
 						/* zbuffer has this inverse corrected, ensures xs,ys are inside pixel */
 						xs= (float)x + R.jit[samp][0] + 0.5f;
 						ys= (float)y + R.jit[samp][1] + 0.5f;
 						
-						if(shi_cp)
+						if (shi_cp)
 							shade_input_copy_triangle(shi, shi-1);
 						
 						shi->mask= (1<<samp);
@@ -1414,7 +1418,7 @@ void shade_samples_fill_with_ps(ShadeSample *ssamp, PixStr *ps, int x, int y)
 						shi->samplenr= R.shadowsamplenr[shi->thread]++;	/* this counter is not being reset per pixel */
 						shade_input_set_viewco(shi, x, y, xs, ys, (float)ps->z);
 						shade_input_set_uv(shi);
-						if(shi_cp==0)
+						if (shi_cp==0)
 							shade_input_set_normals(shi);
 						else  /* XXX shi->flippednor messes up otherwise */
 							shade_input_set_vertex_normals(shi);
@@ -1425,7 +1429,7 @@ void shade_samples_fill_with_ps(ShadeSample *ssamp, PixStr *ps, int x, int y)
 				}
 			}
 			else {
-				if(R.osa) {
+				if (R.osa) {
 					short b= R.samples->centmask[curmask];
 					xs= (float)x + R.samples->centLut[b & 15] + 0.5f;
 					ys= (float)y + R.samples->centLut[b>>4] + 0.5f;
@@ -1444,7 +1448,7 @@ void shade_samples_fill_with_ps(ShadeSample *ssamp, PixStr *ps, int x, int y)
 			}
 			
 			/* total sample amount, shi->sample is static set in initialize */
-			if(shi!=ssamp->shi)
+			if (shi!=ssamp->shi)
 				ssamp->tot= (shi-1)->sample + 1;
 		}
 	}
@@ -1455,7 +1459,7 @@ int shade_samples(ShadeSample *ssamp, PixStr *ps, int x, int y)
 {
 	shade_samples_fill_with_ps(ssamp, ps, x, y);
 	
-	if(ssamp->tot) {
+	if (ssamp->tot) {
 		ShadeInput *shi= ssamp->shi;
 		ShadeResult *shr= ssamp->shr;
 		int samp;
@@ -1464,15 +1468,15 @@ int shade_samples(ShadeSample *ssamp, PixStr *ps, int x, int y)
 		shade_samples_do_AO(ssamp);
 		
 		/* if shade (all shadepinputs have same passflag) */
-		if(ssamp->shi[0].passflag & ~(SCE_PASS_Z|SCE_PASS_INDEXOB|SCE_PASS_INDEXMA)) {
+		if (ssamp->shi[0].passflag & ~(SCE_PASS_Z|SCE_PASS_INDEXOB|SCE_PASS_INDEXMA)) {
 
-			for(samp=0; samp<ssamp->tot; samp++, shi++, shr++) {
+			for (samp=0; samp<ssamp->tot; samp++, shi++, shr++) {
 				shade_input_set_shade_texco(shi);
 				shade_input_do_shade(shi, shr);
 			}
 		}
-		else if(shi->passflag & SCE_PASS_Z) {
-			for(samp=0; samp<ssamp->tot; samp++, shi++, shr++)
+		else if (shi->passflag & SCE_PASS_Z) {
+			for (samp=0; samp<ssamp->tot; samp++, shi++, shr++)
 				shr->z= -shi->co[2];
 		}
 		
