@@ -57,10 +57,6 @@
 #include "volumetric.h"
 #include "volume_precache.h"
 
-#if defined( _MSC_VER ) && !defined( __cplusplus )
-# define inline __inline
-#endif // defined( _MSC_VER ) && !defined( __cplusplus )
-
 #include "BKE_global.h"
 
 /* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ */
@@ -89,7 +85,8 @@ static int intersect_outside_volume(RayObject *tree, Isect *isect, float *offset
 		isect->orig.ob= isect->hit.ob;
 		
 		return intersect_outside_volume(tree, isect, offset, limit-1, depth+1);
-	} else {
+	}
+	else {
 		return depth;
 	}
 }
@@ -140,14 +137,14 @@ void global_bounds_obi(Render *re, ObjectInstanceRen *obi, float *bbmin, float *
 	
 	INIT_MINMAX(bbmin, bbmax);
 	
-	for(a=0; a<obr->totvert; a++) {
-		if((a & 255)==0) ver= obr->vertnodes[a>>8].vert;
+	for (a=0; a<obr->totvert; a++) {
+		if ((a & 255)==0) ver= obr->vertnodes[a>>8].vert;
 		else ver++;
 		
 		copy_v3_v3(co, ver->co);
 		
 		/* transformed object instance in camera space */
-		if(obi->flag & R_TRANSFORMED)
+		if (obi->flag & R_TRANSFORMED)
 			mul_m4_v3(obi->mat, co);
 		
 		/* convert to global space */
@@ -264,19 +261,19 @@ static void lightcache_filter2(VolumePrecache *vp)
 }
 #endif
 
-static inline int ms_I(int x, int y, int z, int *n) //has a pad of 1 voxel surrounding the core for boundary simulation
+BLI_INLINE int ms_I(int x, int y, int z, int *n) //has a pad of 1 voxel surrounding the core for boundary simulation
 { 
 	/* different ordering to light cache */
 	return x*(n[1]+2)*(n[2]+2) + y*(n[2]+2) + z; 	
 }
 
-static inline int v_I_pad(int x, int y, int z, int *n) //has a pad of 1 voxel surrounding the core for boundary simulation
+BLI_INLINE int v_I_pad(int x, int y, int z, int *n) //has a pad of 1 voxel surrounding the core for boundary simulation
 { 
 	/* same ordering to light cache, with padding */
 	return z*(n[1]+2)*(n[0]+2) + y*(n[0]+2) + x;  	
 }
 
-static inline int lc_to_ms_I(int x, int y, int z, int *n)
+BLI_INLINE int lc_to_ms_I(int x, int y, int z, int *n)
 { 
 	/* converting light cache index to multiple scattering index */
 	return (x-1)*(n[1]*n[2]) + (y-1)*(n[2]) + z-1;
@@ -284,7 +281,7 @@ static inline int lc_to_ms_I(int x, int y, int z, int *n)
 
 /* *** multiple scattering approximation *** */
 
-/* get the total amount of light energy in the light cache. used to normalise after multiple scattering */
+/* get the total amount of light energy in the light cache. used to normalize after multiple scattering */
 static float total_ss_energy(Render *re, int do_test_break, VolumePrecache *vp)
 {
 	int x, y, z;
@@ -409,7 +406,7 @@ static void multiple_scattering_diffusion(Render *re, VolumePrecache *vp, Materi
 						sb[j] += vp->data_b[i];
 					
 					/* Displays progress every second */
-					if(time-lasttime>1.0) {
+					if (time-lasttime>1.0) {
 						char str[64];
 						BLI_snprintf(str, sizeof(str), "Simulating multiple scattering: %d%%", (int)(100.0f * (c / total)));
 						re->i.infostr= str;
@@ -437,7 +434,7 @@ static void multiple_scattering_diffusion(Render *re, VolumePrecache *vp, Materi
 		if (re->test_break(re->tbh)) break;
 	}
 	
-	/* normalisation factor to conserve energy */
+	/* normalization factor to conserve energy */
 	energy_ms = total_ms_energy(re, do_test_break, sr, sg, sb, n);
 	fac *= (energy_ss / energy_ms);
 	
@@ -446,7 +443,8 @@ static void multiple_scattering_diffusion(Render *re, VolumePrecache *vp, Materi
 		/* conserve energy - half single, half multiple */
 		origf = 0.5f;
 		fac *= 0.5f;
-	} else {
+	}
+	else {
 		origf = 0.0f;
 	}
 
@@ -483,11 +481,11 @@ static void *vol_precache_part_test(void *data)
 {
 	VolPrecachePart *pa = data;
 
-	printf("part number: %d \n", pa->num);
-	printf("done: %d \n", pa->done);
-	printf("x min: %d   x max: %d \n", pa->minx, pa->maxx);
-	printf("y min: %d   y max: %d \n", pa->miny, pa->maxy);
-	printf("z min: %d   z max: %d \n", pa->minz, pa->maxz);
+	printf("part number: %d\n", pa->num);
+	printf("done: %d\n", pa->done);
+	printf("x min: %d   x max: %d\n", pa->minx, pa->maxx);
+	printf("y min: %d   y max: %d\n", pa->miny, pa->maxy);
+	printf("z min: %d   z max: %d\n", pa->minz, pa->maxz);
 
 	return NULL;
 }
@@ -735,25 +733,25 @@ static void vol_precache_objectinstance_threads(Render *re, ObjectInstanceRen *o
 	queue.done = BLI_thread_queue_init();
 	BLI_thread_queue_nowait(queue.work);
 
-	for(pa= re->volume_precache_parts.first; pa; pa= pa->next)
+	for (pa= re->volume_precache_parts.first; pa; pa= pa->next)
 		BLI_thread_queue_push(queue.work, pa);
 	
 	/* launch threads */
 	BLI_init_threads(&threads, vol_precache_part, totthread);
 
-	for(thread= 0; thread<totthread; thread++)
+	for (thread= 0; thread<totthread; thread++)
 		BLI_insert_thread(&threads, &queue);
 	
 	/* loop waiting for work to be done */
-	while(counter < totparts) {
-		if(re->test_break && re->test_break(re->tbh))
+	while (counter < totparts) {
+		if (re->test_break && re->test_break(re->tbh))
 			break;
 
-		if(BLI_thread_queue_pop_timeout(queue.done, 50))
+		if (BLI_thread_queue_pop_timeout(queue.done, 50))
 			counter++;
 
 		time= PIL_check_seconds_timer();
-		if(time-lasttime>1.0) {
+		if (time-lasttime>1.0) {
 			char str[64];
 			BLI_snprintf(str, sizeof(str), "Precaching volume: %d%%", (int)(100.0f * ((float)counter / (float)totparts)));
 			re->i.infostr= str;
@@ -769,14 +767,13 @@ static void vol_precache_objectinstance_threads(Render *re, ObjectInstanceRen *o
 	BLI_thread_queue_free(queue.done);
 	BLI_freelistN(&re->volume_precache_parts);
 	
-	if(tree) {
+	if (tree) {
 		//TODO: makeraytree_object creates a tree and saves it on OBI, if we free this tree we should also clear other pointers to it
 		//RE_rayobject_free(tree);
 		//tree= NULL;
 	}
 	
-	if (ELEM(ma->vol.shade_type, MA_VOL_SHADE_MULTIPLE, MA_VOL_SHADE_SHADEDPLUSMULTIPLE))
-	{
+	if (ELEM(ma->vol.shade_type, MA_VOL_SHADE_MULTIPLE, MA_VOL_SHADE_SHADEDPLUSMULTIPLE)) {
 		/* this should be before the filtering */
 		multiple_scattering_diffusion(re, obi->volume_precache, ma);
 	}
@@ -786,8 +783,8 @@ static void vol_precache_objectinstance_threads(Render *re, ObjectInstanceRen *o
 
 static int using_lightcache(Material *ma)
 {
-	return (((ma->vol.shadeflag & MA_VOL_PRECACHESHADING) && (ma->vol.shade_type == MA_VOL_SHADE_SHADED))
-		|| (ELEM(ma->vol.shade_type, MA_VOL_SHADE_MULTIPLE, MA_VOL_SHADE_SHADEDPLUSMULTIPLE)));
+	return (((ma->vol.shadeflag & MA_VOL_PRECACHESHADING) && (ma->vol.shade_type == MA_VOL_SHADE_SHADED)) ||
+	        (ELEM(ma->vol.shade_type, MA_VOL_SHADE_MULTIPLE, MA_VOL_SHADE_SHADEDPLUSMULTIPLE)));
 }
 
 /* loop through all objects (and their associated materials)
@@ -800,18 +797,18 @@ void volume_precache(Render *re)
 	re->i.infostr= "Volume preprocessing";
 	re->stats_draw(re->sdh, &re->i);
 
-	for(vo= re->volumes.first; vo; vo= vo->next) {
+	for (vo= re->volumes.first; vo; vo= vo->next) {
 		if (using_lightcache(vo->ma)) {
-			for(obi= re->instancetable.first; obi; obi= obi->next) {
+			for (obi= re->instancetable.first; obi; obi= obi->next) {
 				if (obi->obr == vo->obr) {
 					vol_precache_objectinstance_threads(re, obi, vo->ma);
 
-					if(re->test_break && re->test_break(re->tbh))
+					if (re->test_break && re->test_break(re->tbh))
 						break;
 				}
 			}
 
-			if(re->test_break && re->test_break(re->tbh))
+			if (re->test_break && re->test_break(re->tbh))
 				break;
 		}
 	}
@@ -824,7 +821,7 @@ void free_volume_precache(Render *re)
 {
 	ObjectInstanceRen *obi;
 	
-	for(obi= re->instancetable.first; obi; obi= obi->next) {
+	for (obi= re->instancetable.first; obi; obi= obi->next) {
 		if (obi->volume_precache != NULL) {
 			MEM_freeN(obi->volume_precache->data_r);
 			MEM_freeN(obi->volume_precache->data_g);
