@@ -69,7 +69,7 @@ extern struct Render R;
 /* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ */
 
 /* luminance rec. 709 */
-BM_INLINE float luminance(const float col[3])
+BLI_INLINE float luminance(const float col[3])
 {
 	return (0.212671f*col[0] + 0.71516f*col[1] + 0.072169f*col[2]);
 }
@@ -79,21 +79,23 @@ static float vol_get_shadow(ShadeInput *shi, LampRen *lar, const float co[3])
 {
 	float visibility = 1.f;
 	
-	if(lar->shb) {
+	if (lar->shb) {
 		float dxco[3]={0.f, 0.f, 0.f}, dyco[3]={0.f, 0.f, 0.f};
 		
 		visibility = testshadowbuf(&R, lar->shb, co, dxco, dyco, 1.0, 0.0);		
-	} else if (lar->mode & LA_SHAD_RAY) {
+	}
+	else if (lar->mode & LA_SHAD_RAY) {
 		/* trace shadow manually, no good lamp api atm */
 		Isect is;
 		
 		copy_v3_v3(is.start, co);
-		if(lar->type==LA_SUN || lar->type==LA_HEMI) {
+		if (lar->type==LA_SUN || lar->type==LA_HEMI) {
 			is.dir[0] = -lar->vec[0];
 			is.dir[1] = -lar->vec[1];
 			is.dir[2] = -lar->vec[2];
 			is.dist = R.maxdist;
-		} else {
+		}
+		else {
 			sub_v3_v3v3(is.dir, lar->co, is.start);
 			is.dist = normalize_v3( is.dir );
 		}
@@ -102,7 +104,7 @@ static float vol_get_shadow(ShadeInput *shi, LampRen *lar, const float co[3])
 		is.check = RE_CHECK_VLR_NON_SOLID_MATERIAL;
 		is.skip = 0;
 		
-		if(lar->mode & (LA_LAYER|LA_LAYER_SHADOW))
+		if (lar->mode & (LA_LAYER|LA_LAYER_SHADOW))
 			is.lay= lar->lay;	
 		else
 			is.lay= -1;
@@ -111,7 +113,7 @@ static float vol_get_shadow(ShadeInput *shi, LampRen *lar, const float co[3])
 		is.orig.face = NULL;
 		is.last_hit = lar->last_hit[shi->thread];
 		
-		if(RE_rayobject_raycast(R.raytree,&is)) {
+		if (RE_rayobject_raycast(R.raytree,&is)) {
 			visibility = 0.f;
 		}
 		
@@ -135,19 +137,20 @@ static int vol_get_bounds(ShadeInput *shi, const float co[3], const float vec[3]
 		isect->skip = RE_SKIP_VLR_NEIGHBOUR;
 		isect->orig.face = (void*)shi->vlr;
 		isect->orig.ob = (void*)shi->obi;
-	} else { // if (intersect_type == VOL_BOUNDS_SS) {
+	}
+	else { // if (intersect_type == VOL_BOUNDS_SS) {
 		isect->skip= 0;
 		isect->orig.face= NULL;
 		isect->orig.ob = NULL;
 	}
 	
-	if(RE_rayobject_raycast(R.raytree, isect))
-	{
+	if (RE_rayobject_raycast(R.raytree, isect)) {
 		hitco[0] = isect->start[0] + isect->dist*isect->dir[0];
 		hitco[1] = isect->start[1] + isect->dist*isect->dir[1];
 		hitco[2] = isect->start[2] + isect->dist*isect->dir[2];
 		return 1;
-	} else {
+	}
+	else {
 		return 0;
 	}
 }
@@ -202,9 +205,10 @@ static void vol_trace_behind(ShadeInput *shi, VlakRen *vlr, const float co[3], f
 	isect.lay= -1;
 	
 	/* check to see if there's anything behind the volume, otherwise shade the sky */
-	if(RE_rayobject_raycast(R.raytree, &isect)) {
+	if (RE_rayobject_raycast(R.raytree, &isect)) {
 		shade_intersection(shi, col_r, &isect);
-	} else {
+	}
+	else {
 		shadeSkyView(col_r, co, shi->view, NULL, shi->thread);
 		shadeSunView(col_r, shi->view);
 	} 
@@ -365,7 +369,7 @@ static float vol_get_phasefunc(ShadeInput *UNUSED(shi), float g, const float w[3
 	const float normalize = 0.25f; // = 1.f/4.f = M_PI/(4.f*M_PI)
 	
 	/* normalization constant is 1/4 rather than 1/4pi, since
-	 * Blender's shading system doesn't normalise for
+	 * Blender's shading system doesn't normalize for
 	 * energy conservation - eg. multiplying by pdf ( 1/pi for a lambert brdf ).
 	 * This means that lambert surfaces in Blender are pi times brighter than they 'should be'
 	 * and therefore, with correct energy conservation, volumes will darker than other solid objects,
@@ -376,14 +380,15 @@ static float vol_get_phasefunc(ShadeInput *UNUSED(shi), float g, const float w[3
 	
 	if (g == 0.f) {	/* isotropic */
 		return normalize * 1.f;
-	} else {		/* schlick */
+	}
+	else {		/* schlick */
 		const float k = 1.55f * g - .55f * g * g * g;
 		const float kcostheta = k * dot_v3v3(w, wp);
 		return normalize * (1.f - k*k) / ((1.f - kcostheta) * (1.f - kcostheta));
 	}
 	
-	/*
-	 * not used, but here for reference:
+	/* not used, but here for reference: */
+#if 0
 	switch (phasefunc_type) {
 		case MA_VOL_PH_MIEHAZY:
 			return normalize * (0.5f + 4.5f * powf(0.5 * (1.f + costheta), 8.f));
@@ -392,7 +397,7 @@ static float vol_get_phasefunc(ShadeInput *UNUSED(shi), float g, const float w[3
 		case MA_VOL_PH_RAYLEIGH:
 			return normalize * 3.f/4.f * (1 + costheta * costheta);
 		case MA_VOL_PH_HG:
-			return normalize * (1.f - g*g) / powf(1.f + g*g - 2.f * g * costheta, 1.5f));
+			return normalize * (1.f - g * g) / powf(1.f + g * g - 2.f * g * costheta, 1.5f);
 		case MA_VOL_PH_SCHLICK:
 		{
 			const float k = 1.55f * g - .55f * g * g * g;
@@ -403,7 +408,7 @@ static float vol_get_phasefunc(ShadeInput *UNUSED(shi), float g, const float w[3
 		default:
 			return normalize * 1.f;
 	}
-	*/
+#endif
 }
 
 /* Compute transmittance = e^(-attenuation) */
@@ -470,7 +475,7 @@ static void vol_shade_one_lamp(struct ShadeInput *shi, const float co[3], const
 	float hitco[3], *atten_co;
 	float p, ref_col[3];
 	
-	if (lar->mode & LA_LAYER) if((lar->lay & shi->obi->lay)==0) return;
+	if (lar->mode & LA_LAYER) if ((lar->lay & shi->obi->lay)==0) return;
 	if ((lar->lay & shi->lay)==0) return;
 	if (lar->energy == 0.0f) return;
 	
@@ -478,7 +483,7 @@ static void vol_shade_one_lamp(struct ShadeInput *shi, const float co[3], const
 	
 	copy_v3_v3(lacol, &lar->r);
 	
-	if(lar->mode & LA_TEXTURE) {
+	if (lar->mode & LA_TEXTURE) {
 		shi->osatex= 0;
 		do_lamp_tex(lar, lv, shi, lacol, LA_TEXTURE);
 	}
@@ -492,8 +497,7 @@ static void vol_shade_one_lamp(struct ShadeInput *shi, const float co[3], const
 	if (shi->mat->vol.shade_type == MA_VOL_SHADE_SHADOWED) {
 		mul_v3_fl(lacol, vol_get_shadow(shi, lar, co));
 	}
-	else if (ELEM3(shi->mat->vol.shade_type, MA_VOL_SHADE_SHADED, MA_VOL_SHADE_MULTIPLE, MA_VOL_SHADE_SHADEDPLUSMULTIPLE))
-	{
+	else if (ELEM3(shi->mat->vol.shade_type, MA_VOL_SHADE_SHADED, MA_VOL_SHADE_MULTIPLE, MA_VOL_SHADE_SHADEDPLUSMULTIPLE)) {
 		Isect is;
 		
 		if (shi->mat->vol.shadeflag & MA_VOL_RECV_EXT_SHADOW) {
@@ -517,7 +521,8 @@ static void vol_shade_one_lamp(struct ShadeInput *shi, const float co[3], const
 				atten_co = hitco;
 			else if ( lampdist < dist ) {
 				atten_co = lar->co;
-			} else
+			}
+			else
 				atten_co = hitco;
 			
 			vol_get_transmittance(shi, tr, co, atten_co);
@@ -554,7 +559,7 @@ void vol_get_scattering(ShadeInput *shi, float scatter_col[3], const float co[3]
 	zero_v3(scatter_col);
 
 	lights= get_lights(shi);
-	for(go=lights->first; go; go= go->next)
+	for (go=lights->first; go; go= go->next)
 	{
 		float lacol[3] = {0.f, 0.f, 0.f};
 		lar= go->lampren;
@@ -568,15 +573,15 @@ void vol_get_scattering(ShadeInput *shi, float scatter_col[3], const float co[3]
 
 	
 /*
-The main volumetric integrator, using an emission/absorption/scattering model.
-
-Incoming radiance = 
-
-outgoing radiance from behind surface * beam transmittance/attenuation
-+ added radiance from all points along the ray due to participating media
-	--> radiance for each segment = 
-		(radiance added by scattering + radiance added by emission) * beam transmittance/attenuation
-*/
+ * The main volumetric integrator, using an emission/absorption/scattering model.
+ *
+ * Incoming radiance =
+ *
+ * outgoing radiance from behind surface * beam transmittance/attenuation
+ * + added radiance from all points along the ray due to participating media
+ *     --> radiance for each segment =
+ *         (radiance added by scattering + radiance added by emission) * beam transmittance/attenuation
+ */
 
 /* For ease of use, I've also introduced a 'reflection' and 'reflection color' parameter, which isn't 
  * physically correct. This works as an RGB tint/gain on out-scattered light, but doesn't affect the light 
@@ -627,7 +632,8 @@ static void volumeintegrate(struct ShadeInput *shi, float col[4], const float co
 				p2[2] = p[2] + (step_vec[2] * 0.5f);
 				
 				vol_get_precached_scattering(&R, shi, scatter_col, p2);
-			} else
+			}
+			else
 				vol_get_scattering(shi, scatter_col, p, shi->view);
 			
 			radiance[0] += stepd * tr[0] * (emit_col[0] + scatter_col[0]);
@@ -667,12 +673,12 @@ static void volume_trace(struct ShadeInput *shi, struct ShadeResult *shr, int in
 		int render_this=0;
 		
 		/* don't render the backfaces of ztransp volume materials.
-		 
+		 *
 		 * volume shading renders the internal volume from between the
 		 * ' view intersection of the solid volume to the
 		 * intersection on the other side, as part of the shading of
 		 * the front face.
-		 
+		 *
 		 * Because ztransp renders both front and back faces independently
 		 * this will double up, so here we prevent rendering the backface as well, 
 		 * which would otherwise render the volume in between the camera and the backface
@@ -686,8 +692,7 @@ static void volume_trace(struct ShadeInput *shi, struct ShadeResult *shr, int in
 	}
 	
 
-	if (inside_volume == VOL_SHADE_INSIDE)
-	{
+	if (inside_volume == VOL_SHADE_INSIDE) {
 		startco = shi->camera_co;
 		endco = shi->co;
 		
@@ -695,7 +700,8 @@ static void volume_trace(struct ShadeInput *shi, struct ShadeResult *shr, int in
 			if (!ztransp)
 				/* trace behind the volume object */
 				vol_trace_behind(shi, shi->vlr, endco, col);
-		} else {
+		}
+		else {
 			/* we're tracing through the volume between the camera 
 			 * and a solid surface, so use that pre-shaded radiance */
 			copy_v4_v4(col, shr->combined);
@@ -706,8 +712,7 @@ static void volume_trace(struct ShadeInput *shi, struct ShadeResult *shr, int in
 	}
 	/* trace to find a backface, the other side bounds of the volume */
 	/* (ray intersect ignores front faces here) */
-	else if (vol_get_bounds(shi, shi->co, shi->view, hitco, &is, VOL_BOUNDS_DEPTH))
-	{
+	else if (vol_get_bounds(shi, shi->co, shi->view, hitco, &is, VOL_BOUNDS_DEPTH)) {
 		VlakRen *vlr = (VlakRen *)is.hit.face;
 		
 		startco = shi->co;
@@ -718,7 +723,8 @@ static void volume_trace(struct ShadeInput *shi, struct ShadeResult *shr, int in
 			if (vlr->mat == shi->mat) {
 				/* trace behind the 2nd (raytrace) hit point */
 				vol_trace_behind(shi, (VlakRen *)is.hit.face, endco, col);
-			} else {
+			}
+			else {
 				shade_intersection(shi, col, &is);
 			}
 		}
