@@ -307,7 +307,7 @@ int BL_ArmatureChannel::py_attr_set_joint_rotation(void *self_v, const struct KX
 	float quat[4];
 
 	if (!PySequence_Check(value) || PySequence_Size(value) != 3) {
-		PyErr_SetString(PyExc_AttributeError, "expected a sequence of [3] floats");
+		PyErr_SetString(PyExc_AttributeError, "expected a sequence of 3 floats");
 		return PY_SET_ATTR_FAIL;
 	}
 	for (int i=0; i<3; i++) {
@@ -315,7 +315,7 @@ int BL_ArmatureChannel::py_attr_set_joint_rotation(void *self_v, const struct KX
 		joints[i] = PyFloat_AsDouble(item);
 		Py_DECREF(item);
 		if (joints[i] == -1.0f && PyErr_Occurred()) {
-			PyErr_SetString(PyExc_AttributeError, "expected a sequence of [3] floats");
+			PyErr_SetString(PyExc_AttributeError, "expected a sequence of 3 floats");
 			return PY_SET_ATTR_FAIL;
 		}
 	}
