@@ -29,8 +29,8 @@
  *  \ingroup bgeconv
  */
 
-#ifndef BL_MESHDEFORMER
-#define BL_MESHDEFORMER
+#ifndef __BL_MESHDEFORMER_H__
+#define __BL_MESHDEFORMER_H__
 
 #include "RAS_Deformer.h"
 #include "DNA_object_types.h"
@@ -63,16 +63,16 @@ public:
 		m_lastDeformUpdate(-1)
 	{};
 	virtual ~BL_MeshDeformer();
-	virtual void SetSimulatedTime(double time){};
+	virtual void SetSimulatedTime(double time){}
 	virtual bool Apply(class RAS_IPolyMaterial *mat);
-	virtual bool Update(void){ return false; };
-	virtual bool UpdateBuckets(void){ return false; };
-	virtual	RAS_Deformer*	GetReplica(){return NULL;};
+	virtual bool Update(void){ return false; }
+	virtual bool UpdateBuckets(void){ return false; }
+	virtual	RAS_Deformer*	GetReplica(){return NULL;}
 	virtual void ProcessReplica();
-	struct Mesh* GetMesh() { return m_bmesh; };
-	virtual class RAS_MeshObject* GetRasMesh() { return (RAS_MeshObject*)m_pMeshObject; };
+	struct Mesh* GetMesh() { return m_bmesh; }
+	virtual class RAS_MeshObject* GetRasMesh() { return (RAS_MeshObject*)m_pMeshObject; }
 	virtual float (* GetTransVerts(int *tot))[3]	{	*tot= m_tvtot; return m_transverts; }
-	//	virtual void InitDeform(double time){};
+	//	virtual void InitDeform(double time){}
 
 protected:
 	class RAS_MeshObject*		m_pMeshObject;
