@@ -141,15 +141,15 @@ void BL_ConvertProperties(Object* object,KX_GameObject* gameobj,SCA_TimeEventMan
 		}
 		
 #ifdef WITH_PYTHON
-		/* Warn if we double up on attributes, this isnt quite right since it wont find inherited attributes however there arnt many */
-		for(PyAttributeDef *attrdef = KX_GameObject::Attributes; attrdef->m_name; attrdef++) {
-			if(strcmp(prop->name, attrdef->m_name)==0) {
+		/* Warn if we double up on attributes, this isn't quite right since it wont find inherited attributes however there arnt many */
+		for (PyAttributeDef *attrdef = KX_GameObject::Attributes; attrdef->m_name; attrdef++) {
+			if (strcmp(prop->name, attrdef->m_name)==0) {
 				printf("Warning! user defined property name \"%s\" is also a python attribute for object \"%s\"\n\tUse ob[\"%s\"] syntax to avoid conflict\n", prop->name, object->id.name+2, prop->name);
 				break;
 			}
 		}
-		for(PyMethodDef *methdef = KX_GameObject::Methods; methdef->ml_name; methdef++) {
-			if(strcmp(prop->name, methdef->ml_name)==0) {
+		for (PyMethodDef *methdef = KX_GameObject::Methods; methdef->ml_name; methdef++) {
+			if (strcmp(prop->name, methdef->ml_name)==0) {
 				printf("Warning! user defined property name \"%s\" is also a python method for object \"%s\"\n\tUse ob[\"%s\"] syntax to avoid conflict\n", prop->name, object->id.name+2, prop->name);
 				break;
 			}
@@ -176,9 +176,9 @@ void BL_ConvertProperties(Object* object,KX_GameObject* gameobj,SCA_TimeEventMan
 void BL_ConvertTextProperty(Object* object, KX_FontObject* fontobj,SCA_TimeEventManager* timemgr,SCA_IScene* scene, bool isInActiveLayer)
 {
 	CValue* tprop = fontobj->GetProperty("Text");
-	if(!tprop) return;
+	if (!tprop) return;
 	bProperty* prop = get_ob_property(object, "Text");
-	if(!prop) return;
+	if (!prop) return;
 
 	Curve *curve = static_cast<Curve *>(object->data);
 	STR_String str = curve->str;
@@ -201,7 +201,7 @@ void BL_ConvertTextProperty(Object* object, KX_FontObject* fontobj,SCA_TimeEvent
 		}
 		case GPROP_FLOAT:
 		{
-			float floatprop = atof(str);
+			float floatprop = (float)atof(str);
 			propval = new CFloatValue(floatprop);
 			tprop->SetValue(propval);
 			break;
@@ -214,7 +214,7 @@ void BL_ConvertTextProperty(Object* object, KX_FontObject* fontobj,SCA_TimeEvent
 		}
 		case GPROP_TIME:
 		{
-			float floatprop = atof(str);
+			float floatprop = (float)atof(str);
 
 			CValue* timeval = new CFloatValue(floatprop);
 			// set a subproperty called 'timer' so that
