@@ -1,6 +1,5 @@
 /*
  * ConstExpr.h: interface for the CConstExpr class.
- * $Id: ConstExpr.h,v 1.4 2002/12/27 13:10:39 mein Exp $
  * Copyright (c) 1996-2000 Erwin Coumans <coockie@acm.org>
  *
  * Permission to use, copy, modify, distribute and sell this software
@@ -13,6 +12,10 @@
  *
  */
 
+/** \file ConstExpr.h
+ *  \ingroup expressions
+ */
+
 #ifndef __CONSTEXPR_H__
 #define __CONSTEXPR_H__
 
@@ -32,7 +35,7 @@ public:
 	//bool IsInside(float x,float y,float z,bool bBorderInclude=true);
 	bool NeedsRecalculated();
 	void ClearModified();
-	virtual float GetNumber();
+	virtual double GetNumber();
 	virtual CValue* Calculate();
 	CConstExpr(CValue* constval);
 	CConstExpr();
@@ -41,6 +44,13 @@ public:
 
 private:
 	CValue* m_value;
+
+
+#ifdef WITH_CXX_GUARDEDALLOC
+public:
+	void *operator new(size_t num_bytes) { return MEM_mallocN(num_bytes, "GE:CConstExpr"); }
+	void operator delete( void *mem ) { MEM_freeN(mem); }
+#endif
 };
 
 #endif // !defined(AFX_CONSTEXPR_H__061ECFC3_BE87_11D1_A51C_00A02472FC58__INCLUDED_)
