@@ -29,8 +29,8 @@
  *  \ingroup expressions
  */
 
-#ifndef __IDENTIFIER_EXPR
-#define __IDENTIFIER_EXPR
+#ifndef __IDENTIFIEREXPR_H__
+#define __IDENTIFIEREXPR_H__
 
 #include "Expression.h"
 
@@ -58,5 +58,5 @@ public:
 #endif
 };
 
-#endif //__IDENTIFIER_EXPR
+#endif //__IDENTIFIEREXPR_H__
 
