@@ -16,8 +16,8 @@
  *  \ingroup expressions
  */
 
-#if !defined _OPERATOR2EXPR_H
-#define _OPERATOR2EXPR_H
+#ifndef __OPERATOR2EXPR_H__
+#define __OPERATOR2EXPR_H__
 
 
 #include "Expression.h"
@@ -29,7 +29,7 @@ class COperator2Expr : public CExpression
 
 public:
 	virtual bool MergeExpression(CExpression* otherexpr);
-	virtual unsigned char GetExpressionID() { return COPERATOR2EXPRESSIONID;};
+	virtual unsigned char GetExpressionID() { return COPERATOR2EXPRESSIONID; }
 	virtual void BroadcastOperators(VALUE_OPERATOR op);
 	CExpression* CheckLink(std::vector<CBrokenLinkInfo*>& brokenlinks);
 	//virtual bool IsInside(float x,float y,float z,bool bBorderInclude=true);
@@ -64,5 +64,5 @@ public:
 #endif
 };
 
-#endif // !defined _OPERATOR2EXPR_H
+#endif // !defined __OPERATOR2EXPR_H__
 
