@@ -29,8 +29,8 @@
  *  \ingroup expressions
  */
 
-#ifndef _PY_OBJECT_PLUS_H
-#define _PY_OBJECT_PLUS_H
+#ifndef __PYOBJECTPLUS_H__
+#define __PYOBJECTPLUS_H__
 
 /* for now keep weakrefs optional */
 #define USE_WEAKREFS
@@ -56,13 +56,6 @@ extern "C" {
 
 #define MAX_PROP_NAME 64
 
-static inline void Py_Fatal(const char *M)
-{
-	fprintf(stderr, "%s\n", M);
-	exit(-1);
-};
-
-
 /* Use with ShowDeprecationWarning macro */
 typedef struct {
 	bool warn_done;
@@ -113,7 +106,7 @@ typedef struct PyObjectPlus_Proxy {
 #  define BGE_PROXY_WKREF(_self) (((PyObjectPlus_Proxy *)_self)->in_weakreflist)
 #endif
 
-/* Note, sometimes we dont care what BGE type this is as long as its a proxy */
+/* Note, sometimes we don't care what BGE type this is as long as its a proxy */
 #define BGE_PROXY_CHECK_TYPE(_type) ((_type)->tp_dealloc == PyObjectPlus::py_base_dealloc)
 
 /* Opposite of BGE_PROXY_REF */
@@ -193,7 +186,7 @@ public:                                                                       \
 #define PY_SET_ATTR_SUCCESS		 0
 
 /**
- * These macros are helpfull when embedding Python routines. The second
+ * These macros are helpful when embedding Python routines. The second
  * macro is one that also requires a documentation string
  */
 #define KX_PYMETHOD(class_name, method_name)                                   \
@@ -616,10 +609,10 @@ public:
 
 	static PyObject *GetProxyPlus_Ext(PyObjectPlus *self, PyTypeObject *tp, void *ptr);
 	/* self=NULL => proxy to generic pointer detached from GE object
-	                if py_owns is true, the memory pointed by ptr will be deleted automatially with MEM_freeN 
-	   self!=NULL=> proxy attached to GE object, ptr is optional and point to a struct from which attributes can be defined
-	                if py_owns is true, the object will be deleted automatically, ptr will NOT be deleted 
-					(assume object destructor takes care of it) */
+	 *              if py_owns is true, the memory pointed by ptr will be deleted automatically with MEM_freeN
+	 * self!=NULL=> proxy attached to GE object, ptr is optional and point to a struct from which attributes can be defined
+	 *              if py_owns is true, the object will be deleted automatically, ptr will NOT be deleted
+	 *              (assume object destructor takes care of it) */
 	static PyObject *NewProxyPlus_Ext(PyObjectPlus *self, PyTypeObject *tp, void *ptr, bool py_owns);
 
 	static	WarnLink*		GetDeprecationWarningLinkFirst(void);
@@ -647,9 +640,7 @@ public:
 };
 
 #ifdef WITH_PYTHON
-PyObject *py_getattr_dict(PyObject *pydict, PyObject *tp_dict);
-
 PyObject *PyUnicode_From_STR_String(const STR_String& str);
 #endif
 
-#endif //  _PY_OBJECT_PLUS_H
+#endif //  __PYOBJECTPLUS_H__
