@@ -26,6 +26,8 @@
 #include <map>		// array functionality for the propertylist
 #include "STR_String.h"	// STR_String class
 
+using namespace std;
+
 #ifdef WITH_CXX_GUARDEDALLOC
 #include "MEM_guardedalloc.h"
 #endif
@@ -150,7 +152,7 @@ struct ValueFlags {
 
 /**
  *	Base Class for all Actions performed on CValue's. Can be extended for undo/redo system in future.
-*/
+ */
 class CAction
 {
 public:
@@ -179,7 +181,7 @@ public:
  *
  * Together with CExpression, CValue and it's derived classes can be used to
  * parse expressions into a parsetree with error detecting/correcting capabilities
- * also expandible by a CFactory pluginsystem 
+ * also expandable by a CFactory pluginsystem 
  *
  * Base class for all editor functionality, flexible object type that allows
  * calculations and uses reference counting for memory management.
@@ -314,7 +316,7 @@ public:
 	virtual CValue*		FindIdentifier(const STR_String& identifiername);
 	/** Set the wireframe color of this value depending on the CSG
 	 * operator type <op>
-	 * @attention: not implemented */
+	 * \attention: not implemented */
 	virtual void		SetColorOperator(VALUE_OPERATOR op);
 
 	virtual const STR_String &	GetText() = 0;
@@ -325,7 +327,7 @@ public:
 	virtual STR_String&	GetName() = 0;											// Retrieve the name of the value
 	virtual void		SetName(const char *name) = 0;								// Set the name of the value
 	/** Sets the value to this cvalue.
-	 * @attention this particular function should never be called. Why not abstract? */
+	 * \attention this particular function should never be called. Why not abstract? */
 	virtual void		SetValue(CValue* newval);
 	virtual CValue*		GetReplica() =0;
 	virtual void			ProcessReplica();
