@@ -32,8 +32,8 @@
  *  \ingroup gamelogic
  */
 
-#ifndef __KX_ALWAYSSENSOR
-#define __KX_ALWAYSSENSOR
+#ifndef __SCA_ALWAYSSENSOR_H__
+#define __SCA_ALWAYSSENSOR_H__
 #include "SCA_ISensor.h"
 
 class SCA_AlwaysSensor : public SCA_ISensor
@@ -50,5 +50,5 @@ public:
 	virtual void Init();
 };
 
-#endif //__KX_ALWAYSSENSOR
+#endif //__SCA_ALWAYSSENSOR_H__
 
