@@ -1,14 +1,10 @@
-/**
- * $Id: SCA_IObject.cpp,v 1.4 2004/03/22 22:01:33 jesterking Exp $
- * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
+/*
+ * ***** BEGIN GPL LICENSE BLOCK *****
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version. The Blender
- * Foundation also sells licenses for use in proprietary software under
- * the Blender License.  See http://www.blender.org/BL/ for information
- * about this.
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
@@ -26,9 +22,16 @@
  *
  * Contributor(s): none yet.
  *
- * ***** END GPL/BL DUAL LICENSE BLOCK *****
+ * ***** END GPL LICENSE BLOCK *****
  */
 
+/** \file gameengine/GameLogic/SCA_IObject.cpp
+ *  \ingroup gamelogic
+ */
+
+#include <iostream>
+#include <algorithm>
+
 #include "SCA_IObject.h"
 #include "SCA_ISensor.h"
 #include "SCA_IController.h"
@@ -36,36 +39,48 @@
 #include "MT_Point3.h"
 #include "ListValue.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-
 MT_Point3 SCA_IObject::m_sDummy=MT_Point3(0,0,0);
+SG_QList SCA_IObject::m_activeBookmarkedControllers;
 
-SCA_IObject::SCA_IObject(PyTypeObject* T): CValue(T)
+SCA_IObject::SCA_IObject():
+	CValue(),
+	m_initState(0),
+	m_state(0),
+	m_firstState(NULL)
 {
 	m_suspended = false;
 }
-	
-
 
 SCA_IObject::~SCA_IObject()
 {
 	SCA_SensorList::iterator its;
 	for (its = m_sensors.begin(); !(its == m_sensors.end()); ++its)
 	{
-		((CValue*)(*its))->Release();
+		//Use Delete for sensor to ensure proper cleaning
+		(*its)->Delete();
+		//((CValue*)(*its))->Release();
 	}
 	SCA_ControllerList::iterator itc; 
 	for (itc = m_controllers.begin(); !(itc == m_controllers.end()); ++itc)
 	{
-		((CValue*)(*itc))->Release();
+		//Use Delete for controller to ensure proper cleaning (expression controller)
+		(*itc)->Delete();
+		//((CValue*)(*itc))->Release();
 	}
 	SCA_ActuatorList::iterator ita;
+	for (ita = m_registeredActuators.begin(); !(ita==m_registeredActuators.end()); ++ita)
+	{
+		(*ita)->UnlinkObject(this);
+	}
 	for (ita = m_actuators.begin(); !(ita==m_actuators.end()); ++ita)
 	{
-		((CValue*)(*ita))->Release();
+		(*ita)->Delete();
+	}
+
+	SCA_ObjectList::iterator ito;
+	for (ito = m_registeredObjects.begin(); !(ito==m_registeredObjects.end()); ++ito)
+	{
+		(*ito)->UnlinkObject(this);
 	}
 
 	//T_InterpolatorList::iterator i;
@@ -74,31 +89,9 @@ SCA_IObject::~SCA_IObject()
 	//}
 }
 
-
-
-SCA_ControllerList& SCA_IObject::GetControllers()
-{
-	return m_controllers;
-}
-
-
-
-SCA_SensorList& SCA_IObject::GetSensors()
-{
-	return m_sensors;
-}
-
-
-
-SCA_ActuatorList& SCA_IObject::GetActuators()
-{
-	return m_actuators;
-}
-
-
-
 void SCA_IObject::AddSensor(SCA_ISensor* act)
 {
+	act->AddRef();
 	m_sensors.push_back(act);
 }
 
@@ -106,6 +99,7 @@ void SCA_IObject::AddSensor(SCA_ISensor* act)
 
 void SCA_IObject::AddController(SCA_IController* act)
 {
+	act->AddRef();
 	m_controllers.push_back(act);
 }
 
@@ -113,36 +107,62 @@ void SCA_IObject::AddController(SCA_IController* act)
 
 void SCA_IObject::AddActuator(SCA_IActuator* act)
 {
+	act->AddRef();
 	m_actuators.push_back(act);
 }
 
-
-
-void SCA_IObject::SetIgnoreActivityCulling(bool b)
+void SCA_IObject::RegisterActuator(SCA_IActuator* act)
 {
-	m_ignore_activity_culling = b;
+	// don't increase ref count, it would create dead lock
+	m_registeredActuators.push_back(act);
 }
 
-
-
-bool SCA_IObject::GetIgnoreActivityCulling()
+void SCA_IObject::UnregisterActuator(SCA_IActuator* act)
 {
-	return m_ignore_activity_culling;
+	SCA_ActuatorList::iterator ita;
+	for (ita = m_registeredActuators.begin(); ita != m_registeredActuators.end(); ++ita)
+	{
+		if ((*ita) == act) {
+			(*ita) = m_registeredActuators.back();
+			m_registeredActuators.pop_back();
+			break;
+		}
+	}
 }
 
+void SCA_IObject::RegisterObject(SCA_IObject* obj)
+{
+	// one object may be registered multiple times via constraint target
+	// store multiple reference, this will serve as registration counter
+	m_registeredObjects.push_back(obj);
+}
 
+void SCA_IObject::UnregisterObject(SCA_IObject* obj)
+{
+	SCA_ObjectList::iterator ito;
+	for (ito = m_registeredObjects.begin(); ito != m_registeredObjects.end(); ++ito)
+	{
+		if ((*ito) == obj) {
+			(*ito) = m_registeredObjects.back();
+			m_registeredObjects.pop_back();
+			break;
+		}
+	}
+}
 
 void SCA_IObject::ReParentLogic()
 {
-	SCA_SensorList& oldsensors = GetSensors();
-	
-	int sen = 0;
-	SCA_SensorList::iterator its;
-	for (its = oldsensors.begin(); !(its==oldsensors.end()); ++its)
+	SCA_ActuatorList& oldactuators  = GetActuators();
+	int act = 0;
+	SCA_ActuatorList::iterator ita;
+	for (ita = oldactuators.begin(); !(ita==oldactuators.end()); ++ita)
 	{
-		SCA_ISensor* newsensor = (SCA_ISensor*)(*its)->GetReplica();
-		newsensor->ReParent(this);
-		oldsensors[sen++] = newsensor;
+		SCA_IActuator* newactuator = (SCA_IActuator*) (*ita)->GetReplica();
+		newactuator->ReParent(this);
+		// actuators are initially not connected to any controller
+		newactuator->SetActive(false);
+		newactuator->ClrLink();
+		oldactuators[act++] = newactuator;
 	}
 
 	SCA_ControllerList& oldcontrollers = GetControllers();
@@ -152,21 +172,27 @@ void SCA_IObject::ReParentLogic()
 	{
 		SCA_IController* newcontroller = (SCA_IController*)(*itc)->GetReplica();
 		newcontroller->ReParent(this);
+		newcontroller->SetActive(false);
 		oldcontrollers[con++]=newcontroller;
 
 	}
-	SCA_ActuatorList& oldactuators  = GetActuators();
-	
-	int act = 0;
-	SCA_ActuatorList::iterator ita;
-	for (ita = oldactuators.begin(); !(ita==oldactuators.end()); ++ita)
+	// convert sensors last so that actuators are already available for Actuator sensor
+	SCA_SensorList& oldsensors = GetSensors();
+	int sen = 0;
+	SCA_SensorList::iterator its;
+	for (its = oldsensors.begin(); !(its==oldsensors.end()); ++its)
 	{
-		SCA_IActuator* newactuator = (SCA_IActuator*) (*ita)->GetReplica();
-		newactuator->ReParent(this);
-		newactuator->SetActive(false);
-		oldactuators[act++] = newactuator;
+		SCA_ISensor* newsensor = (SCA_ISensor*)(*its)->GetReplica();
+		newsensor->ReParent(this);
+		newsensor->SetActive(false);
+		// sensors are initially not connected to any controller
+		newsensor->ClrLink();
+		oldsensors[sen++] = newsensor;
 	}
-		
+
+	// a new object cannot be client of any actuator
+	m_registeredActuators.clear();
+	m_registeredObjects.clear();
 }
 
 
@@ -175,7 +201,7 @@ SCA_ISensor* SCA_IObject::FindSensor(const STR_String& sensorname)
 {
 	SCA_ISensor* foundsensor = NULL;
 
-	for (SCA_SensorList::iterator its = m_sensors.begin();!(its==m_sensors.end());its++)
+	for (SCA_SensorList::iterator its = m_sensors.begin();!(its==m_sensors.end());++its)
 	{
 		if ((*its)->GetName() == sensorname)
 		{
@@ -192,7 +218,7 @@ SCA_IController* SCA_IObject::FindController(const STR_String& controllername)
 {
 	SCA_IController* foundcontroller = NULL;
 
-	for (SCA_ControllerList::iterator itc = m_controllers.begin();!(itc==m_controllers.end());itc++)
+	for (SCA_ControllerList::iterator itc = m_controllers.begin();!(itc==m_controllers.end());++itc)
 	{
 		if ((*itc)->GetName() == controllername)
 		{
@@ -209,7 +235,7 @@ SCA_IActuator* SCA_IObject::FindActuator(const STR_String& actuatorname)
 {
 	SCA_IActuator* foundactuator = NULL;
 
-	for (SCA_ActuatorList::iterator ita = m_actuators.begin();!(ita==m_actuators.end());ita++)
+	for (SCA_ActuatorList::iterator ita = m_actuators.begin();!(ita==m_actuators.end());++ita)
 	{
 		if ((*ita)->GetName() == actuatorname)
 		{
@@ -222,72 +248,7 @@ SCA_IActuator* SCA_IObject::FindActuator(const STR_String& actuatorname)
 }
 
 
-
-void SCA_IObject::SetCurrentTime(float currentTime) {
-	//T_InterpolatorList::iterator i;
-	//for (i = m_interpolators.begin(); !(i == m_interpolators.end()); ++i) {
-	//	(*i)->Execute(currentTime);
-	//}
-}
-	
-
-
-const MT_Point3& SCA_IObject::ConvertPythonPylist(PyObject* pylist)
-{
-	bool error = false;
-	m_sDummy = MT_Vector3(0,0,0);
-	if (pylist->ob_type == &CListValue::Type)
-	{
-		CListValue* listval = (CListValue*) pylist;
-		int numelem = listval->GetCount();
-		if ( numelem <= 3)
-		{
-			int index;
-			for (index = 0;index<numelem;index++)
-			{
-				m_sDummy[index] = listval->GetValue(index)->GetNumber();
-			}
-		}	else
-		{
-			error = true;
-		}
-		
-	} else
-	{
-		
-		// assert the list is long enough...
-		int numitems = PyList_Size(pylist);
-		if (numitems <= 3)
-		{
-			int index;
-			for (index=0;index<numitems;index++)
-			{
-				m_sDummy[index] = PyFloat_AsDouble(PyList_GetItem(pylist,index));
-			}
-		}
-		else
-		{
-			error = true;
-		}
-
-	}
-	return m_sDummy;
-}
-
-
-
-const MT_Point3& SCA_IObject::ConvertPythonVectorArg(PyObject* args)
-{
-
-	PyObject* pylist;
-	PyArg_ParseTuple(args,"O",&pylist);
-	m_sDummy = ConvertPythonPylist(pylist);
-	return m_sDummy;
-}
-
-
-
-void SCA_IObject::Suspend(void)
+void SCA_IObject::Suspend()
 {
 	if ((!m_ignore_activity_culling) 
 		&& (!m_suspended))  {
@@ -296,7 +257,7 @@ void SCA_IObject::Suspend(void)
 		SCA_SensorList::iterator i = m_sensors.begin();
 		while (i != m_sensors.end()) {
 			(*i)->Suspend();
-			i++;
+			++i;
 		}
 	}
 }
@@ -311,12 +272,42 @@ void SCA_IObject::Resume(void)
 		SCA_SensorList::iterator i = m_sensors.begin();
 		while (i != m_sensors.end()) {
 			(*i)->Resume();
-			i++;
+			++i;
 		}
 	}
 }
 
+void SCA_IObject::SetState(unsigned int state)
+{
+	unsigned int tmpstate;
+	SCA_ControllerList::iterator contit;
 
+	// we will update the state in two steps:
+	// 1) set the new state bits that are 1
+	// 2) clr the new state bits that are 0
+	// This to ensure continuity if a sensor is attached to two states
+	// that are switching state: no need to deactive and reactive the sensor 
+	
+	tmpstate = m_state | state;
+	if (tmpstate != m_state)
+	{
+		// update the status of the controllers
+		for (contit = m_controllers.begin(); contit != m_controllers.end(); ++contit)
+		{
+			(*contit)->ApplyState(tmpstate);
+		}
+	}
+	m_state = state;
+	if (m_state != tmpstate)
+	{
+		for (contit = m_controllers.begin(); contit != m_controllers.end(); ++contit)
+		{
+			(*contit)->ApplyState(m_state);
+		}
+	}
+}
+
+#ifdef WITH_PYTHON
 
 /* ------------------------------------------------------------------------- */
 /* Python functions                                                          */
@@ -324,43 +315,35 @@ void SCA_IObject::Resume(void)
 
 /* Integration hooks ------------------------------------------------------- */
 PyTypeObject SCA_IObject::Type = {
-	PyObject_HEAD_INIT(&PyType_Type)
-	0,
+	PyVarObject_HEAD_INIT(NULL, 0)
 	"SCA_IObject",
-	sizeof(SCA_IObject),
+	sizeof(PyObjectPlus_Proxy),
 	0,
-	PyDestructor,
-	0,
-	__getattr,
-	__setattr,
-	0, //&MyPyCompare,
-	__repr,
-	0, //&cvalue_as_number,
+	py_base_dealloc,
 	0,
 	0,
 	0,
-	0
-};
-
-
-
-PyParentObject SCA_IObject::Parents[] = {
-	&SCA_IObject::Type,
+	0,
+	py_base_repr,
+	0,0,0,0,0,0,0,0,0,
+	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,
+	0,0,0,0,0,0,0,
+	Methods,
+	0,
+	0,
 	&CValue::Type,
-	NULL
+	0,0,0,0,0,0,
+	py_base_new
 };
 
-
-
 PyMethodDef SCA_IObject::Methods[] = {
 	//{"setOrientation", (PyCFunction) SCA_IObject::sPySetOrientation, METH_VARARGS},
 	//{"getOrientation", (PyCFunction) SCA_IObject::sPyGetOrientation, METH_VARARGS},
 	{NULL,NULL} //Sentinel
 };
 
+PyAttributeDef SCA_IObject::Attributes[] = {
+	{ NULL }	//Sentinel
+};
 
-
-PyObject* SCA_IObject::_getattr(char* attr) {
-	_getattr_up(CValue);
-}
-
+#endif // WITH_PYTHON
